Class: TrinsicApi::AadhaarAddress

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/aadhaar_address.rb

Overview

The structured Indian address.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AadhaarAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::AadhaarAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::AadhaarAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'care_of')
    self.care_of = attributes[:'care_of']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'district')
    self.district = attributes[:'district']
  end

  if attributes.key?(:'house')
    self.house = attributes[:'house']
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'landmark')
    self.landmark = attributes[:'landmark']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'post_office')
    self.post_office = attributes[:'post_office']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'subdistrict')
    self.subdistrict = attributes[:'subdistrict']
  end

  if attributes.key?(:'village_town_city')
    self.village_town_city = attributes[:'village_town_city']
  end
end

Instance Attribute Details

#care_ofObject

The address’s care-of field. This indicates that mail should be delivered to an individual through another person or entity who is a known resident at the address.



20
21
22
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 20

def care_of
  @care_of
end

#countryObject

The address’s country. This is usually formatted as an alpha-2 country code, but localized output may instead contain the country name as written on the document.



23
24
25
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 23

def country
  @country
end

#districtObject

The address’s district.



26
27
28
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 26

def district
  @district
end

#houseObject

The identifier for the house address.



29
30
31
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 29

def house
  @house
end

#landmarkObject

A landmark near the address.



35
36
37
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 35

def landmark
  @landmark
end

#locationObject

The location or locality that helps identify where the address is within a city.



32
33
34
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 32

def location
  @location
end

#post_officeObject

The address’s post office.



41
42
43
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 41

def post_office
  @post_office
end

#postal_codeObject

The address’s postal code.



38
39
40
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 38

def postal_code
  @postal_code
end

#stateObject

The address’s state or union territory.



44
45
46
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 44

def state
  @state
end

#streetObject

The address’s street name.



47
48
49
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 47

def street
  @street
end

#subdistrictObject

The address’s subdistrict.



50
51
52
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 50

def subdistrict
  @subdistrict
end

#village_town_cityObject

The address’s village/town/city.



53
54
55
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 53

def village_town_city
  @village_town_city
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 56

def self.attribute_map
  {
    :'care_of' => :'careOf',
    :'country' => :'country',
    :'district' => :'district',
    :'house' => :'house',
    :'location' => :'location',
    :'landmark' => :'landmark',
    :'postal_code' => :'postalCode',
    :'post_office' => :'postOffice',
    :'state' => :'state',
    :'street' => :'street',
    :'subdistrict' => :'subdistrict',
    :'village_town_city' => :'villageTownCity'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 233

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 102

def self.openapi_nullable
  Set.new([
    :'care_of',
    :'country',
    :'district',
    :'house',
    :'location',
    :'landmark',
    :'postal_code',
    :'post_office',
    :'state',
    :'street',
    :'subdistrict',
    :'village_town_city'
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 84

def self.openapi_types
  {
    :'care_of' => :'String',
    :'country' => :'String',
    :'district' => :'String',
    :'house' => :'String',
    :'location' => :'String',
    :'landmark' => :'String',
    :'postal_code' => :'String',
    :'post_office' => :'String',
    :'state' => :'String',
    :'street' => :'String',
    :'subdistrict' => :'String',
    :'village_town_city' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      care_of == o.care_of &&
      country == o.country &&
      district == o.district &&
      house == o.house &&
      location == o.location &&
      landmark == o.landmark &&
      postal_code == o.postal_code &&
      post_office == o.post_office &&
      state == o.state &&
      street == o.street &&
      subdistrict == o.subdistrict &&
      village_town_city == o.village_town_city
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 226

def hash
  [care_of, country, district, house, location, landmark, postal_code, post_office, state, street, subdistrict, village_town_city].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
# File 'lib/trinsic_api/models/aadhaar_address.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end