Class: TrinsicApi::Address

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/address.rb

Overview

Address information for an individual

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Address

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/trinsic_api/models/address.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Address` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Address`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'line1')
    self.line1 = attributes[:'line1']
  end

  if attributes.key?(:'line2')
    self.line2 = attributes[:'line2']
  end

  if attributes.key?(:'line3')
    self.line3 = attributes[:'line3']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'subdivision')
    self.subdivision = attributes[:'subdivision']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'full_address')
    self.full_address = attributes[:'full_address']
  end
end

Instance Attribute Details

#cityObject

Returns the value of attribute city.



25
26
27
# File 'lib/trinsic_api/models/address.rb', line 25

def city
  @city
end

#countryObject

Returns the value of attribute country.



32
33
34
# File 'lib/trinsic_api/models/address.rb', line 32

def country
  @country
end

#full_addressObject

The full address as a single string



35
36
37
# File 'lib/trinsic_api/models/address.rb', line 35

def full_address
  @full_address
end

#line1Object

Returns the value of attribute line1.



19
20
21
# File 'lib/trinsic_api/models/address.rb', line 19

def line1
  @line1
end

#line2Object

Returns the value of attribute line2.



21
22
23
# File 'lib/trinsic_api/models/address.rb', line 21

def line2
  @line2
end

#line3Object

Returns the value of attribute line3.



23
24
25
# File 'lib/trinsic_api/models/address.rb', line 23

def line3
  @line3
end

#postal_codeObject

Returns the value of attribute postal_code.



30
31
32
# File 'lib/trinsic_api/models/address.rb', line 30

def postal_code
  @postal_code
end

#subdivisionObject

The subdivision code of the address. Subdivision refers to a state, province, or other similar division of a country. Examples include "CA" for California, "QC" for Québec, "MD" for Madrid, or "NSW" for New South Wales.



28
29
30
# File 'lib/trinsic_api/models/address.rb', line 28

def subdivision
  @subdivision
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/trinsic_api/models/address.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/trinsic_api/models/address.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
49
# File 'lib/trinsic_api/models/address.rb', line 38

def self.attribute_map
  {
    :'line1' => :'line1',
    :'line2' => :'line2',
    :'line3' => :'line3',
    :'city' => :'city',
    :'subdivision' => :'subdivision',
    :'postal_code' => :'postalCode',
    :'country' => :'country',
    :'full_address' => :'fullAddress'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/trinsic_api/models/address.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/trinsic_api/models/address.rb', line 76

def self.openapi_nullable
  Set.new([
    :'line1',
    :'line2',
    :'line3',
    :'city',
    :'subdivision',
    :'postal_code',
    :'country',
    :'full_address'
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/trinsic_api/models/address.rb', line 62

def self.openapi_types
  {
    :'line1' => :'String',
    :'line2' => :'String',
    :'line3' => :'String',
    :'city' => :'String',
    :'subdivision' => :'String',
    :'postal_code' => :'String',
    :'country' => :'String',
    :'full_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/trinsic_api/models/address.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      line1 == o.line1 &&
      line2 == o.line2 &&
      line3 == o.line3 &&
      city == o.city &&
      subdivision == o.subdivision &&
      postal_code == o.postal_code &&
      country == o.country &&
      full_address == o.full_address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/trinsic_api/models/address.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/trinsic_api/models/address.rb', line 176

def hash
  [line1, line2, line3, city, subdivision, postal_code, country, full_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
# File 'lib/trinsic_api/models/address.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/trinsic_api/models/address.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
# File 'lib/trinsic_api/models/address.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end