Class: TrinsicApi::AudkenniProviderOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/audkenni_provider_output.rb

Overview

Exposed properties for the ‘audkenni` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AudkenniProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 70

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::AudkenniProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::AudkenniProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'national_register_id')
    self.national_register_id = attributes[:'national_register_id']
  else
    self.national_register_id = nil
  end

  if attributes.key?(:'subject_id')
    self.subject_id = attributes[:'subject_id']
  else
    self.subject_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end
end

Instance Attribute Details

#date_of_birthObject

The date of birth of the individual as parsed from the National Register ID number. Is null if the date of birth could not be parsed, but should always be present



29
30
31
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 29

def date_of_birth
  @date_of_birth
end

#nameObject

The full name of the individual.



26
27
28
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 26

def name
  @name
end

#national_register_idObject

National Register ID number (kennitala) of the individual. Often written with a hyphen following the 6th digit (123456-1234). ID numbers are composed of ten digits. The first six of these are the individual’s date of birth in the format DDMMYY. The seventh and eighth digits are randomly chosen when the ID number is allocated, the ninth digit used to be a check digit (modulus (11) but this has been removed. The tenth indicates the century of the individual’s birth: ‘9’ for 1900–1999, ‘0’ for 2000 and beyond.



20
21
22
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 20

def national_register_id
  @national_register_id
end

#subject_idObject

Unique identifier for the individual across Audkenni. It is recommended to use this identifier instead of using the national register ID directly.



23
24
25
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 23

def subject_id
  @subject_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 32

def self.attribute_map
  {
    :'national_register_id' => :'nationalRegisterId',
    :'subject_id' => :'subjectId',
    :'name' => :'name',
    :'date_of_birth' => :'dateOfBirth'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
66
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 62

def self.openapi_nullable
  Set.new([
    :'date_of_birth'
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 52

def self.openapi_types
  {
    :'national_register_id' => :'String',
    :'subject_id' => :'String',
    :'name' => :'String',
    :'date_of_birth' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      national_register_id == o.national_register_id &&
      subject_id == o.subject_id &&
      name == o.name &&
      date_of_birth == o.date_of_birth
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 186

def hash
  [national_register_id, subject_id, name, date_of_birth].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @national_register_id.nil?
    invalid_properties.push('invalid value for "national_register_id", national_register_id cannot be nil.')
  end

  if @subject_id.nil?
    invalid_properties.push('invalid value for "subject_id", subject_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
133
134
135
# File 'lib/trinsic_api/models/audkenni_provider_output.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @national_register_id.nil?
  return false if @subject_id.nil?
  return false if @name.nil?
  true
end