Class: TrinsicApi::BoliviaCiProviderOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/bolivia_ci_provider_output.rb

Overview

Exposed properties for the ‘bolivia-ci-lookup` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BoliviaCiProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::BoliviaCiProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::BoliviaCiProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  else
    self.full_name = nil
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  else
    self.given_name = nil
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  else
    self.family_name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  else
    self.document_number = nil
  end
end

Instance Attribute Details

#date_of_birthObject

Date of birth as recorded in official Bolivian identity records (RUI — Registro Único de Identificación).



29
30
31
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 29

def date_of_birth
  @date_of_birth
end

#document_numberObject

The CI (Cédula de Identidad) document number for the matched record. The document is officially called the Cédula de Identidad and is commonly called carnet or carnet de identidad in Bolivia. This is the identifier assigned by the Servicio General de Identificación Personal (SEGIP) in the Registro Único de Identificación (RUI). The value is entirely numeric. There is no verification digit or other data encoded in the number. Published regulations do not define a fixed length; digit count may vary.



32
33
34
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 32

def document_number
  @document_number
end

#family_nameObject

Family name(s) of the holder (paternal and maternal) as they appear on the CI (Cédula de Identidad).



26
27
28
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 26

def family_name
  @family_name
end

#full_nameObject

Full name as it appears on the CI (Cédula de Identidad).



20
21
22
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 20

def full_name
  @full_name
end

#given_nameObject

Given name(s) of the holder as they appear on the CI (Cédula de Identidad).



23
24
25
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 23

def given_name
  @given_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 35

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'date_of_birth' => :'dateOfBirth',
    :'document_number' => :'documentNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 220

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 67

def self.openapi_nullable
  Set.new([
    :'date_of_birth',
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 56

def self.openapi_types
  {
    :'full_name' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'date_of_birth' => :'Date',
    :'document_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      date_of_birth == o.date_of_birth &&
      document_number == o.document_number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


207
208
209
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 207

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



213
214
215
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 213

def hash
  [full_name, given_name, family_name, date_of_birth, document_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @full_name.nil?
    invalid_properties.push('invalid value for "full_name", full_name cannot be nil.')
  end

  if @given_name.nil?
    invalid_properties.push('invalid value for "given_name", given_name cannot be nil.')
  end

  if @family_name.nil?
    invalid_properties.push('invalid value for "family_name", family_name cannot be nil.')
  end

  if @document_number.nil?
    invalid_properties.push('invalid value for "document_number", document_number cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
149
150
151
# File 'lib/trinsic_api/models/bolivia_ci_provider_output.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @full_name.nil?
  return false if @given_name.nil?
  return false if @family_name.nil?
  return false if @document_number.nil?
  true
end