Class: TrinsicApi::BrazilCpfCheckInput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/brazil_cpf_check_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BrazilCpfCheckInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 65

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::BrazilCpfCheckInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::BrazilCpfCheckInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cpf_number')
    self.cpf_number = attributes[:'cpf_number']
  else
    self.cpf_number = nil
  end

  if attributes.key?(:'selfie_image')
    self.selfie_image = attributes[:'selfie_image']
  end

  if attributes.key?(:'selfie_image_content_type')
    self.selfie_image_content_type = attributes[:'selfie_image_content_type']
  end
end

Instance Attribute Details

#cpf_numberObject

The user’s 11-digit, numeric CPF Number



19
20
21
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 19

def cpf_number
  @cpf_number
end

#selfie_imageObject

The raw bytes of the selfie image collected from the user.



22
23
24
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 22

def selfie_image
  @selfie_image
end

#selfie_image_content_typeObject

The MIME Type of the file contained in ‘SelfieImage`. Must be one of `image/jpeg` or `image/png`.



25
26
27
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 25

def selfie_image_content_type
  @selfie_image_content_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 28

def self.attribute_map
  {
    :'cpf_number' => :'cpfNumber',
    :'selfie_image' => :'selfieImage',
    :'selfie_image_content_type' => :'selfieImageContentType'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
60
61
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 56

def self.openapi_nullable
  Set.new([
    :'selfie_image',
    :'selfie_image_content_type'
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 47

def self.openapi_types
  {
    :'cpf_number' => :'String',
    :'selfie_image' => :'String',
    :'selfie_image_content_type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cpf_number == o.cpf_number &&
      selfie_image == o.selfie_image &&
      selfie_image_content_type == o.selfie_image_content_type
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 171

def hash
  [cpf_number, selfie_image, selfie_image_content_type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cpf_number.nil?
    invalid_properties.push('invalid value for "cpf_number", cpf_number cannot be nil.')
  end

  if @cpf_number.to_s.length > 11
    invalid_properties.push('invalid value for "cpf_number", the character length must be smaller than or equal to 11.')
  end

  if @cpf_number.to_s.length < 11
    invalid_properties.push('invalid value for "cpf_number", the character length must be greater than or equal to 11.')
  end

  pattern = Regexp.new(/^\d*$/)
  if @cpf_number !~ pattern
    invalid_properties.push("invalid value for \"cpf_number\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



121
122
123
124
125
126
127
128
# File 'lib/trinsic_api/models/brazil_cpf_check_input.rb', line 121

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cpf_number.nil?
  return false if @cpf_number.to_s.length > 11
  return false if @cpf_number.to_s.length < 11
  return false if @cpf_number !~ Regexp.new(/^\d*$/)
  true
end