Class: TrinsicApi::BrazilDigitalCnhInput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/brazil_digital_cnh_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ BrazilDigitalCnhInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::BrazilDigitalCnhInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::BrazilDigitalCnhInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'cpf_number')
    self.cpf_number = attributes[:'cpf_number']
  else
    self.cpf_number = nil
  end

  if attributes.key?(:'digital_cnh_file')
    self.digital_cnh_file = attributes[:'digital_cnh_file']
  end

  if attributes.key?(:'digital_cnh_file_content_type')
    self.digital_cnh_file_content_type = attributes[:'digital_cnh_file_content_type']
  end

  if attributes.key?(:'facial_biometry_photo')
    self.facial_biometry_photo = attributes[:'facial_biometry_photo']
  end
end

Instance Attribute Details

#cpf_numberObject

The user’s 11-digit, numeric CPF Number



19
20
21
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 19

def cpf_number
  @cpf_number
end

#digital_cnh_fileObject

The raw bytes of the digital CNH file collected from the user.



22
23
24
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 22

def digital_cnh_file
  @digital_cnh_file
end

#digital_cnh_file_content_typeObject

The MIME Type of the file contained in ‘DigitalCnhFile`. Must be one of `application/pdf`, `image/jpeg`, or `image/png`.



25
26
27
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 25

def digital_cnh_file_content_type
  @digital_cnh_file_content_type
end

#facial_biometry_photoObject

The raw bytes of the image of the user’s face, collected for biometric comparison.



28
29
30
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 28

def facial_biometry_photo
  @facial_biometry_photo
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 31

def self.attribute_map
  {
    :'cpf_number' => :'cpfNumber',
    :'digital_cnh_file' => :'digitalCnhFile',
    :'digital_cnh_file_content_type' => :'digitalCnhFileContentType',
    :'facial_biometry_photo' => :'facialBiometryPhoto'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
65
66
67
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 61

def self.openapi_nullable
  Set.new([
    :'digital_cnh_file',
    :'digital_cnh_file_content_type',
    :'facial_biometry_photo'
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 51

def self.openapi_types
  {
    :'cpf_number' => :'String',
    :'digital_cnh_file' => :'String',
    :'digital_cnh_file_content_type' => :'String',
    :'facial_biometry_photo' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



165
166
167
168
169
170
171
172
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 165

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      cpf_number == o.cpf_number &&
      digital_cnh_file == o.digital_cnh_file &&
      digital_cnh_file_content_type == o.digital_cnh_file_content_type &&
      facial_biometry_photo == o.facial_biometry_photo
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 182

def hash
  [cpf_number, digital_cnh_file, digital_cnh_file_content_type, facial_biometry_photo].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 106

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @cpf_number.nil?
    invalid_properties.push('invalid value for "cpf_number", cpf_number cannot be nil.')
  end

  if @cpf_number.to_s.length > 11
    invalid_properties.push('invalid value for "cpf_number", the character length must be smaller than or equal to 11.')
  end

  if @cpf_number.to_s.length < 11
    invalid_properties.push('invalid value for "cpf_number", the character length must be greater than or equal to 11.')
  end

  pattern = Regexp.new(/^\d*$/)
  if @cpf_number !~ pattern
    invalid_properties.push("invalid value for \"cpf_number\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



131
132
133
134
135
136
137
138
# File 'lib/trinsic_api/models/brazil_digital_cnh_input.rb', line 131

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @cpf_number.nil?
  return false if @cpf_number.to_s.length > 11
  return false if @cpf_number.to_s.length < 11
  return false if @cpf_number !~ Regexp.new(/^\d*$/)
  true
end