Class: TrinsicApi::ClearProviderOutputCheck

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/clear_provider_output_check.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClearProviderOutputCheck

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutputCheck` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutputCheck`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'verification_check_name')
    self.verification_check_name = attributes[:'verification_check_name']
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'check_result')
    self.check_result = attributes[:'check_result']
  end

  if attributes.key?(:'additional_details')
    self.additional_details = attributes[:'additional_details']
  end

  if attributes.key?(:'params')
    if (value = attributes[:'params']).is_a?(Hash)
      self.params = value
    end
  end
end

Instance Attribute Details

#additional_detailsObject

Additional structured details CLEAR used for this check. Currently modeled details: watchlistHits.



31
32
33
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 31

def additional_details
  @additional_details
end

#check_resultObject

The granular CLEAR result for this check. Known values: - success - failure - indeterminate - not_applicable - awaiting_async_response



28
29
30
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 28

def check_result
  @check_result
end

#paramsObject

Custom parameters configured for this CLEAR check.



34
35
36
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 34

def params
  @params
end

#statusObject

Whether CLEAR performed the check. Known values: - completed - skipped - error



25
26
27
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 25

def status
  @status
end

#valueObject

The boolean check value. This can be null when a check is skipped or unable to evaluate to a deterministic result.



22
23
24
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 22

def value
  @value
end

#verification_check_nameObject

The verification check name as specified in the CLEAR verification configuration.



19
20
21
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 19

def verification_check_name
  @verification_check_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 37

def self.attribute_map
  {
    :'verification_check_name' => :'verificationCheckName',
    :'value' => :'value',
    :'status' => :'status',
    :'check_result' => :'checkResult',
    :'additional_details' => :'additionalDetails',
    :'params' => :'params'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 168

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
76
77
78
79
80
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 71

def self.openapi_nullable
  Set.new([
    :'verification_check_name',
    :'value',
    :'status',
    :'check_result',
    :'additional_details',
    :'params'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 59

def self.openapi_types
  {
    :'verification_check_name' => :'String',
    :'value' => :'Boolean',
    :'status' => :'String',
    :'check_result' => :'String',
    :'additional_details' => :'ClearProviderOutputCheckAdditionalDetails',
    :'params' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      verification_check_name == o.verification_check_name &&
      value == o.value &&
      status == o.status &&
      check_result == o.check_result &&
      additional_details == o.additional_details &&
      params == o.params
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


155
156
157
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 155

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



161
162
163
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 161

def hash
  [verification_check_name, value, status, check_result, additional_details, params].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



190
191
192
193
194
195
196
197
198
199
200
201
202
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 190

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/trinsic_api/models/clear_provider_output_check.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end