Class: TrinsicApi::ClearProviderOutputDocument

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/clear_provider_output_document.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClearProviderOutputDocument

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutputDocument` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutputDocument`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.key?(:'document_type')
    self.document_type = attributes[:'document_type']
  end

  if attributes.key?(:'issuing_country')
    self.issuing_country = attributes[:'issuing_country']
  end

  if attributes.key?(:'issuing_subdivision')
    self.issuing_subdivision = attributes[:'issuing_subdivision']
  end

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  end

  if attributes.key?(:'date_of_expiry')
    self.date_of_expiry = attributes[:'date_of_expiry']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end
end

Instance Attribute Details

#addressObject

The address scanned from the document.



40
41
42
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 40

def address
  @address
end

#date_of_birthObject

The date of birth scanned from the document.



43
44
45
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 43

def date_of_birth
  @date_of_birth
end

#date_of_expiryObject

The document expiration date.



34
35
36
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 34

def date_of_expiry
  @date_of_expiry
end

#document_numberObject

The document number scanned from the document.



31
32
33
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 31

def document_number
  @document_number
end

#document_typeObject

The document type scanned by CLEAR. Known values: - drivers_license - paper_passport - passport_card - id_card - visa - health_care_card - other



22
23
24
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 22

def document_type
  @document_type
end

#first_nameObject

The first name scanned from the document.



46
47
48
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 46

def first_name
  @first_name
end

#full_nameObject

The full name scanned from the document.



55
56
57
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 55

def full_name
  @full_name
end

#genderObject

The gender scanned from the document. CLEAR does not publish a closed set of possible values for this field.



37
38
39
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 37

def gender
  @gender
end

#issuing_countryObject

The ISO 3166-1 alpha-2 country code of issue.



25
26
27
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 25

def issuing_country
  @issuing_country
end

#issuing_subdivisionObject

The ISO 3166 subdivision issuer of the document.



28
29
30
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 28

def issuing_subdivision
  @issuing_subdivision
end

#last_nameObject

The last name scanned from the document.



49
50
51
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 49

def last_name
  @last_name
end

#middle_nameObject

The middle name scanned from the document.



52
53
54
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 52

def middle_name
  @middle_name
end

#nationalityObject

The nationality scanned from the document, normalized to an ISO 3166-1 alpha-2 country code.



19
20
21
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 19

def nationality
  @nationality
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



77
78
79
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 77

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



82
83
84
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 82

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 58

def self.attribute_map
  {
    :'nationality' => :'nationality',
    :'document_type' => :'documentType',
    :'issuing_country' => :'issuingCountry',
    :'issuing_subdivision' => :'issuingSubdivision',
    :'document_number' => :'documentNumber',
    :'date_of_expiry' => :'dateOfExpiry',
    :'gender' => :'gender',
    :'address' => :'address',
    :'date_of_birth' => :'dateOfBirth',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'middle_name' => :'middleName',
    :'full_name' => :'fullName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 243

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 106

def self.openapi_nullable
  Set.new([
    :'nationality',
    :'document_type',
    :'issuing_country',
    :'issuing_subdivision',
    :'document_number',
    :'date_of_expiry',
    :'gender',
    :'address',
    :'date_of_birth',
    :'first_name',
    :'last_name',
    :'middle_name',
    :'full_name'
  ])
end

.openapi_typesObject

Attribute type mapping.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 87

def self.openapi_types
  {
    :'nationality' => :'String',
    :'document_type' => :'String',
    :'issuing_country' => :'String',
    :'issuing_subdivision' => :'String',
    :'document_number' => :'String',
    :'date_of_expiry' => :'Date',
    :'gender' => :'String',
    :'address' => :'ClearProviderOutputAddress',
    :'date_of_birth' => :'Date',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'middle_name' => :'String',
    :'full_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      nationality == o.nationality &&
      document_type == o.document_type &&
      issuing_country == o.issuing_country &&
      issuing_subdivision == o.issuing_subdivision &&
      document_number == o.document_number &&
      date_of_expiry == o.date_of_expiry &&
      gender == o.gender &&
      address == o.address &&
      date_of_birth == o.date_of_birth &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      middle_name == o.middle_name &&
      full_name == o.full_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


230
231
232
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 230

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



236
237
238
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 236

def hash
  [nationality, document_type, issuing_country, issuing_subdivision, document_number, date_of_expiry, gender, address, date_of_birth, first_name, last_name, middle_name, full_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



195
196
197
198
199
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 195

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 265

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



203
204
205
206
# File 'lib/trinsic_api/models/clear_provider_output_document.rb', line 203

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end