Class: TrinsicApi::ClearProviderOutputHealthInsurance
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ClearProviderOutputHealthInsurance
- Defined in:
- lib/trinsic_api/models/clear_provider_output_health_insurance.rb
Instance Attribute Summary collapse
-
#group_id ⇒ Object
The health insurance group identifier.
-
#group_name ⇒ Object
The health insurance group name.
-
#insurance_member_id ⇒ Object
The health insurance member identifier.
-
#payer_id ⇒ Object
The health insurance payer identifier.
-
#payer_name ⇒ Object
The health insurance payer name.
-
#plan_status ⇒ Object
The health insurance plan status.
-
#policy_holder_first_name ⇒ Object
The first name of the policy holder.
-
#policy_holder_last_name ⇒ Object
The last name of the policy holder.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClearProviderOutputHealthInsurance
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClearProviderOutputHealthInsurance
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutputHealthInsurance` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutputHealthInsurance`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'payer_id') self.payer_id = attributes[:'payer_id'] end if attributes.key?(:'payer_name') self.payer_name = attributes[:'payer_name'] end if attributes.key?(:'plan_status') self.plan_status = attributes[:'plan_status'] end if attributes.key?(:'group_name') self.group_name = attributes[:'group_name'] end if attributes.key?(:'group_id') self.group_id = attributes[:'group_id'] end if attributes.key?(:'insurance_member_id') self.insurance_member_id = attributes[:'insurance_member_id'] end if attributes.key?(:'policy_holder_first_name') self.policy_holder_first_name = attributes[:'policy_holder_first_name'] end if attributes.key?(:'policy_holder_last_name') self.policy_holder_last_name = attributes[:'policy_holder_last_name'] end end |
Instance Attribute Details
#group_id ⇒ Object
The health insurance group identifier.
31 32 33 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 31 def group_id @group_id end |
#group_name ⇒ Object
The health insurance group name.
28 29 30 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 28 def group_name @group_name end |
#insurance_member_id ⇒ Object
The health insurance member identifier.
34 35 36 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 34 def insurance_member_id @insurance_member_id end |
#payer_id ⇒ Object
The health insurance payer identifier.
19 20 21 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 19 def payer_id @payer_id end |
#payer_name ⇒ Object
The health insurance payer name.
22 23 24 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 22 def payer_name @payer_name end |
#plan_status ⇒ Object
The health insurance plan status.
25 26 27 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 25 def plan_status @plan_status end |
#policy_holder_first_name ⇒ Object
The first name of the policy holder.
37 38 39 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 37 def policy_holder_first_name @policy_holder_first_name end |
#policy_holder_last_name ⇒ Object
The last name of the policy holder.
40 41 42 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 40 def policy_holder_last_name @policy_holder_last_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 43 def self.attribute_map { :'payer_id' => :'payerId', :'payer_name' => :'payerName', :'plan_status' => :'planStatus', :'group_name' => :'groupName', :'group_id' => :'groupId', :'insurance_member_id' => :'insuranceMemberId', :'policy_holder_first_name' => :'policyHolderFirstName', :'policy_holder_last_name' => :'policyHolderLastName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 81 def self.openapi_nullable Set.new([ :'payer_id', :'payer_name', :'plan_status', :'group_name', :'group_id', :'insurance_member_id', :'policy_holder_first_name', :'policy_holder_last_name' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 67 def self.openapi_types { :'payer_id' => :'String', :'payer_name' => :'String', :'plan_status' => :'String', :'group_name' => :'String', :'group_id' => :'String', :'insurance_member_id' => :'String', :'policy_holder_first_name' => :'String', :'policy_holder_last_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && payer_id == o.payer_id && payer_name == o.payer_name && plan_status == o.plan_status && group_name == o.group_name && group_id == o.group_id && insurance_member_id == o.insurance_member_id && policy_holder_first_name == o.policy_holder_first_name && policy_holder_last_name == o.policy_holder_last_name end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 181 def hash [payer_id, payer_name, plan_status, group_name, group_id, insurance_member_id, policy_holder_first_name, policy_holder_last_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/trinsic_api/models/clear_provider_output_health_insurance.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |