Class: TrinsicApi::ClearProviderOutputLocationInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ClearProviderOutputLocationInfo
- Defined in:
- lib/trinsic_api/models/clear_provider_output_location_info.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city name.
-
#country ⇒ Object
The country name.
-
#country_iso ⇒ Object
The ISO 3166 alpha-2 country code.
-
#latitude ⇒ Object
The latitude parsed from the request.
-
#longitude ⇒ Object
The longitude parsed from the request.
-
#subdivision ⇒ Object
The subdivision name.
-
#subdivision_type ⇒ Object
The subdivision type, such as state or province.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClearProviderOutputLocationInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClearProviderOutputLocationInfo
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutputLocationInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutputLocationInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'country_iso') self.country_iso = attributes[:'country_iso'] end if attributes.key?(:'subdivision') self.subdivision = attributes[:'subdivision'] end if attributes.key?(:'subdivision_type') self.subdivision_type = attributes[:'subdivision_type'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'latitude') self.latitude = attributes[:'latitude'] end if attributes.key?(:'longitude') self.longitude = attributes[:'longitude'] end end |
Instance Attribute Details
#city ⇒ Object
The city name.
31 32 33 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 31 def city @city end |
#country ⇒ Object
The country name.
19 20 21 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 19 def country @country end |
#country_iso ⇒ Object
The ISO 3166 alpha-2 country code.
22 23 24 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 22 def country_iso @country_iso end |
#latitude ⇒ Object
The latitude parsed from the request.
34 35 36 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 34 def latitude @latitude end |
#longitude ⇒ Object
The longitude parsed from the request.
37 38 39 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 37 def longitude @longitude end |
#subdivision ⇒ Object
The subdivision name.
25 26 27 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 25 def subdivision @subdivision end |
#subdivision_type ⇒ Object
The subdivision type, such as state or province.
28 29 30 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 28 def subdivision_type @subdivision_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 40 def self.attribute_map { :'country' => :'country', :'country_iso' => :'countryIso', :'subdivision' => :'subdivision', :'subdivision_type' => :'subdivisionType', :'city' => :'city', :'latitude' => :'latitude', :'longitude' => :'longitude' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 76 def self.openapi_nullable Set.new([ :'country', :'country_iso', :'subdivision', :'subdivision_type', :'city', :'latitude', :'longitude' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 63 def self.openapi_types { :'country' => :'String', :'country_iso' => :'String', :'subdivision' => :'String', :'subdivision_type' => :'String', :'city' => :'String', :'latitude' => :'String', :'longitude' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && country == o.country && country_iso == o.country_iso && subdivision == o.subdivision && subdivision_type == o.subdivision_type && city == o.city && latitude == o.latitude && longitude == o.longitude end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 170 def hash [country, country_iso, subdivision, subdivision_type, city, latitude, longitude].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 |
# File 'lib/trinsic_api/models/clear_provider_output_location_info.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |