Class: TrinsicApi::ClearProviderOutputWatchlistHit

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ClearProviderOutputWatchlistHit

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutputWatchlistHit` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutputWatchlistHit`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'entity_type')
    self.entity_type = attributes[:'entity_type']
  end

  if attributes.key?(:'details')
    self.details = attributes[:'details']
  end

  if attributes.key?(:'source_lists')
    if (value = attributes[:'source_lists']).is_a?(Array)
      self.source_lists = value
    end
  end

  if attributes.key?(:'hit_types')
    if (value = attributes[:'hit_types']).is_a?(Array)
      self.hit_types = value
    end
  end
end

Instance Attribute Details

#detailsObject

More details about the watchlist hit entity.



22
23
24
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 22

def details
  @details
end

#entity_typeObject

The watchlist entity type. Known values: - person



19
20
21
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 19

def entity_type
  @entity_type
end

#hit_typesObject

The types of watchlist hits. Known values: - sanction - pep - warning - adverse_media



28
29
30
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 28

def hit_types
  @hit_types
end

#source_listsObject

The watchlist source lists where CLEAR found the hit.



25
26
27
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 25

def source_lists
  @source_lists
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 31

def self.attribute_map
  {
    :'entity_type' => :'entityType',
    :'details' => :'details',
    :'source_lists' => :'sourceLists',
    :'hit_types' => :'hitTypes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
65
66
67
68
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 61

def self.openapi_nullable
  Set.new([
    :'entity_type',
    :'details',
    :'source_lists',
    :'hit_types'
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 51

def self.openapi_types
  {
    :'entity_type' => :'String',
    :'details' => :'ClearProviderOutputWatchlistHitDetails',
    :'source_lists' => :'Array<ClearProviderOutputWatchlistSource>',
    :'hit_types' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



124
125
126
127
128
129
130
131
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 124

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      entity_type == o.entity_type &&
      details == o.details &&
      source_lists == o.source_lists &&
      hit_types == o.hit_types
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 141

def hash
  [entity_type, details, source_lists, hit_types].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



109
110
111
112
113
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 109

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



117
118
119
120
# File 'lib/trinsic_api/models/clear_provider_output_watchlist_hit.rb', line 117

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end