Class: TrinsicApi::ColombiaCcLookupInput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/colombia_cc_lookup_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ColombiaCcLookupInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ColombiaCcLookupInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ColombiaCcLookupInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  end

  if attributes.key?(:'issue_date')
    self.issue_date = attributes[:'issue_date']
  end
end

Instance Attribute Details

#document_numberObject

The CC (Cédula de Ciudadanía, Citizenship Document) document number. Format: - Cédulas after 2004 use the NUIP (Número Único de Identificación Personal), which is 10 digits. Older documents may have fewer than 10 digits and are still valid. - In Colombia the number is often written with dots as thousands separators (e.g. 1.234.567.890). If dots, hyphens, spaces, or other non-alphanumeric characters are included, they will be sanitized before lookup.



19
20
21
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 19

def document_number
  @document_number
end

#issue_dateObject

Document issue date, in ‘YYYY-MM-DD` format



22
23
24
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 22

def issue_date
  @issue_date
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 25

def self.attribute_map
  {
    :'document_number' => :'documentNumber',
    :'issue_date' => :'issueDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 122

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
55
56
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 51

def self.openapi_nullable
  Set.new([
    :'document_number',
    :'issue_date'
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 43

def self.openapi_types
  {
    :'document_number' => :'String',
    :'issue_date' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



100
101
102
103
104
105
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 100

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      document_number == o.document_number &&
      issue_date == o.issue_date
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


109
110
111
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 109

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



115
116
117
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 115

def hash
  [document_number, issue_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



85
86
87
88
89
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 85

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 144

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



93
94
95
96
# File 'lib/trinsic_api/models/colombia_cc_lookup_input.rb', line 93

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end