Class: TrinsicApi::CreateAdvancedProviderSessionRequest
- Inherits:
-
Object
- Object
- TrinsicApi::CreateAdvancedProviderSessionRequest
- Defined in:
- lib/trinsic_api/models/create_advanced_provider_session_request.rb
Instance Attribute Summary collapse
-
#capabilities ⇒ Object
The list of capabilities your integration supports.
-
#fallback_to_hosted_ui ⇒ Object
Whether the session should fall back to a Trinsic-hosted UI in certain instances.
-
#provider ⇒ Object
The ID of the provider to launch.
-
#provider_input ⇒ Object
Provider-specific input for those providers which require it.
-
#redirect_url ⇒ Object
The Redirect URL to which the user should be sent after the session is complete.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAdvancedProviderSessionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ CreateAdvancedProviderSessionRequest
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CreateAdvancedProviderSessionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CreateAdvancedProviderSessionRequest`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'provider_input') self.provider_input = attributes[:'provider_input'] end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Array) self.capabilities = value end else self.capabilities = nil end if attributes.key?(:'fallback_to_hosted_ui') self.fallback_to_hosted_ui = attributes[:'fallback_to_hosted_ui'] end end |
Instance Attribute Details
#capabilities ⇒ Object
The list of capabilities your integration supports. Capabilities are the core of Trinsic’s whitelabel-with-optional-fallback offering. Most capabilities align with either an IntegrationLaunchMethod or an IntegrationCollectionMethod. The exception being refresh content to support updating the content of the launch method. For example, to support a basic redirect-based flow, you must include the LaunchRedirect and CaptureRedirect capabilities. To support a mobile deeplink / polling flow, you must include the DeeplinkToMobile and PollForResults capabilities. If FallbackToHostedUi is true, Trinsic will automatically fall back to a Trinsic-hosted UI to cover any gaps in your integration’s capabilities. If FallbackToHostedUi is false, gaps in your integration’s capabilities will result in an error during Session creation. Read more on how to integrate at <a href="docs.trinsic.id/docs/advanced-provider-sessions">the guide on Advanced Provider Sessions</a>
28 29 30 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 28 def capabilities @capabilities end |
#fallback_to_hosted_ui ⇒ Object
Whether the session should fall back to a Trinsic-hosted UI in certain instances. Specifically, fallback will occur if any of the following are true: - You attempted to launch a provider which requires a capability you did not express support for - In this case, Trinsic’s hosted UI will perform the necessary capability - You attempted to launch a provider which requires input, and the input was either not provided or incomplete - In this case, Trinsic’s hosted UI will collect the necessary input from the user If fallback occurs, the session’s NextStep will always be LaunchBrowser, and the CollectionMethod will always be CaptureRedirect. If this field is set to true, you must also: 1. Set the RedirectUrl field to a non-empty value 2. Include the LaunchBrowser and CaptureRedirect capabilities in the Capabilities field
31 32 33 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 31 def fallback_to_hosted_ui @fallback_to_hosted_ui end |
#provider ⇒ Object
The ID of the provider to launch
19 20 21 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 19 def provider @provider end |
#provider_input ⇒ Object
Provider-specific input for those providers which require it.
22 23 24 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 22 def provider_input @provider_input end |
#redirect_url ⇒ Object
The Redirect URL to which the user should be sent after the session is complete. This field is required for providers which employ a redirect-based flow.
25 26 27 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 25 def redirect_url @redirect_url end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 225 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 45 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 34 def self.attribute_map { :'provider' => :'provider', :'provider_input' => :'providerInput', :'redirect_url' => :'redirectUrl', :'capabilities' => :'capabilities', :'fallback_to_hosted_ui' => :'fallbackToHostedUI' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 66 67 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 61 def self.openapi_nullable Set.new([ :'provider_input', :'redirect_url', :'fallback_to_hosted_ui' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 58 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 50 def self.openapi_types { :'provider' => :'String', :'provider_input' => :'ProviderInput', :'redirect_url' => :'String', :'capabilities' => :'Array<IntegrationCapability>', :'fallback_to_hosted_ui' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && provider == o.provider && provider_input == o.provider_input && redirect_url == o.redirect_url && capabilities == o.capabilities && fallback_to_hosted_ui == o.fallback_to_hosted_ui end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 296 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 194 def hash [provider, provider_input, redirect_url, capabilities, fallback_to_hosted_ui].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @provider.to_s.length < 1 invalid_properties.push('invalid value for "provider", the character length must be great than or equal to 1.') end if @capabilities.nil? invalid_properties.push('invalid value for "capabilities", capabilities cannot be nil.') end if @capabilities.length < 1 invalid_properties.push('invalid value for "capabilities", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
272 273 274 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 272 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 278 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
266 267 268 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 266 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 141 142 143 144 |
# File 'lib/trinsic_api/models/create_advanced_provider_session_request.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @provider.nil? return false if @provider.to_s.length < 1 return false if @capabilities.nil? return false if @capabilities.length < 1 true end |