Class: TrinsicApi::CzechMojeIdAddressOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/czech_moje_id_address_output.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CzechMojeIdAddressOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CzechMojeIdAddressOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CzechMojeIdAddressOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'street_address')
    self.street_address = attributes[:'street_address']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'region')
    self.region = attributes[:'region']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'formatted_address')
    self.formatted_address = attributes[:'formatted_address']
  end
end

Instance Attribute Details

#cityObject

The city or locality.



22
23
24
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 22

def city
  @city
end

#countryObject

The ISO 3166-1 alpha-2 country code.



31
32
33
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 31

def country
  @country
end

#formatted_addressObject

The full address as a formatted string, with components separated by newlines.



34
35
36
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 34

def formatted_address
  @formatted_address
end

#postal_codeObject

The postal code.



28
29
30
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 28

def postal_code
  @postal_code
end

#regionObject

The region or state.



25
26
27
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 25

def region
  @region
end

#street_addressObject

The street address line, including house number.



19
20
21
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 19

def street_address
  @street_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 37

def self.attribute_map
  {
    :'street_address' => :'streetAddress',
    :'city' => :'city',
    :'region' => :'region',
    :'postal_code' => :'postalCode',
    :'country' => :'country',
    :'formatted_address' => :'formattedAddress'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 166

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
75
76
77
78
79
80
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 71

def self.openapi_nullable
  Set.new([
    :'street_address',
    :'city',
    :'region',
    :'postal_code',
    :'country',
    :'formatted_address'
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 59

def self.openapi_types
  {
    :'street_address' => :'String',
    :'city' => :'String',
    :'region' => :'String',
    :'postal_code' => :'String',
    :'country' => :'String',
    :'formatted_address' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



140
141
142
143
144
145
146
147
148
149
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 140

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      street_address == o.street_address &&
      city == o.city &&
      region == o.region &&
      postal_code == o.postal_code &&
      country == o.country &&
      formatted_address == o.formatted_address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


153
154
155
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 153

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



159
160
161
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 159

def hash
  [street_address, city, region, postal_code, country, formatted_address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 188

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
# File 'lib/trinsic_api/models/czech_moje_id_address_output.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end