Class: TrinsicApi::DigilockerAadhaarProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb

Overview

Exposed properties for the india-digilocker-aadhaar Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DigilockerAadhaarProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 91

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::DigilockerAadhaarProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::DigilockerAadhaarProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'document_type')
    self.document_type = attributes[:'document_type']
  end

  if attributes.key?(:'timestamp')
    self.timestamp = attributes[:'timestamp']
  end

  if attributes.key?(:'time_to_live')
    self.time_to_live = attributes[:'time_to_live']
  end

  if attributes.key?(:'aadhaar_number_last_four')
    self.aadhaar_number_last_four = attributes[:'aadhaar_number_last_four']
  end

  if attributes.key?(:'claims')
    self.claims = attributes[:'claims']
  end

  if attributes.key?(:'localized_claims')
    self.localized_claims = attributes[:'localized_claims']
  end

  if attributes.key?(:'document_signature_validated')
    self.document_signature_validated = attributes[:'document_signature_validated']
  end
end

Instance Attribute Details

#aadhaar_number_last_fourObject

The Aadhaar number (UID) value for the individual. This is only the last four digits of the Aadhaar number.



29
30
31
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 29

def aadhaar_number_last_four
  @aadhaar_number_last_four
end

#claimsObject

The claims extracted from the Aadhaar document.



32
33
34
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 32

def claims
  @claims
end

#document_signature_validatedObject

Whether our own validation of the Aadhaar document signature and certificate chain succeeded. When the signed document (e.g. Digilocker XML) is available, we validate it using the standard CCA/SafeScrypt chain. When the document is not returned, the signature cannot be validated and this is false. Some providers (e.g. Signzy) also supply a separate DSC validation indicator in the webhook payload; that is independent of this flag, which reflects only our validation.



38
39
40
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 38

def document_signature_validated
  @document_signature_validated
end

#document_typeObject

The document type from which the identity data was retrieved.



20
21
22
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 20

def document_type
  @document_type
end

#localized_claimsObject

The localized claims extracted from the Aadhaar document.



35
36
37
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 35

def localized_claims
  @localized_claims
end

#time_to_liveObject

The validity expiration timestamp for the verification document.



26
27
28
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 26

def time_to_live
  @time_to_live
end

#timestampObject

The timestamp when the signed document was generated and verified.



23
24
25
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 23

def timestamp
  @timestamp
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 41

def self.attribute_map
  {
    :'document_type' => :'documentType',
    :'timestamp' => :'timestamp',
    :'time_to_live' => :'timeToLive',
    :'aadhaar_number_last_four' => :'aadhaarNumberLastFour',
    :'claims' => :'claims',
    :'localized_claims' => :'localizedClaims',
    :'document_signature_validated' => :'documentSignatureValidated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 178

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
81
82
83
84
85
86
87
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 77

def self.openapi_nullable
  Set.new([
    :'document_type',
    :'timestamp',
    :'time_to_live',
    :'aadhaar_number_last_four',
    :'claims',
    :'localized_claims',
    :'document_signature_validated'
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 64

def self.openapi_types
  {
    :'document_type' => :'String',
    :'timestamp' => :'Time',
    :'time_to_live' => :'Time',
    :'aadhaar_number_last_four' => :'String',
    :'claims' => :'AadhaarClaims',
    :'localized_claims' => :'AadhaarLocalizedClaims',
    :'document_signature_validated' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



151
152
153
154
155
156
157
158
159
160
161
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 151

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      document_type == o.document_type &&
      timestamp == o.timestamp &&
      time_to_live == o.time_to_live &&
      aadhaar_number_last_four == o.aadhaar_number_last_four &&
      claims == o.claims &&
      localized_claims == o.localized_claims &&
      document_signature_validated == o.document_signature_validated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


165
166
167
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 165

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



171
172
173
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 171

def hash
  [document_type, timestamp, time_to_live, aadhaar_number_last_four, claims, localized_claims, document_signature_validated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 200

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end