Class: TrinsicApi::DocumentData

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/document_data.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DocumentData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
# File 'lib/trinsic_api/models/document_data.rb', line 112

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::DocumentData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::DocumentData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'number')
    self.number = attributes[:'number']
  end

  if attributes.key?(:'issue_date')
    self.issue_date = attributes[:'issue_date']
  end

  if attributes.key?(:'expiration_date')
    self.expiration_date = attributes[:'expiration_date']
  end

  if attributes.key?(:'issuing_country')
    self.issuing_country = attributes[:'issuing_country']
  end

  if attributes.key?(:'issuing_subdivision')
    self.issuing_subdivision = attributes[:'issuing_subdivision']
  end

  if attributes.key?(:'issuing_authority')
    self.issuing_authority = attributes[:'issuing_authority']
  end
end

Instance Attribute Details

#expiration_dateObject

The date the document expires.



28
29
30
# File 'lib/trinsic_api/models/document_data.rb', line 28

def expiration_date
  @expiration_date
end

#issue_dateObject

The date the document was issued.



25
26
27
# File 'lib/trinsic_api/models/document_data.rb', line 25

def issue_date
  @issue_date
end

#issuing_authorityObject

The name of the authority which issued the document.



37
38
39
# File 'lib/trinsic_api/models/document_data.rb', line 37

def issuing_authority
  @issuing_authority
end

#issuing_countryObject

The ISO 3166-1 alpha-2 country code of the country that issued the document.



31
32
33
# File 'lib/trinsic_api/models/document_data.rb', line 31

def issuing_country
  @issuing_country
end

#issuing_subdivisionObject

The ISO 3166-2 subdivision code of the issuing authority which issued the document. This is always in the form CountryCode-SubdivisionCode, where CountryCode is 2 letters and SubdivisionCode is 1-3 alphanumeric characters.



34
35
36
# File 'lib/trinsic_api/models/document_data.rb', line 34

def issuing_subdivision
  @issuing_subdivision
end

#numberObject

The primary identifying number of the document.



22
23
24
# File 'lib/trinsic_api/models/document_data.rb', line 22

def number
  @number
end

#typeObject

The type of the document.



19
20
21
# File 'lib/trinsic_api/models/document_data.rb', line 19

def type
  @type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/trinsic_api/models/document_data.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/trinsic_api/models/document_data.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/trinsic_api/models/document_data.rb', line 62

def self.attribute_map
  {
    :'type' => :'type',
    :'number' => :'number',
    :'issue_date' => :'issueDate',
    :'expiration_date' => :'expirationDate',
    :'issuing_country' => :'issuingCountry',
    :'issuing_subdivision' => :'issuingSubdivision',
    :'issuing_authority' => :'issuingAuthority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/trinsic_api/models/document_data.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
103
104
105
106
107
108
# File 'lib/trinsic_api/models/document_data.rb', line 98

def self.openapi_nullable
  Set.new([
    :'type',
    :'number',
    :'issue_date',
    :'expiration_date',
    :'issuing_country',
    :'issuing_subdivision',
    :'issuing_authority'
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/trinsic_api/models/document_data.rb', line 85

def self.openapi_types
  {
    :'type' => :'DocumentType',
    :'number' => :'String',
    :'issue_date' => :'Date',
    :'expiration_date' => :'Date',
    :'issuing_country' => :'String',
    :'issuing_subdivision' => :'String',
    :'issuing_authority' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/document_data.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      number == o.number &&
      issue_date == o.issue_date &&
      expiration_date == o.expiration_date &&
      issuing_country == o.issuing_country &&
      issuing_subdivision == o.issuing_subdivision &&
      issuing_authority == o.issuing_authority
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/trinsic_api/models/document_data.rb', line 186

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



192
193
194
# File 'lib/trinsic_api/models/document_data.rb', line 192

def hash
  [type, number, issue_date, expiration_date, issuing_country, issuing_subdivision, issuing_authority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



157
158
159
160
161
# File 'lib/trinsic_api/models/document_data.rb', line 157

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/trinsic_api/models/document_data.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



165
166
167
168
# File 'lib/trinsic_api/models/document_data.rb', line 165

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end