Class: TrinsicApi::EudiAgeVerificationCredential
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::EudiAgeVerificationCredential
- Defined in:
- lib/trinsic_api/models/eudi_age_verification_credential.rb
Overview
An EUDI Age Verification credential, with document type ‘eu.europa.ec.eudi.av.1`. This is the age verification credential type defined in the EUDI Wallet framework.
Instance Attribute Summary collapse
-
#age_over ⇒ Object
Processed age-over claims returned by the credential.
-
#expiry_date ⇒ Object
Date when the age verification data expires.
-
#issuing_country ⇒ Object
ISO 3166-1 alpha-2 country code of the country or territory of the issuer of the credential.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EudiAgeVerificationCredential
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EudiAgeVerificationCredential
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::EudiAgeVerificationCredential` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::EudiAgeVerificationCredential`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'age_over') if (value = attributes[:'age_over']).is_a?(Array) self.age_over = value end end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'issuing_country') self.issuing_country = attributes[:'issuing_country'] end end |
Instance Attribute Details
#age_over ⇒ Object
Processed age-over claims returned by the credential.
20 21 22 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 20 def age_over @age_over end |
#expiry_date ⇒ Object
Date when the age verification data expires.
23 24 25 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 23 def expiry_date @expiry_date end |
#issuing_country ⇒ Object
ISO 3166-1 alpha-2 country code of the country or territory of the issuer of the credential.
26 27 28 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 26 def issuing_country @issuing_country end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
29 30 31 32 33 34 35 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 29 def self.attribute_map { :'age_over' => :'ageOver', :'expiry_date' => :'expiryDate', :'issuing_country' => :'issuingCountry' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 136 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 57 def self.openapi_nullable Set.new([ :'age_over', :'expiry_date', :'issuing_country' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 48 def self.openapi_types { :'age_over' => :'Array<AgeOverOutput>', :'expiry_date' => :'Date', :'issuing_country' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
113 114 115 116 117 118 119 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 113 def ==(o) return true if self.equal?(o) self.class == o.class && age_over == o.age_over && expiry_date == o.expiry_date && issuing_country == o.issuing_country end |
#eql?(o) ⇒ Boolean
123 124 125 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 123 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
129 130 131 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 129 def hash [age_over, expiry_date, issuing_country].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
98 99 100 101 102 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 98 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 158 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
106 107 108 109 |
# File 'lib/trinsic_api/models/eudi_age_verification_credential.rb', line 106 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |