Class: TrinsicApi::FinnishTrustNetworkProviderOutput
- Inherits:
-
Object
- Object
- TrinsicApi::FinnishTrustNetworkProviderOutput
- Defined in:
- lib/trinsic_api/models/finnish_trust_network_provider_output.rb
Overview
Exposed properties for the ‘finnish-trust-network` Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#bank ⇒ Object
The bank used to perform the identification for the verified individual.
-
#date_of_birth ⇒ Object
The date of birth of the individual.
-
#family_name ⇒ Object
The family name of the individual.
-
#full_name ⇒ Object
The full name of the individual.
-
#given_name ⇒ Object
The given name of the individual.
-
#level_of_assurance ⇒ Object
The level of assurance (LOA) for the verification.
-
#organization_name ⇒ Object
The organization name that the individual is associated with.
-
#personal_identification_code ⇒ Object
The 11-digit Finnish Personal Identification Code (Henkilötunnus) of the verified individual.
-
#phone_number ⇒ Object
The phone number of the verified individual.
-
#unique_identification_number ⇒ Object
The 9-digit Finnish Unique Identification Number (FINUID, or sähköinen asiointitunnus SATU) of the verified individual.
-
#vat_number ⇒ Object
The VAT number of the organization that the individual is associated with.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FinnishTrustNetworkProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FinnishTrustNetworkProviderOutput
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::FinnishTrustNetworkProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::FinnishTrustNetworkProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'personal_identification_code') self.personal_identification_code = attributes[:'personal_identification_code'] end if attributes.key?(:'unique_identification_number') self.unique_identification_number = attributes[:'unique_identification_number'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'level_of_assurance') self.level_of_assurance = attributes[:'level_of_assurance'] end if attributes.key?(:'bank') self.bank = attributes[:'bank'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'organization_name') self.organization_name = attributes[:'organization_name'] end if attributes.key?(:'vat_number') self.vat_number = attributes[:'vat_number'] end end |
Instance Attribute Details
#bank ⇒ Object
The bank used to perform the identification for the verified individual.
41 42 43 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 41 def bank @bank end |
#date_of_birth ⇒ Object
The date of birth of the individual.
23 24 25 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 23 def date_of_birth @date_of_birth end |
#family_name ⇒ Object
The family name of the individual.
35 36 37 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 35 def family_name @family_name end |
#full_name ⇒ Object
The full name of the individual.
20 21 22 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 20 def full_name @full_name end |
#given_name ⇒ Object
The given name of the individual.
32 33 34 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 32 def given_name @given_name end |
#level_of_assurance ⇒ Object
The level of assurance (LOA) for the verification. The LOA refers to the degree of confidence in the claimed identity of a person. The European Digital Identity Framework (EUDI) measures the confidence of the digital identity’s verification and authentication strength by a set of requirements for different levels. To learn more, see: ec.europa.eu/digital-building-blocks/sites/spaces/DIGITAL/pages/467110081/eIDAS+Levels+of+Assurance Possible values: - Low: The user has self asserted their identity and multifactor authentication is not required. - Substantial: The user has performed either a remote or in-person identity verification and multifactor authentication is required. - High: The user has performed an in-person identity proofing with an authorized representative and has strong cryptographic authentication requirements such as using a smart card.
38 39 40 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 38 def level_of_assurance @level_of_assurance end |
#organization_name ⇒ Object
The organization name that the individual is associated with. This is returned for requests that contain the organization scope.
47 48 49 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 47 def organization_name @organization_name end |
#personal_identification_code ⇒ Object
The 11-digit Finnish Personal Identification Code (Henkilötunnus) of the verified individual. This is in the format DDMMYYCZZZQ, where: - DDMMYY is the date of birth - C is a symbol which determines the century of birth - ZZZ is an individual number, indicating gender - Q is a checksum character If ZZZ is even, the individual is female. If ZZZ is odd, the individual is male. If C is ‘+’, the individual was born in the 19th century (1800-1899). If C is ‘-’, ‘U’, ‘V’, ‘W’, ‘X’, or ‘Y’, the individual was born in the 20th century (1900-1999). If C is ‘A’, ‘B’, ‘C’, ‘D’, ‘E’, or ‘F’, the individual was born in the 21st century (2000-2099).
26 27 28 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 26 def personal_identification_code @personal_identification_code end |
#phone_number ⇒ Object
The phone number of the verified individual. This is only returned if the user authenticated with MobileID (Mobiilivarmenne).
44 45 46 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 44 def phone_number @phone_number end |
#unique_identification_number ⇒ Object
The 9-digit Finnish Unique Identification Number (FINUID, or sähköinen asiointitunnus SATU) of the verified individual. This number is typically used for online transactions and unlike the Finnish Personal Identification Code, does not reveal personal information such as birthdate. The first 8 digits are randomly generated and the last character is a check control.
29 30 31 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 29 def unique_identification_number @unique_identification_number end |
#vat_number ⇒ Object
The VAT number of the organization that the individual is associated with. This is returned for requests that contain the organization scope.
50 51 52 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 50 def vat_number @vat_number end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 246 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 53 def self.attribute_map { :'full_name' => :'fullName', :'date_of_birth' => :'dateOfBirth', :'personal_identification_code' => :'personalIdentificationCode', :'unique_identification_number' => :'uniqueIdentificationNumber', :'given_name' => :'givenName', :'family_name' => :'familyName', :'level_of_assurance' => :'levelOfAssurance', :'bank' => :'bank', :'phone_number' => :'phoneNumber', :'organization_name' => :'organizationName', :'vat_number' => :'vatNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 222 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 97 def self.openapi_nullable Set.new([ :'full_name', :'date_of_birth', :'personal_identification_code', :'unique_identification_number', :'given_name', :'family_name', :'level_of_assurance', :'bank', :'phone_number', :'organization_name', :'vat_number' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 80 def self.openapi_types { :'full_name' => :'String', :'date_of_birth' => :'Date', :'personal_identification_code' => :'String', :'unique_identification_number' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'level_of_assurance' => :'String', :'bank' => :'String', :'phone_number' => :'String', :'organization_name' => :'String', :'vat_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && date_of_birth == o.date_of_birth && personal_identification_code == o.personal_identification_code && unique_identification_number == o.unique_identification_number && given_name == o.given_name && family_name == o.family_name && level_of_assurance == o.level_of_assurance && bank == o.bank && phone_number == o.phone_number && organization_name == o.organization_name && vat_number == o.vat_number end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
317 318 319 320 321 322 323 324 325 326 327 328 329 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 317 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
209 210 211 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 209 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 215 def hash [full_name, date_of_birth, personal_identification_code, unique_identification_number, given_name, family_name, level_of_assurance, bank, phone_number, organization_name, vat_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 176 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
293 294 295 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 293 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
299 300 301 302 303 304 305 306 307 308 309 310 311 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 299 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
287 288 289 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 287 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 |
# File 'lib/trinsic_api/models/finnish_trust_network_provider_output.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |