Class: TrinsicApi::GoogleWalletProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/google_wallet_provider_output.rb

Overview

Exposed properties for the ‘google-wallet` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ GoogleWalletProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 66

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::GoogleWalletProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::GoogleWalletProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mobile_drivers_license')
    self.mobile_drivers_license = attributes[:'mobile_drivers_license']
  end

  if attributes.key?(:'id_pass')
    self.id_pass = attributes[:'id_pass']
  end

  if attributes.key?(:'raw_mdl_output')
    self.raw_mdl_output = attributes[:'raw_mdl_output']
  else
    self.raw_mdl_output = nil
  end
end

Instance Attribute Details

#id_passObject

A Google Wallet ID Pass credential (‘com.google.wallet.idcard.1`), retrieved from the individual’s wallet.



23
24
25
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 23

def id_pass
  @id_pass
end

#mobile_drivers_licenseObject

A standard 18013-5 Mobile Driver’s License credential, retrieved from the individual’s wallet.



20
21
22
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 20

def mobile_drivers_license
  @mobile_drivers_license
end

#raw_mdl_outputObject

The raw output of the mDL exchange performed through Google Wallet.



26
27
28
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 26

def raw_mdl_output
  @raw_mdl_output
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 29

def self.attribute_map
  {
    :'mobile_drivers_license' => :'mobileDriversLicense',
    :'id_pass' => :'idPass',
    :'raw_mdl_output' => :'rawMdlOutput'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 150

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
62
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 57

def self.openapi_nullable
  Set.new([
    :'mobile_drivers_license',
    :'id_pass',
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 48

def self.openapi_types
  {
    :'mobile_drivers_license' => :'Iso180135MobileDriversLicenseCredential',
    :'id_pass' => :'GoogleWalletIdPassCredential',
    :'raw_mdl_output' => :'MdlOutput'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



127
128
129
130
131
132
133
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 127

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mobile_drivers_license == o.mobile_drivers_license &&
      id_pass == o.id_pass &&
      raw_mdl_output == o.raw_mdl_output
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


137
138
139
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 137

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



143
144
145
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 143

def hash
  [mobile_drivers_license, id_pass, raw_mdl_output].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @raw_mdl_output.nil?
    invalid_properties.push('invalid value for "raw_mdl_output", raw_mdl_output cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 172

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



109
110
111
112
113
# File 'lib/trinsic_api/models/google_wallet_provider_output.rb', line 109

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @raw_mdl_output.nil?
  true
end