Class: TrinsicApi::IdentityData
- Inherits:
-
Object
- Object
- TrinsicApi::IdentityData
- Defined in:
- lib/trinsic_api/models/identity_data.rb
Instance Attribute Summary collapse
-
#attachments ⇒ Object
Information for each attachment included with this set of identity data.
-
#document ⇒ Object
Identity data of the document involved in verification, if relevant.
-
#match ⇒ Object
Match results for the data being matched against.
-
#originating_provider_id ⇒ Object
The ID of the provider from which this data originated (eg "yoti", "clear").
-
#originating_sub_provider_id ⇒ Object
The sub-provider ID of the provider from which this data originated (eg "rabo", "poste-italiane") This is applicable only to federated Identity Providers such as SPID and IDIN.
-
#person ⇒ Object
Identity data of the individual who was verified.
-
#provider_output ⇒ Object
Provider-specific output data that doesn’t fit the standard identity data schema.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdentityData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ IdentityData
Initializes the object
89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/trinsic_api/models/identity_data.rb', line 89 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IdentityData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IdentityData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'originating_provider_id') self.originating_provider_id = attributes[:'originating_provider_id'] end if attributes.key?(:'originating_sub_provider_id') self.originating_sub_provider_id = attributes[:'originating_sub_provider_id'] end if attributes.key?(:'person') self.person = attributes[:'person'] end if attributes.key?(:'document') self.document = attributes[:'document'] end if attributes.key?(:'match') self.match = attributes[:'match'] end if attributes.key?(:'attachments') if (value = attributes[:'attachments']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'provider_output') self.provider_output = attributes[:'provider_output'] end end |
Instance Attribute Details
#attachments ⇒ Object
Information for each attachment included with this set of identity data. Use the Attachments API to fetch an attachment by its ID for a given Session.
34 35 36 |
# File 'lib/trinsic_api/models/identity_data.rb', line 34 def @attachments end |
#document ⇒ Object
Identity data of the document involved in verification, if relevant
28 29 30 |
# File 'lib/trinsic_api/models/identity_data.rb', line 28 def document @document end |
#match ⇒ Object
Match results for the data being matched against. This applies to Providers which operate based on matching data / biometrics against a government database, returning match scores or results as opposed to the data itself.
31 32 33 |
# File 'lib/trinsic_api/models/identity_data.rb', line 31 def match @match end |
#originating_provider_id ⇒ Object
The ID of the provider from which this data originated (eg "yoti", "clear")
19 20 21 |
# File 'lib/trinsic_api/models/identity_data.rb', line 19 def originating_provider_id @originating_provider_id end |
#originating_sub_provider_id ⇒ Object
The sub-provider ID of the provider from which this data originated (eg "rabo", "poste-italiane") This is applicable only to federated Identity Providers such as SPID and IDIN.
22 23 24 |
# File 'lib/trinsic_api/models/identity_data.rb', line 22 def originating_sub_provider_id @originating_sub_provider_id end |
#person ⇒ Object
Identity data of the individual who was verified
25 26 27 |
# File 'lib/trinsic_api/models/identity_data.rb', line 25 def person @person end |
#provider_output ⇒ Object
Provider-specific output data that doesn’t fit the standard identity data schema. The structure of this object varies by provider.
37 38 39 |
# File 'lib/trinsic_api/models/identity_data.rb', line 37 def provider_output @provider_output end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/trinsic_api/models/identity_data.rb', line 219 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/trinsic_api/models/identity_data.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/trinsic_api/models/identity_data.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/trinsic_api/models/identity_data.rb', line 40 def self.attribute_map { :'originating_provider_id' => :'originatingProviderId', :'originating_sub_provider_id' => :'originatingSubProviderId', :'person' => :'person', :'document' => :'document', :'match' => :'match', :'attachments' => :'attachments', :'provider_output' => :'providerOutput' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/trinsic_api/models/identity_data.rb', line 195 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 83 84 85 |
# File 'lib/trinsic_api/models/identity_data.rb', line 76 def self.openapi_nullable Set.new([ :'originating_provider_id', :'originating_sub_provider_id', :'person', :'document', :'match', :'provider_output' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/trinsic_api/models/identity_data.rb', line 63 def self.openapi_types { :'originating_provider_id' => :'String', :'originating_sub_provider_id' => :'String', :'person' => :'PersonData', :'document' => :'DocumentData', :'match' => :'MatchData', :'attachments' => :'Array<AttachmentInfo>', :'provider_output' => :'ProviderOutput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/trinsic_api/models/identity_data.rb', line 168 def ==(o) return true if self.equal?(o) self.class == o.class && originating_provider_id == o.originating_provider_id && originating_sub_provider_id == o.originating_sub_provider_id && person == o.person && document == o.document && match == o.match && == o. && provider_output == o.provider_output end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/trinsic_api/models/identity_data.rb', line 290 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
182 183 184 |
# File 'lib/trinsic_api/models/identity_data.rb', line 182 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
188 189 190 |
# File 'lib/trinsic_api/models/identity_data.rb', line 188 def hash [originating_provider_id, originating_sub_provider_id, person, document, match, , provider_output].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 |
# File 'lib/trinsic_api/models/identity_data.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @attachments.nil? invalid_properties.push('invalid value for "attachments", attachments cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
266 267 268 |
# File 'lib/trinsic_api/models/identity_data.rb', line 266 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/trinsic_api/models/identity_data.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
260 261 262 |
# File 'lib/trinsic_api/models/identity_data.rb', line 260 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 |
# File 'lib/trinsic_api/models/identity_data.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @attachments.nil? true end |