Class: TrinsicApi::IndiaDigilockerAadhaarMatchProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::IndiaDigilockerAadhaarMatchProviderOutput
- Defined in:
- lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb
Overview
Exposed properties for the india-digilocker-aadhaar-match Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#date_of_birth ⇒ Object
Date of birth submitted for this DigiLocker Aadhaar match and whether it matched the issuer record for this session.
-
#full_name ⇒ Object
Full name submitted for this DigiLocker Aadhaar match and the similarity score returned for that value.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IndiaDigilockerAadhaarMatchProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IndiaDigilockerAadhaarMatchProviderOutput
Initializes the object
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 61 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IndiaDigilockerAadhaarMatchProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IndiaDigilockerAadhaarMatchProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end end |
Instance Attribute Details
#date_of_birth ⇒ Object
Date of birth submitted for this DigiLocker Aadhaar match and whether it matched the issuer record for this session.
23 24 25 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 23 def date_of_birth @date_of_birth end |
#full_name ⇒ Object
Full name submitted for this DigiLocker Aadhaar match and the similarity score returned for that value.
20 21 22 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 20 def full_name @full_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 26 def self.attribute_map { :'full_name' => :'fullName', :'date_of_birth' => :'dateOfBirth' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 123 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 56 57 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 52 def self.openapi_nullable Set.new([ :'full_name', :'date_of_birth' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 44 def self.openapi_types { :'full_name' => :'IndiaDigilockerAadhaarMatchFullNameField', :'date_of_birth' => :'IndiaDigilockerAadhaarMatchDateOfBirthField' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
101 102 103 104 105 106 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 101 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && date_of_birth == o.date_of_birth end |
#eql?(o) ⇒ Boolean
110 111 112 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 110 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
116 117 118 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 116 def hash [full_name, date_of_birth].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
86 87 88 89 90 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 86 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 145 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
94 95 96 97 |
# File 'lib/trinsic_api/models/india_digilocker_aadhaar_match_provider_output.rb', line 94 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |