Class: TrinsicApi::IndiaPanLookupProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/india_pan_lookup_provider_output.rb

Overview

Exposed properties for the ‘india-pan-lookup` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IndiaPanLookupProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IndiaPanLookupProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IndiaPanLookupProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'permanent_account_number')
    self. = attributes[:'permanent_account_number']
  end

  if attributes.key?(:'structured_permanent_account_number')
    self. = attributes[:'structured_permanent_account_number']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'pan_status')
    self.pan_status = attributes[:'pan_status']
  end
end

Instance Attribute Details

#date_of_birthObject

Date of birth of the individual. NOTE: Only available when PAN status is VALID and the verification is for an individual person.



38
39
40
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 38

def date_of_birth
  @date_of_birth
end

#family_nameObject

Family name of the individual. NOTE: Only available when PAN status is VALID and the verification is for an individual person.



35
36
37
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 35

def family_name
  @family_name
end

#full_nameObject

Full name of the entity subject to income tax. NOTE: Only available when PAN status is VALID.



26
27
28
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 26

def full_name
  @full_name
end

#given_nameObject

Given name of the individual. NOTE: Only available when PAN status is VALID and the verification is for an individual person.



29
30
31
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 29

def given_name
  @given_name
end

#middle_nameObject

Middle name of the individual. NOTE: Only available when PAN status is VALID and the verification is for an individual person.



32
33
34
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 32

def middle_name
  @middle_name
end

#pan_statusObject

PAN card status from Signzy for the lookup. Possible values: - VALID - FAKE - DEACTIVATED - DELETED - INVALID - AMALGAMATION - ACQUISITION - DEATH - DISSOLUTION - LIQUIDATED - MERGER - PARTITION - SPLIT - UNDER LIQUIDATION - INOPERATIVE



41
42
43
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 41

def pan_status
  @pan_status
end

#permanent_account_numberObject

Permanent Account Number (PAN) that was looked up. PAN is a ten-character identifier issued by the Income Tax Department of India.



20
21
22
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 20

def 
  @permanent_account_number
end

#structured_permanent_account_numberObject

PAN split into structural parts for the canonical ten-character format. Covers alphabetic series, assessee category, name prefix letter, serial number, and check letter.



23
24
25
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 23

def 
  @structured_permanent_account_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 44

def self.attribute_map
  {
    :'permanent_account_number' => :'permanentAccountNumber',
    :'structured_permanent_account_number' => :'structuredPermanentAccountNumber',
    :'full_name' => :'fullName',
    :'given_name' => :'givenName',
    :'middle_name' => :'middleName',
    :'family_name' => :'familyName',
    :'date_of_birth' => :'dateOfBirth',
    :'pan_status' => :'panStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 82

def self.openapi_nullable
  Set.new([
    :'permanent_account_number',
    :'structured_permanent_account_number',
    :'full_name',
    :'given_name',
    :'middle_name',
    :'family_name',
    :'date_of_birth',
    :'pan_status'
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 68

def self.openapi_types
  {
    :'permanent_account_number' => :'String',
    :'structured_permanent_account_number' => :'IndiaPanStructuredNumber',
    :'full_name' => :'String',
    :'given_name' => :'String',
    :'middle_name' => :'String',
    :'family_name' => :'String',
    :'date_of_birth' => :'String',
    :'pan_status' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
      full_name == o.full_name &&
      given_name == o.given_name &&
      middle_name == o.middle_name &&
      family_name == o.family_name &&
      date_of_birth == o.date_of_birth &&
      pan_status == o.pan_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 182

def hash
  [, , full_name, given_name, middle_name, family_name, date_of_birth, pan_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
# File 'lib/trinsic_api/models/india_pan_lookup_provider_output.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end