Class: TrinsicApi::IndonesiaDukcapilMatchInput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/indonesia_dukcapil_match_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IndonesiaDukcapilMatchInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IndonesiaDukcapilMatchInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IndonesiaDukcapilMatchInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'nik_id_number')
    self.nik_id_number = attributes[:'nik_id_number']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'selfie_image')
    self.selfie_image = attributes[:'selfie_image']
  end

  if attributes.key?(:'document_image')
    self.document_image = attributes[:'document_image']
  end

  if attributes.key?(:'consent_given_at')
    self.consent_given_at = attributes[:'consent_given_at']
  end
end

Instance Attribute Details

The timestamp when consent was given by the user for the verification.



40
41
42
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 40

def consent_given_at
  @consent_given_at
end

#date_of_birthObject

The user’s date of birth, in ‘YYYY-MM-DD` format



22
23
24
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 22

def date_of_birth
  @date_of_birth
end

#document_imageObject

The raw bytes of the image of the individual’s KTP government ID. Must be JPEG format; 1MB maximum. Optional.



37
38
39
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 37

def document_image
  @document_image
end

#emailObject

The email address of the individual. Either email or phone number must be provided.



28
29
30
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 28

def email
  @email
end

#full_nameObject

The user’s full name



19
20
21
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 19

def full_name
  @full_name
end

#nik_id_numberObject

The user’s Indonesia NIK ID number



25
26
27
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 25

def nik_id_number
  @nik_id_number
end

#phone_numberObject

The phone number of the individual. Either email or phone number must be provided.



31
32
33
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 31

def phone_number
  @phone_number
end

#selfie_imageObject

The raw bytes of the selfie image of the individual. Must be JPEG or PNG format; 10MB maximum.



34
35
36
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 34

def selfie_image
  @selfie_image
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 43

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'date_of_birth' => :'dateOfBirth',
    :'nik_id_number' => :'nikIdNumber',
    :'email' => :'email',
    :'phone_number' => :'phoneNumber',
    :'selfie_image' => :'selfieImage',
    :'document_image' => :'documentImage',
    :'consent_given_at' => :'consentGivenAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 81

def self.openapi_nullable
  Set.new([
    :'full_name',
    :'date_of_birth',
    :'nik_id_number',
    :'email',
    :'phone_number',
    :'selfie_image',
    :'document_image',
    :'consent_given_at'
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 67

def self.openapi_types
  {
    :'full_name' => :'String',
    :'date_of_birth' => :'Date',
    :'nik_id_number' => :'String',
    :'email' => :'String',
    :'phone_number' => :'String',
    :'selfie_image' => :'String',
    :'document_image' => :'String',
    :'consent_given_at' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 160

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      date_of_birth == o.date_of_birth &&
      nik_id_number == o.nik_id_number &&
      email == o.email &&
      phone_number == o.phone_number &&
      selfie_image == o.selfie_image &&
      document_image == o.document_image &&
      consent_given_at == o.consent_given_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 181

def hash
  [full_name, date_of_birth, nik_id_number, email, phone_number, selfie_image, document_image, consent_given_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



145
146
147
148
149
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 145

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



153
154
155
156
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_input.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end