Class: TrinsicApi::IndonesiaDukcapilMatchNationalIdNumberField
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::IndonesiaDukcapilMatchNationalIdNumberField
- Defined in:
- lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb
Instance Attribute Summary collapse
-
#input_value ⇒ Object
The NIK (Nomor Induk Kependudukan) submitted for this check.
-
#outcome ⇒ Object
The provider assessment result for the submitted NIK.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IndonesiaDukcapilMatchNationalIdNumberField
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IndonesiaDukcapilMatchNationalIdNumberField
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IndonesiaDukcapilMatchNationalIdNumberField` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IndonesiaDukcapilMatchNationalIdNumberField`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'input_value') self.input_value = attributes[:'input_value'] end if attributes.key?(:'outcome') self.outcome = attributes[:'outcome'] end end |
Instance Attribute Details
#input_value ⇒ Object
The NIK (Nomor Induk Kependudukan) submitted for this check. NIK is Indonesia's unique population identity number, issued by Indonesia's population administration and civil registration authority (Dukcapil) under the Ministry of Home Affairs. Format: - 16 numeric digits. - Digits 1-2 are the province code. - Digits 3-4 are the regency or city code within that province. - Digits 5-6 are the district code within that regency or city. - Digits 7-12 encode date of birth as DDMMYY. For female NIK holders, the day is increased by 40. - Digits 13-16 are an issuance serial number.
19 20 21 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 19 def input_value @input_value end |
#outcome ⇒ Object
The provider assessment result for the submitted NIK. Local integration code expects the provider to return 0 or 1 for this assessment.
22 23 24 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 22 def outcome @outcome end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
33 34 35 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 33 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
38 39 40 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 38 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
25 26 27 28 29 30 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 25 def self.attribute_map { :'input_value' => :'inputValue', :'outcome' => :'outcome' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 122 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
51 52 53 54 55 56 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 51 def self.openapi_nullable Set.new([ :'input_value', :'outcome' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
43 44 45 46 47 48 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 43 def self.openapi_types { :'input_value' => :'String', :'outcome' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
100 101 102 103 104 105 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 100 def ==(o) return true if self.equal?(o) self.class == o.class && input_value == o.input_value && outcome == o.outcome end |
#eql?(o) ⇒ Boolean
109 110 111 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 109 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
115 116 117 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 115 def hash [input_value, outcome].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
85 86 87 88 89 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 85 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 144 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
93 94 95 96 |
# File 'lib/trinsic_api/models/indonesia_dukcapil_match_national_id_number_field.rb', line 93 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |