Class: TrinsicApi::IndonesiaNikInput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/indonesia_nik_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IndonesiaNikInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 63

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IndonesiaNikInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IndonesiaNikInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  else
    self.full_name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  else
    self.date_of_birth = nil
  end

  if attributes.key?(:'nik_id_number')
    self.nik_id_number = attributes[:'nik_id_number']
  else
    self.nik_id_number = nil
  end
end

Instance Attribute Details

#date_of_birthObject

The user’s date of birth, in ‘YYYY-MM-DD` format



22
23
24
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 22

def date_of_birth
  @date_of_birth
end

#full_nameObject

The user’s full name



19
20
21
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 19

def full_name
  @full_name
end

#nik_id_numberObject

The user’s Indonesia NIK ID number



25
26
27
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 25

def nik_id_number
  @nik_id_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



37
38
39
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 37

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



42
43
44
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 42

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



28
29
30
31
32
33
34
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 28

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'date_of_birth' => :'dateOfBirth',
    :'nik_id_number' => :'nikIdNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 219

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



56
57
58
59
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 56

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



47
48
49
50
51
52
53
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 47

def self.openapi_types
  {
    :'full_name' => :'String',
    :'date_of_birth' => :'Date',
    :'nik_id_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



196
197
198
199
200
201
202
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 196

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      date_of_birth == o.date_of_birth &&
      nik_id_number == o.nik_id_number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


206
207
208
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 206

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



212
213
214
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 212

def hash
  [full_name, date_of_birth, nik_id_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 98

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @full_name.nil?
    invalid_properties.push('invalid value for "full_name", full_name cannot be nil.')
  end

  if @full_name.to_s.length < 1
    invalid_properties.push('invalid value for "full_name", the character length must be greater than or equal to 1.')
  end

  if @date_of_birth.nil?
    invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.')
  end

  if @nik_id_number.nil?
    invalid_properties.push('invalid value for "nik_id_number", nik_id_number cannot be nil.')
  end

  if @nik_id_number.to_s.length > 16
    invalid_properties.push('invalid value for "nik_id_number", the character length must be smaller than or equal to 16.')
  end

  if @nik_id_number.to_s.length < 16
    invalid_properties.push('invalid value for "nik_id_number", the character length must be greater than or equal to 16.')
  end

  pattern = Regexp.new(/^\d*$/)
  if @nik_id_number !~ pattern
    invalid_properties.push("invalid value for \"nik_id_number\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 241

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
140
141
142
143
144
145
# File 'lib/trinsic_api/models/indonesia_nik_input.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @full_name.nil?
  return false if @full_name.to_s.length < 1
  return false if @date_of_birth.nil?
  return false if @nik_id_number.nil?
  return false if @nik_id_number.to_s.length > 16
  return false if @nik_id_number.to_s.length < 16
  return false if @nik_id_number !~ Regexp.new(/^\d*$/)
  true
end