Class: TrinsicApi::InteracProviderOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/interac_provider_output.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InteracProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::InteracProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::InteracProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sub')
    self.sub = attributes[:'sub']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end
end

Instance Attribute Details

#addressObject

The verified address.



43
44
45
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 43

def address
  @address
end

#date_of_birthObject

The date of birth of the verified individual.



34
35
36
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 34

def date_of_birth
  @date_of_birth
end

#emailObject

The email address of the verified individual.



37
38
39
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 37

def email
  @email
end

#family_nameObject

The family name of the verified individual.



28
29
30
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 28

def family_name
  @family_name
end

#given_nameObject

The given name of the verified individual.



22
23
24
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 22

def given_name
  @given_name
end

#middle_nameObject

The middle name of the verified individual.



25
26
27
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 25

def middle_name
  @middle_name
end

#phone_numberObject

The phone number of the verified individual in E.164 format.



40
41
42
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 40

def phone_number
  @phone_number
end

#subObject

The OpenID Connect subject identifier for the verified individual.



19
20
21
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 19

def sub
  @sub
end

#titleObject

The title or honorific of the verified individual, when supplied by the source.



31
32
33
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 31

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 46

def self.attribute_map
  {
    :'sub' => :'sub',
    :'given_name' => :'givenName',
    :'middle_name' => :'middleName',
    :'family_name' => :'familyName',
    :'title' => :'title',
    :'date_of_birth' => :'dateOfBirth',
    :'email' => :'email',
    :'phone_number' => :'phoneNumber',
    :'address' => :'address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 86

def self.openapi_nullable
  Set.new([
    :'sub',
    :'given_name',
    :'middle_name',
    :'family_name',
    :'title',
    :'date_of_birth',
    :'email',
    :'phone_number',
    :'address'
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 71

def self.openapi_types
  {
    :'sub' => :'String',
    :'given_name' => :'String',
    :'middle_name' => :'String',
    :'family_name' => :'String',
    :'title' => :'String',
    :'date_of_birth' => :'Date',
    :'email' => :'String',
    :'phone_number' => :'String',
    :'address' => :'InteracAddress'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sub == o.sub &&
      given_name == o.given_name &&
      middle_name == o.middle_name &&
      family_name == o.family_name &&
      title == o.title &&
      date_of_birth == o.date_of_birth &&
      email == o.email &&
      phone_number == o.phone_number &&
      address == o.address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 186

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



192
193
194
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 192

def hash
  [sub, given_name, middle_name, family_name, title, date_of_birth, email, phone_number, address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



155
156
157
158
159
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 155

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
# File 'lib/trinsic_api/models/interac_provider_output.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end