Class: TrinsicApi::Iso180135AamvaNamespaceOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/iso180135_aamva_namespace_output.rb

Overview

Fields from the AAMVA mDL namespace.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Iso180135AamvaNamespaceOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 211

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Iso180135AamvaNamespaceOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Iso180135AamvaNamespaceOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'domestic_driving_privileges')
    if (value = attributes[:'domestic_driving_privileges']).is_a?(Array)
      self.domestic_driving_privileges = value
    end
  end

  if attributes.key?(:'name_suffix')
    self.name_suffix = attributes[:'name_suffix']
  end

  if attributes.key?(:'organ_donor')
    self.organ_donor = attributes[:'organ_donor']
  end

  if attributes.key?(:'veteran')
    self.veteran = attributes[:'veteran']
  end

  if attributes.key?(:'family_name_truncation')
    self.family_name_truncation = attributes[:'family_name_truncation']
  end

  if attributes.key?(:'given_name_truncation')
    self.given_name_truncation = attributes[:'given_name_truncation']
  end

  if attributes.key?(:'aka_family_name_v2')
    self.aka_family_name_v2 = attributes[:'aka_family_name_v2']
  end

  if attributes.key?(:'aka_given_name_v2')
    self.aka_given_name_v2 = attributes[:'aka_given_name_v2']
  end

  if attributes.key?(:'aka_suffix')
    self.aka_suffix = attributes[:'aka_suffix']
  end

  if attributes.key?(:'weight_range')
    self.weight_range = attributes[:'weight_range']
  end

  if attributes.key?(:'race_ethnicity')
    self.race_ethnicity = attributes[:'race_ethnicity']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'middle_names')
    self.middle_names = attributes[:'middle_names']
  end

  if attributes.key?(:'first_name_truncation')
    self.first_name_truncation = attributes[:'first_name_truncation']
  end

  if attributes.key?(:'middle_names_truncation')
    self.middle_names_truncation = attributes[:'middle_names_truncation']
  end

  if attributes.key?(:'edl_credential')
    self.edl_credential = attributes[:'edl_credential']
  end

  if attributes.key?(:'edl_credential_v2')
    self.edl_credential_v2 = attributes[:'edl_credential_v2']
  end

  if attributes.key?(:'dhs_compliance')
    self.dhs_compliance = attributes[:'dhs_compliance']
  end

  if attributes.key?(:'resident_county')
    self.resident_county = attributes[:'resident_county']
  end

  if attributes.key?(:'resident_county_v2')
    self.resident_county_v2 = attributes[:'resident_county_v2']
  end

  if attributes.key?(:'hazmat_endorsement_expiration_date')
    self.hazmat_endorsement_expiration_date = attributes[:'hazmat_endorsement_expiration_date']
  end

  if attributes.key?(:'cdl_indicator')
    self.cdl_indicator = attributes[:'cdl_indicator']
  end

  if attributes.key?(:'cdl_non_domiciled')
    self.cdl_non_domiciled = attributes[:'cdl_non_domiciled']
  end

  if attributes.key?(:'cdl_non_domiciled_v2')
    self.cdl_non_domiciled_v2 = attributes[:'cdl_non_domiciled_v2']
  end

  if attributes.key?(:'dhs_compliance_text')
    self.dhs_compliance_text = attributes[:'dhs_compliance_text']
  end

  if attributes.key?(:'dhs_temporary_lawful_status')
    self.dhs_temporary_lawful_status = attributes[:'dhs_temporary_lawful_status']
  end
end

Instance Attribute Details

#aka_family_name_v2Object

Other family name by which the individual is known.



38
39
40
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 38

def aka_family_name_v2
  @aka_family_name_v2
end

#aka_given_name_v2Object

Other given name by which the individual is known.



41
42
43
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 41

def aka_given_name_v2
  @aka_given_name_v2
end

#aka_suffixObject

Other suffix by which the individual is known.



44
45
46
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 44

def aka_suffix
  @aka_suffix
end

#cdl_indicatorObject

Whether the credential is a Commercial Driver’s License (CDL) per FMCSA.



86
87
88
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 86

def cdl_indicator
  @cdl_indicator
end

#cdl_non_domiciledObject

Deprecated. Whether the CDL holder is non-domiciled in the issuing jurisdiction.



89
90
91
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 89

def cdl_non_domiciled
  @cdl_non_domiciled
end

#cdl_non_domiciled_v2Object

Whether the CDL holder is non-domiciled in the issuing jurisdiction.



92
93
94
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 92

def cdl_non_domiciled_v2
  @cdl_non_domiciled_v2
end

#dhs_complianceObject

Whether the credential is REAL ID compliant. ‘true` for fully compliant ("F"), `false` for non-compliant ("N"), `null` when not present.



74
75
76
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 74

def dhs_compliance
  @dhs_compliance
end

#dhs_compliance_textObject

Text agreed on between the issuing authority and DHS for non-compliant credentials.



95
96
97
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 95

def dhs_compliance_text
  @dhs_compliance_text
end

#dhs_temporary_lawful_statusObject

Whether the individual has DHS temporary lawful status.



98
99
100
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 98

def dhs_temporary_lawful_status
  @dhs_temporary_lawful_status
end

#domestic_driving_privilegesObject

Domestic categories of vehicles, restrictions, and conditions, parsed per AAMVA Section 7.2.4.



20
21
22
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 20

def domestic_driving_privileges
  @domestic_driving_privileges
end

#edl_credentialObject

Deprecated AAMVA EDL (Enhanced Driver’s License) credential indicator. If present, indicates the type of the EDL credential. Possible values: 1: Driver’s License 2: Identification Card



68
69
70
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 68

def edl_credential
  @edl_credential
end

#edl_credential_v2Object

Whether the credential is an Enhanced Driver’s License (EDL).



71
72
73
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 71

def edl_credential_v2
  @edl_credential_v2
end

#family_name_truncationObject

Indicates whether the family name has been truncated. Possible values: - ‘T’: Truncated - ‘N’: Not truncated - ‘U’: Unknown whether truncated



32
33
34
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 32

def family_name_truncation
  @family_name_truncation
end

#first_nameObject

First name of the individual.



56
57
58
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 56

def first_name
  @first_name
end

#first_name_truncationObject

Whether the first name has been truncated.



62
63
64
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 62

def first_name_truncation
  @first_name_truncation
end

#given_name_truncationObject

Indicates whether the given name has been truncated. Possible values: - ‘T’: Truncated - ‘N’: Not truncated - ‘U’: Unknown whether truncated



35
36
37
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 35

def given_name_truncation
  @given_name_truncation
end

#hazmat_endorsement_expiration_dateObject

Date on which the hazardous material endorsement expires.



83
84
85
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 83

def hazmat_endorsement_expiration_date
  @hazmat_endorsement_expiration_date
end

#middle_namesObject

Middle name or names of the individual.



59
60
61
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 59

def middle_names
  @middle_names
end

#middle_names_truncationObject

Whether the middle name has been truncated.



65
66
67
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 65

def middle_names_truncation
  @middle_names_truncation
end

#name_suffixObject

Name suffix of the individual that has been issued the credential.



23
24
25
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 23

def name_suffix
  @name_suffix
end

#organ_donorObject

Whether the individual is an organ donor.



26
27
28
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 26

def organ_donor
  @organ_donor
end

#race_ethnicityObject

AAMVA D20 race or ethnicity code of the individual.



50
51
52
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 50

def race_ethnicity
  @race_ethnicity
end

#resident_countyObject

Deprecated county code for the county where the individual lives.



77
78
79
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 77

def resident_county
  @resident_county
end

#resident_county_v2Object

County code for the county where the individual lives.



80
81
82
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 80

def resident_county_v2
  @resident_county_v2
end

#sexObject

The sex of the individual as an AAMVA-defined sex code. This is distinct from an ISO/IEC 5218 sex code in two ways: there is no "Unknown" value, and "Not Applicable" is replaced with "Not Specified". Possible values: - 1: Male - 2: Female - 9: Not Specified



53
54
55
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 53

def sex
  @sex
end

#veteranObject

Whether the individual is a veteran.



29
30
31
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 29

def veteran
  @veteran
end

#weight_rangeObject

Approximate weight range of the individual, in kilograms.



47
48
49
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 47

def weight_range
  @weight_range
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



134
135
136
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 134

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



139
140
141
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 139

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 101

def self.attribute_map
  {
    :'domestic_driving_privileges' => :'domesticDrivingPrivileges',
    :'name_suffix' => :'nameSuffix',
    :'organ_donor' => :'organDonor',
    :'veteran' => :'veteran',
    :'family_name_truncation' => :'familyNameTruncation',
    :'given_name_truncation' => :'givenNameTruncation',
    :'aka_family_name_v2' => :'akaFamilyNameV2',
    :'aka_given_name_v2' => :'akaGivenNameV2',
    :'aka_suffix' => :'akaSuffix',
    :'weight_range' => :'weightRange',
    :'race_ethnicity' => :'raceEthnicity',
    :'sex' => :'sex',
    :'first_name' => :'firstName',
    :'middle_names' => :'middleNames',
    :'first_name_truncation' => :'firstNameTruncation',
    :'middle_names_truncation' => :'middleNamesTruncation',
    :'edl_credential' => :'edlCredential',
    :'edl_credential_v2' => :'edlCredentialV2',
    :'dhs_compliance' => :'dhsCompliance',
    :'resident_county' => :'residentCounty',
    :'resident_county_v2' => :'residentCountyV2',
    :'hazmat_endorsement_expiration_date' => :'hazmatEndorsementExpirationDate',
    :'cdl_indicator' => :'cdlIndicator',
    :'cdl_non_domiciled' => :'cdlNonDomiciled',
    :'cdl_non_domiciled_v2' => :'cdlNonDomiciledV2',
    :'dhs_compliance_text' => :'dhsComplianceText',
    :'dhs_temporary_lawful_status' => :'dhsTemporaryLawfulStatus'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 400

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 177

def self.openapi_nullable
  Set.new([
    :'domestic_driving_privileges',
    :'name_suffix',
    :'organ_donor',
    :'veteran',
    :'family_name_truncation',
    :'given_name_truncation',
    :'aka_family_name_v2',
    :'aka_given_name_v2',
    :'aka_suffix',
    :'weight_range',
    :'race_ethnicity',
    :'sex',
    :'first_name',
    :'middle_names',
    :'first_name_truncation',
    :'middle_names_truncation',
    :'edl_credential',
    :'edl_credential_v2',
    :'dhs_compliance',
    :'resident_county',
    :'resident_county_v2',
    :'hazmat_endorsement_expiration_date',
    :'cdl_indicator',
    :'cdl_non_domiciled',
    :'cdl_non_domiciled_v2',
    :'dhs_compliance_text',
    :'dhs_temporary_lawful_status'
  ])
end

.openapi_typesObject

Attribute type mapping.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 144

def self.openapi_types
  {
    :'domestic_driving_privileges' => :'Array<Iso180135AamvaDomesticDrivingPrivilege>',
    :'name_suffix' => :'String',
    :'organ_donor' => :'Boolean',
    :'veteran' => :'Boolean',
    :'family_name_truncation' => :'String',
    :'given_name_truncation' => :'String',
    :'aka_family_name_v2' => :'String',
    :'aka_given_name_v2' => :'String',
    :'aka_suffix' => :'String',
    :'weight_range' => :'Iso180135AamvaWeightRange',
    :'race_ethnicity' => :'String',
    :'sex' => :'Integer',
    :'first_name' => :'String',
    :'middle_names' => :'String',
    :'first_name_truncation' => :'String',
    :'middle_names_truncation' => :'String',
    :'edl_credential' => :'Integer',
    :'edl_credential_v2' => :'Boolean',
    :'dhs_compliance' => :'Boolean',
    :'resident_county' => :'String',
    :'resident_county_v2' => :'String',
    :'hazmat_endorsement_expiration_date' => :'Date',
    :'cdl_indicator' => :'Boolean',
    :'cdl_non_domiciled' => :'Boolean',
    :'cdl_non_domiciled_v2' => :'Boolean',
    :'dhs_compliance_text' => :'String',
    :'dhs_temporary_lawful_status' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 353

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      domestic_driving_privileges == o.domestic_driving_privileges &&
      name_suffix == o.name_suffix &&
      organ_donor == o.organ_donor &&
      veteran == o.veteran &&
      family_name_truncation == o.family_name_truncation &&
      given_name_truncation == o.given_name_truncation &&
      aka_family_name_v2 == o.aka_family_name_v2 &&
      aka_given_name_v2 == o.aka_given_name_v2 &&
      aka_suffix == o.aka_suffix &&
      weight_range == o.weight_range &&
      race_ethnicity == o.race_ethnicity &&
      sex == o.sex &&
      first_name == o.first_name &&
      middle_names == o.middle_names &&
      first_name_truncation == o.first_name_truncation &&
      middle_names_truncation == o.middle_names_truncation &&
      edl_credential == o.edl_credential &&
      edl_credential_v2 == o.edl_credential_v2 &&
      dhs_compliance == o.dhs_compliance &&
      resident_county == o.resident_county &&
      resident_county_v2 == o.resident_county_v2 &&
      hazmat_endorsement_expiration_date == o.hazmat_endorsement_expiration_date &&
      cdl_indicator == o.cdl_indicator &&
      cdl_non_domiciled == o.cdl_non_domiciled &&
      cdl_non_domiciled_v2 == o.cdl_non_domiciled_v2 &&
      dhs_compliance_text == o.dhs_compliance_text &&
      dhs_temporary_lawful_status == o.dhs_temporary_lawful_status
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


387
388
389
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 387

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



393
394
395
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 393

def hash
  [domestic_driving_privileges, name_suffix, organ_donor, veteran, family_name_truncation, given_name_truncation, aka_family_name_v2, aka_given_name_v2, aka_suffix, weight_range, race_ethnicity, sex, first_name, middle_names, first_name_truncation, middle_names_truncation, edl_credential, edl_credential_v2, dhs_compliance, resident_county, resident_county_v2, hazmat_endorsement_expiration_date, cdl_indicator, cdl_non_domiciled, cdl_non_domiciled_v2, dhs_compliance_text, dhs_temporary_lawful_status].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



338
339
340
341
342
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 338

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 422

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



346
347
348
349
# File 'lib/trinsic_api/models/iso180135_aamva_namespace_output.rb', line 346

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end