Class: TrinsicApi::Iso180135DrivingPrivilege
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::Iso180135DrivingPrivilege
- Defined in:
- lib/trinsic_api/models/iso180135_driving_privilege.rb
Overview
A single driving privilege entry from the mDL ‘driving_privileges` field, per ISO 18013-5.
Instance Attribute Summary collapse
-
#codes ⇒ Object
Restriction, condition, or special privilege codes attached to this entry.
-
#expiry_date ⇒ Object
Date when this driving privilege expires.
-
#issue_date ⇒ Object
Date when this driving privilege was issued.
-
#vehicle_category_code ⇒ Object
Vehicle category code that the holder is authorized to operate.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Iso180135DrivingPrivilege
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Iso180135DrivingPrivilege
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Iso180135DrivingPrivilege` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Iso180135DrivingPrivilege`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'vehicle_category_code') self.vehicle_category_code = attributes[:'vehicle_category_code'] else self.vehicle_category_code = nil end if attributes.key?(:'issue_date') self.issue_date = attributes[:'issue_date'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'codes') if (value = attributes[:'codes']).is_a?(Array) self.codes = value end end end |
Instance Attribute Details
#codes ⇒ Object
Restriction, condition, or special privilege codes attached to this entry.
29 30 31 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 29 def codes @codes end |
#expiry_date ⇒ Object
Date when this driving privilege expires.
26 27 28 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 26 def expiry_date @expiry_date end |
#issue_date ⇒ Object
Date when this driving privilege was issued.
23 24 25 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 23 def issue_date @issue_date end |
#vehicle_category_code ⇒ Object
Vehicle category code that the holder is authorized to operate.
20 21 22 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 20 def vehicle_category_code @vehicle_category_code end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 32 def self.attribute_map { :'vehicle_category_code' => :'vehicleCategoryCode', :'issue_date' => :'issueDate', :'expiry_date' => :'expiryDate', :'codes' => :'codes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 163 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 62 def self.openapi_nullable Set.new([ :'issue_date', :'expiry_date', :'codes' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 52 def self.openapi_types { :'vehicle_category_code' => :'String', :'issue_date' => :'Date', :'expiry_date' => :'Date', :'codes' => :'Array<Iso180135DrivingPrivilegeCode>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
139 140 141 142 143 144 145 146 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 139 def ==(o) return true if self.equal?(o) self.class == o.class && vehicle_category_code == o.vehicle_category_code && issue_date == o.issue_date && expiry_date == o.expiry_date && codes == o.codes end |
#eql?(o) ⇒ Boolean
150 151 152 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 150 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
156 157 158 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 156 def hash [vehicle_category_code, issue_date, expiry_date, codes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 114 115 116 117 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @vehicle_category_code.nil? invalid_properties.push('invalid value for "vehicle_category_code", vehicle_category_code cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 185 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 125 |
# File 'lib/trinsic_api/models/iso180135_driving_privilege.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @vehicle_category_code.nil? true end |