Class: TrinsicApi::Iso180135StandardNamespaceOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/iso180135_standard_namespace_output.rb

Overview

Fields from the ISO 18013-5 standard mDL namespace.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Iso180135StandardNamespaceOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 259

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Iso180135StandardNamespaceOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Iso180135StandardNamespaceOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'given_name_national_character')
    self.given_name_national_character = attributes[:'given_name_national_character']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'family_name_national_character')
    self.family_name_national_character = attributes[:'family_name_national_character']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'issue_date')
    self.issue_date = attributes[:'issue_date']
  end

  if attributes.key?(:'expiry_date')
    self.expiry_date = attributes[:'expiry_date']
  end

  if attributes.key?(:'issuing_country')
    self.issuing_country = attributes[:'issuing_country']
  end

  if attributes.key?(:'issuing_authority')
    self.issuing_authority = attributes[:'issuing_authority']
  end

  if attributes.key?(:'issuing_jurisdiction')
    self.issuing_jurisdiction = attributes[:'issuing_jurisdiction']
  end

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  end

  if attributes.key?(:'driving_privileges')
    if (value = attributes[:'driving_privileges']).is_a?(Array)
      self.driving_privileges = value
    end
  end

  if attributes.key?(:'un_distinguishing_sign')
    self.un_distinguishing_sign = attributes[:'un_distinguishing_sign']
  end

  if attributes.key?(:'administrative_number')
    self.administrative_number = attributes[:'administrative_number']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'height_centimeters')
    self.height_centimeters = attributes[:'height_centimeters']
  end

  if attributes.key?(:'weight_kilograms')
    self.weight_kilograms = attributes[:'weight_kilograms']
  end

  if attributes.key?(:'eye_color')
    self.eye_color = attributes[:'eye_color']
  end

  if attributes.key?(:'hair_color')
    self.hair_color = attributes[:'hair_color']
  end

  if attributes.key?(:'birth_place')
    self.birth_place = attributes[:'birth_place']
  end

  if attributes.key?(:'resident_address')
    self.resident_address = attributes[:'resident_address']
  end

  if attributes.key?(:'resident_city')
    self.resident_city = attributes[:'resident_city']
  end

  if attributes.key?(:'resident_state')
    self.resident_state = attributes[:'resident_state']
  end

  if attributes.key?(:'resident_postal_code')
    self.resident_postal_code = attributes[:'resident_postal_code']
  end

  if attributes.key?(:'resident_country')
    self.resident_country = attributes[:'resident_country']
  end

  if attributes.key?(:'portrait_capture_date')
    self.portrait_capture_date = attributes[:'portrait_capture_date']
  end

  if attributes.key?(:'age_in_years')
    self.age_in_years = attributes[:'age_in_years']
  end

  if attributes.key?(:'age_birth_year')
    self.age_birth_year = attributes[:'age_birth_year']
  end

  if attributes.key?(:'age_over')
    if (value = attributes[:'age_over']).is_a?(Array)
      self.age_over = value
    end
  end

  if attributes.key?(:'biometric_template_face')
    self.biometric_template_face = attributes[:'biometric_template_face']
  end

  if attributes.key?(:'biometric_template_voice')
    self.biometric_template_voice = attributes[:'biometric_template_voice']
  end

  if attributes.key?(:'biometric_template_finger')
    self.biometric_template_finger = attributes[:'biometric_template_finger']
  end

  if attributes.key?(:'biometric_template_iris')
    self.biometric_template_iris = attributes[:'biometric_template_iris']
  end

  if attributes.key?(:'biometric_template_retina')
    self.biometric_template_retina = attributes[:'biometric_template_retina']
  end
end

Instance Attribute Details

#administrative_numberObject

Audit control number assigned by the issuing authority. The meaning and semantics of this field are defined by the issuing authority in question.



62
63
64
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 62

def administrative_number
  @administrative_number
end

#age_birth_yearObject

Year of birth of the individual.



104
105
106
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 104

def age_birth_year
  @age_birth_year
end

#age_in_yearsObject

Age of the individual in years.



101
102
103
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 101

def age_in_years
  @age_in_years
end

#age_overObject

Processed age-over claims returned by the mDL.



107
108
109
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 107

def age_over
  @age_over
end

#biometric_template_faceObject

Facial biometric template group from ‘biometric_template_face`, parsed per ISO 18013-2 Annex C.



110
111
112
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 110

def biometric_template_face
  @biometric_template_face
end

#biometric_template_fingerObject

Fingerprint biometric template group from ‘biometric_template_finger`, parsed per ISO 18013-2 Annex C.



116
117
118
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 116

def biometric_template_finger
  @biometric_template_finger
end

#biometric_template_irisObject

Iris biometric template group from ‘biometric_template_iris`, parsed per ISO 18013-2 Annex C.



119
120
121
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 119

def biometric_template_iris
  @biometric_template_iris
end

#biometric_template_retinaObject

Retinal biometric template group from ‘biometric_template_retina`, parsed per ISO 18013-2 Annex C.



122
123
124
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 122

def biometric_template_retina
  @biometric_template_retina
end

#biometric_template_voiceObject

Vocal biometric template group from ‘biometric_template_voice`, parsed per ISO 18013-2 Annex C.



113
114
115
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 113

def biometric_template_voice
  @biometric_template_voice
end

#birth_placeObject

Country and municipality or state/province where the individual was born.



80
81
82
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 80

def birth_place
  @birth_place
end

#date_of_birthObject

The date of birth of the individual.



32
33
34
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 32

def date_of_birth
  @date_of_birth
end

#document_numberObject

The document number assigned to the mDL. This is typically the same as the document number of the underlying physical document used to create the mDL, if one exists.



53
54
55
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 53

def document_number
  @document_number
end

#driving_privilegesObject

Driving privileges of the individual, parsed per ISO 18013-5.



56
57
58
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 56

def driving_privileges
  @driving_privileges
end

#expiry_dateObject

The date when the mDL expires. This date marks the end of the Administrative Validity Period of the mDL, which is usually (but not necessarily always) the same as the expiration date of the underlying physical document used to create the mDL, if one exists.



38
39
40
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 38

def expiry_date
  @expiry_date
end

#eye_colorObject

The individual’s eye color. Possible values: - "black" - "blue" - "brown" - "dichromatic" - "grey" - "green" - "hazel" - "maroon" - "pink" - "unknown"



74
75
76
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 74

def eye_color
  @eye_color
end

#family_nameObject

Last name, surname, or primary identifier of the individual.



26
27
28
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 26

def family_name
  @family_name
end

#family_name_national_characterObject

The family name of the individual using the full UTF-8 character set.



29
30
31
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 29

def family_name_national_character
  @family_name_national_character
end

#given_nameObject

First name(s), other name(s), or secondary identifier of the individual.



20
21
22
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 20

def given_name
  @given_name
end

#given_name_national_characterObject

The given name of the individual using the full UTF-8 character set.



23
24
25
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 23

def given_name_national_character
  @given_name_national_character
end

#hair_colorObject

The individual’s hair color. Possible values: - "bald" - "black" - "blond" - "brown" - "grey" - "red" - "auburn" - "sandy" - "white" - "unknown"



77
78
79
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 77

def hair_color
  @hair_color
end

#height_centimetersObject

The individual’s height in centimeters.



68
69
70
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 68

def height_centimeters
  @height_centimeters
end

#issue_dateObject

The date when the mDL was issued. This date marks the beginning of the Administrative Validity Period of the mDL, which is usually (but not necessarily always) the same as the issue date of the underlying physical document used to create the mDL, if one exists.



35
36
37
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 35

def issue_date
  @issue_date
end

#issuing_authorityObject

Name or identifier of the mDL issuing authority. This field’s contents are arbitrary; it has no guaranteed format.



44
45
46
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 44

def issuing_authority
  @issuing_authority
end

#issuing_countryObject

Alpha-2 country code of the issuing authority’s country or territory.



41
42
43
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 41

def issuing_country
  @issuing_country
end

#issuing_jurisdictionObject

ISO 3166-2 country-subdivision code for the jurisdiction that issued the mDL.



47
48
49
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 47

def issuing_jurisdiction
  @issuing_jurisdiction
end

#nationalityObject

Nationality of the individual as an ISO 3166-1 alpha-2 country code.



50
51
52
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 50

def nationality
  @nationality
end

#portrait_capture_dateObject

Date and time when the portrait image was captured.



98
99
100
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 98

def portrait_capture_date
  @portrait_capture_date
end

#resident_addressObject

Address where the individual resides. The exact format of this field is variable and depends on the issuer. It may map exactly to a "Line1", or it may include city, state, and/or zip code as well.



83
84
85
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 83

def resident_address
  @resident_address
end

#resident_cityObject

City where the individual resides.



86
87
88
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 86

def resident_city
  @resident_city
end

#resident_countryObject

Country where the individual resides as an ISO 3166-1 alpha-2 country code.



95
96
97
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 95

def resident_country
  @resident_country
end

#resident_postal_codeObject

Postal code where the individual resides.



92
93
94
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 92

def resident_postal_code
  @resident_postal_code
end

#resident_stateObject

State, province, or district where the individual resides.



89
90
91
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 89

def resident_state
  @resident_state
end

#sexObject

The individual’s sex as an ISO/IEC 5218 code. Possible values: - 0: Unknown - 1: Male - 2: Female - 9: Not Applicable



65
66
67
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 65

def sex
  @sex
end

#un_distinguishing_signObject

The UN Distinguishing sign of the issuing country according to ISO/IEC 18013-1.



59
60
61
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 59

def un_distinguishing_sign
  @un_distinguishing_sign
end

#weight_kilogramsObject

The individual’s weight in kilograms.



71
72
73
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 71

def weight_kilograms
  @weight_kilograms
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



166
167
168
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 166

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



171
172
173
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 171

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 125

def self.attribute_map
  {
    :'given_name' => :'givenName',
    :'given_name_national_character' => :'givenNameNationalCharacter',
    :'family_name' => :'familyName',
    :'family_name_national_character' => :'familyNameNationalCharacter',
    :'date_of_birth' => :'dateOfBirth',
    :'issue_date' => :'issueDate',
    :'expiry_date' => :'expiryDate',
    :'issuing_country' => :'issuingCountry',
    :'issuing_authority' => :'issuingAuthority',
    :'issuing_jurisdiction' => :'issuingJurisdiction',
    :'nationality' => :'nationality',
    :'document_number' => :'documentNumber',
    :'driving_privileges' => :'drivingPrivileges',
    :'un_distinguishing_sign' => :'unDistinguishingSign',
    :'administrative_number' => :'administrativeNumber',
    :'sex' => :'sex',
    :'height_centimeters' => :'heightCentimeters',
    :'weight_kilograms' => :'weightKilograms',
    :'eye_color' => :'eyeColor',
    :'hair_color' => :'hairColor',
    :'birth_place' => :'birthPlace',
    :'resident_address' => :'residentAddress',
    :'resident_city' => :'residentCity',
    :'resident_state' => :'residentState',
    :'resident_postal_code' => :'residentPostalCode',
    :'resident_country' => :'residentCountry',
    :'portrait_capture_date' => :'portraitCaptureDate',
    :'age_in_years' => :'ageInYears',
    :'age_birth_year' => :'ageBirthYear',
    :'age_over' => :'ageOver',
    :'biometric_template_face' => :'biometricTemplateFace',
    :'biometric_template_voice' => :'biometricTemplateVoice',
    :'biometric_template_finger' => :'biometricTemplateFinger',
    :'biometric_template_iris' => :'biometricTemplateIris',
    :'biometric_template_retina' => :'biometricTemplateRetina'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 490

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 217

def self.openapi_nullable
  Set.new([
    :'given_name',
    :'given_name_national_character',
    :'family_name',
    :'family_name_national_character',
    :'date_of_birth',
    :'issue_date',
    :'expiry_date',
    :'issuing_country',
    :'issuing_authority',
    :'issuing_jurisdiction',
    :'nationality',
    :'document_number',
    :'driving_privileges',
    :'un_distinguishing_sign',
    :'administrative_number',
    :'sex',
    :'height_centimeters',
    :'weight_kilograms',
    :'eye_color',
    :'hair_color',
    :'birth_place',
    :'resident_address',
    :'resident_city',
    :'resident_state',
    :'resident_postal_code',
    :'resident_country',
    :'portrait_capture_date',
    :'age_in_years',
    :'age_birth_year',
    :'age_over',
    :'biometric_template_face',
    :'biometric_template_voice',
    :'biometric_template_finger',
    :'biometric_template_iris',
    :'biometric_template_retina'
  ])
end

.openapi_typesObject

Attribute type mapping.



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 176

def self.openapi_types
  {
    :'given_name' => :'String',
    :'given_name_national_character' => :'String',
    :'family_name' => :'String',
    :'family_name_national_character' => :'String',
    :'date_of_birth' => :'Date',
    :'issue_date' => :'Date',
    :'expiry_date' => :'Date',
    :'issuing_country' => :'String',
    :'issuing_authority' => :'String',
    :'issuing_jurisdiction' => :'String',
    :'nationality' => :'String',
    :'document_number' => :'String',
    :'driving_privileges' => :'Array<Iso180135DrivingPrivilege>',
    :'un_distinguishing_sign' => :'String',
    :'administrative_number' => :'String',
    :'sex' => :'Integer',
    :'height_centimeters' => :'Integer',
    :'weight_kilograms' => :'Integer',
    :'eye_color' => :'String',
    :'hair_color' => :'String',
    :'birth_place' => :'String',
    :'resident_address' => :'String',
    :'resident_city' => :'String',
    :'resident_state' => :'String',
    :'resident_postal_code' => :'String',
    :'resident_country' => :'String',
    :'portrait_capture_date' => :'Time',
    :'age_in_years' => :'Integer',
    :'age_birth_year' => :'Integer',
    :'age_over' => :'Array<AgeOverOutput>',
    :'biometric_template_face' => :'Iso180132BiometricGroupTemplate',
    :'biometric_template_voice' => :'Iso180132BiometricGroupTemplate',
    :'biometric_template_finger' => :'Iso180132BiometricGroupTemplate',
    :'biometric_template_iris' => :'Iso180132BiometricGroupTemplate',
    :'biometric_template_retina' => :'Iso180132BiometricGroupTemplate'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 435

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      given_name == o.given_name &&
      given_name_national_character == o.given_name_national_character &&
      family_name == o.family_name &&
      family_name_national_character == o.family_name_national_character &&
      date_of_birth == o.date_of_birth &&
      issue_date == o.issue_date &&
      expiry_date == o.expiry_date &&
      issuing_country == o.issuing_country &&
      issuing_authority == o.issuing_authority &&
      issuing_jurisdiction == o.issuing_jurisdiction &&
      nationality == o.nationality &&
      document_number == o.document_number &&
      driving_privileges == o.driving_privileges &&
      un_distinguishing_sign == o.un_distinguishing_sign &&
      administrative_number == o.administrative_number &&
      sex == o.sex &&
      height_centimeters == o.height_centimeters &&
      weight_kilograms == o.weight_kilograms &&
      eye_color == o.eye_color &&
      hair_color == o.hair_color &&
      birth_place == o.birth_place &&
      resident_address == o.resident_address &&
      resident_city == o.resident_city &&
      resident_state == o.resident_state &&
      resident_postal_code == o.resident_postal_code &&
      resident_country == o.resident_country &&
      portrait_capture_date == o.portrait_capture_date &&
      age_in_years == o.age_in_years &&
      age_birth_year == o.age_birth_year &&
      age_over == o.age_over &&
      biometric_template_face == o.biometric_template_face &&
      biometric_template_voice == o.biometric_template_voice &&
      biometric_template_finger == o.biometric_template_finger &&
      biometric_template_iris == o.biometric_template_iris &&
      biometric_template_retina == o.biometric_template_retina
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


477
478
479
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 477

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



483
484
485
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 483

def hash
  [given_name, given_name_national_character, family_name, family_name_national_character, date_of_birth, issue_date, expiry_date, issuing_country, issuing_authority, issuing_jurisdiction, nationality, document_number, driving_privileges, un_distinguishing_sign, administrative_number, sex, height_centimeters, weight_kilograms, eye_color, hair_color, birth_place, resident_address, resident_city, resident_state, resident_postal_code, resident_country, portrait_capture_date, age_in_years, age_birth_year, age_over, biometric_template_face, biometric_template_voice, biometric_template_finger, biometric_template_iris, biometric_template_retina].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



420
421
422
423
424
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 420

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



512
513
514
515
516
517
518
519
520
521
522
523
524
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 512

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



428
429
430
431
# File 'lib/trinsic_api/models/iso180135_standard_namespace_output.rb', line 428

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end