Class: TrinsicApi::ItsmeBelgianNationalNumber
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ItsmeBelgianNationalNumber
- Defined in:
- lib/trinsic_api/models/itsme_belgian_national_number.rb
Instance Attribute Summary collapse
-
#issuing_country ⇒ Object
The issuing country as an ISO 3166-1 alpha-2 country code.
-
#number ⇒ Object
The raw Belgian National Register Number of the verified individual.
-
#verification_date ⇒ Object
The date time when the document was last read.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ItsmeBelgianNationalNumber
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ItsmeBelgianNationalNumber
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ItsmeBelgianNationalNumber` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ItsmeBelgianNationalNumber`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number') self.number = attributes[:'number'] end if attributes.key?(:'issuing_country') self.issuing_country = attributes[:'issuing_country'] end if attributes.key?(:'verification_date') self.verification_date = attributes[:'verification_date'] end end |
Instance Attribute Details
#issuing_country ⇒ Object
The issuing country as an ISO 3166-1 alpha-2 country code. Availability by ID document issuing country: always returned for all supported issuing countries.
22 23 24 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 22 def issuing_country @issuing_country end |
#number ⇒ Object
The raw Belgian National Register Number of the verified individual. Availability by ID document issuing country: returned only for Belgian-issued ID documents. This is an 11-digit number in the format YYMMDDXXXCC: - YYMMDD is the date of birth. - XXX is a sequential birth number, odd for males and even for females. - CC is the checksum.
19 20 21 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 19 def number @number end |
#verification_date ⇒ Object
The date time when the document was last read. Availability by ID document issuing country: always returned for supported issuing countries except Belgium, where it is best effort.
25 26 27 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 25 def verification_date @verification_date end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 28 def self.attribute_map { :'number' => :'number', :'issuing_country' => :'issuingCountry', :'verification_date' => :'verificationDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 133 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 60 61 62 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 56 def self.openapi_nullable Set.new([ :'number', :'issuing_country', :'verification_date' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 47 def self.openapi_types { :'number' => :'String', :'issuing_country' => :'String', :'verification_date' => :'Time' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
110 111 112 113 114 115 116 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 110 def ==(o) return true if self.equal?(o) self.class == o.class && number == o.number && issuing_country == o.issuing_country && verification_date == o.verification_date end |
#eql?(o) ⇒ Boolean
120 121 122 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 120 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
126 127 128 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 126 def hash [number, issuing_country, verification_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 99 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 95 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 155 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
103 104 105 106 |
# File 'lib/trinsic_api/models/itsme_belgian_national_number.rb', line 103 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |