Class: TrinsicApi::KenyaNidBiometric2Input
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::KenyaNidBiometric2Input
- Defined in:
- lib/trinsic_api/models/kenya_nid_biometric2_input.rb
Instance Attribute Summary collapse
-
#id_number ⇒ Object
The Kenya National ID Number (Nambari ya Kitambulisho) or Unique Personal Identifier (Maisha Namba).
-
#liveness_images ⇒ Object
An array of exactly 8 images required for biometric liveness verification.
-
#test_selfie ⇒ Object
Test selfie for test environment (optional, maximum 15MB).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KenyaNidBiometric2Input
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ KenyaNidBiometric2Input
Initializes the object
66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 66 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::KenyaNidBiometric2Input` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::KenyaNidBiometric2Input`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id_number') self.id_number = attributes[:'id_number'] end if attributes.key?(:'liveness_images') if (value = attributes[:'liveness_images']).is_a?(Array) self.liveness_images = value end end if attributes.key?(:'test_selfie') self.test_selfie = attributes[:'test_selfie'] end end |
Instance Attribute Details
#id_number ⇒ Object
The Kenya National ID Number (Nambari ya Kitambulisho) or Unique Personal Identifier (Maisha Namba). This is the primary unique identifier for Kenyan citizens in all government systems, issued by the National Registration Bureau (NRB). The format is either 8 digits for National ID or 9 digits for Maisha Namba UPI (the new format since 2023).
19 20 21 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 19 def id_number @id_number end |
#liveness_images ⇒ Object
An array of exactly 8 images required for biometric liveness verification. The first 7 images should be liveness frames captured during the liveness detection process, and the last image (8th) should be a selfie of the user. All images must be in JPEG format and each image must be less than 15MB in size.
22 23 24 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 22 def liveness_images @liveness_images end |
#test_selfie ⇒ Object
Test selfie for test environment (optional, maximum 15MB). Must be JPEG format.
25 26 27 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 25 def test_selfie @test_selfie end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
37 38 39 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 37 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
42 43 44 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 42 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 28 def self.attribute_map { :'id_number' => :'idNumber', :'liveness_images' => :'livenessImages', :'test_selfie' => :'testSelfie' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 135 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
56 57 58 59 60 61 62 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 56 def self.openapi_nullable Set.new([ :'id_number', :'liveness_images', :'test_selfie' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
47 48 49 50 51 52 53 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 47 def self.openapi_types { :'id_number' => :'String', :'liveness_images' => :'Array<String>', :'test_selfie' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
112 113 114 115 116 117 118 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 112 def ==(o) return true if self.equal?(o) self.class == o.class && id_number == o.id_number && liveness_images == o.liveness_images && test_selfie == o.test_selfie end |
#eql?(o) ⇒ Boolean
122 123 124 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 122 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
128 129 130 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 128 def hash [id_number, liveness_images, test_selfie].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
97 98 99 100 101 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 97 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 157 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
105 106 107 108 |
# File 'lib/trinsic_api/models/kenya_nid_biometric2_input.rb', line 105 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |