Class: TrinsicApi::KenyaNidLookup2Input

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/kenya_nid_lookup2_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KenyaNidLookup2Input

Initializes the object



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 54

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::KenyaNidLookup2Input` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::KenyaNidLookup2Input`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id_number')
    self.id_number = attributes[:'id_number']
  end
end

Instance Attribute Details

#id_numberObject

The Kenya National ID Number (Nambari ya Kitambulisho) or Unique Personal Identifier (Maisha Namba). This is the primary unique identifier for Kenyan citizens in all government systems, issued by the National Registration Bureau (NRB). The format is either 8 digits for National ID or 9 digits for Maisha Namba UPI (the new format since 2023).



19
20
21
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 19

def id_number
  @id_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



29
30
31
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 29

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



34
35
36
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 34

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



22
23
24
25
26
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 22

def self.attribute_map
  {
    :'id_number' => :'idNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 111

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



46
47
48
49
50
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 46

def self.openapi_nullable
  Set.new([
    :'id_number'
  ])
end

.openapi_typesObject

Attribute type mapping.



39
40
41
42
43
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 39

def self.openapi_types
  {
    :'id_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



90
91
92
93
94
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 90

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id_number == o.id_number
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


98
99
100
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 98

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



104
105
106
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 104

def hash
  [id_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



75
76
77
78
79
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 75

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 133

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



83
84
85
86
# File 'lib/trinsic_api/models/kenya_nid_lookup2_input.rb', line 83

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end