Class: TrinsicApi::KenyaNidLookup3ProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb

Overview

Exposed properties for the kenya-nid-lookup-3 Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KenyaNidLookup3ProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::KenyaNidLookup3ProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::KenyaNidLookup3ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id_number')
    self.id_number = attributes[:'id_number']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'surname')
    self.surname = attributes[:'surname']
  end

  if attributes.key?(:'other_name')
    self.other_name = attributes[:'other_name']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'citizenship')
    self.citizenship = attributes[:'citizenship']
  end

  if attributes.key?(:'serial_number')
    self.serial_number = attributes[:'serial_number']
  end
end

Instance Attribute Details

#citizenshipObject

Citizenship of the individual. Format - ISO 3166-1 alpha-2 country code



38
39
40
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 38

def citizenship
  @citizenship
end

#date_of_birthObject

The date of birth of the individual. Format - YYYY-MM-DD



35
36
37
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 35

def date_of_birth
  @date_of_birth
end

#first_nameObject

The first name of the individual.



23
24
25
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 23

def first_name
  @first_name
end

#id_numberObject

The Kenya National ID Number (Nambari ya Kitambulisho) or Unique Personal Identifier (Maisha Namba). This is the primary unique identifier for Kenyan citizens in all government systems, issued by the National Registration Bureau (NRB). The format is either 8 digits for National ID or 9 digits for Maisha Namba UPI (the new format since 2023).



20
21
22
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 20

def id_number
  @id_number
end

#other_nameObject

Other name (middle name) of the individual.



29
30
31
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 29

def other_name
  @other_name
end

#serial_numberObject

The physical card serial number printed on the Kenya National ID card. This is distinct from the ID Number and serves as a card issuance tracking identifier maintained by IPRS. This value changes each time a new physical card is issued (loss, damage, renewal).



41
42
43
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 41

def serial_number
  @serial_number
end

#sexObject

The sex of the individual. Possible values: - Male - Female



32
33
34
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 32

def sex
  @sex
end

#surnameObject

The surname of the individual.



26
27
28
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 26

def surname
  @surname
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 44

def self.attribute_map
  {
    :'id_number' => :'idNumber',
    :'first_name' => :'firstName',
    :'surname' => :'surname',
    :'other_name' => :'otherName',
    :'sex' => :'sex',
    :'date_of_birth' => :'dateOfBirth',
    :'citizenship' => :'citizenship',
    :'serial_number' => :'serialNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 82

def self.openapi_nullable
  Set.new([
    :'id_number',
    :'first_name',
    :'surname',
    :'other_name',
    :'sex',
    :'date_of_birth',
    :'citizenship',
    :'serial_number'
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 68

def self.openapi_types
  {
    :'id_number' => :'String',
    :'first_name' => :'String',
    :'surname' => :'String',
    :'other_name' => :'String',
    :'sex' => :'String',
    :'date_of_birth' => :'Date',
    :'citizenship' => :'String',
    :'serial_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id_number == o.id_number &&
      first_name == o.first_name &&
      surname == o.surname &&
      other_name == o.other_name &&
      sex == o.sex &&
      date_of_birth == o.date_of_birth &&
      citizenship == o.citizenship &&
      serial_number == o.serial_number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 182

def hash
  [id_number, first_name, surname, other_name, sex, date_of_birth, citizenship, serial_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
# File 'lib/trinsic_api/models/kenya_nid_lookup3_provider_output.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end