Class: TrinsicApi::KenyaNidMatch2Input

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/kenya_nid_match2_input.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KenyaNidMatch2Input

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 106

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::KenyaNidMatch2Input` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::KenyaNidMatch2Input`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id_number')
    self.id_number = attributes[:'id_number']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end
end

Instance Attribute Details

#date_of_birthObject

The user’s date of birth, in ‘YYYY-MM-DD` format



31
32
33
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 31

def date_of_birth
  @date_of_birth
end

#family_nameObject

The user’s last name as it appears in their National ID



25
26
27
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 25

def family_name
  @family_name
end

#given_nameObject

The user’s first name as it appears in their National ID



22
23
24
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 22

def given_name
  @given_name
end

#id_numberObject

The Kenya National ID Number (Nambari ya Kitambulisho) or Unique Personal Identifier (Maisha Namba). This is the primary unique identifier for Kenyan citizens in all government systems, issued by the National Registration Bureau (NRB). The format is either 8 digits for National ID or 9 digits for Maisha Namba UPI (the new format since 2023).



19
20
21
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 19

def id_number
  @id_number
end

#middle_nameObject

The user’s middle name as it appears in their National ID (optional)



28
29
30
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 28

def middle_name
  @middle_name
end

#sexObject

The user’s sex as it appears in their National ID



34
35
36
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 34

def sex
  @sex
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 59

def self.attribute_map
  {
    :'id_number' => :'idNumber',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'middle_name' => :'middleName',
    :'date_of_birth' => :'dateOfBirth',
    :'sex' => :'sex'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 188

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
97
98
99
100
101
102
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 93

def self.openapi_nullable
  Set.new([
    :'id_number',
    :'given_name',
    :'family_name',
    :'middle_name',
    :'date_of_birth',
    :'sex'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 81

def self.openapi_types
  {
    :'id_number' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'middle_name' => :'String',
    :'date_of_birth' => :'Date',
    :'sex' => :'KenyaNidMatch2InputSex'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
171
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id_number == o.id_number &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      middle_name == o.middle_name &&
      date_of_birth == o.date_of_birth &&
      sex == o.sex
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


175
176
177
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 175

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



181
182
183
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 181

def hash
  [id_number, given_name, family_name, middle_name, date_of_birth, sex].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



147
148
149
150
151
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 147

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 210

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



155
156
157
158
# File 'lib/trinsic_api/models/kenya_nid_match2_input.rb', line 155

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end