Class: TrinsicApi::KoreaTelcoMatchProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/korea_telco_match_provider_output.rb

Overview

Exposed properties for the ‘korea-telco-match` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ KoreaTelcoMatchProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 64

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::KoreaTelcoMatchProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::KoreaTelcoMatchProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  else
    self.phone_number = nil
  end

  if attributes.key?(:'tele_type')
    self.tele_type = attributes[:'tele_type']
  else
    self.tele_type = nil
  end

  if attributes.key?(:'result_code')
    self.result_code = attributes[:'result_code']
  else
    self.result_code = nil
  end
end

Instance Attribute Details

#phone_numberObject

The verified phone number as submitted by the relying party.



20
21
22
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 20

def phone_number
  @phone_number
end

#result_codeObject

The RaonSecure result code returned by the carrier verification system. "0000" indicates a successful match. Common error codes: - "0000": Successful match - "0001": Identity Verification Failed - Verification Information Mismatch (General) - "0002": Identity Verification Failed - Unable to Verify Phone Number - "0004": Identity Verification Failed - Date of Birth Verification Error - "0005": Identity Verification Failed - Gender Verification Error - "0006": Identity Verification Failed - Name Verification Error - "0009": Identity Verification Failed - Device OS Mismatch



26
27
28
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 26

def result_code
  @result_code
end

#tele_typeObject

The mobile carrier used for verification. Possible values: <list type="bullet"><item><description>Lgu</description></item><item><description>Skt</description></item><item><description>Kt</description></item></list>



23
24
25
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 23

def tele_type
  @tele_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 29

def self.attribute_map
  {
    :'phone_number' => :'phoneNumber',
    :'tele_type' => :'teleType',
    :'result_code' => :'resultCode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 182

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 57

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 48

def self.openapi_types
  {
    :'phone_number' => :'String',
    :'tele_type' => :'String',
    :'result_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



159
160
161
162
163
164
165
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 159

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      phone_number == o.phone_number &&
      tele_type == o.tele_type &&
      result_code == o.result_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


169
170
171
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 169

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



175
176
177
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 175

def hash
  [phone_number, tele_type, result_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 99

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @phone_number.nil?
    invalid_properties.push('invalid value for "phone_number", phone_number cannot be nil.')
  end

  if @tele_type.nil?
    invalid_properties.push('invalid value for "tele_type", tele_type cannot be nil.')
  end

  if @result_code.nil?
    invalid_properties.push('invalid value for "result_code", result_code cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 204

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
123
124
125
# File 'lib/trinsic_api/models/korea_telco_match_provider_output.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @phone_number.nil?
  return false if @tele_type.nil?
  return false if @result_code.nil?
  true
end