Class: TrinsicApi::LatviaEparakstsMobileProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb

Overview

Exposed properties for the a-lv-eparaksts-mobile-login Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ LatviaEparakstsMobileProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::LatviaEparakstsMobileProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::LatviaEparakstsMobileProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'personal_code')
    self.personal_code = attributes[:'personal_code']
  end
end

Instance Attribute Details

#first_nameObject

The first name of the verified individual



20
21
22
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 20

def first_name
  @first_name
end

#last_nameObject

The last name of the verified individual



23
24
25
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 23

def last_name
  @last_name
end

#personal_codeObject

The 11-digit Latvian personal code ("personas kods") of the verified individual. This has two possible formats, depending on whether the personal code was issued after July 1, 2017. For personal codes issued before July 1, 2017, the format is DDMMYY-CZZZQ, where: - DDMMYY is the date of birth, followed by an optional hyphen - C represents the century of birth ('0' for 1800-1899, '1' for 1900-1999, '2' for 2000-2099) - ZZZ is a serial number - Q is a checksum digit For personal codes issued on or after July 1, 2017, the format is 32ZZZZZZZZQ, where: - 32 is a fixed prefix - ZZZZZZZQ are 8 random digits - Q is a checksum digit NOTE: Individuals born before July 1, 2017 can elect to be issued a new personal code which does not contain their birthdate. Therefore, no concrete assumptions may be made about an individual's date of birth based solely on the format of their personal code.



26
27
28
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 26

def personal_code
  @personal_code
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 29

def self.attribute_map
  {
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'personal_code' => :'personalCode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 134

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
62
63
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 57

def self.openapi_nullable
  Set.new([
    :'first_name',
    :'last_name',
    :'personal_code'
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 48

def self.openapi_types
  {
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'personal_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



111
112
113
114
115
116
117
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 111

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      personal_code == o.personal_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


121
122
123
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 121

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



127
128
129
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 127

def hash
  [first_name, last_name, personal_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



96
97
98
99
100
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 156

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



104
105
106
107
# File 'lib/trinsic_api/models/latvia_eparaksts_mobile_provider_output.rb', line 104

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end