Class: TrinsicApi::MdlOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::MdlOutput
- Defined in:
- lib/trinsic_api/models/mdl_output.rb
Instance Attribute Summary collapse
-
#document_signer_certificate ⇒ Object
Information about the Document Signer Certificate which signed the mDoc presented by the individual.
-
#document_type ⇒ Object
The document type of the mDoc presented by the individual.
-
#iaca_root_certificate ⇒ Object
Information about the IACA Root Certificate which signed (directly or indirectly) the Document Signer Certificate for this mDoc.
-
#name_spaces ⇒ Object
The namespaces, and fields within those namespaces, which were present in the processed mDL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MdlOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MdlOutput
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::MdlOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::MdlOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'iaca_root_certificate') self.iaca_root_certificate = attributes[:'iaca_root_certificate'] end if attributes.key?(:'document_signer_certificate') self.document_signer_certificate = attributes[:'document_signer_certificate'] end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] end if attributes.key?(:'name_spaces') if (value = attributes[:'name_spaces']).is_a?(Hash) self.name_spaces = value end end end |
Instance Attribute Details
#document_signer_certificate ⇒ Object
Information about the Document Signer Certificate which signed the mDoc presented by the individual.
22 23 24 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 22 def document_signer_certificate @document_signer_certificate end |
#document_type ⇒ Object
The document type of the mDoc presented by the individual. Common values: - "org.iso.18013.5.1.mDL" for ISO 18013-5 mDLs - "com.google.wallet.idcard.1" for Google Wallet ID Cards
25 26 27 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 25 def document_type @document_type end |
#iaca_root_certificate ⇒ Object
Information about the IACA Root Certificate which signed (directly or indirectly) the Document Signer Certificate for this mDoc.
19 20 21 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 19 def iaca_root_certificate @iaca_root_certificate end |
#name_spaces ⇒ Object
The namespaces, and fields within those namespaces, which were present in the processed mDL.
28 29 30 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 28 def name_spaces @name_spaces end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 31 def self.attribute_map { :'iaca_root_certificate' => :'iacaRootCertificate', :'document_signer_certificate' => :'documentSignerCertificate', :'document_type' => :'documentType', :'name_spaces' => :'nameSpaces' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 146 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 65 66 67 68 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 61 def self.openapi_nullable Set.new([ :'iaca_root_certificate', :'document_signer_certificate', :'document_type', :'name_spaces' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 51 def self.openapi_types { :'iaca_root_certificate' => :'MdlOutputCertificateData', :'document_signer_certificate' => :'MdlOutputCertificateData', :'document_type' => :'String', :'name_spaces' => :'Hash<String, Hash<String, MdlOutputFieldData>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
122 123 124 125 126 127 128 129 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 122 def ==(o) return true if self.equal?(o) self.class == o.class && iaca_root_certificate == o.iaca_root_certificate && document_signer_certificate == o.document_signer_certificate && document_type == o.document_type && name_spaces == o.name_spaces end |
#eql?(o) ⇒ Boolean
133 134 135 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 133 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
139 140 141 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 139 def hash [iaca_root_certificate, document_signer_certificate, document_type, name_spaces].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
107 108 109 110 111 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 107 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 168 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
115 116 117 118 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 115 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |