Class: TrinsicApi::NetherlandsIdinAddress

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/netherlands_idin_address.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetherlandsIdinAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::NetherlandsIdinAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::NetherlandsIdinAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  end

  if attributes.key?(:'house_number')
    self.house_number = attributes[:'house_number']
  end

  if attributes.key?(:'house_number_suffix')
    self.house_number_suffix = attributes[:'house_number_suffix']
  end

  if attributes.key?(:'address_extra')
    self.address_extra = attributes[:'address_extra']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  end

  if attributes.key?(:'international_address_line1')
    self.international_address_line1 = attributes[:'international_address_line1']
  end

  if attributes.key?(:'international_address_line2')
    self.international_address_line2 = attributes[:'international_address_line2']
  end

  if attributes.key?(:'international_address_line3')
    self.international_address_line3 = attributes[:'international_address_line3']
  end
end

Instance Attribute Details

#address_extraObject

Additional domestic address information returned by iDIN.



28
29
30
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 28

def address_extra
  @address_extra
end

#cityObject

City of the individual's domestic address.



34
35
36
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 34

def city
  @city
end

#country_codeObject

Country code of the individual's address in ISO 3166-1 alpha-2 format.



37
38
39
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 37

def country_code
  @country_code
end

#house_numberObject

House number of the individual's domestic address.



22
23
24
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 22

def house_number
  @house_number
end

#house_number_suffixObject

House number suffix of the individual's domestic address.



25
26
27
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 25

def house_number_suffix
  @house_number_suffix
end

#international_address_line1Object

First line of the individual's international address.



40
41
42
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 40

def international_address_line1
  @international_address_line1
end

#international_address_line2Object

Second line of the individual's international address.



43
44
45
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 43

def international_address_line2
  @international_address_line2
end

#international_address_line3Object

Third line of the individual's international address.



46
47
48
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 46

def international_address_line3
  @international_address_line3
end

#postal_codeObject

Postal code of the individual's domestic address. A postal code in The Netherlands is a 4-digit number and two letters.



31
32
33
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 31

def postal_code
  @postal_code
end

#streetObject

Street name of the individual's domestic address.



19
20
21
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 19

def street
  @street
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 49

def self.attribute_map
  {
    :'street' => :'street',
    :'house_number' => :'houseNumber',
    :'house_number_suffix' => :'houseNumberSuffix',
    :'address_extra' => :'addressExtra',
    :'postal_code' => :'postalCode',
    :'city' => :'city',
    :'country_code' => :'countryCode',
    :'international_address_line1' => :'internationalAddressLine1',
    :'international_address_line2' => :'internationalAddressLine2',
    :'international_address_line3' => :'internationalAddressLine3'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 210

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 91

def self.openapi_nullable
  Set.new([
    :'street',
    :'house_number',
    :'house_number_suffix',
    :'address_extra',
    :'postal_code',
    :'city',
    :'country_code',
    :'international_address_line1',
    :'international_address_line2',
    :'international_address_line3'
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 75

def self.openapi_types
  {
    :'street' => :'String',
    :'house_number' => :'String',
    :'house_number_suffix' => :'String',
    :'address_extra' => :'String',
    :'postal_code' => :'String',
    :'city' => :'String',
    :'country_code' => :'String',
    :'international_address_line1' => :'String',
    :'international_address_line2' => :'String',
    :'international_address_line3' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



180
181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 180

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      street == o.street &&
      house_number == o.house_number &&
      house_number_suffix == o.house_number_suffix &&
      address_extra == o.address_extra &&
      postal_code == o.postal_code &&
      city == o.city &&
      country_code == o.country_code &&
      international_address_line1 == o.international_address_line1 &&
      international_address_line2 == o.international_address_line2 &&
      international_address_line3 == o.international_address_line3
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


197
198
199
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 197

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



203
204
205
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 203

def hash
  [street, house_number, house_number_suffix, address_extra, postal_code, city, country_code, international_address_line1, international_address_line2, international_address_line3].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 232

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 173

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end