Class: TrinsicApi::NetherlandsIdinProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/netherlands_idin_provider_output.rb

Overview

Exposed properties for the netherlands-idin Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetherlandsIdinProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::NetherlandsIdinProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::NetherlandsIdinProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'authority_id')
    self.authority_id = attributes[:'authority_id']
  end

  if attributes.key?(:'authority_name')
    self.authority_name = attributes[:'authority_name']
  end

  if attributes.key?(:'customer_id')
    self.customer_id = attributes[:'customer_id']
  end

  if attributes.key?(:'initials')
    self.initials = attributes[:'initials']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'birth_date')
    self.birth_date = attributes[:'birth_date']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end
end

Instance Attribute Details

#addressObject

Address of the individual.



35
36
37
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 35

def address
  @address
end

#authority_idObject

Unique identifier of the authority that was used to verify the individual. For banks this follows the SWIFT/BIC (Bank Identification Code) format.



20
21
22
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 20

def authority_id
  @authority_id
end

#authority_nameObject

Name of the authority that was used to verify the individual.



23
24
25
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 23

def authority_name
  @authority_name
end

#birth_dateObject

Date of birth of the individual.



38
39
40
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 38

def birth_date
  @birth_date
end

#customer_idObject

Unique identifier of the customer's account with the issuing authority. This identifier is generated by each authority and is unique per customer registration, authority, and individual. The identifier should be treated as a unique opaque string.



26
27
28
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 26

def customer_id
  @customer_id
end

#emailObject

Email address of the individual.



47
48
49
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 47

def email
  @email
end

#family_nameObject

Last/family name of the individual.



32
33
34
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 32

def family_name
  @family_name
end

#genderObject

Gender of the individual. Possible values: - Male - Female - Unknown



41
42
43
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 41

def gender
  @gender
end

#initialsObject

The initials of the Consumer, defined as the first letter of each of the Consumer’s first names. Maximum of 24 capitalized letters. Only the first letter of each first name is used which must be capitalized and returned without spaces or dots. Given the name “Jan-Jaap Christaan Jozefszoon” or “jan-jaap christaan jozefszoon”, the value of this field will be “JC”.



29
30
31
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 29

def initials
  @initials
end

#phone_numberObject

Phone number of the individual in E164 format.



44
45
46
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 44

def phone_number
  @phone_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 50

def self.attribute_map
  {
    :'authority_id' => :'authorityId',
    :'authority_name' => :'authorityName',
    :'customer_id' => :'customerId',
    :'initials' => :'initials',
    :'family_name' => :'familyName',
    :'address' => :'address',
    :'birth_date' => :'birthDate',
    :'gender' => :'gender',
    :'phone_number' => :'phoneNumber',
    :'email' => :'email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 92

def self.openapi_nullable
  Set.new([
    :'authority_id',
    :'authority_name',
    :'customer_id',
    :'initials',
    :'family_name',
    :'address',
    :'birth_date',
    :'gender',
    :'phone_number',
    :'email'
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 76

def self.openapi_types
  {
    :'authority_id' => :'String',
    :'authority_name' => :'String',
    :'customer_id' => :'String',
    :'initials' => :'String',
    :'family_name' => :'String',
    :'address' => :'NetherlandsIdinAddress',
    :'birth_date' => :'Date',
    :'gender' => :'String',
    :'phone_number' => :'String',
    :'email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      authority_id == o.authority_id &&
      authority_name == o.authority_name &&
      customer_id == o.customer_id &&
      initials == o.initials &&
      family_name == o.family_name &&
      address == o.address &&
      birth_date == o.birth_date &&
      gender == o.gender &&
      phone_number == o.phone_number &&
      email == o.email
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 204

def hash
  [authority_id, authority_name, customer_id, initials, family_name, address, birth_date, gender, phone_number, email].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
# File 'lib/trinsic_api/models/netherlands_idin_provider_output.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end