Class: TrinsicApi::NigeriaNinInput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/nigeria_nin_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NigeriaNinInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::NigeriaNinInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::NigeriaNinInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  else
    self.first_name = nil
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  else
    self.last_name = nil
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  else
    self.date_of_birth = nil
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'national_id_number')
    self.national_id_number = attributes[:'national_id_number']
  else
    self.national_id_number = nil
  end
end

Instance Attribute Details

#date_of_birthObject

The user’s date of birth, in ‘YYYY-MM-DD` format



31
32
33
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 31

def date_of_birth
  @date_of_birth
end

#first_nameObject

The user’s first name as it appears in their National ID



19
20
21
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 19

def first_name
  @first_name
end

#genderObject

The user’s gender as it appears in their National ID (e.g., male, female)



34
35
36
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 34

def gender
  @gender
end

#last_nameObject

The user’s last name as it appears in their National ID (optional)



25
26
27
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 25

def last_name
  @last_name
end

#middle_nameObject

The user’s middle name as it appears in their National ID (optional)



22
23
24
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 22

def middle_name
  @middle_name
end

#national_id_numberObject

The user’s National ID number



37
38
39
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 37

def national_id_number
  @national_id_number
end

#phone_numberObject

The user’s phone number (optional)



28
29
30
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 28

def phone_number
  @phone_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 40

def self.attribute_map
  {
    :'first_name' => :'firstName',
    :'middle_name' => :'middleName',
    :'last_name' => :'lastName',
    :'phone_number' => :'phoneNumber',
    :'date_of_birth' => :'dateOfBirth',
    :'gender' => :'gender',
    :'national_id_number' => :'nationalIdNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 288

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
80
81
82
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 76

def self.openapi_nullable
  Set.new([
    :'middle_name',
    :'phone_number',
    :'gender',
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 63

def self.openapi_types
  {
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'last_name' => :'String',
    :'phone_number' => :'String',
    :'date_of_birth' => :'Date',
    :'gender' => :'String',
    :'national_id_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



261
262
263
264
265
266
267
268
269
270
271
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 261

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      last_name == o.last_name &&
      phone_number == o.phone_number &&
      date_of_birth == o.date_of_birth &&
      gender == o.gender &&
      national_id_number == o.national_id_number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


275
276
277
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 275

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



281
282
283
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 281

def hash
  [first_name, middle_name, last_name, phone_number, date_of_birth, gender, national_id_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @first_name.nil?
    invalid_properties.push('invalid value for "first_name", first_name cannot be nil.')
  end

  if @first_name.to_s.length < 1
    invalid_properties.push('invalid value for "first_name", the character length must be greater than or equal to 1.')
  end

  if @last_name.nil?
    invalid_properties.push('invalid value for "last_name", last_name cannot be nil.')
  end

  if @last_name.to_s.length < 1
    invalid_properties.push('invalid value for "last_name", the character length must be greater than or equal to 1.')
  end

  if @date_of_birth.nil?
    invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.')
  end

  if @national_id_number.nil?
    invalid_properties.push('invalid value for "national_id_number", national_id_number cannot be nil.')
  end

  if @national_id_number.to_s.length > 11
    invalid_properties.push('invalid value for "national_id_number", the character length must be smaller than or equal to 11.')
  end

  if @national_id_number.to_s.length < 11
    invalid_properties.push('invalid value for "national_id_number", the character length must be greater than or equal to 11.')
  end

  pattern = Regexp.new(/^\d*$/)
  if @national_id_number !~ pattern
    invalid_properties.push("invalid value for \"national_id_number\", must conform to the pattern #{pattern}.")
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 310

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/trinsic_api/models/nigeria_nin_input.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @first_name.nil?
  return false if @first_name.to_s.length < 1
  return false if @last_name.nil?
  return false if @last_name.to_s.length < 1
  return false if @date_of_birth.nil?
  return false if @national_id_number.nil?
  return false if @national_id_number.to_s.length > 11
  return false if @national_id_number.to_s.length < 11
  return false if @national_id_number !~ Regexp.new(/^\d*$/)
  true
end