Class: TrinsicApi::NigeriaNinLookup2ProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb

Overview

Exposed properties for the nigeria-nin-lookup-2 Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NigeriaNinLookup2ProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::NigeriaNinLookup2ProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::NigeriaNinLookup2ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'surname')
    self.surname = attributes[:'surname']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'birth_country')
    self.birth_country = attributes[:'birth_country']
  end

  if attributes.key?(:'national_identity_number')
    self.national_identity_number = attributes[:'national_identity_number']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'local_government_area')
    self.local_government_area = attributes[:'local_government_area']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end
end

Instance Attribute Details

#addressObject

Full residential address as a single string, normalized to lowercase without delimiters.



47
48
49
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 47

def address
  @address
end

#birth_countryObject

Country of birth as an ISO 3166-1 alpha-2 code.



35
36
37
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 35

def birth_country
  @birth_country
end

#date_of_birthObject

The date of birth of the ID holder.



32
33
34
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 32

def date_of_birth
  @date_of_birth
end

#emailObject

Email address registered with the National Identity Management Commission.



44
45
46
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 44

def email
  @email
end

#first_nameObject

The first name (given name) of the ID holder.



20
21
22
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 20

def first_name
  @first_name
end

#local_government_areaObject

Local Government Area of residence. Nigeria is divided into 774 Local Government Areas (LGAs), which are the third-tier administrative divisions below states and the Federal Capital Territory. LGAs are roughly equivalent to counties or municipalities in other countries.



50
51
52
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 50

def local_government_area
  @local_government_area
end

#middle_nameObject

The middle name of the ID holder.



23
24
25
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 23

def middle_name
  @middle_name
end

#national_identity_numberObject

National Identification Number (NIN). This is a unique, permanent identifier assigned by the National Identity Management Commission (NIMC) upon enrollment. Format: - 11 numeric digits - No publicly known encoding scheme is used to encode personal information in the NIN - Last digit is a checksum using the Verhoeff algorithm



38
39
40
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 38

def national_identity_number
  @national_identity_number
end

#phone_numberObject

Phone number registered with the National Identity Management Commission. Format: - Valid Nigerian numbers are returned in international E.164 format (for example, +2348031234567). - Otherwise, the value is returned in trunk notation (leading zero included) as provided by the authority (for example, 0123456789).



41
42
43
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 41

def phone_number
  @phone_number
end

#sexObject

The sex of the ID holder. Possible values: - Male - Female



29
30
31
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 29

def sex
  @sex
end

#stateObject

State of residence.



53
54
55
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 53

def state
  @state
end

#surnameObject

The surname (family name) of the ID holder.



26
27
28
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 26

def surname
  @surname
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 56

def self.attribute_map
  {
    :'first_name' => :'firstName',
    :'middle_name' => :'middleName',
    :'surname' => :'surname',
    :'sex' => :'sex',
    :'date_of_birth' => :'dateOfBirth',
    :'birth_country' => :'birthCountry',
    :'national_identity_number' => :'nationalIdentityNumber',
    :'phone_number' => :'phoneNumber',
    :'email' => :'email',
    :'address' => :'address',
    :'local_government_area' => :'localGovernmentArea',
    :'state' => :'state'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 233

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 102

def self.openapi_nullable
  Set.new([
    :'first_name',
    :'middle_name',
    :'surname',
    :'sex',
    :'date_of_birth',
    :'birth_country',
    :'national_identity_number',
    :'phone_number',
    :'email',
    :'address',
    :'local_government_area',
    :'state'
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 84

def self.openapi_types
  {
    :'first_name' => :'String',
    :'middle_name' => :'String',
    :'surname' => :'String',
    :'sex' => :'String',
    :'date_of_birth' => :'Date',
    :'birth_country' => :'String',
    :'national_identity_number' => :'String',
    :'phone_number' => :'String',
    :'email' => :'String',
    :'address' => :'String',
    :'local_government_area' => :'String',
    :'state' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      first_name == o.first_name &&
      middle_name == o.middle_name &&
      surname == o.surname &&
      sex == o.sex &&
      date_of_birth == o.date_of_birth &&
      birth_country == o.birth_country &&
      national_identity_number == o.national_identity_number &&
      phone_number == o.phone_number &&
      email == o.email &&
      address == o.address &&
      local_government_area == o.local_government_area &&
      state == o.state
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 226

def hash
  [first_name, middle_name, surname, sex, date_of_birth, birth_country, national_identity_number, phone_number, email, address, local_government_area, state].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
# File 'lib/trinsic_api/models/nigeria_nin_lookup2_provider_output.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end