Class: TrinsicApi::NorwegianBankIdProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/norwegian_bank_id_provider_output.rb

Overview

Exposed properties for the ‘norway-bankid` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NorwegianBankIdProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::NorwegianBankIdProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::NorwegianBankIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'personal_identifier')
    self.personal_identifier = attributes[:'personal_identifier']
  end

  if attributes.key?(:'national_identity_number')
    self.national_identity_number = attributes[:'national_identity_number']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'level_of_assurance')
    self.level_of_assurance = attributes[:'level_of_assurance']
  end

  if attributes.key?(:'authentication_method')
    self.authentication_method = attributes[:'authentication_method']
  end
end

Instance Attribute Details

#authentication_methodObject

The authentication method used by the individual. Possible values: - urn:bankid:bis - BankID with Biometrics - urn:bankid:bid - Standard BankID with High Assurance



41
42
43
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 41

def authentication_method
  @authentication_method
end

#date_of_birthObject

The date of birth of the individual.



23
24
25
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 23

def date_of_birth
  @date_of_birth
end

#family_nameObject

The family name of the individual.



35
36
37
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 35

def family_name
  @family_name
end

#full_nameObject

The full name of the individual.



20
21
22
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 20

def full_name
  @full_name
end

#given_nameObject

The given name of the individual.



32
33
34
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 32

def given_name
  @given_name
end

#level_of_assuranceObject

The level of assurance (LOA) for the verification. The LOA refers to the degree of confidence in the claimed identity of a person. The European Digital Identity Framework (EUDI) measures the confidence of the digital identity’s verification and authentication strength by a set of requirements for different levels. To learn more, see: ec.europa.eu/digital-building-blocks/sites/spaces/DIGITAL/pages/467110081/eIDAS+Levels+of+Assurance Possible values: - Low: The individual has self asserted their identity and multifactor authentication is not required. - Substantial: The individual has performed either a remote or in-person identity verification and multifactor authentication is required. - High: The individual has performed an in-person identity proofing with an authorized representative and has strong cryptographic authentication requirements such as using a smart card.



38
39
40
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 38

def level_of_assurance
  @level_of_assurance
end

#national_identity_numberObject

The 11-digit Norwegian National Identity Number (fødselsnummer) of the verified individual. This is in the format DDMMYYZZZCC, where: - DDMMYY is the date of birth (In some cases, this is not the date of birth due to no available identity numbers for some dates - ZZZ is an individual number, indicating gender - CC is a checksum character If ZZZ is even, the individual is female. If ZZZ is odd, the individual is male.



29
30
31
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 29

def national_identity_number
  @national_identity_number
end

#personal_identifierObject

The personal identifier for Norwegian BankID. This uniquely identifies the individual in the Norwegian BankID system and is considered a stable identifier to use.



26
27
28
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 26

def personal_identifier
  @personal_identifier
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 44

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'date_of_birth' => :'dateOfBirth',
    :'personal_identifier' => :'personalIdentifier',
    :'national_identity_number' => :'nationalIdentityNumber',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'level_of_assurance' => :'levelOfAssurance',
    :'authentication_method' => :'authenticationMethod'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 189

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 82

def self.openapi_nullable
  Set.new([
    :'full_name',
    :'date_of_birth',
    :'personal_identifier',
    :'national_identity_number',
    :'given_name',
    :'family_name',
    :'level_of_assurance',
    :'authentication_method'
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 68

def self.openapi_types
  {
    :'full_name' => :'String',
    :'date_of_birth' => :'Date',
    :'personal_identifier' => :'String',
    :'national_identity_number' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'level_of_assurance' => :'String',
    :'authentication_method' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 161

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      date_of_birth == o.date_of_birth &&
      personal_identifier == o.personal_identifier &&
      national_identity_number == o.national_identity_number &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      level_of_assurance == o.level_of_assurance &&
      authentication_method == o.authentication_method
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


176
177
178
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 176

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



182
183
184
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 182

def hash
  [full_name, date_of_birth, personal_identifier, national_identity_number, given_name, family_name, level_of_assurance, authentication_method].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



146
147
148
149
150
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 146

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 211

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
# File 'lib/trinsic_api/models/norwegian_bank_id_provider_output.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end