Class: TrinsicApi::OneIdProviderAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::OneIdProviderAddress
- Defined in:
- lib/trinsic_api/models/one_id_provider_address.rb
Instance Attribute Summary collapse
-
#country_code ⇒ Object
The alpha-2 country code of the address.
-
#locality ⇒ Object
The locality or city portion of the address.
-
#postal_code ⇒ Object
The postal code of the address.
-
#region ⇒ Object
The region or subdivision portion of the address.
-
#street_address ⇒ Object
The line or street portion of the address.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ OneIdProviderAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ OneIdProviderAddress
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::OneIdProviderAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::OneIdProviderAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'street_address') self.street_address = attributes[:'street_address'] end if attributes.key?(:'locality') self.locality = attributes[:'locality'] end if attributes.key?(:'region') self.region = attributes[:'region'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country_code') self.country_code = attributes[:'country_code'] end end |
Instance Attribute Details
#country_code ⇒ Object
The alpha-2 country code of the address.
31 32 33 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 31 def country_code @country_code end |
#locality ⇒ Object
The locality or city portion of the address.
22 23 24 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 22 def locality @locality end |
#postal_code ⇒ Object
The postal code of the address.
28 29 30 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 28 def postal_code @postal_code end |
#region ⇒ Object
The region or subdivision portion of the address.
25 26 27 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 25 def region @region end |
#street_address ⇒ Object
The line or street portion of the address.
19 20 21 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 19 def street_address @street_address end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 34 def self.attribute_map { :'street_address' => :'streetAddress', :'locality' => :'locality', :'region' => :'region', :'postal_code' => :'postalCode', :'country_code' => :'countryCode' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 155 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 71 72 73 74 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 66 def self.openapi_nullable Set.new([ :'street_address', :'locality', :'region', :'postal_code', :'country_code' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 55 def self.openapi_types { :'street_address' => :'String', :'locality' => :'String', :'region' => :'String', :'postal_code' => :'String', :'country_code' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && street_address == o.street_address && locality == o.locality && region == o.region && postal_code == o.postal_code && country_code == o.country_code end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 148 def hash [street_address, locality, region, postal_code, country_code].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 |
# File 'lib/trinsic_api/models/one_id_provider_address.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |