Class: TrinsicApi::OneIdProviderOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/one_id_provider_output.rb

Overview

Exposed properties for the ‘oneid` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ OneIdProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::OneIdProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::OneIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'sub')
    self.sub = attributes[:'sub']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'birthdate')
    self.birthdate = attributes[:'birthdate']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end
end

Instance Attribute Details

#addressObject

The address of the individual.



35
36
37
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 35

def address
  @address
end

#birthdateObject

The date of birth of the individual.



32
33
34
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 32

def birthdate
  @birthdate
end

#family_nameObject

The individual’s family name.



29
30
31
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 29

def family_name
  @family_name
end

#full_nameObject

The individual’s full name.



23
24
25
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 23

def full_name
  @full_name
end

#given_nameObject

The individual’s given name.



26
27
28
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 26

def given_name
  @given_name
end

#subObject

The OpenID Connect (OIDC) subject identifier (sub).



20
21
22
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 20

def sub
  @sub
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 38

def self.attribute_map
  {
    :'sub' => :'sub',
    :'full_name' => :'fullName',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'birthdate' => :'birthdate',
    :'address' => :'address'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
77
78
79
80
81
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 72

def self.openapi_nullable
  Set.new([
    :'sub',
    :'full_name',
    :'given_name',
    :'family_name',
    :'birthdate',
    :'address'
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 60

def self.openapi_types
  {
    :'sub' => :'String',
    :'full_name' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'birthdate' => :'Date',
    :'address' => :'OneIdProviderAddress'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



141
142
143
144
145
146
147
148
149
150
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 141

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      sub == o.sub &&
      full_name == o.full_name &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      birthdate == o.birthdate &&
      address == o.address
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 160

def hash
  [sub, full_name, given_name, family_name, birthdate, address].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



126
127
128
129
130
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 126

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 189

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



134
135
136
137
# File 'lib/trinsic_api/models/one_id_provider_output.rb', line 134

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end