Class: TrinsicApi::PanamaCedulaProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/panama_cedula_provider_output.rb

Overview

Exposed properties for the ‘panama-cedula-lookup` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PanamaCedulaProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PanamaCedulaProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PanamaCedulaProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  else
    self.full_name = nil
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  else
    self.given_name = nil
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  else
    self.family_name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  else
    self.document_number = nil
  end

  if attributes.key?(:'nationality_or_residence_type')
    self.nationality_or_residence_type = attributes[:'nationality_or_residence_type']
  else
    self.nationality_or_residence_type = nil
  end

  if attributes.key?(:'subdivision_of_origin')
    self.subdivision_of_origin = attributes[:'subdivision_of_origin']
  end

  if attributes.key?(:'subdivision_of_origin_name')
    self.subdivision_of_origin_name = attributes[:'subdivision_of_origin_name']
  end
end

Instance Attribute Details

#date_of_birthObject

Verified date of birth from Tribunal Electoral records.



29
30
31
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 29

def date_of_birth
  @date_of_birth
end

#document_numberObject

The matched personal identity cédula (Cédula de Identidad Personal) number from Tribunal Electoral records. On output, Trinsic applies the same normalization as for lookup input. Structure is always firstSegment-libro-tomo: libro is one to four digits and tomo is one to six digits, separated by hyphens. Citizen category and format: - Born in Panama format: province-libro-tomo (province is official code 1 through 13). Examples 8-1234-12345, 4-56-789, 12-12-12345. - Panamanian born abroad format: PE-libro-tomo. Example PE-1234-12345. - Foreign national with cédula format: E-libro-tomo. Examples E-1234-12345, E-8-102017. - Naturalized citizen format: N-libro-tomo. Example N-1234-12345. - Pre-2006 civil registry (AV) format: provinceAV-libro-tomo. Example 10AV-1234-12345. - Indigenous (PI) format: provincePI-libro-tomo. Example 1PI-1234-12345.



32
33
34
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 32

def document_number
  @document_number
end

#family_nameObject

Family name(s) from Tribunal Electoral records.



26
27
28
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 26

def family_name
  @family_name
end

#full_nameObject

Full name from Tribunal Electoral records.



20
21
22
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 20

def full_name
  @full_name
end

#given_nameObject

Given name(s) from Tribunal Electoral records.



23
24
25
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 23

def given_name
  @given_name
end

#nationality_or_residence_typeObject

Inferred from DocumentNumber. Values are nationality or residence category. Possible values: - BornInPanama - ForeignNational - BornAbroad - Naturalized - LegacyNumber - Indigenous - Unknown (we were unable to determine the category)



35
36
37
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 35

def nationality_or_residence_type
  @nationality_or_residence_type
end

#subdivision_of_originObject

ISO 3166-2 principal subdivision code. Only available for BornInPanama, LegacyNumber, and Indigenous. Possible values, matching cédula province digits 1–13: 1. PA-1 - Bocas del Toro 2. PA-2 - Coclé 3. PA-3 - Colón 4. PA-4 - Chiriquí 5. PA-5 - Darién 6. PA-6 - Herrera 7. PA-7 - Los Santos 8. PA-8 - Panamá 9. PA-9 - Veraguas 10. PA-KY - Guna Yala 11. PA-EM - Emberá 12. PA-NB - Ngäbe-Buglé 13. PA-10 - Panamá Oeste



38
39
40
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 38

def subdivision_of_origin
  @subdivision_of_origin
end

#subdivision_of_origin_nameObject

Subdivision display name from the ISO 3166-2 registry, when available.



41
42
43
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 41

def subdivision_of_origin_name
  @subdivision_of_origin_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 44

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'date_of_birth' => :'dateOfBirth',
    :'document_number' => :'documentNumber',
    :'nationality_or_residence_type' => :'nationalityOrResidenceType',
    :'subdivision_of_origin' => :'subdivisionOfOrigin',
    :'subdivision_of_origin_name' => :'subdivisionOfOriginName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 269

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
87
88
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 82

def self.openapi_nullable
  Set.new([
    :'date_of_birth',
    :'subdivision_of_origin',
    :'subdivision_of_origin_name'
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 68

def self.openapi_types
  {
    :'full_name' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'date_of_birth' => :'Date',
    :'document_number' => :'String',
    :'nationality_or_residence_type' => :'String',
    :'subdivision_of_origin' => :'String',
    :'subdivision_of_origin_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      date_of_birth == o.date_of_birth &&
      document_number == o.document_number &&
      nationality_or_residence_type == o.nationality_or_residence_type &&
      subdivision_of_origin == o.subdivision_of_origin &&
      subdivision_of_origin_name == o.subdivision_of_origin_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


256
257
258
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 256

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



262
263
264
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 262

def hash
  [full_name, given_name, family_name, date_of_birth, document_number, nationality_or_residence_type, subdivision_of_origin, subdivision_of_origin_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @full_name.nil?
    invalid_properties.push('invalid value for "full_name", full_name cannot be nil.')
  end

  if @given_name.nil?
    invalid_properties.push('invalid value for "given_name", given_name cannot be nil.')
  end

  if @family_name.nil?
    invalid_properties.push('invalid value for "family_name", family_name cannot be nil.')
  end

  if @document_number.nil?
    invalid_properties.push('invalid value for "document_number", document_number cannot be nil.')
  end

  if @nationality_or_residence_type.nil?
    invalid_properties.push('invalid value for "nationality_or_residence_type", nationality_or_residence_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 291

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
185
186
187
# File 'lib/trinsic_api/models/panama_cedula_provider_output.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @full_name.nil?
  return false if @given_name.nil?
  return false if @family_name.nil?
  return false if @document_number.nil?
  return false if @nationality_or_residence_type.nil?
  true
end