Class: TrinsicApi::PersonData

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/person_data.rb

Overview

Identity information for the individual being verified

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PersonData

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/trinsic_api/models/person_data.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PersonData` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PersonData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'suffix')
    self.suffix = attributes[:'suffix']
  end

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'phone_number')
    self.phone_number = attributes[:'phone_number']
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end
end

Instance Attribute Details

#addressObject

Address information for an individual



41
42
43
# File 'lib/trinsic_api/models/person_data.rb', line 41

def address
  @address
end

#date_of_birthObject

Returns the value of attribute date_of_birth.



43
44
45
# File 'lib/trinsic_api/models/person_data.rb', line 43

def date_of_birth
  @date_of_birth
end

#family_nameObject

Family (last) name of the individual



23
24
25
# File 'lib/trinsic_api/models/person_data.rb', line 23

def family_name
  @family_name
end

#full_nameObject

The individual’s full name as a single string. Useful for names which do not fit into a "first middle last" structure.



29
30
31
# File 'lib/trinsic_api/models/person_data.rb', line 29

def full_name
  @full_name
end

#given_nameObject

Given (first) name of the individual



20
21
22
# File 'lib/trinsic_api/models/person_data.rb', line 20

def given_name
  @given_name
end

#middle_nameObject

Middle name of the individual



26
27
28
# File 'lib/trinsic_api/models/person_data.rb', line 26

def middle_name
  @middle_name
end

#nationalityObject

Returns the value of attribute nationality.



34
35
36
# File 'lib/trinsic_api/models/person_data.rb', line 34

def nationality
  @nationality
end

#phone_numberObject

Returns the value of attribute phone_number.



38
39
40
# File 'lib/trinsic_api/models/person_data.rb', line 38

def phone_number
  @phone_number
end

#sexObject

Returns the value of attribute sex.



36
37
38
# File 'lib/trinsic_api/models/person_data.rb', line 36

def sex
  @sex
end

#suffixObject

Suffix of the individual’s name



32
33
34
# File 'lib/trinsic_api/models/person_data.rb', line 32

def suffix
  @suffix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



84
85
86
# File 'lib/trinsic_api/models/person_data.rb', line 84

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/trinsic_api/models/person_data.rb', line 89

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/trinsic_api/models/person_data.rb', line 68

def self.attribute_map
  {
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'middle_name' => :'middleName',
    :'full_name' => :'fullName',
    :'suffix' => :'suffix',
    :'nationality' => :'nationality',
    :'sex' => :'sex',
    :'phone_number' => :'phoneNumber',
    :'address' => :'address',
    :'date_of_birth' => :'dateOfBirth'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/trinsic_api/models/person_data.rb', line 229

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/trinsic_api/models/person_data.rb', line 110

def self.openapi_nullable
  Set.new([
    :'given_name',
    :'family_name',
    :'middle_name',
    :'full_name',
    :'suffix',
    :'nationality',
    :'sex',
    :'phone_number',
    :'address',
    :'date_of_birth'
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/trinsic_api/models/person_data.rb', line 94

def self.openapi_types
  {
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'middle_name' => :'String',
    :'full_name' => :'String',
    :'suffix' => :'String',
    :'nationality' => :'String',
    :'sex' => :'Sex',
    :'phone_number' => :'String',
    :'address' => :'Address',
    :'date_of_birth' => :'Date'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



199
200
201
202
203
204
205
206
207
208
209
210
211
212
# File 'lib/trinsic_api/models/person_data.rb', line 199

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      middle_name == o.middle_name &&
      full_name == o.full_name &&
      suffix == o.suffix &&
      nationality == o.nationality &&
      sex == o.sex &&
      phone_number == o.phone_number &&
      address == o.address &&
      date_of_birth == o.date_of_birth
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


216
217
218
# File 'lib/trinsic_api/models/person_data.rb', line 216

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



222
223
224
# File 'lib/trinsic_api/models/person_data.rb', line 222

def hash
  [given_name, family_name, middle_name, full_name, suffix, nationality, sex, phone_number, address, date_of_birth].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



184
185
186
187
188
# File 'lib/trinsic_api/models/person_data.rb', line 184

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/trinsic_api/models/person_data.rb', line 251

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
# File 'lib/trinsic_api/models/person_data.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end