Class: TrinsicApi::PhilippinesDigitalNidProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::PhilippinesDigitalNidProviderOutput
- Defined in:
- lib/trinsic_api/models/philippines_digital_nid_provider_output.rb
Overview
Exposed properties for the philippines-digital-national-id-qr Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#date_of_birth ⇒ Object
The date of birth of the individual.
-
#document_issue_date ⇒ Object
The date the document was issued.
-
#document_number ⇒ Object
The document number of the digital National ID.
-
#family_name ⇒ Object
The family (last) name of the individual.
-
#given_name ⇒ Object
The given (first) name of the individual.
-
#issuing_authority ⇒ Object
The issuing authority of the document.
-
#middle_name ⇒ Object
The middle name of the individual.
-
#philsys_card_number ⇒ Object
The PhilSys Card Number (PCN).
-
#place_of_birth ⇒ Object
The place of birth of the individual as recorded on the PhilSys credential.
-
#sex ⇒ Object
The sex of the individual.
-
#suffix ⇒ Object
The name suffix of the individual (e.g. Jr., III).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PhilippinesDigitalNidProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PhilippinesDigitalNidProviderOutput
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PhilippinesDigitalNidProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PhilippinesDigitalNidProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'philsys_card_number') self.philsys_card_number = attributes[:'philsys_card_number'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'suffix') self.suffix = attributes[:'suffix'] end if attributes.key?(:'sex') self.sex = attributes[:'sex'] end if attributes.key?(:'place_of_birth') self.place_of_birth = attributes[:'place_of_birth'] end if attributes.key?(:'document_issue_date') self.document_issue_date = attributes[:'document_issue_date'] end if attributes.key?(:'document_number') self.document_number = attributes[:'document_number'] end if attributes.key?(:'issuing_authority') self. = attributes[:'issuing_authority'] end end |
Instance Attribute Details
#date_of_birth ⇒ Object
The date of birth of the individual.
32 33 34 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 32 def date_of_birth @date_of_birth end |
#document_issue_date ⇒ Object
The date the document was issued.
44 45 46 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 44 def document_issue_date @document_issue_date end |
#document_number ⇒ Object
The document number of the digital National ID.
47 48 49 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 47 def document_number @document_number end |
#family_name ⇒ Object
The family (last) name of the individual.
29 30 31 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 29 def family_name @family_name end |
#given_name ⇒ Object
The given (first) name of the individual.
23 24 25 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 23 def given_name @given_name end |
#issuing_authority ⇒ Object
The issuing authority of the document.
50 51 52 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 50 def @issuing_authority end |
#middle_name ⇒ Object
The middle name of the individual.
26 27 28 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 26 def middle_name @middle_name end |
#philsys_card_number ⇒ Object
The PhilSys Card Number (PCN). Every citizen or resident alien registered in PhilSys has a PhilSys Number (PSN). This number is tokenized into a card number to protect the PSN. The PhilSys Card Number is 12 characters long, and often is written in octets with dashes in between.
20 21 22 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 20 def philsys_card_number @philsys_card_number end |
#place_of_birth ⇒ Object
The place of birth of the individual as recorded on the PhilSys credential.
41 42 43 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 41 def place_of_birth @place_of_birth end |
#sex ⇒ Object
The sex of the individual. Possible values: - Male - Female
38 39 40 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 38 def sex @sex end |
#suffix ⇒ Object
The name suffix of the individual (e.g. Jr., III).
35 36 37 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 35 def suffix @suffix end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 53 def self.attribute_map { :'philsys_card_number' => :'philsysCardNumber', :'given_name' => :'givenName', :'middle_name' => :'middleName', :'family_name' => :'familyName', :'date_of_birth' => :'dateOfBirth', :'suffix' => :'suffix', :'sex' => :'sex', :'place_of_birth' => :'placeOfBirth', :'document_issue_date' => :'documentIssueDate', :'document_number' => :'documentNumber', :'issuing_authority' => :'issuingAuthority' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 222 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 97 def self.openapi_nullable Set.new([ :'philsys_card_number', :'given_name', :'middle_name', :'family_name', :'date_of_birth', :'suffix', :'sex', :'place_of_birth', :'document_issue_date', :'document_number', :'issuing_authority' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 80 def self.openapi_types { :'philsys_card_number' => :'String', :'given_name' => :'String', :'middle_name' => :'String', :'family_name' => :'String', :'date_of_birth' => :'Date', :'suffix' => :'String', :'sex' => :'String', :'place_of_birth' => :'String', :'document_issue_date' => :'Date', :'document_number' => :'String', :'issuing_authority' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && philsys_card_number == o.philsys_card_number && given_name == o.given_name && middle_name == o.middle_name && family_name == o.family_name && date_of_birth == o.date_of_birth && suffix == o.suffix && sex == o.sex && place_of_birth == o.place_of_birth && document_issue_date == o.document_issue_date && document_number == o.document_number && == o. end |
#eql?(o) ⇒ Boolean
209 210 211 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 209 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
215 216 217 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 215 def hash [philsys_card_number, given_name, middle_name, family_name, date_of_birth, suffix, sex, place_of_birth, document_issue_date, document_number, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
176 177 178 179 180 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 176 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
244 245 246 247 248 249 250 251 252 253 254 255 256 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 244 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
184 185 186 187 |
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 184 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |