Class: TrinsicApi::PhilippinesPhilsysMatchProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::PhilippinesPhilsysMatchProviderOutput
- Defined in:
- lib/trinsic_api/models/philippines_philsys_match_provider_output.rb
Overview
Exposed properties for the philippines-philsys-match Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#birth_date ⇒ Object
The individual's birth date.
-
#first_name ⇒ Object
The individual's given name.
-
#last_name ⇒ Object
The individual's family name.
-
#middle_name ⇒ Object
The individual's middle name, if provided.
-
#suffix ⇒ Object
The individual's name suffix, if provided.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PhilippinesPhilsysMatchProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PhilippinesPhilsysMatchProviderOutput
Initializes the object
79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 79 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PhilippinesPhilsysMatchProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PhilippinesPhilsysMatchProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'suffix') self.suffix = attributes[:'suffix'] end if attributes.key?(:'birth_date') self.birth_date = attributes[:'birth_date'] end end |
Instance Attribute Details
#birth_date ⇒ Object
The individual's birth date.
32 33 34 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 32 def birth_date @birth_date end |
#first_name ⇒ Object
The individual's given name.
20 21 22 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 20 def first_name @first_name end |
#last_name ⇒ Object
The individual's family name.
23 24 25 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 23 def last_name @last_name end |
#middle_name ⇒ Object
The individual's middle name, if provided.
26 27 28 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 26 def middle_name @middle_name end |
#suffix ⇒ Object
The individual's name suffix, if provided.
29 30 31 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 29 def suffix @suffix end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
46 47 48 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 46 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
51 52 53 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 51 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 35 def self.attribute_map { :'first_name' => :'firstName', :'last_name' => :'lastName', :'middle_name' => :'middleName', :'suffix' => :'suffix', :'birth_date' => :'birthDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 156 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 71 72 73 74 75 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 67 def self.openapi_nullable Set.new([ :'first_name', :'last_name', :'middle_name', :'suffix', :'birth_date' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
56 57 58 59 60 61 62 63 64 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 56 def self.openapi_types { :'first_name' => :'String', :'last_name' => :'String', :'middle_name' => :'String', :'suffix' => :'String', :'birth_date' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
131 132 133 134 135 136 137 138 139 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 131 def ==(o) return true if self.equal?(o) self.class == o.class && first_name == o.first_name && last_name == o.last_name && middle_name == o.middle_name && suffix == o.suffix && birth_date == o.birth_date end |
#eql?(o) ⇒ Boolean
143 144 145 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 143 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
149 150 151 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 149 def hash [first_name, last_name, middle_name, suffix, birth_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
178 179 180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 178 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 |
# File 'lib/trinsic_api/models/philippines_philsys_match_provider_output.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |