Class: TrinsicApi::PolandMobywatelMatchInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::PolandMobywatelMatchInput
- Defined in:
- lib/trinsic_api/models/poland_mobywatel_match_input.rb
Instance Attribute Summary collapse
-
#date_of_birth ⇒ Object
Date of birth as it appears on mobile ID (mDowód).
-
#expiration_date ⇒ Object
Document expiration date as it appears on mobile ID (mDowód).
-
#family_name ⇒ Object
Current legal family name (nazwisko) as it appears on mobile ID (mDowód).
-
#given_name ⇒ Object
Given name as it appears on mobile ID (mDowód).
-
#nationality ⇒ Object
Nationality as it appears on mobile ID (mDowód).
-
#personal_number ⇒ Object
Polish national identification number (PESEL) as it appears on mobile ID (mDowód).
-
#selfie_bytes ⇒ Object
The raw bytes of the selfie image collected from the user.
-
#selfie_image_mime_type ⇒ Object
The MIME Type of the file contained in SelfieBytes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PolandMobywatelMatchInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PolandMobywatelMatchInput
Initializes the object
96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 96 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PolandMobywatelMatchInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PolandMobywatelMatchInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'nationality') self.nationality = attributes[:'nationality'] end if attributes.key?(:'personal_number') self.personal_number = attributes[:'personal_number'] end if attributes.key?(:'expiration_date') self.expiration_date = attributes[:'expiration_date'] end if attributes.key?(:'selfie_bytes') self.selfie_bytes = attributes[:'selfie_bytes'] end if attributes.key?(:'selfie_image_mime_type') self.selfie_image_mime_type = attributes[:'selfie_image_mime_type'] end end |
Instance Attribute Details
#date_of_birth ⇒ Object
Date of birth as it appears on mobile ID (mDowód).
25 26 27 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 25 def date_of_birth @date_of_birth end |
#expiration_date ⇒ Object
Document expiration date as it appears on mobile ID (mDowód).
34 35 36 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 34 def expiration_date @expiration_date end |
#family_name ⇒ Object
Current legal family name (nazwisko) as it appears on mobile ID (mDowód). In Poland the current legal family name (nazwisko) is a separate idea from your birth family name (nazwisko rodowe). They often match, but they can differ after marriage, adoption, or a court-ordered change.
22 23 24 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 22 def family_name @family_name end |
#given_name ⇒ Object
Given name as it appears on mobile ID (mDowód).
19 20 21 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 19 def given_name @given_name end |
#nationality ⇒ Object
Nationality as it appears on mobile ID (mDowód).
28 29 30 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 28 def nationality @nationality end |
#personal_number ⇒ Object
Polish national identification number (PESEL) as it appears on mobile ID (mDowód). NOTE: The provided example value is a randomly generated, but valid PESEL number that does not correspond to a real person.
31 32 33 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 31 def personal_number @personal_number end |
#selfie_bytes ⇒ Object
The raw bytes of the selfie image collected from the user.
37 38 39 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 37 def selfie_bytes @selfie_bytes end |
#selfie_image_mime_type ⇒ Object
The MIME Type of the file contained in SelfieBytes. Only JPEG or PNG formats are supported.
40 41 42 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 40 def selfie_image_mime_type @selfie_image_mime_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 43 def self.attribute_map { :'given_name' => :'givenName', :'family_name' => :'familyName', :'date_of_birth' => :'dateOfBirth', :'nationality' => :'nationality', :'personal_number' => :'personalNumber', :'expiration_date' => :'expirationDate', :'selfie_bytes' => :'selfieBytes', :'selfie_image_mime_type' => :'selfieImageMimeType' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 188 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 81 def self.openapi_nullable Set.new([ :'given_name', :'family_name', :'date_of_birth', :'nationality', :'personal_number', :'expiration_date', :'selfie_bytes', :'selfie_image_mime_type' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 67 def self.openapi_types { :'given_name' => :'String', :'family_name' => :'String', :'date_of_birth' => :'String', :'nationality' => :'String', :'personal_number' => :'String', :'expiration_date' => :'String', :'selfie_bytes' => :'String', :'selfie_image_mime_type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 160 def ==(o) return true if self.equal?(o) self.class == o.class && given_name == o.given_name && family_name == o.family_name && date_of_birth == o.date_of_birth && nationality == o.nationality && personal_number == o.personal_number && expiration_date == o.expiration_date && selfie_bytes == o.selfie_bytes && selfie_image_mime_type == o.selfie_image_mime_type end |
#eql?(o) ⇒ Boolean
175 176 177 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 175 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
181 182 183 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 181 def hash [given_name, family_name, date_of_birth, nationality, personal_number, expiration_date, selfie_bytes, selfie_image_mime_type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
145 146 147 148 149 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 145 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 210 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 |
# File 'lib/trinsic_api/models/poland_mobywatel_match_input.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |