Class: TrinsicApi::PostOfficeEasyIdProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/post_office_easy_id_provider_output.rb

Overview

Exposed properties for the ‘post-office-easyid` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostOfficeEasyIdProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PostOfficeEasyIdProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PostOfficeEasyIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'remember_me_id')
    self.remember_me_id = attributes[:'remember_me_id']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'gender')
    self.gender = attributes[:'gender']
  end

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.key?(:'mobile_number')
    self.mobile_number = attributes[:'mobile_number']
  end

  if attributes.key?(:'structured_postal_address')
    self.structured_postal_address = attributes[:'structured_postal_address']
  end

  if attributes.key?(:'postal_address')
    self.postal_address = attributes[:'postal_address']
  end

  if attributes.key?(:'document_details')
    self.document_details = attributes[:'document_details']
  end
end

Instance Attribute Details

#date_of_birthObject

The date of birth of the individual. Unverified date of birth may be safe to use. For example, Aadhaar card provides date of birth, but due to certain limitations of verifying Aadhaar, Yoti is unable to verify this property so it is listed as "unverified".



35
36
37
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 35

def date_of_birth
  @date_of_birth
end

#document_detailsObject

The details of the underlying document used to help create the Yoti credential



53
54
55
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 53

def document_details
  @document_details
end

#emailObject

The email address of the individual



23
24
25
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 23

def email
  @email
end

#family_nameObject

The family name of the individual



29
30
31
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 29

def family_name
  @family_name
end

#full_nameObject

Full name of the individual which is composed of the given and family name. Unverified full name may be safe to use. For example, Aadhaar card provides full name, but due to certain limitations of verifying Aadhaar, Yoti is unable to verify this property so it is listed as "unverified".



32
33
34
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 32

def full_name
  @full_name
end

#genderObject

The gender of the individual. Depending on the source or country, gender may not be verified. This is a setting that can be configured while setting up scopes. Unverified gender may be safe to use. For example, Aadhaar card provides gender, but due to certain limitations of verifying Aadhaar, Yoti is unable to verify this property so it is listed as "unverified". In some countries Possible values: - "MALE" - "FEMALE" - "TRANSGENDER" - "OTHER"



38
39
40
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 38

def gender
  @gender
end

#given_nameObject

The given name of the individual. This can correspond to first and middle names in English.



26
27
28
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 26

def given_name
  @given_name
end

#mobile_numberObject

The mobile phone number of the individual. This number was verified with a one time password (OTP) during the individual’s registration with Yoti. In some cases, Yoti may do additional checks against its sources to confirm the individual’s identity.



44
45
46
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 44

def mobile_number
  @mobile_number
end

#nationalityObject

The nationality of the individual as a ISO alpha-3 code



41
42
43
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 41

def nationality
  @nationality
end

#postal_addressObject

The whole address for the individual that comes from the underlying document or can be manually added. In the case of being manually added, the address is considered "unverified". The format of this will be different for each country. Refer to ‘StructuredPostalAddress` for a detailed version of the address.



50
51
52
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 50

def postal_address
  @postal_address
end

#remember_me_idObject

A Yoti-generated unique ID for this individual, consistent across repeat shares and different for each Relying Party.



20
21
22
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 20

def remember_me_id
  @remember_me_id
end

#structured_postal_addressObject

A structured postal address for the individual that comes from the underlying document or can be manually added. In the case of being manually added, the address is considered "unverified". Unverified addresses may be safe to use. For example, Aadhaar card provides an address, but due to certain limitations of verifying Aadhaar, Yoti is unable to verify this property so it is listed as "unverified".



47
48
49
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 47

def structured_postal_address
  @structured_postal_address
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



74
75
76
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 74

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



79
80
81
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 79

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 56

def self.attribute_map
  {
    :'remember_me_id' => :'rememberMeId',
    :'email' => :'email',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'full_name' => :'fullName',
    :'date_of_birth' => :'dateOfBirth',
    :'gender' => :'gender',
    :'nationality' => :'nationality',
    :'mobile_number' => :'mobileNumber',
    :'structured_postal_address' => :'structuredPostalAddress',
    :'postal_address' => :'postalAddress',
    :'document_details' => :'documentDetails'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 233

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 102

def self.openapi_nullable
  Set.new([
    :'remember_me_id',
    :'email',
    :'given_name',
    :'family_name',
    :'full_name',
    :'date_of_birth',
    :'gender',
    :'nationality',
    :'mobile_number',
    :'structured_postal_address',
    :'postal_address',
    :'document_details'
  ])
end

.openapi_typesObject

Attribute type mapping.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 84

def self.openapi_types
  {
    :'remember_me_id' => :'String',
    :'email' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'full_name' => :'String',
    :'date_of_birth' => :'Date',
    :'gender' => :'String',
    :'nationality' => :'String',
    :'mobile_number' => :'String',
    :'structured_postal_address' => :'YotiStructuredPostalAddress',
    :'postal_address' => :'String',
    :'document_details' => :'YotiDocumentDetails'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 201

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      remember_me_id == o.remember_me_id &&
      email == o.email &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      full_name == o.full_name &&
      date_of_birth == o.date_of_birth &&
      gender == o.gender &&
      nationality == o.nationality &&
      mobile_number == o.mobile_number &&
      structured_postal_address == o.structured_postal_address &&
      postal_address == o.postal_address &&
      document_details == o.document_details
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


220
221
222
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 220

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



226
227
228
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 226

def hash
  [remember_me_id, email, given_name, family_name, full_name, date_of_birth, gender, nationality, mobile_number, structured_postal_address, postal_address, document_details].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



186
187
188
189
190
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 186

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



255
256
257
258
259
260
261
262
263
264
265
266
267
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 255

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
# File 'lib/trinsic_api/models/post_office_easy_id_provider_output.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end