Class: TrinsicApi::ProviderOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/provider_output.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



576
577
578
579
580
581
582
583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
719
720
721
722
723
724
725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
832
833
834
835
836
837
838
839
840
841
842
843
844
845
846
847
848
849
850
851
852
853
854
855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
874
875
876
877
878
879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
917
918
919
920
921
922
923
924
925
926
927
928
929
930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/trinsic_api/models/provider_output.rb', line 576

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'a_at_handy_signatur_login')
    self. = attributes[:'a_at_handy_signatur_login']
  end

  if attributes.key?(:'a_be_id_login')
    self. = attributes[:'a_be_id_login']
  end

  if attributes.key?(:'a_edoapp_eid_login')
    self. = attributes[:'a_edoapp_eid_login']
  end

  if attributes.key?(:'a_ee_web_eid_login')
    self. = attributes[:'a_ee_web_eid_login']
  end

  if attributes.key?(:'a_fi_id_login')
    self. = attributes[:'a_fi_id_login']
  end

  if attributes.key?(:'a_freja_eid_login')
    self. = attributes[:'a_freja_eid_login']
  end

  if attributes.key?(:'a_itsme_login')
    self. = attributes[:'a_itsme_login']
  end

  if attributes.key?(:'a_lt_id_login')
    self. = attributes[:'a_lt_id_login']
  end

  if attributes.key?(:'a_lv_eparaksts_id_login')
    self. = attributes[:'a_lv_eparaksts_id_login']
  end

  if attributes.key?(:'a_lv_eparaksts_mobile_login')
    self. = attributes[:'a_lv_eparaksts_mobile_login']
  end

  if attributes.key?(:'a_mojeid')
    self.a_mojeid = attributes[:'a_mojeid']
  end

  if attributes.key?(:'a_pl_mojeid_login')
    self. = attributes[:'a_pl_mojeid_login']
  end

  if attributes.key?(:'a_pt_id_login')
    self. = attributes[:'a_pt_id_login']
  end

  if attributes.key?(:'a_rs_id_login')
    self. = attributes[:'a_rs_id_login']
  end

  if attributes.key?(:'apple_wallet')
    self.apple_wallet = attributes[:'apple_wallet']
  end

  if attributes.key?(:'audkenni')
    self.audkenni = attributes[:'audkenni']
  end

  if attributes.key?(:'australia_connect_id')
    self.australia_connect_id = attributes[:'australia_connect_id']
  end

  if attributes.key?(:'austria_valera_eudi_sandbox')
    self.austria_valera_eudi_sandbox = attributes[:'austria_valera_eudi_sandbox']
  end

  if attributes.key?(:'bolivia_ci_lookup')
    self.bolivia_ci_lookup = attributes[:'bolivia_ci_lookup']
  end

  if attributes.key?(:'brazil_cpf_lookup')
    self.brazil_cpf_lookup = attributes[:'brazil_cpf_lookup']
  end

  if attributes.key?(:'brazil_digital_cnh')
    self.brazil_digital_cnh = attributes[:'brazil_digital_cnh']
  end

  if attributes.key?(:'canada_interac')
    self.canada_interac = attributes[:'canada_interac']
  end

  if attributes.key?(:'clear')
    self.clear = attributes[:'clear']
  end

  if attributes.key?(:'colombia_cc_lookup')
    self.colombia_cc_lookup = attributes[:'colombia_cc_lookup']
  end

  if attributes.key?(:'cote_divoire_nid_lookup_2')
    self.cote_divoire_nid_lookup_2 = attributes[:'cote_divoire_nid_lookup_2']
  end

  if attributes.key?(:'denmark_altid')
    self.denmark_altid = attributes[:'denmark_altid']
  end

  if attributes.key?(:'el_salvador_dui_lookup')
    self.el_salvador_dui_lookup = attributes[:'el_salvador_dui_lookup']
  end

  if attributes.key?(:'czech_bank_id')
    self.czech_bank_id = attributes[:'czech_bank_id']
  end

  if attributes.key?(:'czech_republic_mojeid')
    self.czech_republic_mojeid = attributes[:'czech_republic_mojeid']
  end

  if attributes.key?(:'denmark_mitid')
    self.denmark_mitid = attributes[:'denmark_mitid']
  end

  if attributes.key?(:'ethiopia_fayda')
    self.ethiopia_fayda = attributes[:'ethiopia_fayda']
  end

  if attributes.key?(:'evrotrust')
    self.evrotrust = attributes[:'evrotrust']
  end

  if attributes.key?(:'finnish_trust_network')
    self.finnish_trust_network = attributes[:'finnish_trust_network']
  end

  if attributes.key?(:'eudi_reference_wallet')
    self.eudi_reference_wallet = attributes[:'eudi_reference_wallet']
  end

  if attributes.key?(:'france_identite')
    self.france_identite = attributes[:'france_identite']
  end

  if attributes.key?(:'france_identite_numerique')
    self.france_identite_numerique = attributes[:'france_identite_numerique']
  end

  if attributes.key?(:'freja')
    self.freja = attributes[:'freja']
  end

  if attributes.key?(:'germany_eudi_sandbox')
    self.germany_eudi_sandbox = attributes[:'germany_eudi_sandbox']
  end

  if attributes.key?(:'google_wallet')
    self.google_wallet = attributes[:'google_wallet']
  end

  if attributes.key?(:'guatemala_cui_lookup')
    self.guatemala_cui_lookup = attributes[:'guatemala_cui_lookup']
  end

  if attributes.key?(:'panama_cedula_lookup')
    self.panama_cedula_lookup = attributes[:'panama_cedula_lookup']
  end

  if attributes.key?(:'india_digilocker_aadhaar')
    self.india_digilocker_aadhaar = attributes[:'india_digilocker_aadhaar']
  end

  if attributes.key?(:'india_digilocker_aadhaar_fetch')
    self.india_digilocker_aadhaar_fetch = attributes[:'india_digilocker_aadhaar_fetch']
  end

  if attributes.key?(:'india_digilocker_aadhaar_match')
    self.india_digilocker_aadhaar_match = attributes[:'india_digilocker_aadhaar_match']
  end

  if attributes.key?(:'india_pan_lookup')
    self.india_pan_lookup = attributes[:'india_pan_lookup']
  end

  if attributes.key?(:'indonesia_dukcapil_match')
    self.indonesia_dukcapil_match = attributes[:'indonesia_dukcapil_match']
  end

  if attributes.key?(:'indonesia_nik_lookup')
    self.indonesia_nik_lookup = attributes[:'indonesia_nik_lookup']
  end

  if attributes.key?(:'china_resident_id_match')
    self.china_resident_id_match = attributes[:'china_resident_id_match']
  end

  if attributes.key?(:'italy_spid')
    self.italy_spid = attributes[:'italy_spid']
  end

  if attributes.key?(:'itsme')
    self.itsme = attributes[:'itsme']
  end

  if attributes.key?(:'kenya_nid_lookup_2')
    self.kenya_nid_lookup_2 = attributes[:'kenya_nid_lookup_2']
  end

  if attributes.key?(:'kenya_nid_lookup_3')
    self.kenya_nid_lookup_3 = attributes[:'kenya_nid_lookup_3']
  end

  if attributes.key?(:'kenya_nid_match_2')
    self.kenya_nid_match_2 = attributes[:'kenya_nid_match_2']
  end

  if attributes.key?(:'korea_telco_match')
    self.korea_telco_match = attributes[:'korea_telco_match']
  end

  if attributes.key?(:'lloyds_smart_id')
    self.lloyds_smart_id = attributes[:'lloyds_smart_id']
  end

  if attributes.key?(:'mexico_curp_lookup')
    self.mexico_curp_lookup = attributes[:'mexico_curp_lookup']
  end

  if attributes.key?(:'mobile_id')
    self.mobile_id = attributes[:'mobile_id']
  end

  if attributes.key?(:'moldova_evo_wallet')
    self.moldova_evo_wallet = attributes[:'moldova_evo_wallet']
  end

  if attributes.key?(:'netherlands_eudi_sandbox')
    self.netherlands_eudi_sandbox = attributes[:'netherlands_eudi_sandbox']
  end

  if attributes.key?(:'nigeria_nin_lookup_2')
    self.nigeria_nin_lookup_2 = attributes[:'nigeria_nin_lookup_2']
  end

  if attributes.key?(:'nigeria_nin_lookup_3')
    self.nigeria_nin_lookup_3 = attributes[:'nigeria_nin_lookup_3']
  end

  if attributes.key?(:'nigeria_nin_match_2')
    self.nigeria_nin_match_2 = attributes[:'nigeria_nin_match_2']
  end

  if attributes.key?(:'oneid')
    self.oneid = attributes[:'oneid']
  end

  if attributes.key?(:'peru_dni_lookup')
    self.peru_dni_lookup = attributes[:'peru_dni_lookup']
  end

  if attributes.key?(:'norway_bankid')
    self.norway_bankid = attributes[:'norway_bankid']
  end

  if attributes.key?(:'philippines_digital_national_id_qr')
    self.philippines_digital_national_id_qr = attributes[:'philippines_digital_national_id_qr']
  end

  if attributes.key?(:'philippines_philsys_match')
    self.philippines_philsys_match = attributes[:'philippines_philsys_match']
  end

  if attributes.key?(:'philippines_physical_national_id_qr')
    self.philippines_physical_national_id_qr = attributes[:'philippines_physical_national_id_qr']
  end

  if attributes.key?(:'poland_mobywatel_match')
    self.poland_mobywatel_match = attributes[:'poland_mobywatel_match']
  end

  if attributes.key?(:'post_office_easyid')
    self.post_office_easyid = attributes[:'post_office_easyid']
  end

  if attributes.key?(:'samsung_wallet')
    self.samsung_wallet = attributes[:'samsung_wallet']
  end

  if attributes.key?(:'singpass_login')
    self. = attributes[:'singpass_login']
  end

  if attributes.key?(:'singpass_myinfo')
    self.singpass_myinfo = attributes[:'singpass_myinfo']
  end

  if attributes.key?(:'smart_id')
    self.smart_id = attributes[:'smart_id']
  end

  if attributes.key?(:'south_africa_nid_lookup_2')
    self.south_africa_nid_lookup_2 = attributes[:'south_africa_nid_lookup_2']
  end

  if attributes.key?(:'south_africa_nid_match_2')
    self.south_africa_nid_match_2 = attributes[:'south_africa_nid_match_2']
  end

  if attributes.key?(:'uae_pass')
    self.uae_pass = attributes[:'uae_pass']
  end

  if attributes.key?(:'uganda_nid_match_2')
    self.uganda_nid_match_2 = attributes[:'uganda_nid_match_2']
  end

  if attributes.key?(:'uk_evisa_lookup')
    self.uk_evisa_lookup = attributes[:'uk_evisa_lookup']
  end

  if attributes.key?(:'sweden_bankid')
    self.sweden_bankid = attributes[:'sweden_bankid']
  end

  if attributes.key?(:'ukraine_diia')
    self.ukraine_diia = attributes[:'ukraine_diia']
  end

  if attributes.key?(:'usa_alaska_mobile_id')
    self.usa_alaska_mobile_id = attributes[:'usa_alaska_mobile_id']
  end

  if attributes.key?(:'usa_louisiana_wallet')
    self.usa_louisiana_wallet = attributes[:'usa_louisiana_wallet']
  end

  if attributes.key?(:'usa_new_york_mobile_id')
    self.usa_new_york_mobile_id = attributes[:'usa_new_york_mobile_id']
  end

  if attributes.key?(:'netherlands_idin')
    self.netherlands_idin = attributes[:'netherlands_idin']
  end

  if attributes.key?(:'yoti')
    self.yoti = attributes[:'yoti']
  end

  if attributes.key?(:'yoti_deeplink')
    self.yoti_deeplink = attributes[:'yoti_deeplink']
  end

  if attributes.key?(:'zimbabwe_nid_lookup_2')
    self.zimbabwe_nid_lookup_2 = attributes[:'zimbabwe_nid_lookup_2']
  end
end

Instance Attribute Details

#a_at_handy_signatur_loginObject

Exposed properties for the a-at-handy-signatur-login Provider which do not directly map to the normalized IdentityData model.



19
20
21
# File 'lib/trinsic_api/models/provider_output.rb', line 19

def 
  @a_at_handy_signatur_login
end

#a_be_id_loginObject

Exposed properties for the a-be-id-login Provider which do not directly map to the normalized IdentityData model.



22
23
24
# File 'lib/trinsic_api/models/provider_output.rb', line 22

def 
  @a_be_id_login
end

#a_edoapp_eid_loginObject

Exposed properties for the a-edoapp-eid-login Provider which do not directly map to the normalized IdentityData model.



25
26
27
# File 'lib/trinsic_api/models/provider_output.rb', line 25

def 
  @a_edoapp_eid_login
end

#a_ee_web_eid_loginObject

Exposed properties for the a-ee-web-eid-login Provider which do not directly map to the normalized IdentityData model.



28
29
30
# File 'lib/trinsic_api/models/provider_output.rb', line 28

def 
  @a_ee_web_eid_login
end

#a_fi_id_loginObject

Exposed properties for the a-fi-id-login Provider which do not directly map to the normalized IdentityData model.



31
32
33
# File 'lib/trinsic_api/models/provider_output.rb', line 31

def 
  @a_fi_id_login
end

#a_freja_eid_loginObject

Exposed properties for the a-freja-eid-login Provider which do not directly map to the normalized IdentityData model.



34
35
36
# File 'lib/trinsic_api/models/provider_output.rb', line 34

def 
  @a_freja_eid_login
end

#a_itsme_loginObject

Exposed properties for the a-itsme-login Provider which do not directly map to the normalized IdentityData model.



37
38
39
# File 'lib/trinsic_api/models/provider_output.rb', line 37

def 
  @a_itsme_login
end

#a_lt_id_loginObject

Exposed properties for the a-lt-id-login Provider which do not directly map to the normalized IdentityData model.



40
41
42
# File 'lib/trinsic_api/models/provider_output.rb', line 40

def 
  @a_lt_id_login
end

#a_lv_eparaksts_id_loginObject

Exposed properties for the a-lv-eparaksts-id-login Provider which do not directly map to the normalized IdentityData model.



43
44
45
# File 'lib/trinsic_api/models/provider_output.rb', line 43

def 
  @a_lv_eparaksts_id_login
end

#a_lv_eparaksts_mobile_loginObject

Exposed properties for the a-lv-eparaksts-mobile-login Provider which do not directly map to the normalized IdentityData model.



46
47
48
# File 'lib/trinsic_api/models/provider_output.rb', line 46

def 
  @a_lv_eparaksts_mobile_login
end

#a_mojeidObject

Exposed properties for the a-mojeid Provider which do not directly map to the normalized IdentityData model.



49
50
51
# File 'lib/trinsic_api/models/provider_output.rb', line 49

def a_mojeid
  @a_mojeid
end

#a_pl_mojeid_loginObject

Exposed properties for the a-pl-mojeid-login Provider which do not directly map to the normalized IdentityData model.



52
53
54
# File 'lib/trinsic_api/models/provider_output.rb', line 52

def 
  @a_pl_mojeid_login
end

#a_pt_id_loginObject

Exposed properties for the a-pt-id-login Provider which do not directly map to the normalized IdentityData model.



55
56
57
# File 'lib/trinsic_api/models/provider_output.rb', line 55

def 
  @a_pt_id_login
end

#a_rs_id_loginObject

Exposed properties for the a-rs-id-login Provider which do not directly map to the normalized IdentityData model.



58
59
60
# File 'lib/trinsic_api/models/provider_output.rb', line 58

def 
  @a_rs_id_login
end

#apple_walletObject

Exposed properties for the apple-wallet Provider which do not directly map to the normalized IdentityData model.



61
62
63
# File 'lib/trinsic_api/models/provider_output.rb', line 61

def apple_wallet
  @apple_wallet
end

#audkenniObject

Exposed properties for the audkenni provider which do not directly map to the normalized IdentityData model.



64
65
66
# File 'lib/trinsic_api/models/provider_output.rb', line 64

def audkenni
  @audkenni
end

#australia_connect_idObject

Exposed properties for the australia-connect-id Provider which do not directly map to the normalized IdentityData model.



67
68
69
# File 'lib/trinsic_api/models/provider_output.rb', line 67

def australia_connect_id
  @australia_connect_id
end

#austria_valera_eudi_sandboxObject

Exposed properties for the austria-valera-eudi-sandbox Provider which do not directly map to the normalized IdentityData model.



70
71
72
# File 'lib/trinsic_api/models/provider_output.rb', line 70

def austria_valera_eudi_sandbox
  @austria_valera_eudi_sandbox
end

#bolivia_ci_lookupObject

Exposed properties for the bolivia-ci-lookup Provider which do not directly map to the normalized IdentityData model.



73
74
75
# File 'lib/trinsic_api/models/provider_output.rb', line 73

def bolivia_ci_lookup
  @bolivia_ci_lookup
end

#brazil_cpf_lookupObject

Exposed properties for the brazil-cpf-lookup Provider which do not directly map to the normalized IdentityData model.



76
77
78
# File 'lib/trinsic_api/models/provider_output.rb', line 76

def brazil_cpf_lookup
  @brazil_cpf_lookup
end

#brazil_digital_cnhObject

Exposed properties for the brazil-digital-cnh Provider which do not directly map to the normalized IdentityData model.



79
80
81
# File 'lib/trinsic_api/models/provider_output.rb', line 79

def brazil_digital_cnh
  @brazil_digital_cnh
end

#canada_interacObject

Exposed properties for the canada-interac Provider which do not directly map to the normalized IdentityData model.



82
83
84
# File 'lib/trinsic_api/models/provider_output.rb', line 82

def canada_interac
  @canada_interac
end

#china_resident_id_matchObject

Exposed properties for the china-resident-id-match Provider which do not directly map to the normalized IdentityData model.



160
161
162
# File 'lib/trinsic_api/models/provider_output.rb', line 160

def china_resident_id_match
  @china_resident_id_match
end

#clearObject

Exposed properties for the clear Provider which do not directly map to the normalized IdentityData model.



85
86
87
# File 'lib/trinsic_api/models/provider_output.rb', line 85

def clear
  @clear
end

#colombia_cc_lookupObject

Exposed properties for the colombia-cc-lookup Provider which do not directly map to the normalized IdentityData model.



88
89
90
# File 'lib/trinsic_api/models/provider_output.rb', line 88

def colombia_cc_lookup
  @colombia_cc_lookup
end

#cote_divoire_nid_lookup_2Object

Exposed properties for the cote-divoire-nid-lookup-2 Provider which do not directly map to the normalized IdentityData model.



91
92
93
# File 'lib/trinsic_api/models/provider_output.rb', line 91

def cote_divoire_nid_lookup_2
  @cote_divoire_nid_lookup_2
end

#czech_bank_idObject

Exposed properties for the czech-bank-id Provider which do not directly map to the normalized IdentityData model.



100
101
102
# File 'lib/trinsic_api/models/provider_output.rb', line 100

def czech_bank_id
  @czech_bank_id
end

#czech_republic_mojeidObject

Exposed properties for the czech-moje-id Provider which do not directly map to the normalized IdentityData model.



103
104
105
# File 'lib/trinsic_api/models/provider_output.rb', line 103

def czech_republic_mojeid
  @czech_republic_mojeid
end

#denmark_altidObject

Exposed properties for the denmark-altid Provider which do not directly map to the normalized IdentityData model.



94
95
96
# File 'lib/trinsic_api/models/provider_output.rb', line 94

def denmark_altid
  @denmark_altid
end

#denmark_mitidObject

Exposed properties for the denmark-mitid Provider which do not directly map to the normalized IdentityData model.



106
107
108
# File 'lib/trinsic_api/models/provider_output.rb', line 106

def denmark_mitid
  @denmark_mitid
end

#el_salvador_dui_lookupObject

Exposed properties for the el-salvador-dui-lookup Provider which do not directly map to the normalized IdentityData model.



97
98
99
# File 'lib/trinsic_api/models/provider_output.rb', line 97

def el_salvador_dui_lookup
  @el_salvador_dui_lookup
end

#ethiopia_faydaObject

Exposed properties for the ethiopia-fayda Provider which do not directly map to the normalized IdentityData model.



109
110
111
# File 'lib/trinsic_api/models/provider_output.rb', line 109

def ethiopia_fayda
  @ethiopia_fayda
end

#eudi_reference_walletObject

Exposed properties for the eudi-reference-wallet Provider which do not directly map to the normalized IdentityData model.



118
119
120
# File 'lib/trinsic_api/models/provider_output.rb', line 118

def eudi_reference_wallet
  @eudi_reference_wallet
end

#evrotrustObject

Exposed properties for the evrotrust Provider which do not directly map to the normalized IdentityData model.



112
113
114
# File 'lib/trinsic_api/models/provider_output.rb', line 112

def evrotrust
  @evrotrust
end

#finnish_trust_networkObject

Exposed properties for the finnish-trust-network Provider which do not directly map to the normalized IdentityData model.



115
116
117
# File 'lib/trinsic_api/models/provider_output.rb', line 115

def finnish_trust_network
  @finnish_trust_network
end

#france_identiteObject

Exposed properties for the france-identite Provider which do not directly map to the normalized IdentityData model.



121
122
123
# File 'lib/trinsic_api/models/provider_output.rb', line 121

def france_identite
  @france_identite
end

#france_identite_numeriqueObject

Exposed properties for the france-identite-numerique Provider which do not directly map to the normalized IdentityData model.



124
125
126
# File 'lib/trinsic_api/models/provider_output.rb', line 124

def france_identite_numerique
  @france_identite_numerique
end

#frejaObject

Exposed properties for the freja Provider which do not directly map to the normalized IdentityData model.



127
128
129
# File 'lib/trinsic_api/models/provider_output.rb', line 127

def freja
  @freja
end

#germany_eudi_sandboxObject

Exposed properties for the germany-eudi-sandbox Provider which do not directly map to the normalized IdentityData model.



130
131
132
# File 'lib/trinsic_api/models/provider_output.rb', line 130

def germany_eudi_sandbox
  @germany_eudi_sandbox
end

#google_walletObject

Exposed properties for the google-wallet Provider which do not directly map to the normalized IdentityData model.



133
134
135
# File 'lib/trinsic_api/models/provider_output.rb', line 133

def google_wallet
  @google_wallet
end

#guatemala_cui_lookupObject

Exposed properties for the guatemala-cui-lookup Provider which do not directly map to the normalized IdentityData model.



136
137
138
# File 'lib/trinsic_api/models/provider_output.rb', line 136

def guatemala_cui_lookup
  @guatemala_cui_lookup
end

#india_digilocker_aadhaarObject

Exposed properties for the india-digilocker-aadhaar Provider which do not directly map to the normalized IdentityData model.



142
143
144
# File 'lib/trinsic_api/models/provider_output.rb', line 142

def india_digilocker_aadhaar
  @india_digilocker_aadhaar
end

#india_digilocker_aadhaar_fetchObject

Exposed properties for the india-digilocker-aadhaar-fetch Provider which do not directly map to the normalized IdentityData model.



145
146
147
# File 'lib/trinsic_api/models/provider_output.rb', line 145

def india_digilocker_aadhaar_fetch
  @india_digilocker_aadhaar_fetch
end

#india_digilocker_aadhaar_matchObject

Exposed properties for the india-digilocker-aadhaar-match Provider which do not directly map to the normalized IdentityData model.



148
149
150
# File 'lib/trinsic_api/models/provider_output.rb', line 148

def india_digilocker_aadhaar_match
  @india_digilocker_aadhaar_match
end

#india_pan_lookupObject

Exposed properties for the india-pan-lookup Provider which do not directly map to the normalized IdentityData model.



151
152
153
# File 'lib/trinsic_api/models/provider_output.rb', line 151

def india_pan_lookup
  @india_pan_lookup
end

#indonesia_dukcapil_matchObject

Exposed properties for the indonesia-dukcapil-match Provider which do not directly map to the normalized IdentityData model.



154
155
156
# File 'lib/trinsic_api/models/provider_output.rb', line 154

def indonesia_dukcapil_match
  @indonesia_dukcapil_match
end

#indonesia_nik_lookupObject

Exposed properties for the indonesia-nik-lookup Provider which do not directly map to the normalized IdentityData model.



157
158
159
# File 'lib/trinsic_api/models/provider_output.rb', line 157

def indonesia_nik_lookup
  @indonesia_nik_lookup
end

#italy_spidObject

Exposed properties for the italy-spid Provider which do not directly map to the normalized IdentityData model.



163
164
165
# File 'lib/trinsic_api/models/provider_output.rb', line 163

def italy_spid
  @italy_spid
end

#itsmeObject

Exposed properties for the itsme Provider which do not directly map to the normalized IdentityData model.



166
167
168
# File 'lib/trinsic_api/models/provider_output.rb', line 166

def itsme
  @itsme
end

#kenya_nid_lookup_2Object

Exposed properties for the kenya-nid-lookup-2 Provider which do not directly map to the normalized IdentityData model.



169
170
171
# File 'lib/trinsic_api/models/provider_output.rb', line 169

def kenya_nid_lookup_2
  @kenya_nid_lookup_2
end

#kenya_nid_lookup_3Object

Exposed properties for the kenya-nid-lookup-3 Provider which do not directly map to the normalized IdentityData model.



172
173
174
# File 'lib/trinsic_api/models/provider_output.rb', line 172

def kenya_nid_lookup_3
  @kenya_nid_lookup_3
end

#kenya_nid_match_2Object

Exposed properties for the kenya-nid-match-2 Provider which do not directly map to the normalized IdentityData model.



175
176
177
# File 'lib/trinsic_api/models/provider_output.rb', line 175

def kenya_nid_match_2
  @kenya_nid_match_2
end

#korea_telco_matchObject

Exposed properties for the korea-telco-match Provider which do not directly map to the normalized IdentityData model.



178
179
180
# File 'lib/trinsic_api/models/provider_output.rb', line 178

def korea_telco_match
  @korea_telco_match
end

#lloyds_smart_idObject

Exposed properties for the lloyds-smart-id Provider which do not directly map to the normalized IdentityData model.



181
182
183
# File 'lib/trinsic_api/models/provider_output.rb', line 181

def lloyds_smart_id
  @lloyds_smart_id
end

#mexico_curp_lookupObject

Exposed properties for the mexico-curp-lookup Provider which do not directly map to the normalized IdentityData model.



184
185
186
# File 'lib/trinsic_api/models/provider_output.rb', line 184

def mexico_curp_lookup
  @mexico_curp_lookup
end

#mobile_idObject

Exposed properties for the mobile-id Provider which do not directly map to the normalized IdentityData model.



187
188
189
# File 'lib/trinsic_api/models/provider_output.rb', line 187

def mobile_id
  @mobile_id
end

#moldova_evo_walletObject

Exposed properties for the moldova-evo-wallet Provider which do not directly map to the normalized IdentityData model.



190
191
192
# File 'lib/trinsic_api/models/provider_output.rb', line 190

def moldova_evo_wallet
  @moldova_evo_wallet
end

#netherlands_eudi_sandboxObject

Exposed properties for the netherlands-eudi-sandbox Provider which do not directly map to the normalized IdentityData model.



193
194
195
# File 'lib/trinsic_api/models/provider_output.rb', line 193

def netherlands_eudi_sandbox
  @netherlands_eudi_sandbox
end

#netherlands_idinObject

Exposed properties for the netherlands-idin Provider which do not directly map to the normalized IdentityData model.



271
272
273
# File 'lib/trinsic_api/models/provider_output.rb', line 271

def netherlands_idin
  @netherlands_idin
end

#nigeria_nin_lookup_2Object

Exposed properties for the nigeria-nin-lookup-2 Provider which do not directly map to the normalized IdentityData model.



196
197
198
# File 'lib/trinsic_api/models/provider_output.rb', line 196

def nigeria_nin_lookup_2
  @nigeria_nin_lookup_2
end

#nigeria_nin_lookup_3Object

Exposed properties for the nigeria-nin-lookup-3 Provider which do not directly map to the normalized IdentityData model.



199
200
201
# File 'lib/trinsic_api/models/provider_output.rb', line 199

def nigeria_nin_lookup_3
  @nigeria_nin_lookup_3
end

#nigeria_nin_match_2Object

Exposed properties for the nigeria-nin-match-2 Provider which do not directly map to the normalized IdentityData model.



202
203
204
# File 'lib/trinsic_api/models/provider_output.rb', line 202

def nigeria_nin_match_2
  @nigeria_nin_match_2
end

#norway_bankidObject

Exposed properties for the norway-bankid Provider which do not directly map to the normalized IdentityData model.



211
212
213
# File 'lib/trinsic_api/models/provider_output.rb', line 211

def norway_bankid
  @norway_bankid
end

#oneidObject

Exposed properties for the oneid Provider which do not directly map to the normalized IdentityData model.



205
206
207
# File 'lib/trinsic_api/models/provider_output.rb', line 205

def oneid
  @oneid
end

#panama_cedula_lookupObject

Exposed properties for the panama-cedula-lookup Provider which do not directly map to the normalized IdentityData model.



139
140
141
# File 'lib/trinsic_api/models/provider_output.rb', line 139

def panama_cedula_lookup
  @panama_cedula_lookup
end

#peru_dni_lookupObject

Exposed properties for the peru-dni-lookup Provider which do not directly map to the normalized IdentityData model.



208
209
210
# File 'lib/trinsic_api/models/provider_output.rb', line 208

def peru_dni_lookup
  @peru_dni_lookup
end

#philippines_digital_national_id_qrObject

Exposed properties for the philippines-digital-national-id-qr Provider which do not directly map to the normalized IdentityData model.



214
215
216
# File 'lib/trinsic_api/models/provider_output.rb', line 214

def philippines_digital_national_id_qr
  @philippines_digital_national_id_qr
end

#philippines_philsys_matchObject

Exposed properties for the philippines-philsys-match Provider which do not directly map to the normalized IdentityData model.



217
218
219
# File 'lib/trinsic_api/models/provider_output.rb', line 217

def philippines_philsys_match
  @philippines_philsys_match
end

#philippines_physical_national_id_qrObject

Exposed properties for the philippines-physical-national-id-qr Provider which do not directly map to the normalized IdentityData model.



220
221
222
# File 'lib/trinsic_api/models/provider_output.rb', line 220

def philippines_physical_national_id_qr
  @philippines_physical_national_id_qr
end

#poland_mobywatel_matchObject

Exposed properties for the poland-mobywatel-match Provider which do not directly map to the normalized IdentityData model.



223
224
225
# File 'lib/trinsic_api/models/provider_output.rb', line 223

def poland_mobywatel_match
  @poland_mobywatel_match
end

#post_office_easyidObject

Exposed properties for the post-office-easyid Provider which do not directly map to the normalized IdentityData model.



226
227
228
# File 'lib/trinsic_api/models/provider_output.rb', line 226

def post_office_easyid
  @post_office_easyid
end

#samsung_walletObject

Exposed properties for the samsung-wallet Provider which do not directly map to the normalized IdentityData model.



229
230
231
# File 'lib/trinsic_api/models/provider_output.rb', line 229

def samsung_wallet
  @samsung_wallet
end

#singpass_loginObject

Exposed properties for the singpass-login Provider which do not directly map to the normalized IdentityData model.



232
233
234
# File 'lib/trinsic_api/models/provider_output.rb', line 232

def 
  @singpass_login
end

#singpass_myinfoObject

Exposed properties for the singpass-myinfo Provider which do not directly map to the normalized IdentityData model.



235
236
237
# File 'lib/trinsic_api/models/provider_output.rb', line 235

def singpass_myinfo
  @singpass_myinfo
end

#smart_idObject

Exposed properties for the smart-id Provider which do not directly map to the normalized IdentityData model.



238
239
240
# File 'lib/trinsic_api/models/provider_output.rb', line 238

def smart_id
  @smart_id
end

#south_africa_nid_lookup_2Object

Exposed properties for the south-africa-nid-lookup-2 Provider which do not directly map to the normalized IdentityData model.



241
242
243
# File 'lib/trinsic_api/models/provider_output.rb', line 241

def south_africa_nid_lookup_2
  @south_africa_nid_lookup_2
end

#south_africa_nid_match_2Object

Exposed properties for the south-africa-nid-match-2 Provider which do not directly map to the normalized IdentityData model.



244
245
246
# File 'lib/trinsic_api/models/provider_output.rb', line 244

def south_africa_nid_match_2
  @south_africa_nid_match_2
end

#sweden_bankidObject

Exposed properties for the sweden-bankid Provider which do not directly map to the normalized IdentityData model.



256
257
258
# File 'lib/trinsic_api/models/provider_output.rb', line 256

def sweden_bankid
  @sweden_bankid
end

#uae_passObject

Exposed properties for the uae-pass Provider which do not directly map to the normalized IdentityData model.



247
248
249
# File 'lib/trinsic_api/models/provider_output.rb', line 247

def uae_pass
  @uae_pass
end

#uganda_nid_match_2Object

Exposed properties for the uganda-nid-match-2 Provider which do not directly map to the normalized IdentityData model.



250
251
252
# File 'lib/trinsic_api/models/provider_output.rb', line 250

def uganda_nid_match_2
  @uganda_nid_match_2
end

#uk_evisa_lookupObject

Exposed properties for the uk-evisa-lookup Provider which do not directly map to the normalized IdentityData model.



253
254
255
# File 'lib/trinsic_api/models/provider_output.rb', line 253

def uk_evisa_lookup
  @uk_evisa_lookup
end

#ukraine_diiaObject

Exposed properties for the ukraine-diia Provider which do not directly map to the normalized IdentityData model.



259
260
261
# File 'lib/trinsic_api/models/provider_output.rb', line 259

def ukraine_diia
  @ukraine_diia
end

#usa_alaska_mobile_idObject

Exposed properties for the usa-alaska-mobile-id Provider which do not directly map to the normalized IdentityData model.



262
263
264
# File 'lib/trinsic_api/models/provider_output.rb', line 262

def usa_alaska_mobile_id
  @usa_alaska_mobile_id
end

#usa_louisiana_walletObject

Exposed properties for the usa-louisiana-wallet Provider which do not directly map to the normalized IdentityData model.



265
266
267
# File 'lib/trinsic_api/models/provider_output.rb', line 265

def usa_louisiana_wallet
  @usa_louisiana_wallet
end

#usa_new_york_mobile_idObject

Exposed properties for the usa-new-york-mobile-id Provider which do not directly map to the normalized IdentityData model.



268
269
270
# File 'lib/trinsic_api/models/provider_output.rb', line 268

def usa_new_york_mobile_id
  @usa_new_york_mobile_id
end

#yotiObject

Exposed properties for the yoti Provider which do not directly map to the normalized IdentityData model.



274
275
276
# File 'lib/trinsic_api/models/provider_output.rb', line 274

def yoti
  @yoti
end

Exposed properties for the yoti-deeplink Provider which do not directly map to the normalized IdentityData model.



277
278
279
# File 'lib/trinsic_api/models/provider_output.rb', line 277

def yoti_deeplink
  @yoti_deeplink
end

#zimbabwe_nid_lookup_2Object

Exposed properties for the zimbabwe-nid-lookup-2 Provider which do not directly map to the normalized IdentityData model.



280
281
282
# File 'lib/trinsic_api/models/provider_output.rb', line 280

def zimbabwe_nid_lookup_2
  @zimbabwe_nid_lookup_2
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



377
378
379
# File 'lib/trinsic_api/models/provider_output.rb', line 377

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



382
383
384
# File 'lib/trinsic_api/models/provider_output.rb', line 382

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/trinsic_api/models/provider_output.rb', line 283

def self.attribute_map
  {
    :'a_at_handy_signatur_login' => :'a-at-handy-signatur-login',
    :'a_be_id_login' => :'a-be-id-login',
    :'a_edoapp_eid_login' => :'a-edoapp-eid-login',
    :'a_ee_web_eid_login' => :'a-ee-web-eid-login',
    :'a_fi_id_login' => :'a-fi-id-login',
    :'a_freja_eid_login' => :'a-freja-eid-login',
    :'a_itsme_login' => :'a-itsme-login',
    :'a_lt_id_login' => :'a-lt-id-login',
    :'a_lv_eparaksts_id_login' => :'a-lv-eparaksts-id-login',
    :'a_lv_eparaksts_mobile_login' => :'a-lv-eparaksts-mobile-login',
    :'a_mojeid' => :'a-mojeid',
    :'a_pl_mojeid_login' => :'a-pl-mojeid-login',
    :'a_pt_id_login' => :'a-pt-id-login',
    :'a_rs_id_login' => :'a-rs-id-login',
    :'apple_wallet' => :'apple-wallet',
    :'audkenni' => :'audkenni',
    :'australia_connect_id' => :'australia-connect-id',
    :'austria_valera_eudi_sandbox' => :'austria-valera-eudi-sandbox',
    :'bolivia_ci_lookup' => :'bolivia-ci-lookup',
    :'brazil_cpf_lookup' => :'brazil-cpf-lookup',
    :'brazil_digital_cnh' => :'brazil-digital-cnh',
    :'canada_interac' => :'canada-interac',
    :'clear' => :'clear',
    :'colombia_cc_lookup' => :'colombia-cc-lookup',
    :'cote_divoire_nid_lookup_2' => :'cote-divoire-nid-lookup-2',
    :'denmark_altid' => :'denmark-altid',
    :'el_salvador_dui_lookup' => :'el-salvador-dui-lookup',
    :'czech_bank_id' => :'czech-bank-id',
    :'czech_republic_mojeid' => :'czech-republic-mojeid',
    :'denmark_mitid' => :'denmark-mitid',
    :'ethiopia_fayda' => :'ethiopia-fayda',
    :'evrotrust' => :'evrotrust',
    :'finnish_trust_network' => :'finnish-trust-network',
    :'eudi_reference_wallet' => :'eudi-reference-wallet',
    :'france_identite' => :'france-identite',
    :'france_identite_numerique' => :'france-identite-numerique',
    :'freja' => :'freja',
    :'germany_eudi_sandbox' => :'germany-eudi-sandbox',
    :'google_wallet' => :'google-wallet',
    :'guatemala_cui_lookup' => :'guatemala-cui-lookup',
    :'panama_cedula_lookup' => :'panama-cedula-lookup',
    :'india_digilocker_aadhaar' => :'india-digilocker-aadhaar',
    :'india_digilocker_aadhaar_fetch' => :'india-digilocker-aadhaar-fetch',
    :'india_digilocker_aadhaar_match' => :'india-digilocker-aadhaar-match',
    :'india_pan_lookup' => :'india-pan-lookup',
    :'indonesia_dukcapil_match' => :'indonesia-dukcapil-match',
    :'indonesia_nik_lookup' => :'indonesia-nik-lookup',
    :'china_resident_id_match' => :'china-resident-id-match',
    :'italy_spid' => :'italy-spid',
    :'itsme' => :'itsme',
    :'kenya_nid_lookup_2' => :'kenya-nid-lookup-2',
    :'kenya_nid_lookup_3' => :'kenya-nid-lookup-3',
    :'kenya_nid_match_2' => :'kenya-nid-match-2',
    :'korea_telco_match' => :'korea-telco-match',
    :'lloyds_smart_id' => :'lloyds-smart-id',
    :'mexico_curp_lookup' => :'mexico-curp-lookup',
    :'mobile_id' => :'mobile-id',
    :'moldova_evo_wallet' => :'moldova-evo-wallet',
    :'netherlands_eudi_sandbox' => :'netherlands-eudi-sandbox',
    :'nigeria_nin_lookup_2' => :'nigeria-nin-lookup-2',
    :'nigeria_nin_lookup_3' => :'nigeria-nin-lookup-3',
    :'nigeria_nin_match_2' => :'nigeria-nin-match-2',
    :'oneid' => :'oneid',
    :'peru_dni_lookup' => :'peru-dni-lookup',
    :'norway_bankid' => :'norway-bankid',
    :'philippines_digital_national_id_qr' => :'philippines-digital-national-id-qr',
    :'philippines_philsys_match' => :'philippines-philsys-match',
    :'philippines_physical_national_id_qr' => :'philippines-physical-national-id-qr',
    :'poland_mobywatel_match' => :'poland-mobywatel-match',
    :'post_office_easyid' => :'post-office-easyid',
    :'samsung_wallet' => :'samsung-wallet',
    :'singpass_login' => :'singpass-login',
    :'singpass_myinfo' => :'singpass-myinfo',
    :'smart_id' => :'smart-id',
    :'south_africa_nid_lookup_2' => :'south-africa-nid-lookup-2',
    :'south_africa_nid_match_2' => :'south-africa-nid-match-2',
    :'uae_pass' => :'uae-pass',
    :'uganda_nid_match_2' => :'uganda-nid-match-2',
    :'uk_evisa_lookup' => :'uk-evisa-lookup',
    :'sweden_bankid' => :'sweden-bankid',
    :'ukraine_diia' => :'ukraine-diia',
    :'usa_alaska_mobile_id' => :'usa-alaska-mobile-id',
    :'usa_louisiana_wallet' => :'usa-louisiana-wallet',
    :'usa_new_york_mobile_id' => :'usa-new-york-mobile-id',
    :'netherlands_idin' => :'netherlands-idin',
    :'yoti' => :'yoti',
    :'yoti_deeplink' => :'yoti-deeplink',
    :'zimbabwe_nid_lookup_2' => :'zimbabwe-nid-lookup-2'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



1068
1069
1070
1071
1072
1073
1074
1075
1076
1077
1078
1079
1080
1081
1082
1083
1084
1085
1086
# File 'lib/trinsic_api/models/provider_output.rb', line 1068

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
# File 'lib/trinsic_api/models/provider_output.rb', line 481

def self.openapi_nullable
  Set.new([
    :'a_at_handy_signatur_login',
    :'a_be_id_login',
    :'a_edoapp_eid_login',
    :'a_ee_web_eid_login',
    :'a_fi_id_login',
    :'a_freja_eid_login',
    :'a_itsme_login',
    :'a_lt_id_login',
    :'a_lv_eparaksts_id_login',
    :'a_lv_eparaksts_mobile_login',
    :'a_mojeid',
    :'a_pl_mojeid_login',
    :'a_pt_id_login',
    :'a_rs_id_login',
    :'apple_wallet',
    :'audkenni',
    :'australia_connect_id',
    :'austria_valera_eudi_sandbox',
    :'bolivia_ci_lookup',
    :'brazil_cpf_lookup',
    :'brazil_digital_cnh',
    :'canada_interac',
    :'clear',
    :'colombia_cc_lookup',
    :'cote_divoire_nid_lookup_2',
    :'denmark_altid',
    :'el_salvador_dui_lookup',
    :'czech_bank_id',
    :'czech_republic_mojeid',
    :'denmark_mitid',
    :'ethiopia_fayda',
    :'evrotrust',
    :'finnish_trust_network',
    :'eudi_reference_wallet',
    :'france_identite',
    :'france_identite_numerique',
    :'freja',
    :'germany_eudi_sandbox',
    :'google_wallet',
    :'guatemala_cui_lookup',
    :'panama_cedula_lookup',
    :'india_digilocker_aadhaar',
    :'india_digilocker_aadhaar_fetch',
    :'india_digilocker_aadhaar_match',
    :'india_pan_lookup',
    :'indonesia_dukcapil_match',
    :'indonesia_nik_lookup',
    :'china_resident_id_match',
    :'italy_spid',
    :'itsme',
    :'kenya_nid_lookup_2',
    :'kenya_nid_lookup_3',
    :'kenya_nid_match_2',
    :'korea_telco_match',
    :'lloyds_smart_id',
    :'mexico_curp_lookup',
    :'mobile_id',
    :'moldova_evo_wallet',
    :'netherlands_eudi_sandbox',
    :'nigeria_nin_lookup_2',
    :'nigeria_nin_lookup_3',
    :'nigeria_nin_match_2',
    :'oneid',
    :'peru_dni_lookup',
    :'norway_bankid',
    :'philippines_digital_national_id_qr',
    :'philippines_philsys_match',
    :'philippines_physical_national_id_qr',
    :'poland_mobywatel_match',
    :'post_office_easyid',
    :'samsung_wallet',
    :'singpass_login',
    :'singpass_myinfo',
    :'smart_id',
    :'south_africa_nid_lookup_2',
    :'south_africa_nid_match_2',
    :'uae_pass',
    :'uganda_nid_match_2',
    :'uk_evisa_lookup',
    :'sweden_bankid',
    :'ukraine_diia',
    :'usa_alaska_mobile_id',
    :'usa_louisiana_wallet',
    :'usa_new_york_mobile_id',
    :'netherlands_idin',
    :'yoti',
    :'yoti_deeplink',
    :'zimbabwe_nid_lookup_2'
  ])
end

.openapi_typesObject

Attribute type mapping.



387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
# File 'lib/trinsic_api/models/provider_output.rb', line 387

def self.openapi_types
  {
    :'a_at_handy_signatur_login' => :'AustriaHandySignaturProviderOutput',
    :'a_be_id_login' => :'BelgiumIdCardProviderOutput',
    :'a_edoapp_eid_login' => :'PolandEdoAppProviderOutput',
    :'a_ee_web_eid_login' => :'EstoniaIdCardProviderOutput',
    :'a_fi_id_login' => :'FinlandIdCardProviderOutput',
    :'a_freja_eid_login' => :'FrejaIndirectProviderOutput',
    :'a_itsme_login' => :'ItsmeLoginProviderOutput',
    :'a_lt_id_login' => :'LithuaniaIdCardProviderOutput',
    :'a_lv_eparaksts_id_login' => :'LatviaEparakstsProviderOutput',
    :'a_lv_eparaksts_mobile_login' => :'LatviaEparakstsMobileProviderOutput',
    :'a_mojeid' => :'CzechiaMojeIdProviderOutput',
    :'a_pl_mojeid_login' => :'PolandMojeIdProviderOutput',
    :'a_pt_id_login' => :'PortugalIdCardProviderOutput',
    :'a_rs_id_login' => :'SerbiaIdCardProviderOutput',
    :'apple_wallet' => :'AppleWalletProviderOutput',
    :'audkenni' => :'AudkenniProviderOutput',
    :'australia_connect_id' => :'ConnectIdProviderOutput',
    :'austria_valera_eudi_sandbox' => :'AustriaValeraEudiSandboxProviderOutput',
    :'bolivia_ci_lookup' => :'BoliviaCiProviderOutput',
    :'brazil_cpf_lookup' => :'BrazilCpfProviderOutput',
    :'brazil_digital_cnh' => :'BrazilCnhProviderOutput',
    :'canada_interac' => :'InteracProviderOutput',
    :'clear' => :'ClearProviderOutput',
    :'colombia_cc_lookup' => :'ColombiaCcProviderOutput',
    :'cote_divoire_nid_lookup_2' => :'CoteDIvoireNidLookup2ProviderOutput',
    :'denmark_altid' => :'DenmarkAltIdProviderOutput',
    :'el_salvador_dui_lookup' => :'ElSalvadorDuiProviderOutput',
    :'czech_bank_id' => :'CzechBankIdProviderOutput',
    :'czech_republic_mojeid' => :'CzechMojeIdProviderOutput',
    :'denmark_mitid' => :'MitIdProviderOutput',
    :'ethiopia_fayda' => :'FaydaProviderOutput',
    :'evrotrust' => :'EvrotrustProviderOutput',
    :'finnish_trust_network' => :'FinnishTrustNetworkProviderOutput',
    :'eudi_reference_wallet' => :'EudiReferenceWalletProviderOutput',
    :'france_identite' => :'FranceIdentiteProviderOutput',
    :'france_identite_numerique' => :'FrenchNumeriqueProviderOutput',
    :'freja' => :'FrejaProviderOutput',
    :'germany_eudi_sandbox' => :'GermanyEudiSandboxProviderOutput',
    :'google_wallet' => :'GoogleWalletProviderOutput',
    :'guatemala_cui_lookup' => :'GuatemalaCuiProviderOutput',
    :'panama_cedula_lookup' => :'PanamaCedulaProviderOutput',
    :'india_digilocker_aadhaar' => :'DigilockerAadhaarProviderOutput',
    :'india_digilocker_aadhaar_fetch' => :'SignzyIndiaAadhaarFetchProviderOutput',
    :'india_digilocker_aadhaar_match' => :'IndiaDigilockerAadhaarMatchProviderOutput',
    :'india_pan_lookup' => :'IndiaPanLookupProviderOutput',
    :'indonesia_dukcapil_match' => :'IndonesiaDukcapilMatchProviderOutput',
    :'indonesia_nik_lookup' => :'IndonesiaNikMatch',
    :'china_resident_id_match' => :'ChinaResidentIdMatchOutput',
    :'italy_spid' => :'SpidProviderOutput',
    :'itsme' => :'ItsmeProviderOutput',
    :'kenya_nid_lookup_2' => :'KenyaNidLookup2ProviderOutput',
    :'kenya_nid_lookup_3' => :'KenyaNidLookup3ProviderOutput',
    :'kenya_nid_match_2' => :'KenyaNidMatch2ProviderOutput',
    :'korea_telco_match' => :'KoreaTelcoMatchProviderOutput',
    :'lloyds_smart_id' => :'LloydsSmartIdProviderOutput',
    :'mexico_curp_lookup' => :'MexicoCurpProviderOutput',
    :'mobile_id' => :'MobileIdProviderOutput',
    :'moldova_evo_wallet' => :'MoldovaEvoWalletProviderOutput',
    :'netherlands_eudi_sandbox' => :'NetherlandsEudiSandboxProviderOutput',
    :'nigeria_nin_lookup_2' => :'NigeriaNinLookup2ProviderOutput',
    :'nigeria_nin_lookup_3' => :'NigeriaNinLookup3ProviderOutput',
    :'nigeria_nin_match_2' => :'NigeriaNinMatch2ProviderOutput',
    :'oneid' => :'OneIdProviderOutput',
    :'peru_dni_lookup' => :'PeruDniProviderOutput',
    :'norway_bankid' => :'NorwegianBankIdProviderOutput',
    :'philippines_digital_national_id_qr' => :'PhilippinesDigitalNidProviderOutput',
    :'philippines_philsys_match' => :'PhilippinesPhilsysMatchProviderOutput',
    :'philippines_physical_national_id_qr' => :'PhilippinesPhysicalNidProviderOutput',
    :'poland_mobywatel_match' => :'PolandMobywatelMatchProviderOutput',
    :'post_office_easyid' => :'PostOfficeEasyIdProviderOutput',
    :'samsung_wallet' => :'SamsungWalletProviderOutput',
    :'singpass_login' => :'SingpassLoginProviderOutput',
    :'singpass_myinfo' => :'SingpassMyInfoProviderOutput',
    :'smart_id' => :'SmartIdProviderOutput',
    :'south_africa_nid_lookup_2' => :'SouthAfricaNidLookup2ProviderOutput',
    :'south_africa_nid_match_2' => :'SouthAfricaNidMatch2ProviderOutput',
    :'uae_pass' => :'UAEPassProviderOutput',
    :'uganda_nid_match_2' => :'UgandaNidMatch2ProviderOutput',
    :'uk_evisa_lookup' => :'UnitedKingdomEvisaProviderOutput',
    :'sweden_bankid' => :'SwedenBankIdProviderOutput',
    :'ukraine_diia' => :'DiiaProviderOutput',
    :'usa_alaska_mobile_id' => :'AlaskaMobileIdProviderOutput',
    :'usa_louisiana_wallet' => :'LaWalletProviderOutput',
    :'usa_new_york_mobile_id' => :'IdemiaMobileIdProviderOutput',
    :'netherlands_idin' => :'NetherlandsIdinProviderOutput',
    :'yoti' => :'YotiProviderOutput',
    :'yoti_deeplink' => :'YotiDeeplinkProviderOutput',
    :'zimbabwe_nid_lookup_2' => :'ZimbabweNidLookup2ProviderOutput'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



960
961
962
963
964
965
966
967
968
969
970
971
972
973
974
975
976
977
978
979
980
981
982
983
984
985
986
987
988
989
990
991
992
993
994
995
996
997
998
999
1000
1001
1002
1003
1004
1005
1006
1007
1008
1009
1010
1011
1012
1013
1014
1015
1016
1017
1018
1019
1020
1021
1022
1023
1024
1025
1026
1027
1028
1029
1030
1031
1032
1033
1034
1035
1036
1037
1038
1039
1040
1041
1042
1043
1044
1045
1046
1047
1048
1049
1050
1051
# File 'lib/trinsic_api/models/provider_output.rb', line 960

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
       == o. &&
      a_mojeid == o.a_mojeid &&
       == o. &&
       == o. &&
       == o. &&
      apple_wallet == o.apple_wallet &&
      audkenni == o.audkenni &&
      australia_connect_id == o.australia_connect_id &&
      austria_valera_eudi_sandbox == o.austria_valera_eudi_sandbox &&
      bolivia_ci_lookup == o.bolivia_ci_lookup &&
      brazil_cpf_lookup == o.brazil_cpf_lookup &&
      brazil_digital_cnh == o.brazil_digital_cnh &&
      canada_interac == o.canada_interac &&
      clear == o.clear &&
      colombia_cc_lookup == o.colombia_cc_lookup &&
      cote_divoire_nid_lookup_2 == o.cote_divoire_nid_lookup_2 &&
      denmark_altid == o.denmark_altid &&
      el_salvador_dui_lookup == o.el_salvador_dui_lookup &&
      czech_bank_id == o.czech_bank_id &&
      czech_republic_mojeid == o.czech_republic_mojeid &&
      denmark_mitid == o.denmark_mitid &&
      ethiopia_fayda == o.ethiopia_fayda &&
      evrotrust == o.evrotrust &&
      finnish_trust_network == o.finnish_trust_network &&
      eudi_reference_wallet == o.eudi_reference_wallet &&
      france_identite == o.france_identite &&
      france_identite_numerique == o.france_identite_numerique &&
      freja == o.freja &&
      germany_eudi_sandbox == o.germany_eudi_sandbox &&
      google_wallet == o.google_wallet &&
      guatemala_cui_lookup == o.guatemala_cui_lookup &&
      panama_cedula_lookup == o.panama_cedula_lookup &&
      india_digilocker_aadhaar == o.india_digilocker_aadhaar &&
      india_digilocker_aadhaar_fetch == o.india_digilocker_aadhaar_fetch &&
      india_digilocker_aadhaar_match == o.india_digilocker_aadhaar_match &&
      india_pan_lookup == o.india_pan_lookup &&
      indonesia_dukcapil_match == o.indonesia_dukcapil_match &&
      indonesia_nik_lookup == o.indonesia_nik_lookup &&
      china_resident_id_match == o.china_resident_id_match &&
      italy_spid == o.italy_spid &&
      itsme == o.itsme &&
      kenya_nid_lookup_2 == o.kenya_nid_lookup_2 &&
      kenya_nid_lookup_3 == o.kenya_nid_lookup_3 &&
      kenya_nid_match_2 == o.kenya_nid_match_2 &&
      korea_telco_match == o.korea_telco_match &&
      lloyds_smart_id == o.lloyds_smart_id &&
      mexico_curp_lookup == o.mexico_curp_lookup &&
      mobile_id == o.mobile_id &&
      moldova_evo_wallet == o.moldova_evo_wallet &&
      netherlands_eudi_sandbox == o.netherlands_eudi_sandbox &&
      nigeria_nin_lookup_2 == o.nigeria_nin_lookup_2 &&
      nigeria_nin_lookup_3 == o.nigeria_nin_lookup_3 &&
      nigeria_nin_match_2 == o.nigeria_nin_match_2 &&
      oneid == o.oneid &&
      peru_dni_lookup == o.peru_dni_lookup &&
      norway_bankid == o.norway_bankid &&
      philippines_digital_national_id_qr == o.philippines_digital_national_id_qr &&
      philippines_philsys_match == o.philippines_philsys_match &&
      philippines_physical_national_id_qr == o.philippines_physical_national_id_qr &&
      poland_mobywatel_match == o.poland_mobywatel_match &&
      post_office_easyid == o.post_office_easyid &&
      samsung_wallet == o.samsung_wallet &&
       == o. &&
      singpass_myinfo == o.singpass_myinfo &&
      smart_id == o.smart_id &&
      south_africa_nid_lookup_2 == o.south_africa_nid_lookup_2 &&
      south_africa_nid_match_2 == o.south_africa_nid_match_2 &&
      uae_pass == o.uae_pass &&
      uganda_nid_match_2 == o.uganda_nid_match_2 &&
      uk_evisa_lookup == o.uk_evisa_lookup &&
      sweden_bankid == o.sweden_bankid &&
      ukraine_diia == o.ukraine_diia &&
      usa_alaska_mobile_id == o.usa_alaska_mobile_id &&
      usa_louisiana_wallet == o.usa_louisiana_wallet &&
      usa_new_york_mobile_id == o.usa_new_york_mobile_id &&
      netherlands_idin == o.netherlands_idin &&
      yoti == o.yoti &&
      yoti_deeplink == o.yoti_deeplink &&
      zimbabwe_nid_lookup_2 == o.zimbabwe_nid_lookup_2
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


1055
1056
1057
# File 'lib/trinsic_api/models/provider_output.rb', line 1055

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



1061
1062
1063
# File 'lib/trinsic_api/models/provider_output.rb', line 1061

def hash
  [, , , , , , , , , , a_mojeid, , , , apple_wallet, audkenni, australia_connect_id, austria_valera_eudi_sandbox, bolivia_ci_lookup, brazil_cpf_lookup, brazil_digital_cnh, canada_interac, clear, colombia_cc_lookup, cote_divoire_nid_lookup_2, denmark_altid, el_salvador_dui_lookup, czech_bank_id, czech_republic_mojeid, denmark_mitid, ethiopia_fayda, evrotrust, finnish_trust_network, eudi_reference_wallet, france_identite, france_identite_numerique, freja, germany_eudi_sandbox, google_wallet, guatemala_cui_lookup, panama_cedula_lookup, india_digilocker_aadhaar, india_digilocker_aadhaar_fetch, india_digilocker_aadhaar_match, india_pan_lookup, indonesia_dukcapil_match, indonesia_nik_lookup, china_resident_id_match, italy_spid, itsme, kenya_nid_lookup_2, kenya_nid_lookup_3, kenya_nid_match_2, korea_telco_match, lloyds_smart_id, mexico_curp_lookup, mobile_id, moldova_evo_wallet, netherlands_eudi_sandbox, nigeria_nin_lookup_2, nigeria_nin_lookup_3, nigeria_nin_match_2, oneid, peru_dni_lookup, norway_bankid, philippines_digital_national_id_qr, philippines_philsys_match, philippines_physical_national_id_qr, poland_mobywatel_match, post_office_easyid, samsung_wallet, , singpass_myinfo, smart_id, south_africa_nid_lookup_2, south_africa_nid_match_2, uae_pass, uganda_nid_match_2, uk_evisa_lookup, sweden_bankid, ukraine_diia, usa_alaska_mobile_id, usa_louisiana_wallet, usa_new_york_mobile_id, netherlands_idin, yoti, yoti_deeplink, zimbabwe_nid_lookup_2].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



945
946
947
948
949
# File 'lib/trinsic_api/models/provider_output.rb', line 945

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



1090
1091
1092
1093
1094
1095
1096
1097
1098
1099
1100
1101
1102
# File 'lib/trinsic_api/models/provider_output.rb', line 1090

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



953
954
955
956
# File 'lib/trinsic_api/models/provider_output.rb', line 953

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end