Class: TrinsicApi::ProvidersApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trinsic_api/api/providers_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ProvidersApi



19
20
21
# File 'lib/trinsic_api/api/providers_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trinsic_api/api/providers_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_provider(provider_id, opts = {}) ⇒ GetProviderResponse

Get Provider Get a single identity provider by ID, including its license status.



27
28
29
30
# File 'lib/trinsic_api/api/providers_api.rb', line 27

def get_provider(provider_id, opts = {})
  data, _status_code, _headers = get_provider_with_http_info(provider_id, opts)
  data
end

#get_provider_with_http_info(provider_id, opts = {}) ⇒ Array<(GetProviderResponse, Integer, Hash)>

Get Provider Get a single identity provider by ID, including its license status.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/trinsic_api/api/providers_api.rb', line 37

def get_provider_with_http_info(provider_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProvidersApi.get_provider ...'
  end
  # verify the required parameter 'provider_id' is set
  if @api_client.config.client_side_validation && provider_id.nil?
    fail ArgumentError, "Missing the required parameter 'provider_id' when calling ProvidersApi.get_provider"
  end
  # resource path
  local_var_path = '/api/v1/providers/{providerId}'.sub('{' + 'providerId' + '}', CGI.escape(provider_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetProviderResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"ProvidersApi.get_provider",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProvidersApi#get_provider\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_providers(opts = {}) ⇒ ListProvidersResponse

List Providers List all identity providers available to your Organization, including their license status.

Options Hash (opts):

  • :licensed (Boolean)

    Filter by license status. If not specified, returns all providers.



90
91
92
93
# File 'lib/trinsic_api/api/providers_api.rb', line 90

def list_providers(opts = {})
  data, _status_code, _headers = list_providers_with_http_info(opts)
  data
end

#list_providers_with_http_info(opts = {}) ⇒ Array<(ListProvidersResponse, Integer, Hash)>

List Providers List all identity providers available to your Organization, including their license status.

Options Hash (opts):

  • :licensed (Boolean)

    Filter by license status. If not specified, returns all providers.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/trinsic_api/api/providers_api.rb', line 100

def list_providers_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ProvidersApi.list_providers ...'
  end
  # resource path
  local_var_path = '/api/v1/providers'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'licensed'] = opts[:'licensed'] if !opts[:'licensed'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListProvidersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"ProvidersApi.list_providers",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ProvidersApi#list_providers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end