Class: TrinsicApi::Raw18013DocumentRequest

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/raw18013_document_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Raw18013DocumentRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 58

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Raw18013DocumentRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Raw18013DocumentRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'document_type')
    self.document_type = attributes[:'document_type']
  else
    self.document_type = nil
  end

  if attributes.key?(:'name_spaces')
    if (value = attributes[:'name_spaces']).is_a?(Hash)
      self.name_spaces = value
    end
  else
    self.name_spaces = nil
  end
end

Instance Attribute Details

#document_typeObject

The type of the document being requested, as defined by ISO specifications 18013-5, 18013-7, 23220-2, or a similar or related standard. Common values: - "org.iso.18013.5.1.mDL" – a Mobile Driver’s License - "eu.europa.ec.eudi.pid.1" – an EUDI Wallet PID - "com.google.wallet.idcard.1" – a Google Wallet ID Pass - "org.iso.23220.photoid.1" – a generic ISO 23220-2 compliant Photo ID (used by Apple Wallet’s ID Pass)



19
20
21
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 19

def document_type
  @document_type
end

#name_spacesObject

The namespaces and attributes (PII) to request from the document. This is a map of (nameSpaceName -> (attributeName -> willRetain)), where: - nameSpaceName is the name of a NameSpace within the document - attributeName is the name of a specific attribute within the NameSpace - willRetain indicates, to the Wallet, whether you as the Relying Party intend to retain the data for longer than the scope of the transaction Common namespace values: - "org.iso.18013.5.1" – the primary namespace of a Mobile Driver’s License or a Google Wallet ID Pass - "org.iso.18013.5.1.aamva" – the secondary, AAMVA-defined namespace of a Mobile Driver’s License - "eu.europa.ec.eudi.pid.1" – the primary namespace of an EUDI Wallet PID - "org.iso.23220.1" – the primary namespace of an ISO 23220-2 credential or an Apple Wallet ID Pass



22
23
24
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 22

def name_spaces
  @name_spaces
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



33
34
35
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 33

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



38
39
40
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 38

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 25

def self.attribute_map
  {
    :'document_type' => :'documentType',
    :'name_spaces' => :'nameSpaces'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



51
52
53
54
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 51

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



43
44
45
46
47
48
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 43

def self.openapi_types
  {
    :'document_type' => :'String',
    :'name_spaces' => :'Hash<String, Hash<String, Boolean>>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



143
144
145
146
147
148
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 143

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      document_type == o.document_type &&
      name_spaces == o.name_spaces
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 158

def hash
  [document_type, name_spaces].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 89

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @document_type.nil?
    invalid_properties.push('invalid value for "document_type", document_type cannot be nil.')
  end

  if @document_type.to_s.length < 1
    invalid_properties.push('invalid value for "document_type", the character length must be greater than or equal to 1.')
  end

  if @name_spaces.nil?
    invalid_properties.push('invalid value for "name_spaces", name_spaces cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



109
110
111
112
113
114
115
# File 'lib/trinsic_api/models/raw18013_document_request.rb', line 109

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @document_type.nil?
  return false if @document_type.to_s.length < 1
  return false if @name_spaces.nil?
  true
end