Class: TrinsicApi::Raw18013RequestInput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/raw18013_request_input.rb

Overview

A raw 18013-7 exchange request. Use this to specify a raw 18013-7 exchange against an arbitrary document type, namespace, and set of fields.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Raw18013RequestInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 54

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Raw18013RequestInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Raw18013RequestInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'document_requests')
    if (value = attributes[:'document_requests']).is_a?(Array)
      self.document_requests = value
    end
  else
    self.document_requests = nil
  end
end

Instance Attribute Details

#document_requestsObject

A collection of requests for specific document(s), any of which may be used to satisfy the verification. At least one request must be provided. No more than 10 requests may be provided.



20
21
22
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 20

def document_requests
  @document_requests
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



30
31
32
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 30

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



35
36
37
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 35

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



23
24
25
26
27
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 23

def self.attribute_map
  {
    :'document_requests' => :'documentRequests'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 148

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



47
48
49
50
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 47

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



40
41
42
43
44
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 40

def self.openapi_types
  {
    :'document_requests' => :'Array<Raw18013DocumentRequest>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



127
128
129
130
131
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 127

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      document_requests == o.document_requests
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


135
136
137
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 135

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



141
142
143
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 141

def hash
  [document_requests].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 79

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @document_requests.nil?
    invalid_properties.push('invalid value for "document_requests", document_requests cannot be nil.')
  end

  if @document_requests.length > 10
    invalid_properties.push('invalid value for "document_requests", number of items must be less than or equal to 10.')
  end

  if @document_requests.length < 1
    invalid_properties.push('invalid value for "document_requests", number of items must be greater than or equal to 1.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



170
171
172
173
174
175
176
177
178
179
180
181
182
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 170

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/raw18013_request_input.rb', line 99

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @document_requests.nil?
  return false if @document_requests.length > 10
  return false if @document_requests.length < 1
  true
end