Class: TrinsicApi::RecommendationInfo
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::RecommendationInfo
- Defined in:
- lib/trinsic_api/models/recommendation_info.rb
Overview
Information relating to a user; used to generated Identity Provider recommendations.
Instance Attribute Summary collapse
-
#countries ⇒ Object
A list of countries, in alpha-2 ISO 3166 format, which the user is related to.
-
#ip_addresses ⇒ Object
Any IP addresses related to the user.
-
#phone_number ⇒ Object
The phone number of the user you wish to generate a recommendation for.
-
#subdivisions ⇒ Object
If one of the countries has subdivisions (for example: US states), specify those related to the user here (e.g., CA, UT, NY).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecommendationInfo
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RecommendationInfo
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::RecommendationInfo` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::RecommendationInfo`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'countries') if (value = attributes[:'countries']).is_a?(Array) self.countries = value end end if attributes.key?(:'subdivisions') if (value = attributes[:'subdivisions']).is_a?(Array) self.subdivisions = value end end if attributes.key?(:'ip_addresses') if (value = attributes[:'ip_addresses']).is_a?(Array) self.ip_addresses = value end end end |
Instance Attribute Details
#countries ⇒ Object
A list of countries, in alpha-2 ISO 3166 format, which the user is related to. This can include the user’s country of residence, nationality, etc.
23 24 25 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 23 def countries @countries end |
#ip_addresses ⇒ Object
Any IP addresses related to the user. Will be used to determine the user’s geographic location.
29 30 31 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 29 def ip_addresses @ip_addresses end |
#phone_number ⇒ Object
The phone number of the user you wish to generate a recommendation for. Will be used to look up the user’s identity in the network, as well as to determine the user’s geographic location.
20 21 22 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 20 def phone_number @phone_number end |
#subdivisions ⇒ Object
If one of the countries has subdivisions (for example: US states), specify those related to the user here (e.g., CA, UT, NY)
26 27 28 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 26 def subdivisions @subdivisions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 32 def self.attribute_map { :'phone_number' => :'phoneNumber', :'countries' => :'countries', :'subdivisions' => :'subdivisions', :'ip_addresses' => :'ipAddresses' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 151 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 69 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 62 def self.openapi_nullable Set.new([ :'phone_number', :'countries', :'subdivisions', :'ip_addresses' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 52 def self.openapi_types { :'phone_number' => :'String', :'countries' => :'Array<String>', :'subdivisions' => :'Array<String>', :'ip_addresses' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
127 128 129 130 131 132 133 134 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 127 def ==(o) return true if self.equal?(o) self.class == o.class && phone_number == o.phone_number && countries == o.countries && subdivisions == o.subdivisions && ip_addresses == o.ip_addresses end |
#eql?(o) ⇒ Boolean
138 139 140 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 138 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
144 145 146 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 144 def hash [phone_number, countries, subdivisions, ip_addresses].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 173 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
120 121 122 123 |
# File 'lib/trinsic_api/models/recommendation_info.rb', line 120 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |