Class: TrinsicApi::RedirectUrisApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trinsic_api/api/redirect_uris_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ RedirectUrisApi



19
20
21
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#add(opts = {}) ⇒ AddRedirectUriResponse

Add Redirect URI Add a new redirect uri to the authenticated environment.

Options Hash (opts):

  • :add_redirect_uri_request (AddRedirectUriRequest)

    Request for uri to add to the environment. Must be absolute, not relative. Wildcard "*" accepted.



27
28
29
30
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 27

def add(opts = {})
  data, _status_code, _headers = add_with_http_info(opts)
  data
end

#add_with_http_info(opts = {}) ⇒ Array<(AddRedirectUriResponse, Integer, Hash)>

Add Redirect URI Add a new redirect uri to the authenticated environment.

Options Hash (opts):

  • :add_redirect_uri_request (AddRedirectUriRequest)

    Request for uri to add to the environment. Must be absolute, not relative. Wildcard &quot;*&quot; accepted.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 37

def add_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RedirectUrisApi.add ...'
  end
  # resource path
  local_var_path = '/api/valpha/redirect-uris'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'add_redirect_uri_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'AddRedirectUriResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"RedirectUrisApi.add",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RedirectUrisApi#add\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete(id, opts = {}) ⇒ nil

Delete Redirect URI Delete a redirect uri from the environment.



91
92
93
94
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 91

def delete(id, opts = {})
  delete_with_http_info(id, opts)
  nil
end

#delete_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete Redirect URI Delete a redirect uri from the environment.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 101

def delete_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RedirectUrisApi.delete ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling RedirectUrisApi.delete"
  end
  # resource path
  local_var_path = '/api/valpha/redirect-uris/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"RedirectUrisApi.delete",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RedirectUrisApi#delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list(opts = {}) ⇒ ListRedirectUrisResponse

List Redirect URIs List registered Redirect URIs for the authenticated environment

Options Hash (opts):

  • :page (Integer)

    Number of pages of uris to return. (default to 1)

  • :page_size (Integer)

    Size of the list to be returned. Accepted range from 1 to 100 (default to 20)



155
156
157
158
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 155

def list(opts = {})
  data, _status_code, _headers = list_with_http_info(opts)
  data
end

#list_with_http_info(opts = {}) ⇒ Array<(ListRedirectUrisResponse, Integer, Hash)>

List Redirect URIs List registered Redirect URIs for the authenticated environment

Options Hash (opts):

  • :page (Integer)

    Number of pages of uris to return. (default to 1)

  • :page_size (Integer)

    Size of the list to be returned. Accepted range from 1 to 100 (default to 20)



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/trinsic_api/api/redirect_uris_api.rb', line 166

def list_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: RedirectUrisApi.list ...'
  end
  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 2147483647
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling RedirectUrisApi.list, must be smaller than or equal to 2147483647.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling RedirectUrisApi.list, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 100
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling RedirectUrisApi.list, must be smaller than or equal to 100.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling RedirectUrisApi.list, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/api/valpha/redirect-uris'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'page'] = opts[:'page'] if !opts[:'page'].nil?
  query_params[:'pageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListRedirectUrisResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"RedirectUrisApi.list",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: RedirectUrisApi#list\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end