Class: TrinsicApi::SamsungWalletProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/samsung_wallet_provider_output.rb

Overview

Exposed properties for the samsung-wallet Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SamsungWalletProviderOutput

Initializes the object



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::SamsungWalletProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::SamsungWalletProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'mobile_drivers_license')
    self.mobile_drivers_license = attributes[:'mobile_drivers_license']
  end

  if attributes.key?(:'samsung_id_with_clear')
    self.samsung_id_with_clear = attributes[:'samsung_id_with_clear']
  end

  if attributes.key?(:'raw_mdl_output')
    self.raw_mdl_output = attributes[:'raw_mdl_output']
  end
end

Instance Attribute Details

#mobile_drivers_licenseObject

A standard 18013-5 Mobile Driver's License credential, retrieved from the individual's wallet.



20
21
22
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 20

def mobile_drivers_license
  @mobile_drivers_license
end

#raw_mdl_outputObject

The raw output of the mDL exchange performed through Samsung Wallet.



26
27
28
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 26

def raw_mdl_output
  @raw_mdl_output
end

#samsung_id_with_clearObject

A Samsung ID with CLEAR credential, retrieved from the individual's Samsung Wallet.



23
24
25
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 23

def samsung_id_with_clear
  @samsung_id_with_clear
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



38
39
40
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 38

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



43
44
45
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 43

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



29
30
31
32
33
34
35
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 29

def self.attribute_map
  {
    :'mobile_drivers_license' => :'mobileDriversLicense',
    :'samsung_id_with_clear' => :'samsungIdWithClear',
    :'raw_mdl_output' => :'rawMdlOutput'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 134

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



57
58
59
60
61
62
63
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 57

def self.openapi_nullable
  Set.new([
    :'mobile_drivers_license',
    :'samsung_id_with_clear',
    :'raw_mdl_output'
  ])
end

.openapi_typesObject

Attribute type mapping.



48
49
50
51
52
53
54
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 48

def self.openapi_types
  {
    :'mobile_drivers_license' => :'Iso180135MobileDriversLicenseCredential',
    :'samsung_id_with_clear' => :'SamsungIdWithClearCredential',
    :'raw_mdl_output' => :'MdlOutput'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



111
112
113
114
115
116
117
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 111

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      mobile_drivers_license == o.mobile_drivers_license &&
      samsung_id_with_clear == o.samsung_id_with_clear &&
      raw_mdl_output == o.raw_mdl_output
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


121
122
123
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 121

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.



127
128
129
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 127

def hash
  [mobile_drivers_license, samsung_id_with_clear, raw_mdl_output].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?



96
97
98
99
100
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 96

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash



156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 156

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid



104
105
106
107
# File 'lib/trinsic_api/models/samsung_wallet_provider_output.rb', line 104

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end