Class: TrinsicApi::SerbiaIdCardProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::SerbiaIdCardProviderOutput
- Defined in:
- lib/trinsic_api/models/serbia_id_card_provider_output.rb
Overview
Exposed properties for the a-rs-id-login Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#date_of_birth ⇒ Object
The date of birth of the verified individual.
-
#first_name ⇒ Object
The first name of the verified individual.
-
#last_name ⇒ Object
The last name of the verified individual.
-
#unique_master_citizen_number ⇒ Object
The 13-digit Serbian Unique Master Citizen Number ("JMBG" / "Jedinstveni Matični Broj Građana") of the verified individual.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SerbiaIdCardProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SerbiaIdCardProviderOutput
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::SerbiaIdCardProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::SerbiaIdCardProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'unique_master_citizen_number') self.unique_master_citizen_number = attributes[:'unique_master_citizen_number'] end end |
Instance Attribute Details
#date_of_birth ⇒ Object
The date of birth of the verified individual
26 27 28 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 26 def date_of_birth @date_of_birth end |
#first_name ⇒ Object
The first name of the verified individual
20 21 22 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 20 def first_name @first_name end |
#last_name ⇒ Object
The last name of the verified individual
23 24 25 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 23 def last_name @last_name end |
#unique_master_citizen_number ⇒ Object
The 13-digit Serbian Unique Master Citizen Number ("JMBG" / "Jedinstveni Matični Broj Građana") of the verified individual. This is in the format DDMMYYYRRSSSC, where: - DDMM is the day and month of birth - YYY is the last three digits of the year of birth - RR is the political region code of the region of birth (if born after 1976) or of first registration (if born before 1976) - SSS is a unique sex-specific serial number for individuals born on the same date in the same region - C is a checksum digit If YYY is between 000 and 099, the millennium digit of the year is "2"; the individual was born after the year 2000. If YYY is between 800 and 999, the millennium digit of the year is "1"; the individual was born before the year 2000. If SSS is between 000 and 499, the individual is male. If SSS is between 500 and 999, the individual is female.
29 30 31 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 29 def unique_master_citizen_number @unique_master_citizen_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 32 def self.attribute_map { :'first_name' => :'firstName', :'last_name' => :'lastName', :'date_of_birth' => :'dateOfBirth', :'unique_master_citizen_number' => :'uniqueMasterCitizenNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 145 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 69 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 62 def self.openapi_nullable Set.new([ :'first_name', :'last_name', :'date_of_birth', :'unique_master_citizen_number' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 52 def self.openapi_types { :'first_name' => :'String', :'last_name' => :'String', :'date_of_birth' => :'Date', :'unique_master_citizen_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
121 122 123 124 125 126 127 128 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 121 def ==(o) return true if self.equal?(o) self.class == o.class && first_name == o.first_name && last_name == o.last_name && date_of_birth == o.date_of_birth && unique_master_citizen_number == o.unique_master_citizen_number end |
#eql?(o) ⇒ Boolean
132 133 134 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 132 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 138 def hash [first_name, last_name, date_of_birth, unique_master_citizen_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
167 168 169 170 171 172 173 174 175 176 177 178 179 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 167 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 |
# File 'lib/trinsic_api/models/serbia_id_card_provider_output.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |