Class: TrinsicApi::Session

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/session.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Session

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/trinsic_api/models/session.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Session` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Session`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'done')
    self.done = attributes[:'done']
  else
    self.done = nil
  end

  if attributes.key?(:'success')
    self.success = attributes[:'success']
  else
    self.success = nil
  end

  if attributes.key?(:'error_code')
    self.error_code = attributes[:'error_code']
  end

  if attributes.key?(:'created')
    self.created = attributes[:'created']
  else
    self.created = nil
  end

  if attributes.key?(:'updated')
    self.updated = attributes[:'updated']
  else
    self.updated = nil
  end
end

Instance Attribute Details

#createdObject

The unix timestamp, in seconds, when this session was created



30
31
32
# File 'lib/trinsic_api/models/session.rb', line 30

def created
  @created
end

#doneObject

Whether the Session is in a terminal / final state. If this is ‘true`, inspect the value of `Success` to determine whether the Session was successful.



21
22
23
# File 'lib/trinsic_api/models/session.rb', line 21

def done
  @done
end

#error_codeObject

The reason for the Session’s failure. Only present if ‘Success` is `false`.



27
28
29
# File 'lib/trinsic_api/models/session.rb', line 27

def error_code
  @error_code
end

#idObject

Returns the value of attribute id.



18
19
20
# File 'lib/trinsic_api/models/session.rb', line 18

def id
  @id
end

#successObject

Whether the Session has completed successfully. If this is ‘false`, the Session is either not yet done, or has failed. Inspect `Done` and `ErrorCode` for more information. If this is `true`, the Session has completed successfully.



24
25
26
# File 'lib/trinsic_api/models/session.rb', line 24

def success
  @success
end

#updatedObject

The unix timestamp, in seconds, when this session’s data was last updated



33
34
35
# File 'lib/trinsic_api/models/session.rb', line 33

def updated
  @updated
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/trinsic_api/models/session.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/trinsic_api/models/session.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/trinsic_api/models/session.rb', line 58

def self.attribute_map
  {
    :'id' => :'id',
    :'done' => :'done',
    :'success' => :'success',
    :'error_code' => :'errorCode',
    :'created' => :'created',
    :'updated' => :'updated'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/trinsic_api/models/session.rb', line 267

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
# File 'lib/trinsic_api/models/session.rb', line 92

def self.openapi_nullable
  Set.new([
    :'error_code',
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/trinsic_api/models/session.rb', line 80

def self.openapi_types
  {
    :'id' => :'String',
    :'done' => :'Boolean',
    :'success' => :'Boolean',
    :'error_code' => :'SessionErrorCode',
    :'created' => :'Integer',
    :'updated' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
# File 'lib/trinsic_api/models/session.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      done == o.done &&
      success == o.success &&
      error_code == o.error_code &&
      created == o.created &&
      updated == o.updated
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


254
255
256
# File 'lib/trinsic_api/models/session.rb', line 254

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



260
261
262
# File 'lib/trinsic_api/models/session.rb', line 260

def hash
  [id, done, success, error_code, created, updated].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/trinsic_api/models/session.rb', line 151

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @done.nil?
    invalid_properties.push('invalid value for "done", done cannot be nil.')
  end

  if @success.nil?
    invalid_properties.push('invalid value for "success", success cannot be nil.')
  end

  if @created.nil?
    invalid_properties.push('invalid value for "created", created cannot be nil.')
  end

  if @updated.nil?
    invalid_properties.push('invalid value for "updated", updated cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/trinsic_api/models/session.rb', line 289

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



179
180
181
182
183
184
185
186
187
# File 'lib/trinsic_api/models/session.rb', line 179

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @done.nil?
  return false if @success.nil?
  return false if @created.nil?
  return false if @updated.nil?
  true
end