Class: TrinsicApi::SessionsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/trinsic_api/api/sessions_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ SessionsApi

Returns a new instance of SessionsApi.



19
20
21
# File 'lib/trinsic_api/api/sessions_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/trinsic_api/api/sessions_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#cancel_session(session_id, opts = {}) ⇒ CancelSessionResponse

Cancel Session Cancel a Session by its ID

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/trinsic_api/api/sessions_api.rb', line 27

def cancel_session(session_id, opts = {})
  data, _status_code, _headers = cancel_session_with_http_info(session_id, opts)
  data
end

#cancel_session_with_http_info(session_id, opts = {}) ⇒ Array<(CancelSessionResponse, Integer, Hash)>

Cancel Session Cancel a Session by its ID

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(CancelSessionResponse, Integer, Hash)>)

    CancelSessionResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/trinsic_api/api/sessions_api.rb', line 37

def cancel_session_with_http_info(session_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.cancel_session ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.cancel_session"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}/cancel'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'CancelSessionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.cancel_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#cancel_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_direct_provider_session(opts = {}) ⇒ CreateDirectProviderSessionResponse

Create Direct Provider Session Verify a user’s identity with a specific provider, handling additional user interaction in your own UI. Signal which kinds of user interactions your UI can handle using the ‘Capabilities` field. If `FallbackToHostedUi` is `true`, Trinsic’s hosted UI will automatically be invoked to handle any capabilities you do not support.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



90
91
92
93
# File 'lib/trinsic_api/api/sessions_api.rb', line 90

def create_direct_provider_session(opts = {})
  data, _status_code, _headers = create_direct_provider_session_with_http_info(opts)
  data
end

#create_direct_provider_session_with_http_info(opts = {}) ⇒ Array<(CreateDirectProviderSessionResponse, Integer, Hash)>

Create Direct Provider Session Verify a user&#39;s identity with a specific provider, handling additional user interaction in your own UI. Signal which kinds of user interactions your UI can handle using the &#x60;Capabilities&#x60; field. If &#x60;FallbackToHostedUi&#x60; is &#x60;true&#x60;, Trinsic&#39;s hosted UI will automatically be invoked to handle any capabilities you do not support.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/trinsic_api/api/sessions_api.rb', line 100

def create_direct_provider_session_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.create_direct_provider_session ...'
  end
  # resource path
  local_var_path = '/api/v1/sessions/provider/direct'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_direct_provider_session_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'CreateDirectProviderSessionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.create_direct_provider_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#create_direct_provider_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#create_hosted_provider_session(opts = {}) ⇒ CreateHostedProviderSessionResponse

Create Hosted Provider Session Verify a user’s identity with a specific provider, using Trinsic-hosted UI for providers which require additional user interaction.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



154
155
156
157
# File 'lib/trinsic_api/api/sessions_api.rb', line 154

def create_hosted_provider_session(opts = {})
  data, _status_code, _headers = create_hosted_provider_session_with_http_info(opts)
  data
end

#create_hosted_provider_session_with_http_info(opts = {}) ⇒ Array<(CreateHostedProviderSessionResponse, Integer, Hash)>

Create Hosted Provider Session Verify a user&#39;s identity with a specific provider, using Trinsic-hosted UI for providers which require additional user interaction.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/trinsic_api/api/sessions_api.rb', line 164

def create_hosted_provider_session_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.create_hosted_provider_session ...'
  end
  # resource path
  local_var_path = '/api/v1/sessions/provider/hosted'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'create_hosted_provider_session_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'CreateHostedProviderSessionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.create_hosted_provider_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#create_hosted_provider_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_attachment(session_id, attachment_id, opts = {}) ⇒ GetAttachmentResponse

Get Attachment Fetch an Attachment’s contents.

Parameters:

  • session_id (String)

    The ID of the Session to fetch the Attachment from

  • attachment_id (String)

    The ID of the Attachment to fetch

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



220
221
222
223
# File 'lib/trinsic_api/api/sessions_api.rb', line 220

def get_attachment(session_id, attachment_id, opts = {})
  data, _status_code, _headers = get_attachment_with_http_info(session_id, attachment_id, opts)
  data
end

#get_attachment_with_http_info(session_id, attachment_id, opts = {}) ⇒ Array<(GetAttachmentResponse, Integer, Hash)>

Get Attachment Fetch an Attachment&#39;s contents.

Parameters:

  • session_id (String)

    The ID of the Session to fetch the Attachment from

  • attachment_id (String)

    The ID of the Attachment to fetch

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(GetAttachmentResponse, Integer, Hash)>)

    GetAttachmentResponse data, response status code and response headers



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/trinsic_api/api/sessions_api.rb', line 232

def get_attachment_with_http_info(session_id, attachment_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.get_attachment ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.get_attachment"
  end
  # verify the required parameter 'attachment_id' is set
  if @api_client.config.client_side_validation && attachment_id.nil?
    fail ArgumentError, "Missing the required parameter 'attachment_id' when calling SessionsApi.get_attachment"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}/attachments/{attachmentId}/get'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s)).sub('{' + 'attachmentId' + '}', CGI.escape(attachment_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'get_attachment_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'GetAttachmentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.get_attachment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#get_attachment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_session(session_id, opts = {}) ⇒ GetSessionResponse

Get Session Get a Session by its ID

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



294
295
296
297
# File 'lib/trinsic_api/api/sessions_api.rb', line 294

def get_session(session_id, opts = {})
  data, _status_code, _headers = get_session_with_http_info(session_id, opts)
  data
end

#get_session_result(session_id, opts = {}) ⇒ GetSessionResultResponse

Get Session Results

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



357
358
359
360
# File 'lib/trinsic_api/api/sessions_api.rb', line 357

def get_session_result(session_id, opts = {})
  data, _status_code, _headers = get_session_result_with_http_info(session_id, opts)
  data
end

#get_session_result_with_http_info(session_id, opts = {}) ⇒ Array<(GetSessionResultResponse, Integer, Hash)>

Get Session Results

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(GetSessionResultResponse, Integer, Hash)>)

    GetSessionResultResponse data, response status code and response headers



367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
# File 'lib/trinsic_api/api/sessions_api.rb', line 367

def get_session_result_with_http_info(session_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.get_session_result ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.get_session_result"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}/results'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'get_session_result_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'GetSessionResultResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.get_session_result",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#get_session_result\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_session_with_http_info(session_id, opts = {}) ⇒ Array<(GetSessionResponse, Integer, Hash)>

Get Session Get a Session by its ID

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(GetSessionResponse, Integer, Hash)>)

    GetSessionResponse data, response status code and response headers



304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/trinsic_api/api/sessions_api.rb', line 304

def get_session_with_http_info(session_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.get_session ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.get_session"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'GetSessionResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.get_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#get_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#list_sessions(verification_profile_id, opts = {}) ⇒ ListSessionsResponse

List Sessions List Sessions created for a specific Verification Profile

Parameters:

  • verification_profile_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :order_by (SessionOrdering)

    The field by which sessions should be ordered

  • :order_direction (OrderDirection)
  • :page_size (Integer)

    The number of items to return per page – must be between &#x60;1&#x60; and &#x60;50&#x60;

  • :page (Integer)

    The page number to return – starts at &#x60;1&#x60;

Returns:



429
430
431
432
# File 'lib/trinsic_api/api/sessions_api.rb', line 429

def list_sessions(verification_profile_id, opts = {})
  data, _status_code, _headers = list_sessions_with_http_info(verification_profile_id, opts)
  data
end

#list_sessions_with_http_info(verification_profile_id, opts = {}) ⇒ Array<(ListSessionsResponse, Integer, Hash)>

List Sessions List Sessions created for a specific Verification Profile

Parameters:

  • verification_profile_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :order_by (SessionOrdering)

    The field by which sessions should be ordered

  • :order_direction (OrderDirection)
  • :page_size (Integer)

    The number of items to return per page – must be between &#x60;1&#x60; and &#x60;50&#x60;

  • :page (Integer)

    The page number to return – starts at &#x60;1&#x60;

Returns:

  • (Array<(ListSessionsResponse, Integer, Hash)>)

    ListSessionsResponse data, response status code and response headers



443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
# File 'lib/trinsic_api/api/sessions_api.rb', line 443

def list_sessions_with_http_info(verification_profile_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.list_sessions ...'
  end
  # verify the required parameter 'verification_profile_id' is set
  if @api_client.config.client_side_validation && verification_profile_id.nil?
    fail ArgumentError, "Missing the required parameter 'verification_profile_id' when calling SessionsApi.list_sessions"
  end
  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] > 50
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling SessionsApi.list_sessions, must be smaller than or equal to 50.'
  end

  if @api_client.config.client_side_validation && !opts[:'page_size'].nil? && opts[:'page_size'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page_size"]" when calling SessionsApi.list_sessions, must be greater than or equal to 1.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] > 2147483647
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling SessionsApi.list_sessions, must be smaller than or equal to 2147483647.'
  end

  if @api_client.config.client_side_validation && !opts[:'page'].nil? && opts[:'page'] < 1
    fail ArgumentError, 'invalid value for "opts[:"page"]" when calling SessionsApi.list_sessions, must be greater than or equal to 1.'
  end

  # resource path
  local_var_path = '/api/v1/verification-profiles/{verificationProfileId}/sessions'.sub('{' + 'verificationProfileId' + '}', CGI.escape(verification_profile_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'OrderBy'] = opts[:'order_by'] if !opts[:'order_by'].nil?
  query_params[:'OrderDirection'] = opts[:'order_direction'] if !opts[:'order_direction'].nil?
  query_params[:'PageSize'] = opts[:'page_size'] if !opts[:'page_size'].nil?
  query_params[:'Page'] = opts[:'page'] if !opts[:'page'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ListSessionsResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.list_sessions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#list_sessions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#recommend_providers(opts = {}) ⇒ RecommendProvidersResponse

Recommend Providers Recommend providers for a specific user session. You can filter based on health (default=online) and specify country and subdivision information. Trinsic will use the phone number and IP address, if provided, to deduce the country and subdivision of the user and use that info for filtering the providers.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



516
517
518
519
# File 'lib/trinsic_api/api/sessions_api.rb', line 516

def recommend_providers(opts = {})
  data, _status_code, _headers = recommend_providers_with_http_info(opts)
  data
end

#recommend_providers_with_http_info(opts = {}) ⇒ Array<(RecommendProvidersResponse, Integer, Hash)>

Recommend Providers Recommend providers for a specific user session. You can filter based on health (default&#x3D;online) and specify country and subdivision information. Trinsic will use the phone number and IP address, if provided, to deduce the country and subdivision of the user and use that info for filtering the providers.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(RecommendProvidersResponse, Integer, Hash)>)

    RecommendProvidersResponse data, response status code and response headers



526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
# File 'lib/trinsic_api/api/sessions_api.rb', line 526

def recommend_providers_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.recommend_providers ...'
  end
  # resource path
  local_var_path = '/api/v1/sessions/providers/recommend'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'recommend_providers_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'RecommendProvidersResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.recommend_providers",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#recommend_providers\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#redact_session(session_id, opts = {}) ⇒ nil

Redact Session Redact a Session, removing all identity data from Trinsic’s servers. Every verification profile has a redaction period that dictates how long we will hold on to your users’ PII data. Once a session falls outside the redaction cutoff date, all PII will automatically be removed from that session. You can utilize this endpoint to redact a session immediately.

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


580
581
582
583
# File 'lib/trinsic_api/api/sessions_api.rb', line 580

def redact_session(session_id, opts = {})
  redact_session_with_http_info(session_id, opts)
  nil
end

#redact_session_with_http_info(session_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Redact Session Redact a Session, removing all identity data from Trinsic&#39;s servers. Every verification profile has a redaction period that dictates how long we will hold on to your users&#39; PII data. Once a session falls outside the redaction cutoff date, all PII will automatically be removed from that session. You can utilize this endpoint to redact a session immediately.

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
# File 'lib/trinsic_api/api/sessions_api.rb', line 590

def redact_session_with_http_info(session_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.redact_session ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.redact_session"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}/redact'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/problem+json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.redact_session",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#redact_session\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#refresh_step_content(session_id, opts = {}) ⇒ RefreshStepContentResponse

Refresh Step Content Refreshes the content of a Step for a Direct Provider Session.

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



644
645
646
647
# File 'lib/trinsic_api/api/sessions_api.rb', line 644

def refresh_step_content(session_id, opts = {})
  data, _status_code, _headers = refresh_step_content_with_http_info(session_id, opts)
  data
end

#refresh_step_content_with_http_info(session_id, opts = {}) ⇒ Array<(RefreshStepContentResponse, Integer, Hash)>

Refresh Step Content Refreshes the content of a Step for a Direct Provider Session.

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:

  • (Array<(RefreshStepContentResponse, Integer, Hash)>)

    RefreshStepContentResponse data, response status code and response headers



655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
694
695
696
697
698
699
700
701
702
703
704
705
706
# File 'lib/trinsic_api/api/sessions_api.rb', line 655

def refresh_step_content_with_http_info(session_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.refresh_step_content ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.refresh_step_content"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}/step/refresh'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'refresh_step_content_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'RefreshStepContentResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.refresh_step_content",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#refresh_step_content\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#submit_native_challenge_response(session_id, opts = {}) ⇒ SubmitNativeChallengeResponseResponse

Submit Native Challenge Response Submits the response from a Native Challenge (e.g., mDL exchange via DC API) and processes the results.

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



714
715
716
717
# File 'lib/trinsic_api/api/sessions_api.rb', line 714

def submit_native_challenge_response(session_id, opts = {})
  data, _status_code, _headers = submit_native_challenge_response_with_http_info(session_id, opts)
  data
end

#submit_native_challenge_response_with_http_info(session_id, opts = {}) ⇒ Array<(SubmitNativeChallengeResponseResponse, Integer, Hash)>

Submit Native Challenge Response Submits the response from a Native Challenge (e.g., mDL exchange via DC API) and processes the results.

Parameters:

  • session_id (String)
  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

Returns:



725
726
727
728
729
730
731
732
733
734
735
736
737
738
739
740
741
742
743
744
745
746
747
748
749
750
751
752
753
754
755
756
757
758
759
760
761
762
763
764
765
766
767
768
769
770
771
772
773
774
775
776
# File 'lib/trinsic_api/api/sessions_api.rb', line 725

def submit_native_challenge_response_with_http_info(session_id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: SessionsApi.submit_native_challenge_response ...'
  end
  # verify the required parameter 'session_id' is set
  if @api_client.config.client_side_validation && session_id.nil?
    fail ArgumentError, "Missing the required parameter 'session_id' when calling SessionsApi.submit_native_challenge_response"
  end
  # resource path
  local_var_path = '/api/v1/sessions/{sessionId}/native-challenge/submit'.sub('{' + 'sessionId' + '}', CGI.escape(session_id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['text/plain', 'application/json', 'text/json', 'application/problem+json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json', 'text/json', 'application/*+json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'submit_native_challenge_response_request'])

  # return_type
  return_type = opts[:debug_return_type] || 'SubmitNativeChallengeResponseResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['Bearer']

  new_options = opts.merge(
    :operation => :"SessionsApi.submit_native_challenge_response",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: SessionsApi#submit_native_challenge_response\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end