Class: TrinsicApi::SouthAfricaNidLookup2ProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb

Overview

Exposed properties for the south-africa-nid-lookup-2 Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SouthAfricaNidLookup2ProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::SouthAfricaNidLookup2ProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::SouthAfricaNidLookup2ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'national_id_number')
    self.national_id_number = attributes[:'national_id_number']
  end

  if attributes.key?(:'citizenship_status')
    self.citizenship_status = attributes[:'citizenship_status']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  end

  if attributes.key?(:'date_of_death')
    self.date_of_death = attributes[:'date_of_death']
  end

  if attributes.key?(:'birth_country')
    self.birth_country = attributes[:'birth_country']
  end
end

Instance Attribute Details

#birth_countryObject

Country of birth of the individual as an ISO 3166-1 alpha-2 country code.



47
48
49
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 47

def birth_country
  @birth_country
end

#citizenship_statusObject

Citizenship status of the individual. Possible values: - Citizen - PermanentResident - Refugee



23
24
25
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 23

def citizenship_status
  @citizenship_status
end

#date_of_birthObject

Date of birth of the individual.



38
39
40
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 38

def date_of_birth
  @date_of_birth
end

#date_of_deathObject

Date of death of the individual, if recorded by DHA (Department of Home Affairs). Null if the individual is alive, or the data is missing from the registry.



44
45
46
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 44

def date_of_death
  @date_of_death
end

#family_nameObject

Family name of the individual.



29
30
31
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 29

def family_name
  @family_name
end

#first_nameObject

First name of the individual.



26
27
28
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 26

def first_name
  @first_name
end

#full_nameObject

Full name of the individual.



32
33
34
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 32

def full_name
  @full_name
end

#national_id_numberObject

The South African National Identity Number (13 digits). Issued for life by the Department of Home Affairs (DHA) and stored in the HANIS (Home Affairs National Identification System) database. The same number is mandatory for banking, employment, taxation, and voting, and is printed on both the legacy green ID book and the Smart ID Card (rolled out from 2013 onward). Format: - YYMMDD G(4) C A Z - YYMMDD is the date of birth - G(4) is the gender code (below 5000 female, 5000 or above male) - C is the citizenship indicator (0 citizen, 1 permanent resident) - A is reserved (it had a politically sensitive meaning in the past, but is currently semantically meaningless) - Z is a Luhn check digit



20
21
22
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 20

def national_id_number
  @national_id_number
end

#nationalityObject

Nationality of the individual as an ISO 3166-1 alpha-2 country code. Set to ZA when CitizenshipStatus is Citizen. Null when not a South African citizen (Permanent Resident or Refugee).



41
42
43
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 41

def nationality
  @nationality
end

#sexObject

Sex of the individual. Possible values: - Male - Female



35
36
37
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 35

def sex
  @sex
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 50

def self.attribute_map
  {
    :'national_id_number' => :'nationalIdNumber',
    :'citizenship_status' => :'citizenshipStatus',
    :'first_name' => :'firstName',
    :'family_name' => :'familyName',
    :'full_name' => :'fullName',
    :'sex' => :'sex',
    :'date_of_birth' => :'dateOfBirth',
    :'nationality' => :'nationality',
    :'date_of_death' => :'dateOfDeath',
    :'birth_country' => :'birthCountry'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 211

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
96
97
98
99
100
101
102
103
104
105
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 92

def self.openapi_nullable
  Set.new([
    :'national_id_number',
    :'citizenship_status',
    :'first_name',
    :'family_name',
    :'full_name',
    :'sex',
    :'date_of_birth',
    :'nationality',
    :'date_of_death',
    :'birth_country'
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 76

def self.openapi_types
  {
    :'national_id_number' => :'String',
    :'citizenship_status' => :'String',
    :'first_name' => :'String',
    :'family_name' => :'String',
    :'full_name' => :'String',
    :'sex' => :'String',
    :'date_of_birth' => :'Date',
    :'nationality' => :'String',
    :'date_of_death' => :'Date',
    :'birth_country' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      national_id_number == o.national_id_number &&
      citizenship_status == o.citizenship_status &&
      first_name == o.first_name &&
      family_name == o.family_name &&
      full_name == o.full_name &&
      sex == o.sex &&
      date_of_birth == o.date_of_birth &&
      nationality == o.nationality &&
      date_of_death == o.date_of_death &&
      birth_country == o.birth_country
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


198
199
200
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 198

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



204
205
206
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 204

def hash
  [national_id_number, citizenship_status, first_name, family_name, full_name, sex, date_of_birth, nationality, date_of_death, birth_country].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 233

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
# File 'lib/trinsic_api/models/south_africa_nid_lookup2_provider_output.rb', line 174

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end