Class: TrinsicApi::SubProviderMetadata

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/sub_provider_metadata.rb

Overview

Information about a sub-provider.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SubProviderMetadata

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 75

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::SubProviderMetadata` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::SubProviderMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'subtext')
    self.subtext = attributes[:'subtext']
  else
    self.subtext = nil
  end

  if attributes.key?(:'logo_url')
    self.logo_url = attributes[:'logo_url']
  else
    self.logo_url = nil
  end

  if attributes.key?(:'dark_mode_logo_url')
    self.dark_mode_logo_url = attributes[:'dark_mode_logo_url']
  end
end

Instance Attribute Details

#dark_mode_logo_urlObject

An optional URL pointing to a dark mode logo on Trinsic's CDN. It may be a PNG, JPG, or SVG image. If omitted, use LogoUrl in dark mode.



32
33
34
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 32

def dark_mode_logo_url
  @dark_mode_logo_url
end

#idObject

The ID of the sub-provider. This cannot be used as a standalone Provider ID when creating a Session. It must be passed in via the Provider-specific input.



20
21
22
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 20

def id
  @id
end

#logo_urlObject

A URL pointing to the logo on Trinsic's CDN. It may be a PNG, JPG, or SVG image.



29
30
31
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 29

def logo_url
  @logo_url
end

#nameObject

The name of the sub-provider



23
24
25
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 23

def name
  @name
end

#subtextObject

The Provider's subtext recommended to be shown next to the name. This is flavor text, not a full, human-readable description of the provider.



26
27
28
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 26

def subtext
  @subtext
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 35

def self.attribute_map
  {
    :'id' => :'id',
    :'name' => :'name',
    :'subtext' => :'subtext',
    :'logo_url' => :'logoUrl',
    :'dark_mode_logo_url' => :'darkModeLogoUrl'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 220

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 67

def self.openapi_nullable
  Set.new([
    :'dark_mode_logo_url'
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 56

def self.openapi_types
  {
    :'id' => :'String',
    :'name' => :'String',
    :'subtext' => :'String',
    :'logo_url' => :'String',
    :'dark_mode_logo_url' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      name == o.name &&
      subtext == o.subtext &&
      logo_url == o.logo_url &&
      dark_mode_logo_url == o.dark_mode_logo_url
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


207
208
209
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 207

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



213
214
215
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 213

def hash
  [id, name, subtext, logo_url, dark_mode_logo_url].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @subtext.nil?
    invalid_properties.push('invalid value for "subtext", subtext cannot be nil.')
  end

  if @logo_url.nil?
    invalid_properties.push('invalid value for "logo_url", logo_url cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
149
150
151
# File 'lib/trinsic_api/models/sub_provider_metadata.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @name.nil?
  return false if @subtext.nil?
  return false if @logo_url.nil?
  true
end