Class: TrinsicApi::VerificationProfileResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/verification_profile_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VerificationProfileResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 94

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::VerificationProfileResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::VerificationProfileResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'_alias')
    self._alias = attributes[:'_alias']
  else
    self._alias = nil
  end

  if attributes.key?(:'brand_name')
    self.brand_name = attributes[:'brand_name']
  else
    self.brand_name = nil
  end

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'logo_url')
    self.logo_url = attributes[:'logo_url']
  else
    self.logo_url = nil
  end

  if attributes.key?(:'primary_color')
    self.primary_color = attributes[:'primary_color']
  else
    self.primary_color = nil
  end

  if attributes.key?(:'enabled_providers')
    if (value = attributes[:'enabled_providers']).is_a?(Array)
      self.enabled_providers = value
    end
  else
    self.enabled_providers = nil
  end

  if attributes.key?(:'session_expiration')
    self.session_expiration = attributes[:'session_expiration']
  else
    self.session_expiration = nil
  end

  if attributes.key?(:'is_production_usage')
    self.is_production_usage = attributes[:'is_production_usage']
  else
    self.is_production_usage = nil
  end
end

Instance Attribute Details

#_aliasObject

An alias of the verification profile shown to developers and administrators.



22
23
24
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 22

def _alias
  @_alias
end

#brand_nameObject

The brand name of the verification profile shown to end-users.



25
26
27
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 25

def brand_name
  @brand_name
end

#enabled_providersObject

The providers that are currently enabled for the verification profile.



37
38
39
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 37

def enabled_providers
  @enabled_providers
end

#external_idObject

A customer-defined external ID for this verification profile, unique within your organization.



28
29
30
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 28

def external_id
  @external_id
end

#idObject

The ID of the verification profile



19
20
21
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 19

def id
  @id
end

#is_production_usageObject

Whether this profile is for production usage. Only applicable for Live environment profiles.



43
44
45
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 43

def is_production_usage
  @is_production_usage
end

#logo_urlObject

The URL of the verification profile’s logo.



31
32
33
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 31

def logo_url
  @logo_url
end

#primary_colorObject

The primary color of the verification profile.



34
35
36
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 34

def primary_color
  @primary_color
end

#session_expirationObject

The session expiration for verification sessions created with this profile.



40
41
42
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 40

def session_expiration
  @session_expiration
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 46

def self.attribute_map
  {
    :'id' => :'id',
    :'_alias' => :'alias',
    :'brand_name' => :'brandName',
    :'external_id' => :'externalId',
    :'logo_url' => :'logoUrl',
    :'primary_color' => :'primaryColor',
    :'enabled_providers' => :'enabledProviders',
    :'session_expiration' => :'sessionExpiration',
    :'is_production_usage' => :'isProductionUsage'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 329

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
90
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 86

def self.openapi_nullable
  Set.new([
    :'external_id',
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 71

def self.openapi_types
  {
    :'id' => :'String',
    :'_alias' => :'String',
    :'brand_name' => :'String',
    :'external_id' => :'String',
    :'logo_url' => :'String',
    :'primary_color' => :'String',
    :'enabled_providers' => :'Array<String>',
    :'session_expiration' => :'String',
    :'is_production_usage' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 300

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      _alias == o._alias &&
      brand_name == o.brand_name &&
      external_id == o.external_id &&
      logo_url == o.logo_url &&
      primary_color == o.primary_color &&
      enabled_providers == o.enabled_providers &&
      session_expiration == o.session_expiration &&
      is_production_usage == o.is_production_usage
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


316
317
318
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 316

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



322
323
324
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 322

def hash
  [id, _alias, brand_name, external_id, logo_url, primary_color, enabled_providers, session_expiration, is_production_usage].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 165

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @_alias.nil?
    invalid_properties.push('invalid value for "_alias", _alias cannot be nil.')
  end

  if @brand_name.nil?
    invalid_properties.push('invalid value for "brand_name", brand_name cannot be nil.')
  end

  if @logo_url.nil?
    invalid_properties.push('invalid value for "logo_url", logo_url cannot be nil.')
  end

  if @primary_color.nil?
    invalid_properties.push('invalid value for "primary_color", primary_color cannot be nil.')
  end

  if @enabled_providers.nil?
    invalid_properties.push('invalid value for "enabled_providers", enabled_providers cannot be nil.')
  end

  if @session_expiration.nil?
    invalid_properties.push('invalid value for "session_expiration", session_expiration cannot be nil.')
  end

  if @is_production_usage.nil?
    invalid_properties.push('invalid value for "is_production_usage", is_production_usage cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 351

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @_alias.nil?
  return false if @brand_name.nil?
  return false if @logo_url.nil?
  return false if @primary_color.nil?
  return false if @enabled_providers.nil?
  return false if @session_expiration.nil?
  return false if @is_production_usage.nil?
  true
end