Class: TrinsicApi::ZimbabweNidLookup2ProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ZimbabweNidLookup2ProviderOutput
- Defined in:
- lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb
Overview
Exposed properties for the zimbabwe-nid-lookup-2 Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#date_of_birth ⇒ Object
Date of birth of the individual.
-
#date_of_death ⇒ Object
Date of death of the individual, when available.
-
#family_name ⇒ Object
Family name of the individual.
-
#full_name ⇒ Object
Full name of the individual.
-
#given_name ⇒ Object
Given name(s) of the individual.
-
#is_alive ⇒ Object
Whether individual is reported as alive by the Zimbabwean government.
-
#national_id_number ⇒ Object
Zimbabwe National ID number (NID) issued by the Zimbabwean government.
-
#place_of_birth ⇒ Object
Place of birth, typically a municipality or city within Zimbabwe.
-
#sex ⇒ Object
Sex of the individual.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ZimbabweNidLookup2ProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ZimbabweNidLookup2ProviderOutput
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ZimbabweNidLookup2ProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ZimbabweNidLookup2ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'national_id_number') self.national_id_number = attributes[:'national_id_number'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'sex') self.sex = attributes[:'sex'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'place_of_birth') self.place_of_birth = attributes[:'place_of_birth'] end if attributes.key?(:'is_alive') self.is_alive = attributes[:'is_alive'] end if attributes.key?(:'date_of_death') self.date_of_death = attributes[:'date_of_death'] end end |
Instance Attribute Details
#date_of_birth ⇒ Object
Date of birth of the individual.
35 36 37 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 35 def date_of_birth @date_of_birth end |
#date_of_death ⇒ Object
Date of death of the individual, when available.
44 45 46 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 44 def date_of_death @date_of_death end |
#family_name ⇒ Object
Family name of the individual.
26 27 28 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 26 def family_name @family_name end |
#full_name ⇒ Object
Full name of the individual.
29 30 31 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 29 def full_name @full_name end |
#given_name ⇒ Object
Given name(s) of the individual.
23 24 25 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 23 def given_name @given_name end |
#is_alive ⇒ Object
Whether individual is reported as alive by the Zimbabwean government.
41 42 43 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 41 def is_alive @is_alive end |
#national_id_number ⇒ Object
Zimbabwe National ID number (NID) issued by the Zimbabwean government. Format: - 8-9 digits followed by 1 letter and 2 digits - Regex: /^[0-9]8,9\d2$/ - There is no publicly documented encoding scheme for encoding personal information in the NID - No check digit or algorithm has been publicly documented by the Zimbabwean government
20 21 22 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 20 def national_id_number @national_id_number end |
#place_of_birth ⇒ Object
Place of birth, typically a municipality or city within Zimbabwe.
38 39 40 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 38 def place_of_birth @place_of_birth end |
#sex ⇒ Object
Sex of the individual. Possible values: - Male - Female - Not Applicable - Unknown
32 33 34 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 32 def sex @sex end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 47 def self.attribute_map { :'national_id_number' => :'nationalIdNumber', :'given_name' => :'givenName', :'family_name' => :'familyName', :'full_name' => :'fullName', :'sex' => :'sex', :'date_of_birth' => :'dateOfBirth', :'place_of_birth' => :'placeOfBirth', :'is_alive' => :'isAlive', :'date_of_death' => :'dateOfDeath' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 87 def self.openapi_nullable Set.new([ :'national_id_number', :'given_name', :'family_name', :'full_name', :'sex', :'date_of_birth', :'place_of_birth', :'is_alive', :'date_of_death' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 72 def self.openapi_types { :'national_id_number' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'full_name' => :'String', :'sex' => :'String', :'date_of_birth' => :'Date', :'place_of_birth' => :'String', :'is_alive' => :'Boolean', :'date_of_death' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && national_id_number == o.national_id_number && given_name == o.given_name && family_name == o.family_name && full_name == o.full_name && sex == o.sex && date_of_birth == o.date_of_birth && place_of_birth == o.place_of_birth && is_alive == o.is_alive && date_of_death == o.date_of_death end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 193 def hash [national_id_number, given_name, family_name, full_name, sex, date_of_birth, place_of_birth, is_alive, date_of_death].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 |
# File 'lib/trinsic_api/models/zimbabwe_nid_lookup2_provider_output.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |