Class: TrinsicApi::AadhaarLanguage
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::AadhaarLanguage
- Defined in:
- lib/trinsic_api/models/aadhaar_language.rb
Overview
The language used for the localized claims.
Instance Attribute Summary collapse
-
#language_code ⇒ Object
The language code for the localized claims.
-
#language_name ⇒ Object
The language name for the localized claims.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AadhaarLanguage
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AadhaarLanguage
Initializes the object
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 60 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::AadhaarLanguage` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::AadhaarLanguage`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'language_code') self.language_code = attributes[:'language_code'] end if attributes.key?(:'language_name') self.language_name = attributes[:'language_name'] else self.language_name = nil end end |
Instance Attribute Details
#language_code ⇒ Object
The language code for the localized claims.
20 21 22 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 20 def language_code @language_code end |
#language_name ⇒ Object
The language name for the localized claims. This is Trinsic mapping the language from the code. The mapping comes from the spec, however, the code may not always reflect with the actual language used in the localized claims. Use this as a reference. Possible values: - Assamese (01) - Bengali (02) - Gujarati (05) - Hindi (06) - Kannada (07) - Malayalam (11) - Manipuri (12) - Marathi (13) - Oriya (15) - Punjabi (16) - Tamil (20) - Telugu (21) - Urdu (22)
23 24 25 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 23 def language_name @language_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
34 35 36 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 34 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
39 40 41 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 39 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
26 27 28 29 30 31 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 26 def self.attribute_map { :'language_code' => :'languageCode', :'language_name' => :'languageName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 139 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
52 53 54 55 56 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 52 def self.openapi_nullable Set.new([ :'language_code', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
44 45 46 47 48 49 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 44 def self.openapi_types { :'language_code' => :'String', :'language_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
117 118 119 120 121 122 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 117 def ==(o) return true if self.equal?(o) self.class == o.class && language_code == o.language_code && language_name == o.language_name end |
#eql?(o) ⇒ Boolean
126 127 128 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 126 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
132 133 134 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 132 def hash [language_code, language_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
87 88 89 90 91 92 93 94 95 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 87 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @language_name.nil? invalid_properties.push('invalid value for "language_name", language_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 161 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
99 100 101 102 103 |
# File 'lib/trinsic_api/models/aadhaar_language.rb', line 99 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @language_name.nil? true end |