Class: TrinsicApi::ChinaResidentIdMatchInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ChinaResidentIdMatchInput
- Defined in:
- lib/trinsic_api/models/china_resident_id_match_input.rb
Instance Attribute Summary collapse
-
#consent ⇒ Object
Consent from the end user for verification of their data.
-
#date_of_birth ⇒ Object
The person’s date of birth, in ‘YYYY-MM-DD` format.
-
#full_name ⇒ Object
The person’s full name in Chinese characters.
-
#national_id_number ⇒ Object
The person’s 18-character PRC resident identity card number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ChinaResidentIdMatchInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ChinaResidentIdMatchInput
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ChinaResidentIdMatchInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ChinaResidentIdMatchInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] else self.full_name = nil end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] else self.date_of_birth = nil end if attributes.key?(:'national_id_number') self.national_id_number = attributes[:'national_id_number'] else self.national_id_number = nil end if attributes.key?(:'consent') self. = attributes[:'consent'] else self. = nil end end |
Instance Attribute Details
#consent ⇒ Object
Consent from the end user for verification of their data.
28 29 30 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 28 def @consent end |
#date_of_birth ⇒ Object
The person’s date of birth, in ‘YYYY-MM-DD` format.
22 23 24 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 22 def date_of_birth @date_of_birth end |
#full_name ⇒ Object
The person’s full name in Chinese characters.
19 20 21 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 19 def full_name @full_name end |
#national_id_number ⇒ Object
The person’s 18-character PRC resident identity card number.
25 26 27 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 25 def national_id_number @national_id_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 31 def self.attribute_map { :'full_name' => :'fullName', :'date_of_birth' => :'dateOfBirth', :'national_id_number' => :'nationalIdNumber', :'consent' => :'consent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 246 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 51 def self.openapi_types { :'full_name' => :'String', :'date_of_birth' => :'Date', :'national_id_number' => :'String', :'consent' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
222 223 224 225 226 227 228 229 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 222 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && date_of_birth == o.date_of_birth && national_id_number == o.national_id_number && == o. end |
#eql?(o) ⇒ Boolean
233 234 235 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 233 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
239 240 241 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 239 def hash [full_name, date_of_birth, national_id_number, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @full_name.nil? invalid_properties.push('invalid value for "full_name", full_name cannot be nil.') end if @full_name.to_s.length < 1 invalid_properties.push('invalid value for "full_name", the character length must be greater than or equal to 1.') end if @date_of_birth.nil? invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.') end if @national_id_number.nil? invalid_properties.push('invalid value for "national_id_number", national_id_number cannot be nil.') end if @national_id_number.to_s.length > 18 invalid_properties.push('invalid value for "national_id_number", the character length must be smaller than or equal to 18.') end if @national_id_number.to_s.length < 18 invalid_properties.push('invalid value for "national_id_number", the character length must be greater than or equal to 18.') end pattern = Regexp.new(/^\d{17}[\dXx]$/) if @national_id_number !~ pattern invalid_properties.push("invalid value for \"national_id_number\", must conform to the pattern #{pattern}.") end if @consent.nil? invalid_properties.push('invalid value for "consent", consent cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 268 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/trinsic_api/models/china_resident_id_match_input.rb', line 150 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @full_name.nil? return false if @full_name.to_s.length < 1 return false if @date_of_birth.nil? return false if @national_id_number.nil? return false if @national_id_number.to_s.length > 18 return false if @national_id_number.to_s.length < 18 return false if @national_id_number !~ Regexp.new(/^\d{17}[\dXx]$/) return false if @consent.nil? true end |