Class: TrinsicApi::ClearProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ClearProviderOutput
- Defined in:
- lib/trinsic_api/models/clear_provider_output.rb
Overview
Exposed properties for the clear Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#activated_authentication_methods ⇒ Object
The authentication methods the individual activated but did not use as a pre-existing credential during this session.
-
#authenticated ⇒ Object
Whether CLEAR authenticated the individual.
-
#authentication_methods ⇒ Object
The methods the individual authenticated with during the CLEAR flow.
-
#check_metadata ⇒ Object
CLEAR error or metadata codes that influenced check results.
-
#checks ⇒ Object
The checks CLEAR performed on the individual's data and each check's result.
-
#completed_at ⇒ Object
The time the CLEAR verification session completed, as a UTC timestamp.
-
#created_at ⇒ Object
The time the CLEAR verification session was created, as a UTC timestamp.
-
#email ⇒ Object
The individual's verified email address from the session.
-
#expires_at ⇒ Object
The time the CLEAR verification session expires, as a UTC timestamp.
-
#fields_to_collect ⇒ Object
The fields CLEAR still required to complete the current verification step.
-
#idv_status ⇒ Object
The identity verification status.
-
#ip ⇒ Object
The IP addresses used to access this CLEAR verification session.
-
#phone ⇒ Object
The individual's verified phone number, normalized to international E.164 format.
-
#sessions ⇒ Object
Frontend session metadata CLEAR collected.
-
#status ⇒ Object
The CLEAR verification session status.
-
#traits ⇒ Object
The individual traits CLEAR returned after collecting enough information to make a decision.
-
#updated_at ⇒ Object
The time the CLEAR verification session was most recently updated, as a UTC timestamp.
-
#user_agent ⇒ Object
The browser user agents that accessed this CLEAR verification session.
-
#user_created ⇒ Object
Whether CLEAR created a new individual account during this session.
-
#user_id ⇒ Object
The CLEAR identifier for the individual.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClearProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClearProviderOutput
Initializes the object
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 169 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'authenticated') self.authenticated = attributes[:'authenticated'] end if attributes.key?(:'authentication_methods') if (value = attributes[:'authentication_methods']).is_a?(Array) self.authentication_methods = value end end if attributes.key?(:'activated_authentication_methods') if (value = attributes[:'activated_authentication_methods']).is_a?(Array) self.activated_authentication_methods = value end end if attributes.key?(:'checks') if (value = attributes[:'checks']).is_a?(Array) self.checks = value end end if attributes.key?(:'check_metadata') if (value = attributes[:'check_metadata']).is_a?(Array) self. = value end end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'expires_at') self.expires_at = attributes[:'expires_at'] end if attributes.key?(:'fields_to_collect') if (value = attributes[:'fields_to_collect']).is_a?(Array) self.fields_to_collect = value end end if attributes.key?(:'ip') if (value = attributes[:'ip']).is_a?(Array) self.ip = value end end if attributes.key?(:'phone') self.phone = attributes[:'phone'] end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'user_agent') if (value = attributes[:'user_agent']).is_a?(Array) self.user_agent = value end end if attributes.key?(:'user_created') self.user_created = attributes[:'user_created'] end if attributes.key?(:'user_id') self.user_id = attributes[:'user_id'] end if attributes.key?(:'traits') self.traits = attributes[:'traits'] end if attributes.key?(:'idv_status') self.idv_status = attributes[:'idv_status'] end if attributes.key?(:'sessions') if (value = attributes[:'sessions']).is_a?(Array) self.sessions = value end end end |
Instance Attribute Details
#activated_authentication_methods ⇒ Object
The authentication methods the individual activated but did not use as a pre-existing credential during this session. Known values: - webauthn - totp
26 27 28 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 26 def activated_authentication_methods @activated_authentication_methods end |
#authenticated ⇒ Object
Whether CLEAR authenticated the individual.
20 21 22 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 20 def authenticated @authenticated end |
#authentication_methods ⇒ Object
The methods the individual authenticated with during the CLEAR flow. Known values: - webauthn - email - sms_otp
23 24 25 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 23 def authentication_methods @authentication_methods end |
#check_metadata ⇒ Object
CLEAR error or metadata codes that influenced check results.
32 33 34 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 32 def @check_metadata end |
#checks ⇒ Object
The checks CLEAR performed on the individual's data and each check's result.
29 30 31 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 29 def checks @checks end |
#completed_at ⇒ Object
The time the CLEAR verification session completed, as a UTC timestamp.
35 36 37 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 35 def completed_at @completed_at end |
#created_at ⇒ Object
The time the CLEAR verification session was created, as a UTC timestamp.
38 39 40 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 38 def created_at @created_at end |
#email ⇒ Object
The individual's verified email address from the session.
41 42 43 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 41 def email @email end |
#expires_at ⇒ Object
The time the CLEAR verification session expires, as a UTC timestamp.
44 45 46 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 44 def expires_at @expires_at end |
#fields_to_collect ⇒ Object
The fields CLEAR still required to complete the current verification step.
47 48 49 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 47 def fields_to_collect @fields_to_collect end |
#idv_status ⇒ Object
The identity verification status. Known documented value: - verified: CLEAR indicates the individual is verified.
74 75 76 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 74 def idv_status @idv_status end |
#ip ⇒ Object
The IP addresses used to access this CLEAR verification session.
50 51 52 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 50 def ip @ip end |
#phone ⇒ Object
The individual's verified phone number, normalized to international E.164 format.
53 54 55 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 53 def phone @phone end |
#sessions ⇒ Object
Frontend session metadata CLEAR collected.
77 78 79 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 77 def sessions @sessions end |
#status ⇒ Object
The CLEAR verification session status. Known values: - success - fail - awaiting_user_input - deferred - processing_data - expired - awaiting_manual_review - manual_success - manual_fail - canceled
56 57 58 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 56 def status @status end |
#traits ⇒ Object
The individual traits CLEAR returned after collecting enough information to make a decision.
71 72 73 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 71 def traits @traits end |
#updated_at ⇒ Object
The time the CLEAR verification session was most recently updated, as a UTC timestamp.
59 60 61 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 59 def updated_at @updated_at end |
#user_agent ⇒ Object
The browser user agents that accessed this CLEAR verification session.
62 63 64 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 62 def user_agent @user_agent end |
#user_created ⇒ Object
Whether CLEAR created a new individual account during this session.
65 66 67 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 65 def user_created @user_created end |
#user_id ⇒ Object
The CLEAR identifier for the individual.
68 69 70 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 68 def user_id @user_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
106 107 108 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 106 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
111 112 113 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 111 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 80 def self.attribute_map { :'authenticated' => :'authenticated', :'authentication_methods' => :'authenticationMethods', :'activated_authentication_methods' => :'activatedAuthenticationMethods', :'checks' => :'checks', :'check_metadata' => :'checkMetadata', :'completed_at' => :'completedAt', :'created_at' => :'createdAt', :'email' => :'email', :'expires_at' => :'expiresAt', :'fields_to_collect' => :'fieldsToCollect', :'ip' => :'ip', :'phone' => :'phone', :'status' => :'status', :'updated_at' => :'updatedAt', :'user_agent' => :'userAgent', :'user_created' => :'userCreated', :'user_id' => :'userId', :'traits' => :'traits', :'idv_status' => :'idvStatus', :'sessions' => :'sessions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 337 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 142 def self.openapi_nullable Set.new([ :'authenticated', :'authentication_methods', :'activated_authentication_methods', :'checks', :'check_metadata', :'completed_at', :'created_at', :'email', :'expires_at', :'fields_to_collect', :'ip', :'phone', :'status', :'updated_at', :'user_agent', :'user_created', :'user_id', :'traits', :'idv_status', :'sessions' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 116 def self.openapi_types { :'authenticated' => :'Boolean', :'authentication_methods' => :'Array<String>', :'activated_authentication_methods' => :'Array<String>', :'checks' => :'Array<ClearProviderOutputCheck>', :'check_metadata' => :'Array<String>', :'completed_at' => :'Time', :'created_at' => :'Time', :'email' => :'String', :'expires_at' => :'Time', :'fields_to_collect' => :'Array<String>', :'ip' => :'Array<String>', :'phone' => :'String', :'status' => :'String', :'updated_at' => :'Time', :'user_agent' => :'Array<String>', :'user_created' => :'Boolean', :'user_id' => :'String', :'traits' => :'ClearProviderOutputTraits', :'idv_status' => :'String', :'sessions' => :'Array<ClearProviderOutputSessionInfo>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 297 def ==(o) return true if self.equal?(o) self.class == o.class && authenticated == o.authenticated && authentication_methods == o.authentication_methods && activated_authentication_methods == o.activated_authentication_methods && checks == o.checks && == o. && completed_at == o.completed_at && created_at == o.created_at && email == o.email && expires_at == o.expires_at && fields_to_collect == o.fields_to_collect && ip == o.ip && phone == o.phone && status == o.status && updated_at == o.updated_at && user_agent == o.user_agent && user_created == o.user_created && user_id == o.user_id && traits == o.traits && idv_status == o.idv_status && sessions == o.sessions end |
#eql?(o) ⇒ Boolean
324 325 326 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 324 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
330 331 332 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 330 def hash [authenticated, authentication_methods, activated_authentication_methods, checks, , completed_at, created_at, email, expires_at, fields_to_collect, ip, phone, status, updated_at, user_agent, user_created, user_id, traits, idv_status, sessions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
282 283 284 285 286 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 282 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
359 360 361 362 363 364 365 366 367 368 369 370 371 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 359 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
290 291 292 293 |
# File 'lib/trinsic_api/models/clear_provider_output.rb', line 290 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |