Class: TrinsicApi::ClearProviderOutputHistoricalAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ClearProviderOutputHistoricalAddress
- Defined in:
- lib/trinsic_api/models/clear_provider_output_historical_address.rb
Instance Attribute Summary collapse
-
#city ⇒ Object
The city.
-
#country ⇒ Object
The ISO 3166-1 alpha-2 country code.
-
#first_seen ⇒ Object
The first date CLEAR saw this historical address.
-
#last_seen ⇒ Object
The last date CLEAR saw this historical address.
-
#line1 ⇒ Object
The first line of the address.
-
#line2 ⇒ Object
The second line of the address, such as an apartment or suite.
-
#postal_code ⇒ Object
The postal code.
-
#state ⇒ Object
The state, province, or region.
-
#street_name ⇒ Object
The historical address street name.
-
#street_number ⇒ Object
The historical address street number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ClearProviderOutputHistoricalAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ClearProviderOutputHistoricalAddress
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ClearProviderOutputHistoricalAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ClearProviderOutputHistoricalAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'line1') self.line1 = attributes[:'line1'] end if attributes.key?(:'line2') self.line2 = attributes[:'line2'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'postal_code') self.postal_code = attributes[:'postal_code'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'street_number') self.street_number = attributes[:'street_number'] end if attributes.key?(:'street_name') self.street_name = attributes[:'street_name'] end if attributes.key?(:'first_seen') self.first_seen = attributes[:'first_seen'] end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end end |
Instance Attribute Details
#city ⇒ Object
The city.
25 26 27 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 25 def city @city end |
#country ⇒ Object
The ISO 3166-1 alpha-2 country code.
34 35 36 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 34 def country @country end |
#first_seen ⇒ Object
The first date CLEAR saw this historical address.
43 44 45 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 43 def first_seen @first_seen end |
#last_seen ⇒ Object
The last date CLEAR saw this historical address.
46 47 48 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 46 def last_seen @last_seen end |
#line1 ⇒ Object
The first line of the address.
19 20 21 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 19 def line1 @line1 end |
#line2 ⇒ Object
The second line of the address, such as an apartment or suite.
22 23 24 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 22 def line2 @line2 end |
#postal_code ⇒ Object
The postal code.
31 32 33 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 31 def postal_code @postal_code end |
#state ⇒ Object
The state, province, or region.
28 29 30 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 28 def state @state end |
#street_name ⇒ Object
The historical address street name.
40 41 42 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 40 def street_name @street_name end |
#street_number ⇒ Object
The historical address street number.
37 38 39 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 37 def street_number @street_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 49 def self.attribute_map { :'line1' => :'line1', :'line2' => :'line2', :'city' => :'city', :'state' => :'state', :'postal_code' => :'postalCode', :'country' => :'country', :'street_number' => :'streetNumber', :'street_name' => :'streetName', :'first_seen' => :'firstSeen', :'last_seen' => :'lastSeen' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 217 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
107 108 109 110 111 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 107 def self.openapi_all_of [ :'ClearProviderOutputAddress' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 91 def self.openapi_nullable Set.new([ :'line1', :'line2', :'city', :'state', :'postal_code', :'country', :'street_number', :'street_name', :'first_seen', :'last_seen' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 75 def self.openapi_types { :'line1' => :'String', :'line2' => :'String', :'city' => :'String', :'state' => :'String', :'postal_code' => :'String', :'country' => :'String', :'street_number' => :'String', :'street_name' => :'String', :'first_seen' => :'ClearProviderOutputPartialDate', :'last_seen' => :'ClearProviderOutputPartialDate' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
187 188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 187 def ==(o) return true if self.equal?(o) self.class == o.class && line1 == o.line1 && line2 == o.line2 && city == o.city && state == o.state && postal_code == o.postal_code && country == o.country && street_number == o.street_number && street_name == o.street_name && first_seen == o.first_seen && last_seen == o.last_seen end |
#eql?(o) ⇒ Boolean
204 205 206 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 204 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
210 211 212 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 210 def hash [line1, line2, city, state, postal_code, country, street_number, street_name, first_seen, last_seen].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
172 173 174 175 176 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 172 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 239 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 |
# File 'lib/trinsic_api/models/clear_provider_output_historical_address.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |