Class: TrinsicApi::CoteDIvoireNidLookup2ProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb

Overview

Exposed properties for the ‘cote-divoire-nid-lookup-2` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CoteDIvoireNidLookup2ProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CoteDIvoireNidLookup2ProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CoteDIvoireNidLookup2ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  else
    self.full_name = nil
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  else
    self.given_name = nil
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  else
    self.family_name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  else
    self.date_of_birth = nil
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  else
    self.sex = nil
  end

  if attributes.key?(:'nationality')
    self.nationality = attributes[:'nationality']
  else
    self.nationality = nil
  end

  if attributes.key?(:'address')
    self.address = attributes[:'address']
  end

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  end

  if attributes.key?(:'national_id_number')
    self.national_id_number = attributes[:'national_id_number']
  end
end

Instance Attribute Details

#addressObject

Address as returned from ONECI (National Civil Registry and Identification Office). Format is LOCALITY,COMMUNE: the locality (village, neighborhood, or sous-quartier) followed by the commune. Not a full street address.



38
39
40
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 38

def address
  @address
end

#date_of_birthObject

Date of birth as returned by ONECI (National Civil Registry and Identification Office).



29
30
31
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 29

def date_of_birth
  @date_of_birth
end

#document_numberObject

The document’s own identifier (printed on the card; often labeled "Immatriculation" on older cards or "Numéro CNI" in post-2020 cards). On older cards this is usually one letter followed by 10 digits. On new cards it appears as 1 or 2 leading letters plus 9 digits.



41
42
43
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 41

def document_number
  @document_number
end

#family_nameObject

Family name of the ID holder as returned by ONECI (National Civil Registry and Identification Office).



26
27
28
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 26

def family_name
  @family_name
end

#full_nameObject

Full name as returned by ONECI (National Civil Registry and Identification Office).



20
21
22
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 20

def full_name
  @full_name
end

#given_nameObject

Given name of the ID holder as returned by ONECI (National Civil Registry and Identification Office).



23
24
25
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 23

def given_name
  @given_name
end

#national_id_numberObject

The NNI (Numéro National d’Identification): the person’s 11-digit national ID, printed on the back of the new national id card and assigned by ONECI. It is always exactly 11 digits with no letters, and is semi-random, non-repetitive, and does not encode any extra data, such as date of birth, gender, or other readable attributes.



44
45
46
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 44

def national_id_number
  @national_id_number
end

#nationalityObject

Nationality as ISO 3166-1 alpha-2 country code (e.g. "CI" for Côte d’Ivoire).



35
36
37
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 35

def nationality
  @nationality
end

#sexObject

Sex of the ID holder as returned by ONECI (National Civil Registry and Identification Office). Possible values: - Male - Female



32
33
34
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 32

def sex
  @sex
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 47

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'date_of_birth' => :'dateOfBirth',
    :'sex' => :'sex',
    :'nationality' => :'nationality',
    :'address' => :'address',
    :'document_number' => :'documentNumber',
    :'national_id_number' => :'nationalIdNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 296

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



87
88
89
90
91
92
93
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 87

def self.openapi_nullable
  Set.new([
    :'address',
    :'document_number',
    :'national_id_number'
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 72

def self.openapi_types
  {
    :'full_name' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'date_of_birth' => :'Date',
    :'sex' => :'String',
    :'nationality' => :'String',
    :'address' => :'String',
    :'document_number' => :'String',
    :'national_id_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      date_of_birth == o.date_of_birth &&
      sex == o.sex &&
      nationality == o.nationality &&
      address == o.address &&
      document_number == o.document_number &&
      national_id_number == o.national_id_number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


283
284
285
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 283

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



289
290
291
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 289

def hash
  [full_name, given_name, family_name, date_of_birth, sex, nationality, address, document_number, national_id_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 162

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @full_name.nil?
    invalid_properties.push('invalid value for "full_name", full_name cannot be nil.')
  end

  if @given_name.nil?
    invalid_properties.push('invalid value for "given_name", given_name cannot be nil.')
  end

  if @family_name.nil?
    invalid_properties.push('invalid value for "family_name", family_name cannot be nil.')
  end

  if @date_of_birth.nil?
    invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.')
  end

  if @sex.nil?
    invalid_properties.push('invalid value for "sex", sex cannot be nil.')
  end

  if @nationality.nil?
    invalid_properties.push('invalid value for "nationality", nationality cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 318

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
# File 'lib/trinsic_api/models/cote_d_ivoire_nid_lookup2_provider_output.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @full_name.nil?
  return false if @given_name.nil?
  return false if @family_name.nil?
  return false if @date_of_birth.nil?
  return false if @sex.nil?
  return false if @nationality.nil?
  true
end