Class: TrinsicApi::CreateDirectProviderSessionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::CreateDirectProviderSessionRequest
- Defined in:
- lib/trinsic_api/models/create_direct_provider_session_request.rb
Instance Attribute Summary collapse
-
#browser_languages ⇒ Object
Preferences for languages to show first if the session falls back to the Trinsic-hosted UI.
-
#capabilities ⇒ Object
The list of capabilities your integration supports.
-
#fallback_to_hosted_ui ⇒ Object
Whether the session should fall back to a Trinsic-hosted UI in certain instances.
-
#provider ⇒ Object
The ID of the provider to launch.
-
#provider_input ⇒ Object
Provider-specific input for those providers which require it.
-
#redirect_url ⇒ Object
The Redirect URL to which the user should be sent after the session is complete.
-
#verification_profile_id ⇒ Object
The ID of the Verification Profile to use for this session.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateDirectProviderSessionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateDirectProviderSessionRequest
Initializes the object
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 87 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CreateDirectProviderSessionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CreateDirectProviderSessionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'verification_profile_id') self.verification_profile_id = attributes[:'verification_profile_id'] else self.verification_profile_id = nil end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] end if attributes.key?(:'capabilities') if (value = attributes[:'capabilities']).is_a?(Array) self.capabilities = value end else self.capabilities = nil end if attributes.key?(:'fallback_to_hosted_ui') self.fallback_to_hosted_ui = attributes[:'fallback_to_hosted_ui'] end if attributes.key?(:'browser_languages') if (value = attributes[:'browser_languages']).is_a?(Array) self.browser_languages = value end end if attributes.key?(:'provider_input') self.provider_input = attributes[:'provider_input'] end end |
Instance Attribute Details
#browser_languages ⇒ Object
Preferences for languages to show first if the session falls back to the Trinsic-hosted UI. If left empty, the Hosted UI defaults to the user’s navigator languages. If no preferred language is available, the Hosted UI falls back to English. This only will be used if the session falls back to the Trinsic-hosted UI.
34 35 36 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 34 def browser_languages @browser_languages end |
#capabilities ⇒ Object
The list of capabilities your integration supports. Capabilities are the core of Trinsic’s whitelabel-with-optional-fallback offering. Most capabilities align with either an ‘IntegrationLaunchMethod` or an `IntegrationCollectionMethod`. The exception being refresh content to support updating the content of the launch method. For example, to support a basic redirect-based flow, you must include the `LaunchRedirect` and `CaptureRedirect` capabilities. To support a mobile deeplink / polling flow, you must include the `DeeplinkToMobile` and `PollForResults` capabilities. If `FallbackToHostedUi` is `true`, Trinsic will automatically fall back to a Trinsic-hosted UI to cover any gaps in your integration’s capabilities. If ‘FallbackToHostedUi` is `false`, gaps in your integration’s capabilities will result in an error during Session creation. Read more on how to integrate at <a href="docs.trinsic.id/docs/direct-provider-sessions">the guide on Direct Provider Sessions</a>
28 29 30 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 28 def capabilities @capabilities end |
#fallback_to_hosted_ui ⇒ Object
Whether the session should fall back to a Trinsic-hosted UI in certain instances. Specifically, fallback will occur if any of the following are true: - You attempted to launch a provider which requires a capability you did not express support for - In this case, Trinsic’s hosted UI will perform the necessary capability - You attempted to launch a provider which requires input, and the input was either not provided or incomplete - In this case, Trinsic’s hosted UI will collect the necessary input from the user If fallback occurs, the session’s NextStep will always be LaunchBrowser, and the CollectionMethod will always be CaptureRedirect. If this field is set to ‘true`, you must also: 1. Set the `RedirectUrl` field to a non-empty value 2. Include the `LaunchBrowser` and `CaptureRedirect` capabilities in the `Capabilities` field
31 32 33 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 31 def fallback_to_hosted_ui @fallback_to_hosted_ui end |
#provider ⇒ Object
The ID of the provider to launch
19 20 21 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 19 def provider @provider end |
#provider_input ⇒ Object
Provider-specific input for those providers which require it.
37 38 39 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 37 def provider_input @provider_input end |
#redirect_url ⇒ Object
The Redirect URL to which the user should be sent after the session is complete. This field is required for providers which employ a redirect-based flow.
25 26 27 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 25 def redirect_url @redirect_url end |
#verification_profile_id ⇒ Object
The ID of the Verification Profile to use for this session.
22 23 24 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 22 def verification_profile_id @verification_profile_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 40 def self.attribute_map { :'provider' => :'provider', :'verification_profile_id' => :'verificationProfileId', :'redirect_url' => :'redirectUrl', :'capabilities' => :'capabilities', :'fallback_to_hosted_ui' => :'fallbackToHostedUI', :'browser_languages' => :'browserLanguages', :'provider_input' => :'providerInput' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 247 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 83 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 76 def self.openapi_nullable Set.new([ :'redirect_url', :'fallback_to_hosted_ui', :'browser_languages', :'provider_input' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 63 def self.openapi_types { :'provider' => :'String', :'verification_profile_id' => :'String', :'redirect_url' => :'String', :'capabilities' => :'Array<IntegrationCapability>', :'fallback_to_hosted_ui' => :'Boolean', :'browser_languages' => :'Array<String>', :'provider_input' => :'ProviderInput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && provider == o.provider && verification_profile_id == o.verification_profile_id && redirect_url == o.redirect_url && capabilities == o.capabilities && fallback_to_hosted_ui == o.fallback_to_hosted_ui && browser_languages == o.browser_languages && provider_input == o.provider_input end |
#eql?(o) ⇒ Boolean
234 235 236 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 234 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
240 241 242 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 240 def hash [provider, verification_profile_id, redirect_url, capabilities, fallback_to_hosted_ui, browser_languages, provider_input].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 142 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @provider.to_s.length < 1 invalid_properties.push('invalid value for "provider", the character length must be greater than or equal to 1.') end if @verification_profile_id.nil? invalid_properties.push('invalid value for "verification_profile_id", verification_profile_id cannot be nil.') end if @capabilities.nil? invalid_properties.push('invalid value for "capabilities", capabilities cannot be nil.') end if @capabilities.length < 1 invalid_properties.push('invalid value for "capabilities", number of items must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 269 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
170 171 172 173 174 175 176 177 178 |
# File 'lib/trinsic_api/models/create_direct_provider_session_request.rb', line 170 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @provider.nil? return false if @provider.to_s.length < 1 return false if @verification_profile_id.nil? return false if @capabilities.nil? return false if @capabilities.length < 1 true end |