Class: TrinsicApi::CreateHostedProviderSessionRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::CreateHostedProviderSessionRequest
- Defined in:
- lib/trinsic_api/models/create_hosted_provider_session_request.rb
Instance Attribute Summary collapse
-
#browser_languages ⇒ Object
Preferences for languages to show first in the Hosted UI.
-
#provider ⇒ Object
The ID of the provider to launch.
-
#provider_input ⇒ Object
Provider-specific input for those providers which require it.
-
#redirect_url ⇒ Object
The Redirect URL to which the user should be sent after the session is complete.
-
#verification_profile_id ⇒ Object
The ID of the Verification Profile to use for this session.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateHostedProviderSessionRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateHostedProviderSessionRequest
Initializes the object
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 75 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CreateHostedProviderSessionRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CreateHostedProviderSessionRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'provider') self.provider = attributes[:'provider'] else self.provider = nil end if attributes.key?(:'verification_profile_id') self.verification_profile_id = attributes[:'verification_profile_id'] else self.verification_profile_id = nil end if attributes.key?(:'redirect_url') self.redirect_url = attributes[:'redirect_url'] else self.redirect_url = nil end if attributes.key?(:'browser_languages') if (value = attributes[:'browser_languages']).is_a?(Array) self.browser_languages = value end end if attributes.key?(:'provider_input') self.provider_input = attributes[:'provider_input'] end end |
Instance Attribute Details
#browser_languages ⇒ Object
Preferences for languages to show first in the Hosted UI. If left empty, the Hosted UI defaults to the user’s navigator languages. If no preferred language is available, the Hosted UI falls back to English.
28 29 30 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 28 def browser_languages @browser_languages end |
#provider ⇒ Object
The ID of the provider to launch
19 20 21 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 19 def provider @provider end |
#provider_input ⇒ Object
Provider-specific input for those providers which require it. Deprecated: In the future, Hosted Provider Sessions will not accept input on creation, and will instead always redirect the user to a hosted interface to collect input. If you need to collect input from the user yourself, please use the Create Direct Session endpoint instead.
31 32 33 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 31 def provider_input @provider_input end |
#redirect_url ⇒ Object
The Redirect URL to which the user should be sent after the session is complete.
25 26 27 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 25 def redirect_url @redirect_url end |
#verification_profile_id ⇒ Object
The ID of the Verification Profile to use for this session.
22 23 24 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 22 def verification_profile_id @verification_profile_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 34 def self.attribute_map { :'provider' => :'provider', :'verification_profile_id' => :'verificationProfileId', :'redirect_url' => :'redirectUrl', :'browser_languages' => :'browserLanguages', :'provider_input' => :'providerInput' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 223 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 71 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 66 def self.openapi_nullable Set.new([ :'browser_languages', :'provider_input' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 55 def self.openapi_types { :'provider' => :'String', :'verification_profile_id' => :'String', :'redirect_url' => :'String', :'browser_languages' => :'Array<String>', :'provider_input' => :'ProviderInput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
198 199 200 201 202 203 204 205 206 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 198 def ==(o) return true if self.equal?(o) self.class == o.class && provider == o.provider && verification_profile_id == o.verification_profile_id && redirect_url == o.redirect_url && browser_languages == o.browser_languages && provider_input == o.provider_input end |
#eql?(o) ⇒ Boolean
210 211 212 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 210 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
216 217 218 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 216 def hash [provider, verification_profile_id, redirect_url, browser_languages, provider_input].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @provider.nil? invalid_properties.push('invalid value for "provider", provider cannot be nil.') end if @provider.to_s.length < 1 invalid_properties.push('invalid value for "provider", the character length must be greater than or equal to 1.') end if @verification_profile_id.nil? invalid_properties.push('invalid value for "verification_profile_id", verification_profile_id cannot be nil.') end if @redirect_url.nil? invalid_properties.push('invalid value for "redirect_url", redirect_url cannot be nil.') end if @redirect_url.to_s.length < 1 invalid_properties.push('invalid value for "redirect_url", the character length must be greater than or equal to 1.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 245 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
148 149 150 151 152 153 154 155 156 |
# File 'lib/trinsic_api/models/create_hosted_provider_session_request.rb', line 148 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @provider.nil? return false if @provider.to_s.length < 1 return false if @verification_profile_id.nil? return false if @redirect_url.nil? return false if @redirect_url.to_s.length < 1 true end |