Class: TrinsicApi::CzechBankIdAddress
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::CzechBankIdAddress
- Defined in:
- lib/trinsic_api/models/czech_bank_id_address.rb
Instance Attribute Summary collapse
-
#building_apartment ⇒ Object
The address land registry number.
-
#city ⇒ Object
The city name.
-
#city_area ⇒ Object
The city area name.
-
#country ⇒ Object
The country code in ISO 3166-1 alpha-2 format.
-
#evidence_number ⇒ Object
The house evidence number.
-
#ruian_reference ⇒ Object
The address identifier in the Czech RUIAN address register.
-
#street ⇒ Object
The street name.
-
#street_number ⇒ Object
The additional address house number.
-
#type ⇒ Object
The address type.
-
#zipcode ⇒ Object
The zip of the address.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CzechBankIdAddress
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CzechBankIdAddress
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CzechBankIdAddress` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CzechBankIdAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'street') self.street = attributes[:'street'] end if attributes.key?(:'building_apartment') self.building_apartment = attributes[:'building_apartment'] end if attributes.key?(:'street_number') self.street_number = attributes[:'street_number'] end if attributes.key?(:'evidence_number') self.evidence_number = attributes[:'evidence_number'] end if attributes.key?(:'city') self.city = attributes[:'city'] end if attributes.key?(:'city_area') self.city_area = attributes[:'city_area'] end if attributes.key?(:'zipcode') self.zipcode = attributes[:'zipcode'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'ruian_reference') self.ruian_reference = attributes[:'ruian_reference'] end end |
Instance Attribute Details
#building_apartment ⇒ Object
The address land registry number. This is usually present, but unused for small houses.
25 26 27 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 25 def building_apartment @building_apartment end |
#city ⇒ Object
The city name.
34 35 36 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 34 def city @city end |
#city_area ⇒ Object
The city area name. This is usually present.
37 38 39 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 37 def city_area @city_area end |
#country ⇒ Object
The country code in ISO 3166-1 alpha-2 format.
43 44 45 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 43 def country @country end |
#evidence_number ⇒ Object
The house evidence number. This is rarely used in suburbs. An evidence number is used for addresses that are residential, temporary or non-residential buildings, e.g. cabins, garages etc.
31 32 33 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 31 def evidence_number @evidence_number end |
#ruian_reference ⇒ Object
The address identifier in the Czech RUIAN address register. RUIAN is the Czech Register of Territorial Identification, Addresses, and Real Estate. This value identifies the address record in that register and can be used to reconcile the address against Czech government address data.
46 47 48 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 46 def ruian_reference @ruian_reference end |
#street ⇒ Object
The street name. This is usually present, but unused for small villages.
22 23 24 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 22 def street @street end |
#street_number ⇒ Object
The additional address house number. This is usually present, but unused for small villages.
28 29 30 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 28 def street_number @street_number end |
#type ⇒ Object
The address type. Possible values are: - PERMANENT_RESIDENCE - SECONDARY_RESIDENCE - UNKNOWN
19 20 21 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 19 def type @type end |
#zipcode ⇒ Object
The zip of the address.
40 41 42 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 40 def zipcode @zipcode end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 49 def self.attribute_map { :'type' => :'type', :'street' => :'street', :'building_apartment' => :'buildingApartment', :'street_number' => :'streetNumber', :'evidence_number' => :'evidenceNumber', :'city' => :'city', :'city_area' => :'cityArea', :'zipcode' => :'zipcode', :'country' => :'country', :'ruian_reference' => :'ruianReference' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 91 def self.openapi_nullable Set.new([ :'type', :'street', :'building_apartment', :'street_number', :'evidence_number', :'city', :'city_area', :'zipcode', :'country', :'ruian_reference' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 75 def self.openapi_types { :'type' => :'String', :'street' => :'String', :'building_apartment' => :'String', :'street_number' => :'String', :'evidence_number' => :'String', :'city' => :'String', :'city_area' => :'String', :'zipcode' => :'String', :'country' => :'String', :'ruian_reference' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && street == o.street && building_apartment == o.building_apartment && street_number == o.street_number && evidence_number == o.evidence_number && city == o.city && city_area == o.city_area && zipcode == o.zipcode && country == o.country && ruian_reference == o.ruian_reference end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 203 def hash [type, street, building_apartment, street_number, evidence_number, city, city_area, zipcode, country, ruian_reference].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 232 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 |
# File 'lib/trinsic_api/models/czech_bank_id_address.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |