Class: TrinsicApi::CzechBankIdCard
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::CzechBankIdCard
- Defined in:
- lib/trinsic_api/models/czech_bank_id_card.rb
Instance Attribute Summary collapse
-
#country ⇒ Object
The country for which the identity document is valid.
-
#description ⇒ Object
The localized identity document type description.
-
#issue_date ⇒ Object
The identity document issue date.
-
#issuer ⇒ Object
The office that issued the identity document.
-
#number ⇒ Object
The identity document number.
-
#type ⇒ Object
The identity document type code.
-
#valid_to ⇒ Object
The identity document expiration date.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CzechBankIdCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CzechBankIdCard
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CzechBankIdCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CzechBankIdCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'number') self.number = attributes[:'number'] end if attributes.key?(:'valid_to') self.valid_to = attributes[:'valid_to'] end if attributes.key?(:'issuer') self.issuer = attributes[:'issuer'] end if attributes.key?(:'issue_date') self.issue_date = attributes[:'issue_date'] end end |
Instance Attribute Details
#country ⇒ Object
The country for which the identity document is valid.
25 26 27 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 25 def country @country end |
#description ⇒ Object
The localized identity document type description.
22 23 24 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 22 def description @description end |
#issue_date ⇒ Object
The identity document issue date.
37 38 39 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 37 def issue_date @issue_date end |
#issuer ⇒ Object
The office that issued the identity document.
34 35 36 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 34 def issuer @issuer end |
#number ⇒ Object
The identity document number.
28 29 30 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 28 def number @number end |
#type ⇒ Object
The identity document type code. Possible values are: - ID - Identity card - P - Passport - DL - Driving license - IR - Residence permit - VS - Visa permit label - PS - Residential label - IX - Book with residence permit - IE - Form with temporary residence - OP - Identity card – without machine readable zone - CA - Passport of the Czech Republic resident – without machine readable zone - UNKNOWN - Unknown id card type
19 20 21 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 19 def type @type end |
#valid_to ⇒ Object
The identity document expiration date.
31 32 33 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 31 def valid_to @valid_to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
53 54 55 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 53 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
58 59 60 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 58 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 40 def self.attribute_map { :'type' => :'type', :'description' => :'description', :'country' => :'country', :'number' => :'number', :'valid_to' => :'validTo', :'issuer' => :'issuer', :'issue_date' => :'issueDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 177 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 76 def self.openapi_nullable Set.new([ :'type', :'description', :'country', :'number', :'valid_to', :'issuer', :'issue_date' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 63 def self.openapi_types { :'type' => :'String', :'description' => :'String', :'country' => :'String', :'number' => :'String', :'valid_to' => :'Date', :'issuer' => :'String', :'issue_date' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 150 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && description == o.description && country == o.country && number == o.number && valid_to == o.valid_to && issuer == o.issuer && issue_date == o.issue_date end |
#eql?(o) ⇒ Boolean
164 165 166 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 164 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
170 171 172 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 170 def hash [type, description, country, number, valid_to, issuer, issue_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
199 200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 199 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 |
# File 'lib/trinsic_api/models/czech_bank_id_card.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |