Class: TrinsicApi::CzechBankIdProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::CzechBankIdProviderOutput
- Defined in:
- lib/trinsic_api/models/czech_bank_id_provider_output.rb
Overview
Exposed properties for the czech-bank-id Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#addresses ⇒ Object
The individual's addresses.
-
#age ⇒ Object
The individual's age.
-
#birth_country ⇒ Object
The individual's country of birth.
-
#birth_number ⇒ Object
The individual's Czech birth number.
-
#birth_place ⇒ Object
The individual's place of birth.
-
#date_of_birth ⇒ Object
The individual's date of birth.
-
#date_of_death ⇒ Object
The individual's date of death, if available.
-
#email ⇒ Object
The individual's email address.
-
#email_verified ⇒ Object
Whether the individual's email address has been verified.
-
#family_name ⇒ Object
The individual's family or last name.
-
#full_name ⇒ Object
The individual's full name.
-
#gender ⇒ Object
The individual's gender.
-
#given_name ⇒ Object
The individual's given or first name.
-
#id_cards ⇒ Object
The individual's identity documents.
-
#is_adult ⇒ Object
Whether the individual is an adult.
-
#is_politically_exposed_person ⇒ Object
Whether the individual is a politically exposed person.
-
#limited_legal_capacity ⇒ Object
Whether the individual is a person with limited legal capacity.
-
#locale ⇒ Object
The individual's locale.
-
#marital_status ⇒ Object
The individual's marital status.
-
#middle_name ⇒ Object
The individual's middle name.
-
#nationalities ⇒ Object
The individual's nationalities.
-
#nickname ⇒ Object
Nickname used by a physical person A casual name, not necessarily the legal given name.
-
#phone_number ⇒ Object
The individual's phone number.
-
#phone_number_verified ⇒ Object
Whether the individual's phone number has been verified.
-
#preferred_username ⇒ Object
The individual's preferred username.
-
#primary_nationality ⇒ Object
The individual's primary nationality.
-
#subject_identifier ⇒ Object
The subject identifier for the verified individual.
-
#titles ⇒ Object
The individual's title prefixes and suffixes.
-
#updated_at ⇒ Object
The UTC date and time when the identity data was last updated.
-
#verification ⇒ Object
Metadata about how the identity information was verified for Anti Money Laundering scope.
-
#zone_info ⇒ Object
The individual's time zone.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CzechBankIdProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CzechBankIdProviderOutput
Initializes the object
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 235 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CzechBankIdProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CzechBankIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'subject_identifier') self.subject_identifier = attributes[:'subject_identifier'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'nickname') self.nickname = attributes[:'nickname'] end if attributes.key?(:'preferred_username') self.preferred_username = attributes[:'preferred_username'] end if attributes.key?(:'gender') self.gender = attributes[:'gender'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'birth_number') self.birth_number = attributes[:'birth_number'] end if attributes.key?(:'age') self.age = attributes[:'age'] end if attributes.key?(:'is_adult') self.is_adult = attributes[:'is_adult'] end if attributes.key?(:'date_of_death') self.date_of_death = attributes[:'date_of_death'] end if attributes.key?(:'birth_place') self.birth_place = attributes[:'birth_place'] end if attributes.key?(:'birth_country') self.birth_country = attributes[:'birth_country'] end if attributes.key?(:'primary_nationality') self.primary_nationality = attributes[:'primary_nationality'] end if attributes.key?(:'nationalities') if (value = attributes[:'nationalities']).is_a?(Array) self.nationalities = value end end if attributes.key?(:'marital_status') self.marital_status = attributes[:'marital_status'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'phone_number_verified') self.phone_number_verified = attributes[:'phone_number_verified'] end if attributes.key?(:'is_politically_exposed_person') self.is_politically_exposed_person = attributes[:'is_politically_exposed_person'] end if attributes.key?(:'limited_legal_capacity') self.limited_legal_capacity = attributes[:'limited_legal_capacity'] end if attributes.key?(:'verification') self.verification = attributes[:'verification'] end if attributes.key?(:'addresses') if (value = attributes[:'addresses']).is_a?(Array) self.addresses = value end end if attributes.key?(:'id_cards') if (value = attributes[:'id_cards']).is_a?(Array) self.id_cards = value end end if attributes.key?(:'updated_at') self.updated_at = attributes[:'updated_at'] end if attributes.key?(:'zone_info') self.zone_info = attributes[:'zone_info'] end if attributes.key?(:'locale') self.locale = attributes[:'locale'] end if attributes.key?(:'titles') if (value = attributes[:'titles']).is_a?(Array) self.titles = value end end end |
Instance Attribute Details
#addresses ⇒ Object
The individual's addresses. This can include permanent residence and contact addresses. Only returned for Identify verifications.
95 96 97 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 95 def addresses @addresses end |
#age ⇒ Object
The individual's age.
50 51 52 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 50 def age @age end |
#birth_country ⇒ Object
The individual's country of birth. Only returned for Identify Plus verifications.
62 63 64 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 62 def birth_country @birth_country end |
#birth_number ⇒ Object
The individual's Czech birth number. This value is written without the traditional forward slash. Czech birth numbers are Czech public-authority identifiers administered through the Ministry of Interior's birth-number register. The Ministry can assign one to Czech citizens and to foreign nationals with temporary or permanent residence in the Czech Republic. For foreign nationals, this is still a Czech birth number in the Czech format, not an identity number from another country. The common current format is YYXXDDSSSC: - YY: Two digit birth year - XX: Encoded birth month, see below for encoding logic - DD: Birth day - SSS: Sequence number - C: Modulo-11 checksum digit. Not present for people born before 1954. The encoded month is MM for men, MM + 50 for women, and can be MM + 20 for men or MM + 70 for women when additional number ranges are needed. Older numbers for people born before 1954 can use YYXXDDSSS and do not use the modulo-11 checksum. Only returned for Identify verifications.
47 48 49 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 47 def birth_number @birth_number end |
#birth_place ⇒ Object
The individual's place of birth. Only returned for Identify Plus verifications.
59 60 61 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 59 def birth_place @birth_place end |
#date_of_birth ⇒ Object
The individual's date of birth. This is a string because the value may have reduced precision, such as only a year.
44 45 46 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 44 def date_of_birth @date_of_birth end |
#date_of_death ⇒ Object
The individual's date of death, if available.
56 57 58 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 56 def date_of_death @date_of_death end |
#email ⇒ Object
The individual's email address.
74 75 76 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 74 def email @email end |
#email_verified ⇒ Object
Whether the individual's email address has been verified.
77 78 79 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 77 def email_verified @email_verified end |
#family_name ⇒ Object
The individual's family or last name.
29 30 31 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 29 def family_name @family_name end |
#full_name ⇒ Object
The individual's full name.
23 24 25 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 23 def full_name @full_name end |
#gender ⇒ Object
The individual's gender. Possible values: - Male - Female - Other Only returned for Identify verifications.
41 42 43 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 41 def gender @gender end |
#given_name ⇒ Object
The individual's given or first name.
26 27 28 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 26 def given_name @given_name end |
#id_cards ⇒ Object
The individual's identity documents. This can include document type, country, number, issuer, and validity dates. Only returned for Identify Plus verifications.
98 99 100 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 98 def id_cards @id_cards end |
#is_adult ⇒ Object
Whether the individual is an adult. In the Czech Republic, legal majority (adulthood) is reached at 18 years old. Only returned for Identify Plus verifications.
53 54 55 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 53 def is_adult @is_adult end |
#is_politically_exposed_person ⇒ Object
Whether the individual is a politically exposed person. This follows Czech anti-money-laundering rules, indicating a person that is at risk for corruption, bribery or money laundering activities. Mandatory screening of these individuals is required for compliance. Typically set for people such as the Prime Minister, ministers, etc.
86 87 88 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 86 def is_politically_exposed_person @is_politically_exposed_person end |
#limited_legal_capacity ⇒ Object
Whether the individual is a person with limited legal capacity.
89 90 91 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 89 def limited_legal_capacity @limited_legal_capacity end |
#locale ⇒ Object
The individual's locale. This is represented as a BCP 47/RFC 5646 language tag. Some values may use an underscore separator, such as cs_CZ.
107 108 109 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 107 def locale @locale end |
#marital_status ⇒ Object
The individual's marital status. Possible values: - COHABITATION - MARRIED - DIVORCED - REGISTERED_PARTNERSHIP - REGISTERED_PARTNERSHIP_CANCELED - WIDOWED - SINGLE - PARTNERSHIP - PARTNERSHIP_CANCELED - SEPARATED - REGISTERED_PARTNERSHIP_WIDOWED - LAPSED_MARRIAGE - UNKNOWN Only returned for Identify Plus verifications.
71 72 73 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 71 def marital_status @marital_status end |
#middle_name ⇒ Object
The individual's middle name.
32 33 34 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 32 def middle_name @middle_name end |
#nationalities ⇒ Object
The individual's nationalities.
68 69 70 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 68 def nationalities @nationalities end |
#nickname ⇒ Object
Nickname used by a physical person A casual name, not necessarily the legal given name.
35 36 37 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 35 def nickname @nickname end |
#phone_number ⇒ Object
The individual's phone number. This value is normalized to E.164 format.
80 81 82 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 80 def phone_number @phone_number end |
#phone_number_verified ⇒ Object
Whether the individual's phone number has been verified.
83 84 85 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 83 def phone_number_verified @phone_number_verified end |
#preferred_username ⇒ Object
The individual's preferred username. The user has chosen this as the preferred name for logins.
38 39 40 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 38 def preferred_username @preferred_username end |
#primary_nationality ⇒ Object
The individual's primary nationality. The value is an ISO 3166-1 alpha-2 country code. Only returned for Identify Plus verifications.
65 66 67 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 65 def primary_nationality @primary_nationality end |
#subject_identifier ⇒ Object
The subject identifier for the verified individual.
20 21 22 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 20 def subject_identifier @subject_identifier end |
#titles ⇒ Object
The individual's title prefixes and suffixes. Only returned for Identify verifications.
110 111 112 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 110 def titles @titles end |
#updated_at ⇒ Object
The UTC date and time when the identity data was last updated.
101 102 103 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 101 def updated_at @updated_at end |
#verification ⇒ Object
Metadata about how the identity information was verified for Anti Money Laundering scope. Only returned for Identify AML verifications.
92 93 94 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 92 def verification @verification end |
#zone_info ⇒ Object
The individual's time zone. This is represented as a zoneinfo/IANA Time Zone Database value.
104 105 106 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 104 def zone_info @zone_info end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
150 151 152 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 150 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
155 156 157 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 155 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 113 def self.attribute_map { :'subject_identifier' => :'subjectIdentifier', :'full_name' => :'fullName', :'given_name' => :'givenName', :'family_name' => :'familyName', :'middle_name' => :'middleName', :'nickname' => :'nickname', :'preferred_username' => :'preferredUsername', :'gender' => :'gender', :'date_of_birth' => :'dateOfBirth', :'birth_number' => :'birthNumber', :'age' => :'age', :'is_adult' => :'isAdult', :'date_of_death' => :'dateOfDeath', :'birth_place' => :'birthPlace', :'birth_country' => :'birthCountry', :'primary_nationality' => :'primaryNationality', :'nationalities' => :'nationalities', :'marital_status' => :'maritalStatus', :'email' => :'email', :'email_verified' => :'emailVerified', :'phone_number' => :'phoneNumber', :'phone_number_verified' => :'phoneNumberVerified', :'is_politically_exposed_person' => :'isPoliticallyExposedPerson', :'limited_legal_capacity' => :'limitedLegalCapacity', :'verification' => :'verification', :'addresses' => :'addresses', :'id_cards' => :'idCards', :'updated_at' => :'updatedAt', :'zone_info' => :'zoneInfo', :'locale' => :'locale', :'titles' => :'titles' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 450 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 197 def self.openapi_nullable Set.new([ :'subject_identifier', :'full_name', :'given_name', :'family_name', :'middle_name', :'nickname', :'preferred_username', :'gender', :'date_of_birth', :'birth_number', :'age', :'is_adult', :'date_of_death', :'birth_place', :'birth_country', :'primary_nationality', :'nationalities', :'marital_status', :'email', :'email_verified', :'phone_number', :'phone_number_verified', :'is_politically_exposed_person', :'limited_legal_capacity', :'verification', :'addresses', :'id_cards', :'updated_at', :'zone_info', :'locale', :'titles' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 160 def self.openapi_types { :'subject_identifier' => :'String', :'full_name' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'middle_name' => :'String', :'nickname' => :'String', :'preferred_username' => :'String', :'gender' => :'String', :'date_of_birth' => :'String', :'birth_number' => :'String', :'age' => :'Integer', :'is_adult' => :'Boolean', :'date_of_death' => :'Date', :'birth_place' => :'String', :'birth_country' => :'String', :'primary_nationality' => :'String', :'nationalities' => :'Array<String>', :'marital_status' => :'String', :'email' => :'String', :'email_verified' => :'Boolean', :'phone_number' => :'String', :'phone_number_verified' => :'Boolean', :'is_politically_exposed_person' => :'Boolean', :'limited_legal_capacity' => :'Boolean', :'verification' => :'CzechBankIdVerification', :'addresses' => :'Array<CzechBankIdAddress>', :'id_cards' => :'Array<CzechBankIdCard>', :'updated_at' => :'Time', :'zone_info' => :'String', :'locale' => :'String', :'titles' => :'Array<CzechBankIdTitle>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 399 def ==(o) return true if self.equal?(o) self.class == o.class && subject_identifier == o.subject_identifier && full_name == o.full_name && given_name == o.given_name && family_name == o.family_name && middle_name == o.middle_name && nickname == o.nickname && preferred_username == o.preferred_username && gender == o.gender && date_of_birth == o.date_of_birth && birth_number == o.birth_number && age == o.age && is_adult == o.is_adult && date_of_death == o.date_of_death && birth_place == o.birth_place && birth_country == o.birth_country && primary_nationality == o.primary_nationality && nationalities == o.nationalities && marital_status == o.marital_status && email == o.email && email_verified == o.email_verified && phone_number == o.phone_number && phone_number_verified == o.phone_number_verified && is_politically_exposed_person == o.is_politically_exposed_person && limited_legal_capacity == o.limited_legal_capacity && verification == o.verification && addresses == o.addresses && id_cards == o.id_cards && updated_at == o.updated_at && zone_info == o.zone_info && locale == o.locale && titles == o.titles end |
#eql?(o) ⇒ Boolean
437 438 439 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 437 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
443 444 445 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 443 def hash [subject_identifier, full_name, given_name, family_name, middle_name, nickname, preferred_username, gender, date_of_birth, birth_number, age, is_adult, date_of_death, birth_place, birth_country, primary_nationality, nationalities, marital_status, email, email_verified, phone_number, phone_number_verified, is_politically_exposed_person, limited_legal_capacity, verification, addresses, id_cards, updated_at, zone_info, locale, titles].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
384 385 386 387 388 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 384 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
472 473 474 475 476 477 478 479 480 481 482 483 484 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 472 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
392 393 394 395 |
# File 'lib/trinsic_api/models/czech_bank_id_provider_output.rb', line 392 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |