Class: TrinsicApi::CzechMojeIdProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::CzechMojeIdProviderOutput
- Defined in:
- lib/trinsic_api/models/czech_moje_id_provider_output.rb
Overview
Exposed properties for the ‘czech-moje-id` Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#account_validated ⇒ Object
The MojeID account has been validated.
-
#billing_address ⇒ Object
The individual’s billing address, from the ‘mojeid_address_bill` claim.
-
#company_registration_number ⇒ Object
The individual’s or organization’s Czech Registration ID (ICO), the Czech company registration number.
-
#date_of_birth ⇒ Object
The individual’s date of birth.
-
#email ⇒ Object
The individual’s email address.
-
#email_verified ⇒ Object
Whether the individual’s email address has been verified by MojeID.
-
#family_name ⇒ Object
The individual’s family (last) name.
-
#gender ⇒ Object
The individual’s gender as reported by MojeID.
-
#given_name ⇒ Object
The individual’s given (first) name.
-
#home_address ⇒ Object
The individual’s home (default) address, from the ‘mojeid_address_def` claim.
-
#id_card_number ⇒ Object
The individual’s Czech ID card number.
-
#is_adult ⇒ Object
The individual is an adult (18 years or older).
-
#is_student ⇒ Object
Whether the individual is a student.
-
#isds_id ⇒ Object
The individual’s ISDS identifier (Informační systém datových schránek — Czech data box system), used for official electronic communication with Czech government authorities.
-
#name ⇒ Object
The individual’s full name.
-
#nia_verified ⇒ Object
The individual’s identity has been verified through the Czech National Identity Authority (NIA).
-
#nickname ⇒ Object
The individual’s nickname.
-
#passport_number ⇒ Object
The individual’s Czech passport number.
-
#phone_number ⇒ Object
The individual’s phone number.
-
#phone_number_verified ⇒ Object
An individual’s phone number has been verified by MojeID.
-
#shipping_address ⇒ Object
The individual’s shipping address, from the ‘mojeid_address_ship` claim.
-
#social_security_number ⇒ Object
The individual’s Ministry of Labour and Social Affairs identifier (Czech social security equivalent).
-
#subject_identifier ⇒ Object
The subject identifier (sub) of the verified individual’s MojeID account.
-
#tax_identification_number ⇒ Object
The individual’s or organization’s Danove Identifikacni Cislo (DIC), the Czech tax identification number.
-
#transaction_id ⇒ Object
Unique login transaction identifier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CzechMojeIdProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CzechMojeIdProviderOutput
Initializes the object
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 199 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::CzechMojeIdProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::CzechMojeIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'subject_identifier') self.subject_identifier = attributes[:'subject_identifier'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'nickname') self.nickname = attributes[:'nickname'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'phone_number_verified') self.phone_number_verified = attributes[:'phone_number_verified'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'gender') self.gender = attributes[:'gender'] end if attributes.key?(:'id_card_number') self.id_card_number = attributes[:'id_card_number'] end if attributes.key?(:'passport_number') self.passport_number = attributes[:'passport_number'] end if attributes.key?(:'social_security_number') self. = attributes[:'social_security_number'] end if attributes.key?(:'is_adult') self.is_adult = attributes[:'is_adult'] end if attributes.key?(:'account_validated') self.account_validated = attributes[:'account_validated'] end if attributes.key?(:'isds_id') self.isds_id = attributes[:'isds_id'] end if attributes.key?(:'is_student') self.is_student = attributes[:'is_student'] end if attributes.key?(:'company_registration_number') self.company_registration_number = attributes[:'company_registration_number'] end if attributes.key?(:'tax_identification_number') self.tax_identification_number = attributes[:'tax_identification_number'] end if attributes.key?(:'nia_verified') self.nia_verified = attributes[:'nia_verified'] end if attributes.key?(:'transaction_id') self.transaction_id = attributes[:'transaction_id'] end if attributes.key?(:'home_address') self.home_address = attributes[:'home_address'] end if attributes.key?(:'billing_address') self.billing_address = attributes[:'billing_address'] end if attributes.key?(:'shipping_address') self.shipping_address = attributes[:'shipping_address'] end end |
Instance Attribute Details
#account_validated ⇒ Object
The MojeID account has been validated. A validated account indicates the individual’s identity has been verified to a higher level of assurance within the MojeID system.
65 66 67 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 65 def account_validated @account_validated end |
#billing_address ⇒ Object
The individual’s billing address, from the ‘mojeid_address_bill` claim.
89 90 91 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 89 def billing_address @billing_address end |
#company_registration_number ⇒ Object
The individual’s or organization’s Czech Registration ID (ICO), the Czech company registration number.
74 75 76 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 74 def company_registration_number @company_registration_number end |
#date_of_birth ⇒ Object
The individual’s date of birth. Formatted as an ISO 8601 Date.
47 48 49 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 47 def date_of_birth @date_of_birth end |
#email ⇒ Object
The individual’s email address.
35 36 37 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 35 def email @email end |
#email_verified ⇒ Object
Whether the individual’s email address has been verified by MojeID. (Verification email and link clicked)
38 39 40 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 38 def email_verified @email_verified end |
#family_name ⇒ Object
The individual’s family (last) name.
29 30 31 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 29 def family_name @family_name end |
#gender ⇒ Object
The individual’s gender as reported by MojeID.
50 51 52 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 50 def gender @gender end |
#given_name ⇒ Object
The individual’s given (first) name.
26 27 28 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 26 def given_name @given_name end |
#home_address ⇒ Object
The individual’s home (default) address, from the ‘mojeid_address_def` claim.
86 87 88 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 86 def home_address @home_address end |
#id_card_number ⇒ Object
The individual’s Czech ID card number.
53 54 55 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 53 def id_card_number @id_card_number end |
#is_adult ⇒ Object
The individual is an adult (18 years or older).
62 63 64 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 62 def is_adult @is_adult end |
#is_student ⇒ Object
Whether the individual is a student.
71 72 73 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 71 def is_student @is_student end |
#isds_id ⇒ Object
The individual’s ISDS identifier (Informační systém datových schránek — Czech data box system), used for official electronic communication with Czech government authorities.
68 69 70 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 68 def isds_id @isds_id end |
#name ⇒ Object
The individual’s full name.
23 24 25 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 23 def name @name end |
#nia_verified ⇒ Object
The individual’s identity has been verified through the Czech National Identity Authority (NIA). NIA verification indicates a higher level of identity assurance, typically involving government-issued credentials verified through the Czech eGovernment infrastructure.
80 81 82 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 80 def nia_verified @nia_verified end |
#nickname ⇒ Object
The individual’s nickname.
32 33 34 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 32 def nickname @nickname end |
#passport_number ⇒ Object
The individual’s Czech passport number.
56 57 58 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 56 def passport_number @passport_number end |
#phone_number ⇒ Object
The individual’s phone number.
41 42 43 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 41 def phone_number @phone_number end |
#phone_number_verified ⇒ Object
An individual’s phone number has been verified by MojeID. (SMS verification)
44 45 46 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 44 def phone_number_verified @phone_number_verified end |
#shipping_address ⇒ Object
The individual’s shipping address, from the ‘mojeid_address_ship` claim.
92 93 94 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 92 def shipping_address @shipping_address end |
#social_security_number ⇒ Object
The individual’s Ministry of Labour and Social Affairs identifier (Czech social security equivalent).
59 60 61 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 59 def @social_security_number end |
#subject_identifier ⇒ Object
The subject identifier (sub) of the verified individual’s MojeID account. This is a unique identifier that represents the individual within the MojeID system.
20 21 22 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 20 def subject_identifier @subject_identifier end |
#tax_identification_number ⇒ Object
The individual’s or organization’s Danove Identifikacni Cislo (DIC), the Czech tax identification number.
77 78 79 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 77 def tax_identification_number @tax_identification_number end |
#transaction_id ⇒ Object
Unique login transaction identifier
83 84 85 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 83 def transaction_id @transaction_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
126 127 128 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 126 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
131 132 133 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 131 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 95 def self.attribute_map { :'subject_identifier' => :'subjectIdentifier', :'name' => :'name', :'given_name' => :'givenName', :'family_name' => :'familyName', :'nickname' => :'nickname', :'email' => :'email', :'email_verified' => :'emailVerified', :'phone_number' => :'phoneNumber', :'phone_number_verified' => :'phoneNumberVerified', :'date_of_birth' => :'dateOfBirth', :'gender' => :'gender', :'id_card_number' => :'idCardNumber', :'passport_number' => :'passportNumber', :'social_security_number' => :'socialSecurityNumber', :'is_adult' => :'isAdult', :'account_validated' => :'accountValidated', :'isds_id' => :'isdsId', :'is_student' => :'isStudent', :'company_registration_number' => :'companyRegistrationNumber', :'tax_identification_number' => :'taxIdentificationNumber', :'nia_verified' => :'niaVerified', :'transaction_id' => :'transactionId', :'home_address' => :'homeAddress', :'billing_address' => :'billingAddress', :'shipping_address' => :'shippingAddress' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 376 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 167 def self.openapi_nullable Set.new([ :'subject_identifier', :'name', :'given_name', :'family_name', :'nickname', :'email', :'email_verified', :'phone_number', :'phone_number_verified', :'date_of_birth', :'gender', :'id_card_number', :'passport_number', :'social_security_number', :'is_adult', :'account_validated', :'isds_id', :'is_student', :'company_registration_number', :'tax_identification_number', :'nia_verified', :'transaction_id', :'home_address', :'billing_address', :'shipping_address' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 136 def self.openapi_types { :'subject_identifier' => :'String', :'name' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'nickname' => :'String', :'email' => :'String', :'email_verified' => :'Boolean', :'phone_number' => :'String', :'phone_number_verified' => :'Boolean', :'date_of_birth' => :'Date', :'gender' => :'String', :'id_card_number' => :'String', :'passport_number' => :'String', :'social_security_number' => :'String', :'is_adult' => :'Boolean', :'account_validated' => :'Boolean', :'isds_id' => :'String', :'is_student' => :'Boolean', :'company_registration_number' => :'String', :'tax_identification_number' => :'String', :'nia_verified' => :'Boolean', :'transaction_id' => :'String', :'home_address' => :'CzechMojeIdAddressOutput', :'billing_address' => :'CzechMojeIdAddressOutput', :'shipping_address' => :'CzechMojeIdAddressOutput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 331 def ==(o) return true if self.equal?(o) self.class == o.class && subject_identifier == o.subject_identifier && name == o.name && given_name == o.given_name && family_name == o.family_name && nickname == o.nickname && email == o.email && email_verified == o.email_verified && phone_number == o.phone_number && phone_number_verified == o.phone_number_verified && date_of_birth == o.date_of_birth && gender == o.gender && id_card_number == o.id_card_number && passport_number == o.passport_number && == o. && is_adult == o.is_adult && account_validated == o.account_validated && isds_id == o.isds_id && is_student == o.is_student && company_registration_number == o.company_registration_number && tax_identification_number == o.tax_identification_number && nia_verified == o.nia_verified && transaction_id == o.transaction_id && home_address == o.home_address && billing_address == o.billing_address && shipping_address == o.shipping_address end |
#eql?(o) ⇒ Boolean
363 364 365 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 363 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
369 370 371 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 369 def hash [subject_identifier, name, given_name, family_name, nickname, email, email_verified, phone_number, phone_number_verified, date_of_birth, gender, id_card_number, passport_number, , is_adult, account_validated, isds_id, is_student, company_registration_number, tax_identification_number, nia_verified, transaction_id, home_address, billing_address, shipping_address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
316 317 318 319 320 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 316 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
398 399 400 401 402 403 404 405 406 407 408 409 410 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 398 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
324 325 326 327 |
# File 'lib/trinsic_api/models/czech_moje_id_provider_output.rb', line 324 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |