Class: TrinsicApi::DigilockerAadhaarProviderOutput
- Inherits:
-
Object
- Object
- TrinsicApi::DigilockerAadhaarProviderOutput
- Defined in:
- lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb
Overview
Exposed properties for the ‘india-digilocker-aadhaar` Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#aadhaar_number_last_four ⇒ Object
The Aadhaar number (UID) value for the individual.
-
#claims ⇒ Object
The claims extracted from the signed Aadhaar document.
-
#document_signature_validated ⇒ Object
Whether the downloaded Aadhaar document signature and certificate chain validation succeeded.
-
#document_type ⇒ Object
The document type from which the identity data was retrieved from.
-
#localized_claims ⇒ Object
The localized claims extracted from the signed Aadhaar document.
-
#time_to_live ⇒ Object
The validity expiration timestamp for the verification document.
-
#timestamp ⇒ Object
The timestamp when the signed document was generated and verified.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DigilockerAadhaarProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ DigilockerAadhaarProviderOutput
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::DigilockerAadhaarProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::DigilockerAadhaarProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] end if attributes.key?(:'document_signature_validated') self.document_signature_validated = attributes[:'document_signature_validated'] else self.document_signature_validated = nil end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'time_to_live') self.time_to_live = attributes[:'time_to_live'] end if attributes.key?(:'aadhaar_number_last_four') self.aadhaar_number_last_four = attributes[:'aadhaar_number_last_four'] end if attributes.key?(:'claims') self.claims = attributes[:'claims'] end if attributes.key?(:'localized_claims') self.localized_claims = attributes[:'localized_claims'] end end |
Instance Attribute Details
#aadhaar_number_last_four ⇒ Object
The Aadhaar number (UID) value for the individual. This is only the last four digits of the Aadhaar number.
32 33 34 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 32 def aadhaar_number_last_four @aadhaar_number_last_four end |
#claims ⇒ Object
The claims extracted from the signed Aadhaar document.
35 36 37 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 35 def claims @claims end |
#document_signature_validated ⇒ Object
Whether the downloaded Aadhaar document signature and certificate chain validation succeeded. In some cases, the document may not be returned, but the data is. When the document is received, a certificate validation is performed. When it is not, the signature can not be validated.
23 24 25 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 23 def document_signature_validated @document_signature_validated end |
#document_type ⇒ Object
The document type from which the identity data was retrieved from. Possible values: - ADHAR - PANCR
20 21 22 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 20 def document_type @document_type end |
#localized_claims ⇒ Object
The localized claims extracted from the signed Aadhaar document.
38 39 40 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 38 def localized_claims @localized_claims end |
#time_to_live ⇒ Object
The validity expiration timestamp for the verification document. This is parsed as a date-time value. Aadhaar may omit timezone information.
29 30 31 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 29 def time_to_live @time_to_live end |
#timestamp ⇒ Object
The timestamp when the signed document was generated and verified. This is parsed as a date-time value. Aadhaar may omit timezone information.
26 27 28 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 26 def @timestamp end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 218 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 41 def self.attribute_map { :'document_type' => :'documentType', :'document_signature_validated' => :'documentSignatureValidated', :'timestamp' => :'timestamp', :'time_to_live' => :'timeToLive', :'aadhaar_number_last_four' => :'aadhaarNumberLastFour', :'claims' => :'claims', :'localized_claims' => :'localizedClaims' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 81 82 83 84 85 86 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 77 def self.openapi_nullable Set.new([ :'document_type', :'timestamp', :'time_to_live', :'aadhaar_number_last_four', :'claims', :'localized_claims' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 64 def self.openapi_types { :'document_type' => :'String', :'document_signature_validated' => :'Boolean', :'timestamp' => :'Time', :'time_to_live' => :'Time', :'aadhaar_number_last_four' => :'String', :'claims' => :'AadhaarClaims', :'localized_claims' => :'AadhaarLocalizedClaims' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 167 def ==(o) return true if self.equal?(o) self.class == o.class && document_type == o.document_type && document_signature_validated == o.document_signature_validated && == o. && time_to_live == o.time_to_live && aadhaar_number_last_four == o.aadhaar_number_last_four && claims == o.claims && localized_claims == o.localized_claims end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 289 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 187 def hash [document_type, document_signature_validated, , time_to_live, aadhaar_number_last_four, claims, localized_claims].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @document_signature_validated.nil? invalid_properties.push('invalid value for "document_signature_validated", document_signature_validated cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
265 266 267 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 265 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 271 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
259 260 261 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 259 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 |
# File 'lib/trinsic_api/models/digilocker_aadhaar_provider_output.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @document_signature_validated.nil? true end |