Class: TrinsicApi::EvrotrustProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::EvrotrustProviderOutput
- Defined in:
- lib/trinsic_api/models/evrotrust_provider_output.rb
Overview
Exposed properties for the evrotrust Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#address ⇒ Object
The full address of the individual.
-
#address_components ⇒ Object
The structured address fragments of the individual, if available.
-
#date_of_birth ⇒ Object
The date of birth of the individual in YYYY-MM-DD format.
-
#doc_type ⇒ Object
The canonical Evrotrust document type code.
-
#document_country ⇒ Object
The identity document issuing country.
-
#document_country_code ⇒ Object
The identity document issuing country code.
-
#document_issue_date ⇒ Object
The identity document issue date in YYYY-MM-DD format.
-
#document_issuer_name ⇒ Object
The name of the authority that issued the identity document.
-
#document_number ⇒ Object
The identity document number.
-
#document_type ⇒ Object
The localized document type label of the identity document.
-
#document_valid_date ⇒ Object
The identity document expiration date in YYYY-MM-DD format.
-
#email_addresses ⇒ Object
The email addresses of the individual, if available.
-
#first_name ⇒ Object
The given name of the individual.
-
#first_name_latin ⇒ Object
The Latin-script given name of the individual.
-
#gender ⇒ Object
The gender label of the individual.
-
#gender_latin ⇒ Object
The Latin-script gender label of the individual.
-
#identification_before ⇒ Object
The deadline or contextual value supplied for the identification request.
-
#identification_number ⇒ Object
The national identification number of the individual.
-
#identification_reason ⇒ Object
The relying party-provided reason for requesting identification.
-
#last_name ⇒ Object
The family name of the individual.
-
#last_name_latin ⇒ Object
The Latin-script family name of the individual.
-
#latin_names ⇒ Object
The full Latin-script name of the individual.
-
#middle_name ⇒ Object
The middle name of the individual.
-
#middle_name_latin ⇒ Object
The Latin-script middle name of the individual.
-
#names ⇒ Object
The full name of the individual.
-
#nationality ⇒ Object
The nationality label of the individual.
-
#nationality_country ⇒ Object
The nationality country of the individual.
-
#nationality_country_code ⇒ Object
The nationality country code of the individual.
-
#phone_numbers ⇒ Object
The phone numbers of the individual in E.164 format, if available.
-
#place_of_birth ⇒ Object
The place of birth of the individual, if available.
-
#user_gender ⇒ Object
The gender value from Evrotrust's user data object.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EvrotrustProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EvrotrustProviderOutput
Initializes the object
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 235 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::EvrotrustProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::EvrotrustProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'names') self.names = attributes[:'names'] end if attributes.key?(:'latin_names') self.latin_names = attributes[:'latin_names'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'first_name_latin') self.first_name_latin = attributes[:'first_name_latin'] end if attributes.key?(:'middle_name_latin') self.middle_name_latin = attributes[:'middle_name_latin'] end if attributes.key?(:'last_name_latin') self.last_name_latin = attributes[:'last_name_latin'] end if attributes.key?(:'nationality') self.nationality = attributes[:'nationality'] end if attributes.key?(:'nationality_country') self.nationality_country = attributes[:'nationality_country'] end if attributes.key?(:'nationality_country_code') self.nationality_country_code = attributes[:'nationality_country_code'] end if attributes.key?(:'gender') self.gender = attributes[:'gender'] end if attributes.key?(:'gender_latin') self.gender_latin = attributes[:'gender_latin'] end if attributes.key?(:'user_gender') self.user_gender = attributes[:'user_gender'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'place_of_birth') self.place_of_birth = attributes[:'place_of_birth'] end if attributes.key?(:'identification_number') self.identification_number = attributes[:'identification_number'] end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] end if attributes.key?(:'doc_type') self.doc_type = attributes[:'doc_type'] end if attributes.key?(:'document_number') self.document_number = attributes[:'document_number'] end if attributes.key?(:'document_issuer_name') self.document_issuer_name = attributes[:'document_issuer_name'] end if attributes.key?(:'document_issue_date') self.document_issue_date = attributes[:'document_issue_date'] end if attributes.key?(:'document_valid_date') self.document_valid_date = attributes[:'document_valid_date'] end if attributes.key?(:'document_country') self.document_country = attributes[:'document_country'] end if attributes.key?(:'document_country_code') self.document_country_code = attributes[:'document_country_code'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'address_components') self.address_components = attributes[:'address_components'] end if attributes.key?(:'email_addresses') if (value = attributes[:'email_addresses']).is_a?(Array) self.email_addresses = value end end if attributes.key?(:'phone_numbers') if (value = attributes[:'phone_numbers']).is_a?(Array) self.phone_numbers = value end end if attributes.key?(:'identification_reason') self.identification_reason = attributes[:'identification_reason'] end if attributes.key?(:'identification_before') self.identification_before = attributes[:'identification_before'] end end |
Instance Attribute Details
#address ⇒ Object
The full address of the individual.
95 96 97 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 95 def address @address end |
#address_components ⇒ Object
The structured address fragments of the individual, if available.
98 99 100 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 98 def address_components @address_components end |
#date_of_birth ⇒ Object
The date of birth of the individual in YYYY-MM-DD format.
62 63 64 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 62 def date_of_birth @date_of_birth end |
#doc_type ⇒ Object
The canonical Evrotrust document type code. Known values: - IDcard: an identity card. - Passport: a passport.
74 75 76 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 74 def doc_type @doc_type end |
#document_country ⇒ Object
The identity document issuing country.
89 90 91 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 89 def document_country @document_country end |
#document_country_code ⇒ Object
The identity document issuing country code. Evrotrust uses ISO 3166-1 alpha-3 country codes.
92 93 94 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 92 def document_country_code @document_country_code end |
#document_issue_date ⇒ Object
The identity document issue date in YYYY-MM-DD format. Evrotrust documents timestamp 0 for this field as no value; it is omitted from provider-specific output.
83 84 85 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 83 def document_issue_date @document_issue_date end |
#document_issuer_name ⇒ Object
The name of the authority that issued the identity document.
80 81 82 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 80 def document_issuer_name @document_issuer_name end |
#document_number ⇒ Object
The identity document number.
77 78 79 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 77 def document_number @document_number end |
#document_type ⇒ Object
The localized document type label of the identity document. For Evrotrust's canonical document type code, see docType.
71 72 73 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 71 def document_type @document_type end |
#document_valid_date ⇒ Object
The identity document expiration date in YYYY-MM-DD format. Evrotrust documents timestamp 0 for this field as no value; it is omitted from provider-specific output.
86 87 88 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 86 def document_valid_date @document_valid_date end |
#email_addresses ⇒ Object
The email addresses of the individual, if available.
101 102 103 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 101 def email_addresses @email_addresses end |
#first_name ⇒ Object
The given name of the individual.
26 27 28 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 26 def first_name @first_name end |
#first_name_latin ⇒ Object
The Latin-script given name of the individual.
35 36 37 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 35 def first_name_latin @first_name_latin end |
#gender ⇒ Object
The gender label of the individual. Known values in Evrotrust API docs: - Male: the individual is male. - Female: the individual is female.
53 54 55 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 53 def gender @gender end |
#gender_latin ⇒ Object
The Latin-script gender label of the individual. Known values in Evrotrust API docs: - Male: the individual is male. - Female: the individual is female.
56 57 58 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 56 def gender_latin @gender_latin end |
#identification_before ⇒ Object
The deadline or contextual value supplied for the identification request.
110 111 112 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 110 def identification_before @identification_before end |
#identification_number ⇒ Object
The national identification number of the individual. The format depends on the verified document and issuing country.
68 69 70 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 68 def identification_number @identification_number end |
#identification_reason ⇒ Object
The relying party-provided reason for requesting identification.
107 108 109 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 107 def identification_reason @identification_reason end |
#last_name ⇒ Object
The family name of the individual.
32 33 34 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 32 def last_name @last_name end |
#last_name_latin ⇒ Object
The Latin-script family name of the individual.
41 42 43 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 41 def last_name_latin @last_name_latin end |
#latin_names ⇒ Object
The full Latin-script name of the individual.
23 24 25 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 23 def latin_names @latin_names end |
#middle_name ⇒ Object
The middle name of the individual.
29 30 31 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 29 def middle_name @middle_name end |
#middle_name_latin ⇒ Object
The Latin-script middle name of the individual.
38 39 40 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 38 def middle_name_latin @middle_name_latin end |
#names ⇒ Object
The full name of the individual.
20 21 22 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 20 def names @names end |
#nationality ⇒ Object
The nationality label of the individual.
44 45 46 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 44 def nationality @nationality end |
#nationality_country ⇒ Object
The nationality country of the individual.
47 48 49 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 47 def nationality_country @nationality_country end |
#nationality_country_code ⇒ Object
The nationality country code of the individual. Evrotrust uses ISO 3166-1 alpha-3 country codes.
50 51 52 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 50 def nationality_country_code @nationality_country_code end |
#phone_numbers ⇒ Object
The phone numbers of the individual in E.164 format, if available.
104 105 106 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 104 def phone_numbers @phone_numbers end |
#place_of_birth ⇒ Object
The place of birth of the individual, if available.
65 66 67 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 65 def place_of_birth @place_of_birth end |
#user_gender ⇒ Object
The gender value from Evrotrust's user data object. Evrotrust documents this separately from the identification metadata gender labels. Known values: - Male: the individual is male. - Female: the individual is female.
59 60 61 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 59 def user_gender @user_gender end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
150 151 152 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 150 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
155 156 157 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 155 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 113 def self.attribute_map { :'names' => :'names', :'latin_names' => :'latinNames', :'first_name' => :'firstName', :'middle_name' => :'middleName', :'last_name' => :'lastName', :'first_name_latin' => :'firstNameLatin', :'middle_name_latin' => :'middleNameLatin', :'last_name_latin' => :'lastNameLatin', :'nationality' => :'nationality', :'nationality_country' => :'nationalityCountry', :'nationality_country_code' => :'nationalityCountryCode', :'gender' => :'gender', :'gender_latin' => :'genderLatin', :'user_gender' => :'userGender', :'date_of_birth' => :'dateOfBirth', :'place_of_birth' => :'placeOfBirth', :'identification_number' => :'identificationNumber', :'document_type' => :'documentType', :'doc_type' => :'docType', :'document_number' => :'documentNumber', :'document_issuer_name' => :'documentIssuerName', :'document_issue_date' => :'documentIssueDate', :'document_valid_date' => :'documentValidDate', :'document_country' => :'documentCountry', :'document_country_code' => :'documentCountryCode', :'address' => :'address', :'address_components' => :'addressComponents', :'email_addresses' => :'emailAddresses', :'phone_numbers' => :'phoneNumbers', :'identification_reason' => :'identificationReason', :'identification_before' => :'identificationBefore' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 446 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 197 def self.openapi_nullable Set.new([ :'names', :'latin_names', :'first_name', :'middle_name', :'last_name', :'first_name_latin', :'middle_name_latin', :'last_name_latin', :'nationality', :'nationality_country', :'nationality_country_code', :'gender', :'gender_latin', :'user_gender', :'date_of_birth', :'place_of_birth', :'identification_number', :'document_type', :'doc_type', :'document_number', :'document_issuer_name', :'document_issue_date', :'document_valid_date', :'document_country', :'document_country_code', :'address', :'address_components', :'email_addresses', :'phone_numbers', :'identification_reason', :'identification_before' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 160 def self.openapi_types { :'names' => :'String', :'latin_names' => :'String', :'first_name' => :'String', :'middle_name' => :'String', :'last_name' => :'String', :'first_name_latin' => :'String', :'middle_name_latin' => :'String', :'last_name_latin' => :'String', :'nationality' => :'String', :'nationality_country' => :'String', :'nationality_country_code' => :'String', :'gender' => :'String', :'gender_latin' => :'String', :'user_gender' => :'String', :'date_of_birth' => :'Date', :'place_of_birth' => :'String', :'identification_number' => :'String', :'document_type' => :'String', :'doc_type' => :'String', :'document_number' => :'String', :'document_issuer_name' => :'String', :'document_issue_date' => :'Date', :'document_valid_date' => :'Date', :'document_country' => :'String', :'document_country_code' => :'String', :'address' => :'String', :'address_components' => :'EvrotrustAddressComponents', :'email_addresses' => :'Array<String>', :'phone_numbers' => :'Array<String>', :'identification_reason' => :'String', :'identification_before' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 395 def ==(o) return true if self.equal?(o) self.class == o.class && names == o.names && latin_names == o.latin_names && first_name == o.first_name && middle_name == o.middle_name && last_name == o.last_name && first_name_latin == o.first_name_latin && middle_name_latin == o.middle_name_latin && last_name_latin == o.last_name_latin && nationality == o.nationality && nationality_country == o.nationality_country && nationality_country_code == o.nationality_country_code && gender == o.gender && gender_latin == o.gender_latin && user_gender == o.user_gender && date_of_birth == o.date_of_birth && place_of_birth == o.place_of_birth && identification_number == o.identification_number && document_type == o.document_type && doc_type == o.doc_type && document_number == o.document_number && document_issuer_name == o.document_issuer_name && document_issue_date == o.document_issue_date && document_valid_date == o.document_valid_date && document_country == o.document_country && document_country_code == o.document_country_code && address == o.address && address_components == o.address_components && email_addresses == o.email_addresses && phone_numbers == o.phone_numbers && identification_reason == o.identification_reason && identification_before == o.identification_before end |
#eql?(o) ⇒ Boolean
433 434 435 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 433 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
439 440 441 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 439 def hash [names, latin_names, first_name, middle_name, last_name, first_name_latin, middle_name_latin, last_name_latin, nationality, nationality_country, nationality_country_code, gender, gender_latin, user_gender, date_of_birth, place_of_birth, identification_number, document_type, doc_type, document_number, document_issuer_name, document_issue_date, document_valid_date, document_country, document_country_code, address, address_components, email_addresses, phone_numbers, identification_reason, identification_before].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
380 381 382 383 384 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 380 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 468 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
388 389 390 391 |
# File 'lib/trinsic_api/models/evrotrust_provider_output.rb', line 388 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |