Class: TrinsicApi::FaydaProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::FaydaProviderOutput
- Defined in:
- lib/trinsic_api/models/fayda_provider_output.rb
Overview
Exposed properties for the ‘ethiopia-fayda` Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#address ⇒ Object
The address of the verified individual.
-
#arabic_name ⇒ Object
The full Arabic name of the verified individual.
-
#birthdate ⇒ Object
The date of birth of the verified individual.
-
#email ⇒ Object
The email address of the verified individual.
-
#english_name ⇒ Object
The full English name of the verified individual.
-
#gender ⇒ Object
The sex of the verified individual.
-
#name ⇒ Object
The full name of the verified individual.
-
#nationality ⇒ Object
The nationality of the verified individual as an ISO 3166-1 alpha-2 country code.
-
#phone_number ⇒ Object
The phone number of the verified individual.
-
#sub ⇒ Object
A unique eKYC identifying token used to match the original eKYC token received from the provider when the individual was initially registered.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FaydaProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FaydaProviderOutput
Initializes the object
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 109 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::FaydaProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::FaydaProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'sub') self.sub = attributes[:'sub'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'english_name') self.english_name = attributes[:'english_name'] end if attributes.key?(:'arabic_name') self.arabic_name = attributes[:'arabic_name'] end if attributes.key?(:'birthdate') self.birthdate = attributes[:'birthdate'] end if attributes.key?(:'gender') self.gender = attributes[:'gender'] end if attributes.key?(:'nationality') self.nationality = attributes[:'nationality'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'address') self.address = attributes[:'address'] end end |
Instance Attribute Details
#address ⇒ Object
The address of the verified individual. This attribute is only available if registered directly.
47 48 49 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 47 def address @address end |
#arabic_name ⇒ Object
The full Arabic name of the verified individual.
29 30 31 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 29 def arabic_name @arabic_name end |
#birthdate ⇒ Object
The date of birth of the verified individual. This attribute is only available if registered directly.
32 33 34 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 32 def birthdate @birthdate end |
#email ⇒ Object
The email address of the verified individual. This attribute is only available if registered directly.
44 45 46 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 44 def email @email end |
#english_name ⇒ Object
The full English name of the verified individual.
26 27 28 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 26 def english_name @english_name end |
#gender ⇒ Object
The sex of the verified individual. Possible values: - Unknown - NotApplicable - Male - Female This attribute is only available if registered directly.
35 36 37 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 35 def gender @gender end |
#name ⇒ Object
The full name of the verified individual. This may be an English or Arabic name if the individual only has it one language, otherwise this will be null and the other names will be populated.
23 24 25 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 23 def name @name end |
#nationality ⇒ Object
The nationality of the verified individual as an ISO 3166-1 alpha-2 country code. This attribute is only available if registered directly.
38 39 40 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 38 def nationality @nationality end |
#phone_number ⇒ Object
The phone number of the verified individual. This attribute is only available if registered directly.
41 42 43 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 41 def phone_number @phone_number end |
#sub ⇒ Object
A unique eKYC identifying token used to match the original eKYC token received from the provider when the individual was initially registered. Since Fayda does not return identifying data, it is the responsibility of the relying party to keep the unique individual token received from Fayda when the individual was initially registered to do a comparison of the subs to verify that it is the same person.
20 21 22 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 20 def sub @sub end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 50 def self.attribute_map { :'sub' => :'sub', :'name' => :'name', :'english_name' => :'englishName', :'arabic_name' => :'arabicName', :'birthdate' => :'birthdate', :'gender' => :'gender', :'nationality' => :'nationality', :'phone_number' => :'phoneNumber', :'email' => :'email', :'address' => :'address' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 92 def self.openapi_nullable Set.new([ :'sub', :'name', :'english_name', :'arabic_name', :'birthdate', :'gender', :'nationality', :'phone_number', :'email', :'address' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 76 def self.openapi_types { :'sub' => :'String', :'name' => :'String', :'english_name' => :'String', :'arabic_name' => :'String', :'birthdate' => :'Date', :'gender' => :'String', :'nationality' => :'String', :'phone_number' => :'String', :'email' => :'String', :'address' => :'FaydaProviderAddress' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 181 def ==(o) return true if self.equal?(o) self.class == o.class && sub == o.sub && name == o.name && english_name == o.english_name && arabic_name == o.arabic_name && birthdate == o.birthdate && gender == o.gender && nationality == o.nationality && phone_number == o.phone_number && email == o.email && address == o.address end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 204 def hash [sub, name, english_name, arabic_name, birthdate, gender, nationality, phone_number, email, address].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |