Class: TrinsicApi::FaydaProviderOutput
- Inherits:
-
Object
- Object
- TrinsicApi::FaydaProviderOutput
- Defined in:
- lib/trinsic_api/models/fayda_provider_output.rb
Overview
Exposed properties for the ‘ethiopia-fayda` Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#arabic_name ⇒ Object
The full Arabic name of the verified individual.
-
#english_name ⇒ Object
The full English name of the verified individual.
-
#name ⇒ Object
The full name of the verified individual.
-
#sub ⇒ Object
A unique eKYC identifying token used to match the original eKYC token received from the provider when the user was initially registered.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FaydaProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FaydaProviderOutput
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::FaydaProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::FaydaProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'sub') self.sub = attributes[:'sub'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'english_name') self.english_name = attributes[:'english_name'] end if attributes.key?(:'arabic_name') self.arabic_name = attributes[:'arabic_name'] end end |
Instance Attribute Details
#arabic_name ⇒ Object
The full Arabic name of the verified individual.
29 30 31 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 29 def arabic_name @arabic_name end |
#english_name ⇒ Object
The full English name of the verified individual.
26 27 28 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 26 def english_name @english_name end |
#name ⇒ Object
The full name of the verified individual. This may be an English or Arabic name if the individual only has it one language, otherwise this will be null and the other names will be populated.
23 24 25 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 23 def name @name end |
#sub ⇒ Object
A unique eKYC identifying token used to match the original eKYC token received from the provider when the user was initially registered. Since Fayda does not return identifying data, it is the responsibility of the relying party to keep the unique user token received from Fayda when the user was initially registered to do a comparison of the subs to verify that it is the same person.
20 21 22 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 20 def sub @sub end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 169 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 32 def self.attribute_map { :'sub' => :'sub', :'name' => :'name', :'english_name' => :'englishName', :'arabic_name' => :'arabicName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 145 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 66 67 68 69 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 62 def self.openapi_nullable Set.new([ :'sub', :'name', :'english_name', :'arabic_name' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 52 def self.openapi_types { :'sub' => :'String', :'name' => :'String', :'english_name' => :'String', :'arabic_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
121 122 123 124 125 126 127 128 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 121 def ==(o) return true if self.equal?(o) self.class == o.class && sub == o.sub && name == o.name && english_name == o.english_name && arabic_name == o.arabic_name end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 240 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
132 133 134 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 132 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
138 139 140 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 138 def hash [sub, name, english_name, arabic_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
106 107 108 109 110 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 106 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
216 217 218 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 216 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
210 211 212 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 210 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
114 115 116 117 |
# File 'lib/trinsic_api/models/fayda_provider_output.rb', line 114 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |