Class: TrinsicApi::GuatemalaCuiProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::GuatemalaCuiProviderOutput
- Defined in:
- lib/trinsic_api/models/guatemala_cui_provider_output.rb
Overview
Exposed properties for the ‘guatemala-cui-lookup` Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#array_name ⇒ Object
All names of the CUI holder, as an array of strings (e.g. given and family name parts).
-
#date_of_birth ⇒ Object
Date of birth of the CUI holder.
-
#document_number ⇒ Object
The Guatemalan Código Único de Identificación (CUI) number.
-
#family_name ⇒ Object
Family name(s) of the CUI holder, including maternal and paternal names.
-
#full_name ⇒ Object
Full name, including given and family names of the CUI holder.
-
#geographic_digits ⇒ Object
The last four digits encode birthplace department and municipality.
-
#given_name ⇒ Object
Given name(s) of the CUI holder.
-
#serial_digits ⇒ Object
The first 8 digits of the CUI: the portion RENAP assigns from its registration system, before the verifier digit and the four-place geographic codes.
-
#sex ⇒ Object
Sex of the CUI holder.
-
#verifier_digit ⇒ Object
The 9th digit of the CUI (verifier digit / dígito verificador).
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ GuatemalaCuiProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ GuatemalaCuiProviderOutput
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::GuatemalaCuiProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::GuatemalaCuiProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] else self.full_name = nil end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] else self.given_name = nil end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] else self.family_name = nil end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'document_number') self.document_number = attributes[:'document_number'] else self.document_number = nil end if attributes.key?(:'serial_digits') self.serial_digits = attributes[:'serial_digits'] else self.serial_digits = nil end if attributes.key?(:'verifier_digit') self.verifier_digit = attributes[:'verifier_digit'] else self.verifier_digit = nil end if attributes.key?(:'geographic_digits') self.geographic_digits = attributes[:'geographic_digits'] else self.geographic_digits = nil end if attributes.key?(:'sex') self.sex = attributes[:'sex'] else self.sex = nil end if attributes.key?(:'array_name') if (value = attributes[:'array_name']).is_a?(Array) self.array_name = value end else self.array_name = nil end end |
Instance Attribute Details
#array_name ⇒ Object
All names of the CUI holder, as an array of strings (e.g. given and family name parts).
47 48 49 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 47 def array_name @array_name end |
#date_of_birth ⇒ Object
Date of birth of the CUI holder.
29 30 31 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 29 def date_of_birth @date_of_birth end |
#document_number ⇒ Object
The Guatemalan Código Único de Identificación (CUI) number. Assigned and maintained by RENAP (Registro Nacional de las Personas). Official format: exactly 13 numeric digits. 8 RENAP-assigned serial digits, 1 verifier digit (dígito verificador), and 4 geographic digits for department and municipality of birth. The CUI is printed on the Documento Personal de Identificación (DPI) in three groups (4–5–4) separated by spaces. Trinsic normalizes to digits-only when returning the result, automatically removing spaces, dots, hyphens, and other non-alphanumeric characters. No verifier algorithm appears in publicly accessible RENAP resources. Community-maintained validators often use modulus-11 (non-official).
32 33 34 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 32 def document_number @document_number end |
#family_name ⇒ Object
Family name(s) of the CUI holder, including maternal and paternal names.
26 27 28 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 26 def family_name @family_name end |
#full_name ⇒ Object
Full name, including given and family names of the CUI holder.
20 21 22 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 20 def full_name @full_name end |
#geographic_digits ⇒ Object
The last four digits encode birthplace department and municipality. There is not a publicly accessible dataset from RENAP for geographic codes. The INE (Instituto Nacional de Estadística y Censos) provides a dictionary of variables (Educación Formal 2024) that includes statistical codes for decoding departments and municipalities. Be careful using these resources, as these codes are not official RENAP codes. They may not always map to the correct department and municipality for consular registrations, naturalizations, foreign residents, and other edge cases. For the dataset, see: datos.ine.gob.gt/dataset/educacion-formal-2024 under "Diccionario de Variables (Educación Formal 2024)"
41 42 43 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 41 def geographic_digits @geographic_digits end |
#given_name ⇒ Object
Given name(s) of the CUI holder.
23 24 25 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 23 def given_name @given_name end |
#serial_digits ⇒ Object
The first 8 digits of the CUI: the portion RENAP assigns from its registration system, before the verifier digit and the four-place geographic codes. Called the “serial” numbers in community-maintained validators.
35 36 37 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 35 def serial_digits @serial_digits end |
#sex ⇒ Object
Sex of the CUI holder. Possible values: - Male - Female - Unknown
44 45 46 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 44 def sex @sex end |
#verifier_digit ⇒ Object
The 9th digit of the CUI (verifier digit / dígito verificador). No verifier algorithm appears in publicly accessible RENAP resources. However, community-maintained validators often use modulus-11 (non-official).
38 39 40 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 38 def verifier_digit @verifier_digit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 50 def self.attribute_map { :'full_name' => :'fullName', :'given_name' => :'givenName', :'family_name' => :'familyName', :'date_of_birth' => :'dateOfBirth', :'document_number' => :'documentNumber', :'serial_digits' => :'serialDigits', :'verifier_digit' => :'verifierDigit', :'geographic_digits' => :'geographicDigits', :'sex' => :'sex', :'array_name' => :'arrayName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 357 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 92 def self.openapi_nullable Set.new([ :'date_of_birth', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 76 def self.openapi_types { :'full_name' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'date_of_birth' => :'Date', :'document_number' => :'String', :'serial_digits' => :'String', :'verifier_digit' => :'String', :'geographic_digits' => :'String', :'sex' => :'String', :'array_name' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
327 328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 327 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && given_name == o.given_name && family_name == o.family_name && date_of_birth == o.date_of_birth && document_number == o.document_number && serial_digits == o.serial_digits && verifier_digit == o.verifier_digit && geographic_digits == o.geographic_digits && sex == o.sex && array_name == o.array_name end |
#eql?(o) ⇒ Boolean
344 345 346 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 344 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
350 351 352 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 350 def hash [full_name, given_name, family_name, date_of_birth, document_number, serial_digits, verifier_digit, geographic_digits, sex, array_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @full_name.nil? invalid_properties.push('invalid value for "full_name", full_name cannot be nil.') end if @given_name.nil? invalid_properties.push('invalid value for "given_name", given_name cannot be nil.') end if @family_name.nil? invalid_properties.push('invalid value for "family_name", family_name cannot be nil.') end if @document_number.nil? invalid_properties.push('invalid value for "document_number", document_number cannot be nil.') end if @serial_digits.nil? invalid_properties.push('invalid value for "serial_digits", serial_digits cannot be nil.') end if @verifier_digit.nil? invalid_properties.push('invalid value for "verifier_digit", verifier_digit cannot be nil.') end if @geographic_digits.nil? invalid_properties.push('invalid value for "geographic_digits", geographic_digits cannot be nil.') end if @sex.nil? invalid_properties.push('invalid value for "sex", sex cannot be nil.') end if @array_name.nil? invalid_properties.push('invalid value for "array_name", array_name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
379 380 381 382 383 384 385 386 387 388 389 390 391 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 379 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/trinsic_api/models/guatemala_cui_provider_output.rb', line 221 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @full_name.nil? return false if @given_name.nil? return false if @family_name.nil? return false if @document_number.nil? return false if @serial_digits.nil? return false if @verifier_digit.nil? return false if @geographic_digits.nil? return false if @sex.nil? return false if @array_name.nil? true end |