Class: TrinsicApi::IdemiaMobileIdProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::IdemiaMobileIdProviderOutput
- Defined in:
- lib/trinsic_api/models/idemia_mobile_id_provider_output.rb
Overview
Exposed properties for Idemia Mobile ID Providers which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#age_over18 ⇒ Object
Whether the individual is over 18 years old.
-
#age_over21 ⇒ Object
Whether the individual is over 21 years old.
-
#age_over25 ⇒ Object
Whether the individual is over 25 years old.
-
#birth_date ⇒ Object
The individual's birth date.
-
#document_number ⇒ Object
The individual's document number.
-
#document_type ⇒ Object
The document type.
-
#email ⇒ Object
The individual's email address.
-
#email_verified ⇒ Object
Whether the individual's email address has been verified.
-
#expiry_date ⇒ Object
The date the document expires.
-
#family_name ⇒ Object
The individual's family name.
-
#full_name ⇒ Object
The individual's full name.
-
#given_name ⇒ Object
The individual's given name.
-
#issue_date ⇒ Object
The date the document was issued.
-
#issuing_authority ⇒ Object
The authority that issued the document.
-
#issuing_country ⇒ Object
The country that issued the document.
-
#issuing_jurisdiction ⇒ Object
The jurisdiction that issued the document.
-
#name_suffix ⇒ Object
The individual's name suffix.
-
#resident_address ⇒ Object
The individual's resident street address.
-
#resident_city ⇒ Object
The individual's resident city.
-
#resident_country ⇒ Object
The individual's resident country.
-
#resident_postal_code ⇒ Object
The individual's resident postal code.
-
#resident_state ⇒ Object
The individual's resident state.
-
#sex ⇒ Object
The individual's sex.
-
#sub ⇒ Object
The OpenID Connect subject identifier for the verified individual.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IdemiaMobileIdProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IdemiaMobileIdProviderOutput
Initializes the object
193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 193 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IdemiaMobileIdProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IdemiaMobileIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'sub') self.sub = attributes[:'sub'] end if attributes.key?(:'name_suffix') self.name_suffix = attributes[:'name_suffix'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'birth_date') self.birth_date = attributes[:'birth_date'] end if attributes.key?(:'age_over18') self.age_over18 = attributes[:'age_over18'] end if attributes.key?(:'age_over21') self.age_over21 = attributes[:'age_over21'] end if attributes.key?(:'age_over25') self.age_over25 = attributes[:'age_over25'] end if attributes.key?(:'resident_address') self.resident_address = attributes[:'resident_address'] end if attributes.key?(:'resident_state') self.resident_state = attributes[:'resident_state'] end if attributes.key?(:'resident_country') self.resident_country = attributes[:'resident_country'] end if attributes.key?(:'resident_postal_code') self.resident_postal_code = attributes[:'resident_postal_code'] end if attributes.key?(:'resident_city') self.resident_city = attributes[:'resident_city'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'email_verified') self.email_verified = attributes[:'email_verified'] end if attributes.key?(:'document_number') self.document_number = attributes[:'document_number'] end if attributes.key?(:'issue_date') self.issue_date = attributes[:'issue_date'] end if attributes.key?(:'issuing_country') self.issuing_country = attributes[:'issuing_country'] end if attributes.key?(:'issuing_authority') self. = attributes[:'issuing_authority'] end if attributes.key?(:'expiry_date') self.expiry_date = attributes[:'expiry_date'] end if attributes.key?(:'issuing_jurisdiction') self.issuing_jurisdiction = attributes[:'issuing_jurisdiction'] end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] end if attributes.key?(:'sex') self.sex = attributes[:'sex'] end end |
Instance Attribute Details
#age_over18 ⇒ Object
Whether the individual is over 18 years old.
38 39 40 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 38 def age_over18 @age_over18 end |
#age_over21 ⇒ Object
Whether the individual is over 21 years old.
41 42 43 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 41 def age_over21 @age_over21 end |
#age_over25 ⇒ Object
Whether the individual is over 25 years old.
44 45 46 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 44 def age_over25 @age_over25 end |
#birth_date ⇒ Object
The individual's birth date.
35 36 37 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 35 def birth_date @birth_date end |
#document_number ⇒ Object
The individual's document number.
68 69 70 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 68 def document_number @document_number end |
#document_type ⇒ Object
The document type.
86 87 88 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 86 def document_type @document_type end |
#email ⇒ Object
The individual's email address.
62 63 64 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 62 def email @email end |
#email_verified ⇒ Object
Whether the individual's email address has been verified.
65 66 67 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 65 def email_verified @email_verified end |
#expiry_date ⇒ Object
The date the document expires.
80 81 82 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 80 def expiry_date @expiry_date end |
#family_name ⇒ Object
The individual's family name.
32 33 34 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 32 def family_name @family_name end |
#full_name ⇒ Object
The individual's full name.
26 27 28 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 26 def full_name @full_name end |
#given_name ⇒ Object
The individual's given name.
29 30 31 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 29 def given_name @given_name end |
#issue_date ⇒ Object
The date the document was issued.
71 72 73 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 71 def issue_date @issue_date end |
#issuing_authority ⇒ Object
The authority that issued the document.
77 78 79 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 77 def @issuing_authority end |
#issuing_country ⇒ Object
The country that issued the document.
74 75 76 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 74 def issuing_country @issuing_country end |
#issuing_jurisdiction ⇒ Object
The jurisdiction that issued the document.
83 84 85 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 83 def issuing_jurisdiction @issuing_jurisdiction end |
#name_suffix ⇒ Object
The individual's name suffix.
23 24 25 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 23 def name_suffix @name_suffix end |
#resident_address ⇒ Object
The individual's resident street address.
47 48 49 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 47 def resident_address @resident_address end |
#resident_city ⇒ Object
The individual's resident city.
59 60 61 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 59 def resident_city @resident_city end |
#resident_country ⇒ Object
The individual's resident country.
53 54 55 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 53 def resident_country @resident_country end |
#resident_postal_code ⇒ Object
The individual's resident postal code.
56 57 58 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 56 def resident_postal_code @resident_postal_code end |
#resident_state ⇒ Object
The individual's resident state.
50 51 52 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 50 def resident_state @resident_state end |
#sex ⇒ Object
The individual's sex.
89 90 91 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 89 def sex @sex end |
#sub ⇒ Object
The OpenID Connect subject identifier for the verified individual.
20 21 22 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 20 def sub @sub end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
122 123 124 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 122 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
127 128 129 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 127 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 92 def self.attribute_map { :'sub' => :'sub', :'name_suffix' => :'nameSuffix', :'full_name' => :'fullName', :'given_name' => :'givenName', :'family_name' => :'familyName', :'birth_date' => :'birthDate', :'age_over18' => :'ageOver18', :'age_over21' => :'ageOver21', :'age_over25' => :'ageOver25', :'resident_address' => :'residentAddress', :'resident_state' => :'residentState', :'resident_country' => :'residentCountry', :'resident_postal_code' => :'residentPostalCode', :'resident_city' => :'residentCity', :'email' => :'email', :'email_verified' => :'emailVerified', :'document_number' => :'documentNumber', :'issue_date' => :'issueDate', :'issuing_country' => :'issuingCountry', :'issuing_authority' => :'issuingAuthority', :'expiry_date' => :'expiryDate', :'issuing_jurisdiction' => :'issuingJurisdiction', :'document_type' => :'documentType', :'sex' => :'sex' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 365 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 162 def self.openapi_nullable Set.new([ :'sub', :'name_suffix', :'full_name', :'given_name', :'family_name', :'birth_date', :'age_over18', :'age_over21', :'age_over25', :'resident_address', :'resident_state', :'resident_country', :'resident_postal_code', :'resident_city', :'email', :'email_verified', :'document_number', :'issue_date', :'issuing_country', :'issuing_authority', :'expiry_date', :'issuing_jurisdiction', :'document_type', :'sex' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 132 def self.openapi_types { :'sub' => :'String', :'name_suffix' => :'String', :'full_name' => :'String', :'given_name' => :'String', :'family_name' => :'String', :'birth_date' => :'String', :'age_over18' => :'String', :'age_over21' => :'String', :'age_over25' => :'String', :'resident_address' => :'String', :'resident_state' => :'String', :'resident_country' => :'String', :'resident_postal_code' => :'String', :'resident_city' => :'String', :'email' => :'String', :'email_verified' => :'Boolean', :'document_number' => :'String', :'issue_date' => :'String', :'issuing_country' => :'String', :'issuing_authority' => :'String', :'expiry_date' => :'String', :'issuing_jurisdiction' => :'String', :'document_type' => :'String', :'sex' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 321 def ==(o) return true if self.equal?(o) self.class == o.class && sub == o.sub && name_suffix == o.name_suffix && full_name == o.full_name && given_name == o.given_name && family_name == o.family_name && birth_date == o.birth_date && age_over18 == o.age_over18 && age_over21 == o.age_over21 && age_over25 == o.age_over25 && resident_address == o.resident_address && resident_state == o.resident_state && resident_country == o.resident_country && resident_postal_code == o.resident_postal_code && resident_city == o.resident_city && email == o.email && email_verified == o.email_verified && document_number == o.document_number && issue_date == o.issue_date && issuing_country == o.issuing_country && == o. && expiry_date == o.expiry_date && issuing_jurisdiction == o.issuing_jurisdiction && document_type == o.document_type && sex == o.sex end |
#eql?(o) ⇒ Boolean
352 353 354 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 352 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
358 359 360 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 358 def hash [sub, name_suffix, full_name, given_name, family_name, birth_date, age_over18, age_over21, age_over25, resident_address, resident_state, resident_country, resident_postal_code, resident_city, email, email_verified, document_number, issue_date, issuing_country, , expiry_date, issuing_jurisdiction, document_type, sex].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
306 307 308 309 310 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 306 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
387 388 389 390 391 392 393 394 395 396 397 398 399 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 387 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
314 315 316 317 |
# File 'lib/trinsic_api/models/idemia_mobile_id_provider_output.rb', line 314 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |