Class: TrinsicApi::IndonesiaNikMatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::IndonesiaNikMatch
- Defined in:
- lib/trinsic_api/models/indonesia_nik_match.rb
Overview
Exposed properties for the indonesia-nik-lookup Provider which do not directly map to the normalized IdentityData model.
Instance Attribute Summary collapse
-
#date_of_birth ⇒ Object
Date of birth match result from Indonesia NIK verification.
-
#date_of_birth_national_id_number ⇒ Object
Date of birth extracted from digits 7-12 of the NIK number.
-
#district_code ⇒ Object
Six-digit district code extracted from digits 1-6 of the NIK number, including province and regency/city code prefixes.
-
#full_name ⇒ Object
Full name match result from Indonesia NIK verification.
-
#national_id_number ⇒ Object
NIK number match result from Indonesia NIK verification.
-
#province_code ⇒ Object
Two-digit province code extracted from digits 1-2 of the NIK number.
-
#regency_or_city_code ⇒ Object
Four-digit regency or city code extracted from digits 1-4 of the NIK number, including the province code prefix.
-
#serial_number ⇒ Object
Four-digit issuance serial number extracted from digits 13-16 of the NIK number.
-
#sex_national_id_number ⇒ Object
Sex extracted from the birth-day portion of the NIK number.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IndonesiaNikMatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IndonesiaNikMatch
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::IndonesiaNikMatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::IndonesiaNikMatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end if attributes.key?(:'national_id_number') self.national_id_number = attributes[:'national_id_number'] end if attributes.key?(:'province_code') self.province_code = attributes[:'province_code'] end if attributes.key?(:'regency_or_city_code') self.regency_or_city_code = attributes[:'regency_or_city_code'] end if attributes.key?(:'district_code') self.district_code = attributes[:'district_code'] end if attributes.key?(:'date_of_birth_national_id_number') self.date_of_birth_national_id_number = attributes[:'date_of_birth_national_id_number'] end if attributes.key?(:'sex_national_id_number') self.sex_national_id_number = attributes[:'sex_national_id_number'] end if attributes.key?(:'serial_number') self.serial_number = attributes[:'serial_number'] end end |
Instance Attribute Details
#date_of_birth ⇒ Object
Date of birth match result from Indonesia NIK verification.
23 24 25 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 23 def date_of_birth @date_of_birth end |
#date_of_birth_national_id_number ⇒ Object
Date of birth extracted from digits 7-12 of the NIK number. The NIK encodes date of birth as DDMMYY. For female NIK holders, the encoded day is increased by 40 before being stored in the NIK number.
38 39 40 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 38 def date_of_birth_national_id_number @date_of_birth_national_id_number end |
#district_code ⇒ Object
Six-digit district code extracted from digits 1-6 of the NIK number, including province and regency/city code prefixes.
35 36 37 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 35 def district_code @district_code end |
#full_name ⇒ Object
Full name match result from Indonesia NIK verification.
20 21 22 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 20 def full_name @full_name end |
#national_id_number ⇒ Object
NIK number match result from Indonesia NIK verification. NIK stands for Nomor Induk Kependudukan. It is Indonesia's unique population identity number, issued by Indonesia's population administration and civil registration authority (Dukcapil) under the Ministry of Home Affairs. A NIK has 16 digits: - Digits 1-2 are the province code. - Digits 3-4 are the regency or city code within that province. - Digits 5-6 are the district code within that regency or city. - Digits 7-12 encode date of birth as DDMMYY. For female NIK holders, the day is increased by 40. - Digits 13-16 are an issuance serial number.
26 27 28 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 26 def national_id_number @national_id_number end |
#province_code ⇒ Object
Two-digit province code extracted from digits 1-2 of the NIK number.
29 30 31 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 29 def province_code @province_code end |
#regency_or_city_code ⇒ Object
Four-digit regency or city code extracted from digits 1-4 of the NIK number, including the province code prefix.
32 33 34 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 32 def regency_or_city_code @regency_or_city_code end |
#serial_number ⇒ Object
Four-digit issuance serial number extracted from digits 13-16 of the NIK number.
44 45 46 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 44 def serial_number @serial_number end |
#sex_national_id_number ⇒ Object
Sex extracted from the birth-day portion of the NIK number. The encoded day value is increased by 40 for female NIK holders.
41 42 43 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 41 def sex_national_id_number @sex_national_id_number end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 47 def self.attribute_map { :'full_name' => :'fullName', :'date_of_birth' => :'dateOfBirth', :'national_id_number' => :'nationalIdNumber', :'province_code' => :'provinceCode', :'regency_or_city_code' => :'regencyOrCityCode', :'district_code' => :'districtCode', :'date_of_birth_national_id_number' => :'dateOfBirthNationalIdNumber', :'sex_national_id_number' => :'sexNationalIdNumber', :'serial_number' => :'serialNumber' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 87 def self.openapi_nullable Set.new([ :'full_name', :'date_of_birth', :'national_id_number', :'province_code', :'regency_or_city_code', :'district_code', :'date_of_birth_national_id_number', :'sex_national_id_number', :'serial_number' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 72 def self.openapi_types { :'full_name' => :'IndonesiaNikMatchField', :'date_of_birth' => :'IndonesiaNikMatchField', :'national_id_number' => :'IndonesiaNikMatchField', :'province_code' => :'String', :'regency_or_city_code' => :'String', :'district_code' => :'String', :'date_of_birth_national_id_number' => :'Date', :'sex_national_id_number' => :'String', :'serial_number' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 171 def ==(o) return true if self.equal?(o) self.class == o.class && full_name == o.full_name && date_of_birth == o.date_of_birth && national_id_number == o.national_id_number && province_code == o.province_code && regency_or_city_code == o.regency_or_city_code && district_code == o.district_code && date_of_birth_national_id_number == o.date_of_birth_national_id_number && sex_national_id_number == o.sex_national_id_number && serial_number == o.serial_number end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 193 def hash [full_name, date_of_birth, national_id_number, province_code, regency_or_city_code, district_code, date_of_birth_national_id_number, sex_national_id_number, serial_number].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
156 157 158 159 160 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 156 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
164 165 166 167 |
# File 'lib/trinsic_api/models/indonesia_nik_match.rb', line 164 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |