Class: TrinsicApi::Iso180132BiometricTemplateHeader
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::Iso180132BiometricTemplateHeader
- Defined in:
- lib/trinsic_api/models/iso180132_biometric_template_header.rb
Overview
Header fields of a biometric template per ISO 18013-2 Table C.12.
Instance Attribute Summary collapse
-
#biometric_data_block_format_owner ⇒ Object
Format owner of the biometric data block.
-
#biometric_data_block_format_type ⇒ Object
Format type of the biometric data block.
-
#biometric_data_block_product ⇒ Object
Owner and type identifying the product that produced the biometric data block.
-
#biometric_information_record_creator ⇒ Object
Name of the Biometric Information Record (BIR) creator.
-
#biometric_information_record_index ⇒ Object
Index identifier of the Biometric Information Record, when present.
-
#biometric_sub_type ⇒ Object
Biometric sub-type code per ISO 18013-2.
-
#biometric_type ⇒ Object
Biometric type code per ISO 18013-2.
-
#creation_date ⇒ Object
Date and time the biometric template was created.
-
#patron_header_version ⇒ Object
Patron header version (defaults to 0x0101).
-
#validity_period ⇒ Object
Validity period of the biometric data block.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Iso180132BiometricTemplateHeader
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Iso180132BiometricTemplateHeader
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::Iso180132BiometricTemplateHeader` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::Iso180132BiometricTemplateHeader`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'patron_header_version') self.patron_header_version = attributes[:'patron_header_version'] else self.patron_header_version = nil end if attributes.key?(:'biometric_type') self.biometric_type = attributes[:'biometric_type'] end if attributes.key?(:'biometric_sub_type') self.biometric_sub_type = attributes[:'biometric_sub_type'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'biometric_information_record_creator') self.biometric_information_record_creator = attributes[:'biometric_information_record_creator'] end if attributes.key?(:'validity_period') self.validity_period = attributes[:'validity_period'] end if attributes.key?(:'biometric_data_block_product') self.biometric_data_block_product = attributes[:'biometric_data_block_product'] end if attributes.key?(:'biometric_data_block_format_owner') self.biometric_data_block_format_owner = attributes[:'biometric_data_block_format_owner'] else self.biometric_data_block_format_owner = nil end if attributes.key?(:'biometric_data_block_format_type') self.biometric_data_block_format_type = attributes[:'biometric_data_block_format_type'] else self.biometric_data_block_format_type = nil end if attributes.key?(:'biometric_information_record_index') self.biometric_information_record_index = attributes[:'biometric_information_record_index'] end end |
Instance Attribute Details
#biometric_data_block_format_owner ⇒ Object
Format owner of the biometric data block.
41 42 43 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 41 def biometric_data_block_format_owner @biometric_data_block_format_owner end |
#biometric_data_block_format_type ⇒ Object
Format type of the biometric data block.
44 45 46 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 44 def biometric_data_block_format_type @biometric_data_block_format_type end |
#biometric_data_block_product ⇒ Object
Owner and type identifying the product that produced the biometric data block.
38 39 40 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 38 def biometric_data_block_product @biometric_data_block_product end |
#biometric_information_record_creator ⇒ Object
Name of the Biometric Information Record (BIR) creator.
32 33 34 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 32 def biometric_information_record_creator @biometric_information_record_creator end |
#biometric_information_record_index ⇒ Object
Index identifier of the Biometric Information Record, when present.
47 48 49 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 47 def biometric_information_record_index @biometric_information_record_index end |
#biometric_sub_type ⇒ Object
Biometric sub-type code per ISO 18013-2.
26 27 28 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 26 def biometric_sub_type @biometric_sub_type end |
#biometric_type ⇒ Object
Biometric type code per ISO 18013-2.
23 24 25 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 23 def biometric_type @biometric_type end |
#creation_date ⇒ Object
Date and time the biometric template was created.
29 30 31 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 29 def creation_date @creation_date end |
#patron_header_version ⇒ Object
Patron header version (defaults to 0x0101).
20 21 22 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 20 def patron_header_version @patron_header_version end |
#validity_period ⇒ Object
Validity period of the biometric data block.
35 36 37 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 35 def validity_period @validity_period end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 50 def self.attribute_map { :'patron_header_version' => :'patronHeaderVersion', :'biometric_type' => :'biometricType', :'biometric_sub_type' => :'biometricSubType', :'creation_date' => :'creationDate', :'biometric_information_record_creator' => :'biometricInformationRecordCreator', :'validity_period' => :'validityPeriod', :'biometric_data_block_product' => :'biometricDataBlockProduct', :'biometric_data_block_format_owner' => :'biometricDataBlockFormatOwner', :'biometric_data_block_format_type' => :'biometricDataBlockFormatType', :'biometric_information_record_index' => :'biometricInformationRecordIndex' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 259 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 92 def self.openapi_nullable Set.new([ :'biometric_type', :'biometric_sub_type', :'creation_date', :'biometric_information_record_creator', :'validity_period', :'biometric_data_block_product', :'biometric_information_record_index' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 76 def self.openapi_types { :'patron_header_version' => :'Integer', :'biometric_type' => :'Integer', :'biometric_sub_type' => :'Integer', :'creation_date' => :'Time', :'biometric_information_record_creator' => :'String', :'validity_period' => :'Iso180132BiometricValidityPeriod', :'biometric_data_block_product' => :'Iso180132BiometricDataBlockProduct', :'biometric_data_block_format_owner' => :'Integer', :'biometric_data_block_format_type' => :'Integer', :'biometric_information_record_index' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 229 def ==(o) return true if self.equal?(o) self.class == o.class && patron_header_version == o.patron_header_version && biometric_type == o.biometric_type && biometric_sub_type == o.biometric_sub_type && creation_date == o.creation_date && biometric_information_record_creator == o.biometric_information_record_creator && validity_period == o.validity_period && biometric_data_block_product == o.biometric_data_block_product && biometric_data_block_format_owner == o.biometric_data_block_format_owner && biometric_data_block_format_type == o.biometric_data_block_format_type && biometric_information_record_index == o.biometric_information_record_index end |
#eql?(o) ⇒ Boolean
246 247 248 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 246 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
252 253 254 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 252 def hash [patron_header_version, biometric_type, biometric_sub_type, creation_date, biometric_information_record_creator, validity_period, biometric_data_block_product, biometric_data_block_format_owner, biometric_data_block_format_type, biometric_information_record_index].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @patron_header_version.nil? invalid_properties.push('invalid value for "patron_header_version", patron_header_version cannot be nil.') end if @biometric_data_block_format_owner.nil? invalid_properties.push('invalid value for "biometric_data_block_format_owner", biometric_data_block_format_owner cannot be nil.') end if @biometric_data_block_format_type.nil? invalid_properties.push('invalid value for "biometric_data_block_format_type", biometric_data_block_format_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 281 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
189 190 191 192 193 194 195 |
# File 'lib/trinsic_api/models/iso180132_biometric_template_header.rb', line 189 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @patron_header_version.nil? return false if @biometric_data_block_format_owner.nil? return false if @biometric_data_block_format_type.nil? true end |