Class: TrinsicApi::ItsmeBelgianIdentityCard
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ItsmeBelgianIdentityCard
- Defined in:
- lib/trinsic_api/models/itsme_belgian_identity_card.rb
Instance Attribute Summary collapse
-
#issuance_locality ⇒ Object
The locality that issued the identity card.
-
#issuing_country ⇒ Object
The issuing country as an ISO 3166-1 alpha-2 country code.
-
#number ⇒ Object
The Belgian eID card number.
-
#validity_from ⇒ Object
The identity card validity start date time.
-
#validity_to ⇒ Object
The identity card validity end date time.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ItsmeBelgianIdentityCard
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ItsmeBelgianIdentityCard
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ItsmeBelgianIdentityCard` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ItsmeBelgianIdentityCard`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'number') self.number = attributes[:'number'] end if attributes.key?(:'issuing_country') self.issuing_country = attributes[:'issuing_country'] end if attributes.key?(:'validity_from') self.validity_from = attributes[:'validity_from'] end if attributes.key?(:'validity_to') self.validity_to = attributes[:'validity_to'] end if attributes.key?(:'issuance_locality') self.issuance_locality = attributes[:'issuance_locality'] end end |
Instance Attribute Details
#issuance_locality ⇒ Object
The locality that issued the identity card. Availability by ID document issuing country: best effort for Belgian-issued ID documents; not returned for other supported issuing countries.
31 32 33 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 31 def issuance_locality @issuance_locality end |
#issuing_country ⇒ Object
The issuing country as an ISO 3166-1 alpha-2 country code. Availability by ID document issuing country: always returned for all supported issuing countries.
22 23 24 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 22 def issuing_country @issuing_country end |
#number ⇒ Object
The Belgian eID card number. This identifies the card document, not the person's Belgian National Register Number. Availability by ID document issuing country: returned only for Belgian-issued ID documents. Belgian citizen examples are 12 digits in the form xxx-xxxxxxx-yy; EU, EEA, and Swiss resident card examples can start with a letter followed by digits.
19 20 21 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 19 def number @number end |
#validity_from ⇒ Object
The identity card validity start date time. Availability by ID document issuing country: best effort for Belgian-issued ID documents; not returned for other supported issuing countries.
25 26 27 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 25 def validity_from @validity_from end |
#validity_to ⇒ Object
The identity card validity end date time. Availability by ID document issuing country: always returned for supported issuing countries except Belgium, where it is best effort.
28 29 30 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 28 def validity_to @validity_to end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 34 def self.attribute_map { :'number' => :'number', :'issuing_country' => :'issuingCountry', :'validity_from' => :'validityFrom', :'validity_to' => :'validityTo', :'issuance_locality' => :'issuanceLocality' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 155 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 70 71 72 73 74 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 66 def self.openapi_nullable Set.new([ :'number', :'issuing_country', :'validity_from', :'validity_to', :'issuance_locality' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 55 def self.openapi_types { :'number' => :'String', :'issuing_country' => :'String', :'validity_from' => :'Time', :'validity_to' => :'Time', :'issuance_locality' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 138 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && number == o.number && issuing_country == o.issuing_country && validity_from == o.validity_from && validity_to == o.validity_to && issuance_locality == o.issuance_locality end |
#eql?(o) ⇒ Boolean
142 143 144 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 142 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
148 149 150 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 148 def hash [number, issuing_country, validity_from, validity_to, issuance_locality].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
115 116 117 118 119 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 115 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 177 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
123 124 125 126 |
# File 'lib/trinsic_api/models/itsme_belgian_identity_card.rb', line 123 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |