Class: TrinsicApi::ItsmeDirectDevice
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ItsmeDirectDevice
- Defined in:
- lib/trinsic_api/models/itsme_direct_device.rb
Instance Attribute Summary collapse
-
#app_name ⇒ Object
The itsme app name reported for the verification.
-
#app_release ⇒ Object
The itsme app release reported for the verification.
-
#debug_enabled ⇒ Object
Whether the itsme device had debugging enabled.
-
#device_id ⇒ Object
The device identifier.
-
#device_label ⇒ Object
The device label.
-
#device_lock_level ⇒ Object
The device lock level value.
-
#device_model ⇒ Object
The device model reported for the itsme device.
-
#manufacturer ⇒ Object
The device manufacturer reported for the itsme device.
-
#msisdn ⇒ Object
The Mobile Station International Subscriber Directory Number (MSISDN) value for the device.
-
#operating_system ⇒ Object
The operating system reported for the itsme device.
-
#operating_system_release ⇒ Object
The operating system release reported for the itsme device.
-
#rooted ⇒ Object
Whether the itsme device was reported as rooted.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ItsmeDirectDevice
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ItsmeDirectDevice
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ItsmeDirectDevice` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ItsmeDirectDevice`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'operating_system') self. = attributes[:'operating_system'] end if attributes.key?(:'operating_system_release') self. = attributes[:'operating_system_release'] end if attributes.key?(:'app_name') self.app_name = attributes[:'app_name'] end if attributes.key?(:'app_release') self.app_release = attributes[:'app_release'] end if attributes.key?(:'manufacturer') self.manufacturer = attributes[:'manufacturer'] end if attributes.key?(:'device_model') self.device_model = attributes[:'device_model'] end if attributes.key?(:'device_label') self.device_label = attributes[:'device_label'] end if attributes.key?(:'device_id') self.device_id = attributes[:'device_id'] end if attributes.key?(:'debug_enabled') self.debug_enabled = attributes[:'debug_enabled'] end if attributes.key?(:'rooted') self.rooted = attributes[:'rooted'] end if attributes.key?(:'device_lock_level') self.device_lock_level = attributes[:'device_lock_level'] end if attributes.key?(:'msisdn') self.msisdn = attributes[:'msisdn'] end end |
Instance Attribute Details
#app_name ⇒ Object
The itsme app name reported for the verification. Availability by ID document issuing country: best effort for all supported issuing countries.
25 26 27 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 25 def app_name @app_name end |
#app_release ⇒ Object
The itsme app release reported for the verification. Availability by ID document issuing country: best effort for all supported issuing countries.
28 29 30 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 28 def app_release @app_release end |
#debug_enabled ⇒ Object
Whether the itsme device had debugging enabled. Availability by ID document issuing country: best effort for all supported issuing countries.
43 44 45 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 43 def debug_enabled @debug_enabled end |
#device_id ⇒ Object
The device identifier. Availability by ID document issuing country: best effort for all supported issuing countries.
40 41 42 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 40 def device_id @device_id end |
#device_label ⇒ Object
The device label. Availability by ID document issuing country: best effort for all supported issuing countries.
37 38 39 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 37 def device_label @device_label end |
#device_lock_level ⇒ Object
The device lock level value. Availability by ID document issuing country: best effort for all supported issuing countries.
49 50 51 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 49 def device_lock_level @device_lock_level end |
#device_model ⇒ Object
The device model reported for the itsme device. Availability by ID document issuing country: best effort for all supported issuing countries.
34 35 36 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 34 def device_model @device_model end |
#manufacturer ⇒ Object
The device manufacturer reported for the itsme device. Availability by ID document issuing country: best effort for all supported issuing countries.
31 32 33 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 31 def manufacturer @manufacturer end |
#msisdn ⇒ Object
The Mobile Station International Subscriber Directory Number (MSISDN) value for the device. Availability by ID document issuing country: best effort for all supported issuing countries.
52 53 54 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 52 def msisdn @msisdn end |
#operating_system ⇒ Object
The operating system reported for the itsme device. Availability by ID document issuing country: best effort for all supported issuing countries.
19 20 21 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 19 def @operating_system end |
#operating_system_release ⇒ Object
The operating system release reported for the itsme device. Availability by ID document issuing country: best effort for all supported issuing countries.
22 23 24 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 22 def @operating_system_release end |
#rooted ⇒ Object
Whether the itsme device was reported as rooted. Availability by ID document issuing country: best effort for all supported issuing countries.
46 47 48 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 46 def rooted @rooted end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 55 def self.attribute_map { :'operating_system' => :'operatingSystem', :'operating_system_release' => :'operatingSystemRelease', :'app_name' => :'appName', :'app_release' => :'appRelease', :'manufacturer' => :'manufacturer', :'device_model' => :'deviceModel', :'device_label' => :'deviceLabel', :'device_id' => :'deviceId', :'debug_enabled' => :'debugEnabled', :'rooted' => :'rooted', :'device_lock_level' => :'deviceLockLevel', :'msisdn' => :'msisdn' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 232 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 101 def self.openapi_nullable Set.new([ :'operating_system', :'operating_system_release', :'app_name', :'app_release', :'manufacturer', :'device_model', :'device_label', :'device_id', :'debug_enabled', :'rooted', :'device_lock_level', :'msisdn' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 83 def self.openapi_types { :'operating_system' => :'String', :'operating_system_release' => :'String', :'app_name' => :'String', :'app_release' => :'String', :'manufacturer' => :'String', :'device_model' => :'String', :'device_label' => :'String', :'device_id' => :'String', :'debug_enabled' => :'Boolean', :'rooted' => :'Boolean', :'device_lock_level' => :'String', :'msisdn' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 200 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && == o. && app_name == o.app_name && app_release == o.app_release && manufacturer == o.manufacturer && device_model == o.device_model && device_label == o.device_label && device_id == o.device_id && debug_enabled == o.debug_enabled && rooted == o.rooted && device_lock_level == o.device_lock_level && msisdn == o.msisdn end |
#eql?(o) ⇒ Boolean
219 220 221 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 219 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 225 def hash [, , app_name, app_release, manufacturer, device_model, device_label, device_id, debug_enabled, rooted, device_lock_level, msisdn].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 |
# File 'lib/trinsic_api/models/itsme_direct_device.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |