Class: TrinsicApi::ItsmeProviderOutput

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/itsme_provider_output.rb

Overview

Exposed properties for the ‘a-itsme-login` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ItsmeProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ItsmeProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ItsmeProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  else
    self.first_name = nil
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  else
    self.last_name = nil
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  else
    self.date_of_birth = nil
  end

  if attributes.key?(:'hashed_national_register_number')
    self.hashed_national_register_number = attributes[:'hashed_national_register_number']
  end

  if attributes.key?(:'national_register_number')
    self.national_register_number = attributes[:'national_register_number']
  end
end

Instance Attribute Details

#date_of_birthObject

The date of birth of the verified individual



26
27
28
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 26

def date_of_birth
  @date_of_birth
end

#first_nameObject

The first name of the verified individual



20
21
22
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 20

def first_name
  @first_name
end

#hashed_national_register_numberObject

The hashed version of the Belgian National Register Number of the verified individual. By default, itsme does not return the raw National Register Number of the individual; instead, only a hashed version is returned. Your account must be approved by itsme to receive the raw, unhashed National Register Number.



29
30
31
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 29

def hashed_national_register_number
  @hashed_national_register_number
end

#last_nameObject

The last name of the verified individual



23
24
25
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 23

def last_name
  @last_name
end

#national_register_numberObject

The raw (not hashed) Belgian National Register Number ("Rijksregisternummer") of the verified individual. Only returned if your account has been explicitly authorized to receive it by itsme; by law, this data is considered sensitive personal data. This is an 11-digit number in the format YYMMDDXXXCC, where: - YYMMDD represents the individual’s date of birth (year, month, day). - XXX is a sequential birth number, odd for females and even for males. - CC is a checksum, calculated with the equation: 97 - (YYMMDDXXX mod 97) For births in the year 2000 or later, the digit ‘2’ is prepended to the first 9 digits during checksum calculation.



32
33
34
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 32

def national_register_number
  @national_register_number
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



46
47
48
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 46

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



51
52
53
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 51

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 35

def self.attribute_map
  {
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'date_of_birth' => :'dateOfBirth',
    :'hashed_national_register_number' => :'hashedNationalRegisterNumber',
    :'national_register_number' => :'nationalRegisterNumber'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 204

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
71
72
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 67

def self.openapi_nullable
  Set.new([
    :'hashed_national_register_number',
    :'national_register_number'
  ])
end

.openapi_typesObject

Attribute type mapping.



56
57
58
59
60
61
62
63
64
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 56

def self.openapi_types
  {
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'date_of_birth' => :'Date',
    :'hashed_national_register_number' => :'String',
    :'national_register_number' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
187
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      date_of_birth == o.date_of_birth &&
      hashed_national_register_number == o.hashed_national_register_number &&
      national_register_number == o.national_register_number
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 197

def hash
  [first_name, last_name, date_of_birth, hashed_national_register_number, national_register_number].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @first_name.nil?
    invalid_properties.push('invalid value for "first_name", first_name cannot be nil.')
  end

  if @last_name.nil?
    invalid_properties.push('invalid value for "last_name", last_name cannot be nil.')
  end

  if @date_of_birth.nil?
    invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
144
145
# File 'lib/trinsic_api/models/itsme_provider_output.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @first_name.nil?
  return false if @last_name.nil?
  return false if @date_of_birth.nil?
  true
end