Class: TrinsicApi::KoreaTelcoMatchInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::KoreaTelcoMatchInput
- Defined in:
- lib/trinsic_api/models/korea_telco_match_input.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#carrier ⇒ Object
Mobile carrier.
-
#date_of_birth ⇒ Object
Date of birth.
-
#full_name ⇒ Object
Full legal name (UTF-8), e.g.
-
#operating_system ⇒ Object
Device operating system.
-
#phone_number ⇒ Object
Phone number without dashes, e.g.
-
#sex ⇒ Object
Sex.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ KoreaTelcoMatchInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ KoreaTelcoMatchInput
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::KoreaTelcoMatchInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::KoreaTelcoMatchInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] else self.phone_number = nil end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] else self.full_name = nil end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] else self.date_of_birth = nil end if attributes.key?(:'sex') self.sex = attributes[:'sex'] else self.sex = nil end if attributes.key?(:'carrier') self.carrier = attributes[:'carrier'] else self.carrier = nil end if attributes.key?(:'operating_system') self. = attributes[:'operating_system'] else self. = nil end end |
Instance Attribute Details
#carrier ⇒ Object
Mobile carrier. Lgu = LG U+, Skt = SK Telecom, Kt = KT.
31 32 33 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 31 def carrier @carrier end |
#date_of_birth ⇒ Object
Date of birth.
25 26 27 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 25 def date_of_birth @date_of_birth end |
#full_name ⇒ Object
Full legal name (UTF-8), e.g. "홍길동" or "Hong Gildong".
22 23 24 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 22 def full_name @full_name end |
#operating_system ⇒ Object
Device operating system.
34 35 36 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 34 def @operating_system end |
#phone_number ⇒ Object
Phone number without dashes, e.g. "010XXXXXXXX".
19 20 21 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 19 def phone_number @phone_number end |
#sex ⇒ Object
Sex. Must be Male or Female.
28 29 30 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 28 def sex @sex end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 59 def self.attribute_map { :'phone_number' => :'phoneNumber', :'full_name' => :'fullName', :'date_of_birth' => :'dateOfBirth', :'sex' => :'sex', :'carrier' => :'carrier', :'operating_system' => :'operatingSystem' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 302 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 81 def self.openapi_types { :'phone_number' => :'String', :'full_name' => :'String', :'date_of_birth' => :'Date', :'sex' => :'KoreaTelcoMatchSex', :'carrier' => :'MobileCarrier', :'operating_system' => :'MobileOperatingSystem' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 276 def ==(o) return true if self.equal?(o) self.class == o.class && phone_number == o.phone_number && full_name == o.full_name && date_of_birth == o.date_of_birth && sex == o.sex && carrier == o.carrier && == o. end |
#eql?(o) ⇒ Boolean
289 290 291 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 289 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
295 296 297 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 295 def hash [phone_number, full_name, date_of_birth, sex, carrier, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 153 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @phone_number.nil? invalid_properties.push('invalid value for "phone_number", phone_number cannot be nil.') end if @phone_number.to_s.length < 1 invalid_properties.push('invalid value for "phone_number", the character length must be greater than or equal to 1.') end if @full_name.nil? invalid_properties.push('invalid value for "full_name", full_name cannot be nil.') end if @full_name.to_s.length < 1 invalid_properties.push('invalid value for "full_name", the character length must be greater than or equal to 1.') end if @date_of_birth.nil? invalid_properties.push('invalid value for "date_of_birth", date_of_birth cannot be nil.') end if @sex.nil? invalid_properties.push('invalid value for "sex", sex cannot be nil.') end if @carrier.nil? invalid_properties.push('invalid value for "carrier", carrier cannot be nil.') end if @operating_system.nil? invalid_properties.push('invalid value for "operating_system", operating_system cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 324 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/trinsic_api/models/korea_telco_match_input.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @phone_number.nil? return false if @phone_number.to_s.length < 1 return false if @full_name.nil? return false if @full_name.to_s.length < 1 return false if @date_of_birth.nil? return false if @sex.nil? return false if @carrier.nil? return false if @operating_system.nil? true end |