Class: TrinsicApi::MdlOutput
- Inherits:
-
Object
- Object
- TrinsicApi::MdlOutput
- Defined in:
- lib/trinsic_api/models/mdl_output.rb
Instance Attribute Summary collapse
-
#document_signer_certificate ⇒ Object
Information about the Document Signer Certificate which signed the mDL presented by the user.
-
#document_type ⇒ Object
The document type of the mDL presented by the user.
-
#iaca_root_certificate ⇒ Object
Information about the IACA Root Certificate which signed (directly or indirectly) the Document Signer Certificate for this mDL.
-
#name_spaces ⇒ Object
The namespaces, and fields within those namespaces, which were present in the processed mDL.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MdlOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MdlOutput
Initializes the object
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 68 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::MdlOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::MdlOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'iaca_root_certificate') self.iaca_root_certificate = attributes[:'iaca_root_certificate'] else self.iaca_root_certificate = nil end if attributes.key?(:'document_signer_certificate') self.document_signer_certificate = attributes[:'document_signer_certificate'] else self.document_signer_certificate = nil end if attributes.key?(:'document_type') self.document_type = attributes[:'document_type'] else self.document_type = nil end if attributes.key?(:'name_spaces') if (value = attributes[:'name_spaces']).is_a?(Hash) self.name_spaces = value end else self.name_spaces = nil end end |
Instance Attribute Details
#document_signer_certificate ⇒ Object
Information about the Document Signer Certificate which signed the mDL presented by the user.
22 23 24 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 22 def document_signer_certificate @document_signer_certificate end |
#document_type ⇒ Object
The document type of the mDL presented by the user. Common values: - "org.iso.18013.5.1.mDL" for ISO 18013-5 mDLs - "com.google.wallet.idcard.1" for Google Wallet ID Cards
25 26 27 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 25 def document_type @document_type end |
#iaca_root_certificate ⇒ Object
Information about the IACA Root Certificate which signed (directly or indirectly) the Document Signer Certificate for this mDL.
19 20 21 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 19 def iaca_root_certificate @iaca_root_certificate end |
#name_spaces ⇒ Object
The namespaces, and fields within those namespaces, which were present in the processed mDL.
28 29 30 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 28 def name_spaces @name_spaces end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 234 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 31 def self.attribute_map { :'iaca_root_certificate' => :'iacaRootCertificate', :'document_signer_certificate' => :'documentSignerCertificate', :'document_type' => :'documentType', :'name_spaces' => :'nameSpaces' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 210 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
61 62 63 64 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 61 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 51 def self.openapi_types { :'iaca_root_certificate' => :'MdlOutputCertificateData', :'document_signer_certificate' => :'MdlOutputCertificateData', :'document_type' => :'String', :'name_spaces' => :'Hash<String, Hash<String, MdlOutputFieldData>>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && iaca_root_certificate == o.iaca_root_certificate && document_signer_certificate == o.document_signer_certificate && document_type == o.document_type && name_spaces == o.name_spaces end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 305 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
197 198 199 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 197 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
203 204 205 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 203 def hash [iaca_root_certificate, document_signer_certificate, document_type, name_spaces].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 111 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @iaca_root_certificate.nil? invalid_properties.push('invalid value for "iaca_root_certificate", iaca_root_certificate cannot be nil.') end if @document_signer_certificate.nil? invalid_properties.push('invalid value for "document_signer_certificate", document_signer_certificate cannot be nil.') end if @document_type.nil? invalid_properties.push('invalid value for "document_type", document_type cannot be nil.') end if @name_spaces.nil? invalid_properties.push('invalid value for "name_spaces", name_spaces cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
281 282 283 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 281 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
287 288 289 290 291 292 293 294 295 296 297 298 299 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 287 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
275 276 277 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 275 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
135 136 137 138 139 140 141 142 |
# File 'lib/trinsic_api/models/mdl_output.rb', line 135 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @iaca_root_certificate.nil? return false if @document_signer_certificate.nil? return false if @document_type.nil? return false if @name_spaces.nil? true end |