Class: TrinsicApi::NetherlandsIdinAddress

Inherits:
ApiModelBase show all
Defined in:
lib/trinsic_api/models/netherlands_idin_address.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NetherlandsIdinAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::NetherlandsIdinAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::NetherlandsIdinAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'street')
    self.street = attributes[:'street']
  else
    self.street = nil
  end

  if attributes.key?(:'house_number')
    self.house_number = attributes[:'house_number']
  else
    self.house_number = nil
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  else
    self.postal_code = nil
  end

  if attributes.key?(:'city')
    self.city = attributes[:'city']
  else
    self.city = nil
  end

  if attributes.key?(:'country_code')
    self.country_code = attributes[:'country_code']
  else
    self.country_code = nil
  end
end

Instance Attribute Details

#cityObject

City of the individual’s address.



28
29
30
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 28

def city
  @city
end

#country_codeObject

Country code of the individual’s address in ISO 3166-1 alpha-2 format.



31
32
33
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 31

def country_code
  @country_code
end

#house_numberObject

House number of the individual’s address.



22
23
24
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 22

def house_number
  @house_number
end

#postal_codeObject

Postal code of the individual’s address. A postal code in The Netherlands is a 4-digit number and two letters.



25
26
27
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 25

def postal_code
  @postal_code
end

#streetObject

Street name of the individual’s address.



19
20
21
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 19

def street
  @street
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 34

def self.attribute_map
  {
    :'street' => :'street',
    :'house_number' => :'houseNumber',
    :'postal_code' => :'postalCode',
    :'city' => :'city',
    :'country_code' => :'countryCode'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 235

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 55

def self.openapi_types
  {
    :'street' => :'String',
    :'house_number' => :'String',
    :'postal_code' => :'String',
    :'city' => :'String',
    :'country_code' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



210
211
212
213
214
215
216
217
218
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 210

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      street == o.street &&
      house_number == o.house_number &&
      postal_code == o.postal_code &&
      city == o.city &&
      country_code == o.country_code
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


222
223
224
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 222

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



228
229
230
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 228

def hash
  [street, house_number, postal_code, city, country_code].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @street.nil?
    invalid_properties.push('invalid value for "street", street cannot be nil.')
  end

  if @house_number.nil?
    invalid_properties.push('invalid value for "house_number", house_number cannot be nil.')
  end

  if @postal_code.nil?
    invalid_properties.push('invalid value for "postal_code", postal_code cannot be nil.')
  end

  if @city.nil?
    invalid_properties.push('invalid value for "city", city cannot be nil.')
  end

  if @country_code.nil?
    invalid_properties.push('invalid value for "country_code", country_code cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 257

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
153
154
155
156
# File 'lib/trinsic_api/models/netherlands_idin_address.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @street.nil?
  return false if @house_number.nil?
  return false if @postal_code.nil?
  return false if @city.nil?
  return false if @country_code.nil?
  true
end