Class: TrinsicApi::PersonData
- Inherits:
-
Object
- Object
- TrinsicApi::PersonData
- Defined in:
- lib/trinsic_api/models/person_data.rb
Overview
Identity information for the individual being verified
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#address ⇒ Object
Address information for an individual.
-
#date_of_birth ⇒ Object
Returns the value of attribute date_of_birth.
-
#family_name ⇒ Object
Family (last) name of the individual.
-
#full_name ⇒ Object
The individual’s full name as a single string.
-
#given_name ⇒ Object
Given (first) name of the individual.
-
#middle_name ⇒ Object
Middle name of the individual.
-
#nationality ⇒ Object
Returns the value of attribute nationality.
-
#phone_number ⇒ Object
Returns the value of attribute phone_number.
-
#sex ⇒ Object
Returns the value of attribute sex.
-
#suffix ⇒ Object
Suffix of the individual’s name.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PersonData
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ PersonData
Initializes the object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/trinsic_api/models/person_data.rb', line 127 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PersonData` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PersonData`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'given_name') self.given_name = attributes[:'given_name'] end if attributes.key?(:'family_name') self.family_name = attributes[:'family_name'] end if attributes.key?(:'middle_name') self.middle_name = attributes[:'middle_name'] end if attributes.key?(:'full_name') self.full_name = attributes[:'full_name'] end if attributes.key?(:'suffix') self.suffix = attributes[:'suffix'] end if attributes.key?(:'nationality') self.nationality = attributes[:'nationality'] end if attributes.key?(:'sex') self.sex = attributes[:'sex'] end if attributes.key?(:'phone_number') self.phone_number = attributes[:'phone_number'] end if attributes.key?(:'address') self.address = attributes[:'address'] end if attributes.key?(:'date_of_birth') self.date_of_birth = attributes[:'date_of_birth'] end end |
Instance Attribute Details
#address ⇒ Object
Address information for an individual
41 42 43 |
# File 'lib/trinsic_api/models/person_data.rb', line 41 def address @address end |
#date_of_birth ⇒ Object
Returns the value of attribute date_of_birth.
43 44 45 |
# File 'lib/trinsic_api/models/person_data.rb', line 43 def date_of_birth @date_of_birth end |
#family_name ⇒ Object
Family (last) name of the individual
23 24 25 |
# File 'lib/trinsic_api/models/person_data.rb', line 23 def family_name @family_name end |
#full_name ⇒ Object
The individual’s full name as a single string. Useful for names which do not fit into a "first middle last" structure.
29 30 31 |
# File 'lib/trinsic_api/models/person_data.rb', line 29 def full_name @full_name end |
#given_name ⇒ Object
Given (first) name of the individual
20 21 22 |
# File 'lib/trinsic_api/models/person_data.rb', line 20 def given_name @given_name end |
#middle_name ⇒ Object
Middle name of the individual
26 27 28 |
# File 'lib/trinsic_api/models/person_data.rb', line 26 def middle_name @middle_name end |
#nationality ⇒ Object
Returns the value of attribute nationality.
34 35 36 |
# File 'lib/trinsic_api/models/person_data.rb', line 34 def nationality @nationality end |
#phone_number ⇒ Object
Returns the value of attribute phone_number.
38 39 40 |
# File 'lib/trinsic_api/models/person_data.rb', line 38 def phone_number @phone_number end |
#sex ⇒ Object
Returns the value of attribute sex.
36 37 38 |
# File 'lib/trinsic_api/models/person_data.rb', line 36 def sex @sex end |
#suffix ⇒ Object
Suffix of the individual’s name
32 33 34 |
# File 'lib/trinsic_api/models/person_data.rb', line 32 def suffix @suffix end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 |
# File 'lib/trinsic_api/models/person_data.rb', line 253 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
84 85 86 |
# File 'lib/trinsic_api/models/person_data.rb', line 84 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/trinsic_api/models/person_data.rb', line 89 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/trinsic_api/models/person_data.rb', line 68 def self.attribute_map { :'given_name' => :'givenName', :'family_name' => :'familyName', :'middle_name' => :'middleName', :'full_name' => :'fullName', :'suffix' => :'suffix', :'nationality' => :'nationality', :'sex' => :'sex', :'phone_number' => :'phoneNumber', :'address' => :'address', :'date_of_birth' => :'dateOfBirth' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/trinsic_api/models/person_data.rb', line 229 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/trinsic_api/models/person_data.rb', line 110 def self.openapi_nullable Set.new([ :'given_name', :'family_name', :'middle_name', :'full_name', :'suffix', :'nationality', :'sex', :'phone_number', :'address', :'date_of_birth' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/trinsic_api/models/person_data.rb', line 94 def self.openapi_types { :'given_name' => :'String', :'family_name' => :'String', :'middle_name' => :'String', :'full_name' => :'String', :'suffix' => :'String', :'nationality' => :'String', :'sex' => :'Sex', :'phone_number' => :'String', :'address' => :'Address', :'date_of_birth' => :'Date' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/trinsic_api/models/person_data.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && given_name == o.given_name && family_name == o.family_name && middle_name == o.middle_name && full_name == o.full_name && suffix == o.suffix && nationality == o.nationality && sex == o.sex && phone_number == o.phone_number && address == o.address && date_of_birth == o.date_of_birth end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/trinsic_api/models/person_data.rb', line 324 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/trinsic_api/models/person_data.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/trinsic_api/models/person_data.rb', line 222 def hash [given_name, family_name, middle_name, full_name, suffix, nationality, sex, phone_number, address, date_of_birth].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 |
# File 'lib/trinsic_api/models/person_data.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
300 301 302 |
# File 'lib/trinsic_api/models/person_data.rb', line 300 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/trinsic_api/models/person_data.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
294 295 296 |
# File 'lib/trinsic_api/models/person_data.rb', line 294 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 |
# File 'lib/trinsic_api/models/person_data.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |