Class: TrinsicApi::PhilippinesDigitalNidProviderOutput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/trinsic_api/models/philippines_digital_nid_provider_output.rb

Overview

Exposed properties for the ‘philippines-digital-national-id-qr` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PhilippinesDigitalNidProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::PhilippinesDigitalNidProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::PhilippinesDigitalNidProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'philsys_card_number')
    self.philsys_card_number = attributes[:'philsys_card_number']
  else
    self.philsys_card_number = nil
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'middle_name')
    self.middle_name = attributes[:'middle_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'suffix')
    self.suffix = attributes[:'suffix']
  end

  if attributes.key?(:'sex')
    self.sex = attributes[:'sex']
  end

  if attributes.key?(:'place_of_birth')
    self.place_of_birth = attributes[:'place_of_birth']
  end

  if attributes.key?(:'document_issue_date')
    self.document_issue_date = attributes[:'document_issue_date']
  end

  if attributes.key?(:'document_number')
    self.document_number = attributes[:'document_number']
  end

  if attributes.key?(:'issuing_authority')
    self.issuing_authority = attributes[:'issuing_authority']
  end
end

Instance Attribute Details

#date_of_birthObject

The date of birth of the individual.



32
33
34
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 32

def date_of_birth
  @date_of_birth
end

#document_issue_dateObject

The date the document was issued.



44
45
46
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 44

def document_issue_date
  @document_issue_date
end

#document_numberObject

The document number of the digital National ID.



47
48
49
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 47

def document_number
  @document_number
end

#family_nameObject

The family (last) name of the individual.



29
30
31
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 29

def family_name
  @family_name
end

#given_nameObject

The given (first) name of the individual.



23
24
25
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 23

def given_name
  @given_name
end

#issuing_authorityObject

The issuing authority of the document.



50
51
52
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 50

def issuing_authority
  @issuing_authority
end

#middle_nameObject

The middle name of the individual.



26
27
28
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 26

def middle_name
  @middle_name
end

#philsys_card_numberObject

The PhilSys Card Number (PCN). Every citizen or resident alien registered in PhilSys has a PhilSys Number (PSN). This number is tokenized into a card number to protect the PSN. The PhilSys Card Number is 12 characters long, and often is written in octets with dashes in between.



20
21
22
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 20

def philsys_card_number
  @philsys_card_number
end

#place_of_birthObject

The place of birth of the individual as recorded on the PhilSys credential.



41
42
43
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 41

def place_of_birth
  @place_of_birth
end

#sexObject

The sex of the individual. Possible values: - Male - Female



38
39
40
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 38

def sex
  @sex
end

#suffixObject

The name suffix of the individual (e.g. Jr., III).



35
36
37
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 35

def suffix
  @suffix
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 53

def self.attribute_map
  {
    :'philsys_card_number' => :'philsysCardNumber',
    :'given_name' => :'givenName',
    :'middle_name' => :'middleName',
    :'family_name' => :'familyName',
    :'date_of_birth' => :'dateOfBirth',
    :'suffix' => :'suffix',
    :'sex' => :'sex',
    :'place_of_birth' => :'placeOfBirth',
    :'document_issue_date' => :'documentIssueDate',
    :'document_number' => :'documentNumber',
    :'issuing_authority' => :'issuingAuthority'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 97

def self.openapi_nullable
  Set.new([
    :'given_name',
    :'middle_name',
    :'family_name',
    :'date_of_birth',
    :'suffix',
    :'sex',
    :'place_of_birth',
    :'document_issue_date',
    :'document_number',
    :'issuing_authority'
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 80

def self.openapi_types
  {
    :'philsys_card_number' => :'String',
    :'given_name' => :'String',
    :'middle_name' => :'String',
    :'family_name' => :'String',
    :'date_of_birth' => :'Date',
    :'suffix' => :'String',
    :'sex' => :'String',
    :'place_of_birth' => :'String',
    :'document_issue_date' => :'Date',
    :'document_number' => :'String',
    :'issuing_authority' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 207

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      philsys_card_number == o.philsys_card_number &&
      given_name == o.given_name &&
      middle_name == o.middle_name &&
      family_name == o.family_name &&
      date_of_birth == o.date_of_birth &&
      suffix == o.suffix &&
      sex == o.sex &&
      place_of_birth == o.place_of_birth &&
      document_issue_date == o.document_issue_date &&
      document_number == o.document_number &&
      issuing_authority == o.issuing_authority
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 231

def hash
  [philsys_card_number, given_name, middle_name, family_name, date_of_birth, suffix, sex, place_of_birth, document_issue_date, document_number, issuing_authority].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



177
178
179
180
181
182
183
184
185
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 177

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @philsys_card_number.nil?
    invalid_properties.push('invalid value for "philsys_card_number", philsys_card_number cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
# File 'lib/trinsic_api/models/philippines_digital_nid_provider_output.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @philsys_card_number.nil?
  true
end