Class: TrinsicApi::ProviderInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ProviderInput
- Defined in:
- lib/trinsic_api/models/provider_input.rb
Instance Attribute Summary collapse
-
#apple_wallet ⇒ Object
Input for the
apple-walletprovider. -
#austria_valera_eudi_sandbox ⇒ Object
Returns the value of attribute austria_valera_eudi_sandbox.
-
#bolivia_ci_lookup ⇒ Object
Input for the
bolivia-ci-lookupprovider. -
#brazil_cpf_lookup ⇒ Object
Input for the
brazil-cpf-lookupprovider. -
#brazil_digital_cnh ⇒ Object
Input for the
brazil-digital-cnhprovider. -
#china_resident_id_match ⇒ Object
Input for the
china-resident-id-matchprovider. -
#colombia_cc_lookup ⇒ Object
Input for the
colombia-cc-lookupprovider. -
#cote_divoire_nid_lookup_2 ⇒ Object
Input for the
cote-divoire-nid-lookup-2provider. -
#denmark_altid ⇒ Object
Returns the value of attribute denmark_altid.
-
#el_salvador_dui_lookup ⇒ Object
Input for the
el-salvador-dui-lookupprovider. -
#evrotrust ⇒ Object
Input for the
evrotrustprovider. -
#france_identite ⇒ Object
Input for the
france-identiteprovider. -
#germany_eudi_sandbox ⇒ Object
Returns the value of attribute germany_eudi_sandbox.
-
#google_wallet ⇒ Object
Input for the
google-walletprovider. -
#guatemala_cui_lookup ⇒ Object
Input for the
guatemala-cui-lookupprovider. -
#india_digilocker_aadhaar_match ⇒ Object
Input for the
india-digilocker-aadhaar-matchprovider. -
#india_pan_lookup ⇒ Object
Input for the
india-pan-lookupprovider. -
#indonesia_dukcapil_match ⇒ Object
Input for the
indonesia-dukcapil-matchprovider. -
#indonesia_nik_lookup ⇒ Object
Input for the
indonesia-nik-lookupprovider. -
#italy_spid ⇒ Object
Input for the
italy-spidprovider. -
#kenya_nid_lookup ⇒ Object
Input for the
kenya-nid-lookupprovider. -
#kenya_nid_lookup_2 ⇒ Object
Input for the
kenya-nid-lookup-2provider. -
#kenya_nid_lookup_3 ⇒ Object
Input for the
kenya-nid-lookup-3provider. -
#kenya_nid_match_2 ⇒ Object
Input for the
kenya-nid-match-2provider. -
#korea_telco_match ⇒ Object
Input for the
korea-telco-matchprovider. -
#mexico_curp_lookup ⇒ Object
Input for the
mexico-curp-lookupprovider. -
#mobile_id ⇒ Object
Input for the
mobile-idprovider. -
#moldova_evo_wallet ⇒ Object
Input for the
moldova-evo-walletprovider. -
#netherlands_eudi_sandbox ⇒ Object
Input for the
netherlands-eudi-sandboxprovider. -
#netherlands_idin ⇒ Object
Input for the
netherlands-idinprovider. -
#nigeria_nin_lookup ⇒ Object
Input for the
nigeria-nin-lookupprovider. -
#nigeria_nin_lookup_2 ⇒ Object
Input for the
nigeria-nin-lookup-2provider. -
#nigeria_nin_lookup_3 ⇒ Object
Input for the
nigeria-nin-lookup-3provider. -
#nigeria_nin_match_2 ⇒ Object
Input for the
nigeria-nin-match-2provider. -
#panama_cedula_lookup ⇒ Object
Input for the
panama-cedula-lookupprovider. -
#peru_dni_lookup ⇒ Object
Input for the
peru-dni-lookupprovider. -
#philippines_digital_national_id_qr ⇒ Object
Input for the
philippines-digital-national-id-qrprovider. -
#philippines_philsys_match ⇒ Object
Input for the
philippines-philsys-matchprovider. -
#philippines_physical_national_id_qr ⇒ Object
Input for the
philippines-physical-national-id-qrprovider. -
#poland_mobywatel_match ⇒ Object
Input for the
poland-mobywatel-matchprovider. -
#samsung_wallet ⇒ Object
Input for the
samsung-walletprovider. -
#smart_id ⇒ Object
Input for the
smart-idprovider. -
#south_africa_nid_lookup ⇒ Object
Input for the
south-africa-nid-lookupprovider. -
#south_africa_nid_lookup_2 ⇒ Object
Input for the
south-africa-nid-lookup-2provider. -
#south_africa_nid_match_2 ⇒ Object
Input for the
south-africa-nid-match-2provider. -
#trinsic_mock_output ⇒ Object
TEST MODE ONLY. Input for the
trinsic-mock-outputprovider. -
#trinsic_test_database_lookup ⇒ Object
TEST MODE ONLY. Input for the
trinsic-test-database-lookupprovider. -
#trinsic_test_sub_providers ⇒ Object
TEST MODE ONLY. Input for the
trinsic-test-sub-providersprovider. -
#uganda_nid_match_2 ⇒ Object
Input for the
uganda-nid-match-2provider. -
#uk_evisa_lookup ⇒ Object
Input for the
uk-evisa-lookupprovider. -
#usa_california_dmv ⇒ Object
Input for the
usa-california-dmvprovider. -
#zimbabwe_nid_lookup_2 ⇒ Object
Input for the
zimbabwe-nid-lookup-2provider.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProviderInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProviderInput
Initializes the object
357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 |
# File 'lib/trinsic_api/models/provider_input.rb', line 357 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ProviderInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ProviderInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'trinsic_mock_output') self.trinsic_mock_output = attributes[:'trinsic_mock_output'] end if attributes.key?(:'indonesia_nik_lookup') self.indonesia_nik_lookup = attributes[:'indonesia_nik_lookup'] end if attributes.key?(:'china_resident_id_match') self.china_resident_id_match = attributes[:'china_resident_id_match'] end if attributes.key?(:'evrotrust') self.evrotrust = attributes[:'evrotrust'] end if attributes.key?(:'indonesia_dukcapil_match') self.indonesia_dukcapil_match = attributes[:'indonesia_dukcapil_match'] end if attributes.key?(:'mexico_curp_lookup') self.mexico_curp_lookup = attributes[:'mexico_curp_lookup'] end if attributes.key?(:'south_africa_nid_lookup') self.south_africa_nid_lookup = attributes[:'south_africa_nid_lookup'] end if attributes.key?(:'kenya_nid_lookup') self.kenya_nid_lookup = attributes[:'kenya_nid_lookup'] end if attributes.key?(:'kenya_nid_match_2') self.kenya_nid_match_2 = attributes[:'kenya_nid_match_2'] end if attributes.key?(:'kenya_nid_lookup_2') self.kenya_nid_lookup_2 = attributes[:'kenya_nid_lookup_2'] end if attributes.key?(:'south_africa_nid_lookup_2') self.south_africa_nid_lookup_2 = attributes[:'south_africa_nid_lookup_2'] end if attributes.key?(:'south_africa_nid_match_2') self.south_africa_nid_match_2 = attributes[:'south_africa_nid_match_2'] end if attributes.key?(:'nigeria_nin_lookup_2') self.nigeria_nin_lookup_2 = attributes[:'nigeria_nin_lookup_2'] end if attributes.key?(:'nigeria_nin_lookup_3') self.nigeria_nin_lookup_3 = attributes[:'nigeria_nin_lookup_3'] end if attributes.key?(:'kenya_nid_lookup_3') self.kenya_nid_lookup_3 = attributes[:'kenya_nid_lookup_3'] end if attributes.key?(:'cote_divoire_nid_lookup_2') self.cote_divoire_nid_lookup_2 = attributes[:'cote_divoire_nid_lookup_2'] end if attributes.key?(:'zimbabwe_nid_lookup_2') self.zimbabwe_nid_lookup_2 = attributes[:'zimbabwe_nid_lookup_2'] end if attributes.key?(:'nigeria_nin_match_2') self.nigeria_nin_match_2 = attributes[:'nigeria_nin_match_2'] end if attributes.key?(:'uganda_nid_match_2') self.uganda_nid_match_2 = attributes[:'uganda_nid_match_2'] end if attributes.key?(:'nigeria_nin_lookup') self.nigeria_nin_lookup = attributes[:'nigeria_nin_lookup'] end if attributes.key?(:'india_digilocker_aadhaar_match') self.india_digilocker_aadhaar_match = attributes[:'india_digilocker_aadhaar_match'] end if attributes.key?(:'india_pan_lookup') self.india_pan_lookup = attributes[:'india_pan_lookup'] end if attributes.key?(:'korea_telco_match') self.korea_telco_match = attributes[:'korea_telco_match'] end if attributes.key?(:'brazil_cpf_lookup') self.brazil_cpf_lookup = attributes[:'brazil_cpf_lookup'] end if attributes.key?(:'brazil_digital_cnh') self.brazil_digital_cnh = attributes[:'brazil_digital_cnh'] end if attributes.key?(:'philippines_philsys_match') self.philippines_philsys_match = attributes[:'philippines_philsys_match'] end if attributes.key?(:'philippines_physical_national_id_qr') self.philippines_physical_national_id_qr = attributes[:'philippines_physical_national_id_qr'] end if attributes.key?(:'philippines_digital_national_id_qr') self.philippines_digital_national_id_qr = attributes[:'philippines_digital_national_id_qr'] end if attributes.key?(:'smart_id') self.smart_id = attributes[:'smart_id'] end if attributes.key?(:'mobile_id') self.mobile_id = attributes[:'mobile_id'] end if attributes.key?(:'netherlands_idin') self.netherlands_idin = attributes[:'netherlands_idin'] end if attributes.key?(:'italy_spid') self.italy_spid = attributes[:'italy_spid'] end if attributes.key?(:'google_wallet') self.google_wallet = attributes[:'google_wallet'] end if attributes.key?(:'apple_wallet') self.apple_wallet = attributes[:'apple_wallet'] end if attributes.key?(:'samsung_wallet') self.samsung_wallet = attributes[:'samsung_wallet'] end if attributes.key?(:'france_identite') self.france_identite = attributes[:'france_identite'] end if attributes.key?(:'moldova_evo_wallet') self.moldova_evo_wallet = attributes[:'moldova_evo_wallet'] end if attributes.key?(:'germany_eudi_sandbox') self.germany_eudi_sandbox = attributes[:'germany_eudi_sandbox'] end if attributes.key?(:'denmark_altid') self.denmark_altid = attributes[:'denmark_altid'] end if attributes.key?(:'austria_valera_eudi_sandbox') self.austria_valera_eudi_sandbox = attributes[:'austria_valera_eudi_sandbox'] end if attributes.key?(:'netherlands_eudi_sandbox') self.netherlands_eudi_sandbox = attributes[:'netherlands_eudi_sandbox'] end if attributes.key?(:'poland_mobywatel_match') self.poland_mobywatel_match = attributes[:'poland_mobywatel_match'] end if attributes.key?(:'bolivia_ci_lookup') self.bolivia_ci_lookup = attributes[:'bolivia_ci_lookup'] end if attributes.key?(:'colombia_cc_lookup') self.colombia_cc_lookup = attributes[:'colombia_cc_lookup'] end if attributes.key?(:'el_salvador_dui_lookup') self.el_salvador_dui_lookup = attributes[:'el_salvador_dui_lookup'] end if attributes.key?(:'guatemala_cui_lookup') self.guatemala_cui_lookup = attributes[:'guatemala_cui_lookup'] end if attributes.key?(:'panama_cedula_lookup') self.panama_cedula_lookup = attributes[:'panama_cedula_lookup'] end if attributes.key?(:'peru_dni_lookup') self.peru_dni_lookup = attributes[:'peru_dni_lookup'] end if attributes.key?(:'uk_evisa_lookup') self.uk_evisa_lookup = attributes[:'uk_evisa_lookup'] end if attributes.key?(:'usa_california_dmv') self.usa_california_dmv = attributes[:'usa_california_dmv'] end if attributes.key?(:'trinsic_test_database_lookup') self.trinsic_test_database_lookup = attributes[:'trinsic_test_database_lookup'] end if attributes.key?(:'trinsic_test_sub_providers') self.trinsic_test_sub_providers = attributes[:'trinsic_test_sub_providers'] end end |
Instance Attribute Details
#apple_wallet ⇒ Object
Input for the apple-wallet provider
118 119 120 |
# File 'lib/trinsic_api/models/provider_input.rb', line 118 def apple_wallet @apple_wallet end |
#austria_valera_eudi_sandbox ⇒ Object
Returns the value of attribute austria_valera_eudi_sandbox.
133 134 135 |
# File 'lib/trinsic_api/models/provider_input.rb', line 133 def austria_valera_eudi_sandbox @austria_valera_eudi_sandbox end |
#bolivia_ci_lookup ⇒ Object
Input for the bolivia-ci-lookup provider
142 143 144 |
# File 'lib/trinsic_api/models/provider_input.rb', line 142 def bolivia_ci_lookup @bolivia_ci_lookup end |
#brazil_cpf_lookup ⇒ Object
Input for the brazil-cpf-lookup provider
88 89 90 |
# File 'lib/trinsic_api/models/provider_input.rb', line 88 def brazil_cpf_lookup @brazil_cpf_lookup end |
#brazil_digital_cnh ⇒ Object
Input for the brazil-digital-cnh provider
91 92 93 |
# File 'lib/trinsic_api/models/provider_input.rb', line 91 def brazil_digital_cnh @brazil_digital_cnh end |
#china_resident_id_match ⇒ Object
Input for the china-resident-id-match provider
25 26 27 |
# File 'lib/trinsic_api/models/provider_input.rb', line 25 def china_resident_id_match @china_resident_id_match end |
#colombia_cc_lookup ⇒ Object
Input for the colombia-cc-lookup provider
145 146 147 |
# File 'lib/trinsic_api/models/provider_input.rb', line 145 def colombia_cc_lookup @colombia_cc_lookup end |
#cote_divoire_nid_lookup_2 ⇒ Object
Input for the cote-divoire-nid-lookup-2 provider
64 65 66 |
# File 'lib/trinsic_api/models/provider_input.rb', line 64 def cote_divoire_nid_lookup_2 @cote_divoire_nid_lookup_2 end |
#denmark_altid ⇒ Object
Returns the value of attribute denmark_altid.
131 132 133 |
# File 'lib/trinsic_api/models/provider_input.rb', line 131 def denmark_altid @denmark_altid end |
#el_salvador_dui_lookup ⇒ Object
Input for the el-salvador-dui-lookup provider
148 149 150 |
# File 'lib/trinsic_api/models/provider_input.rb', line 148 def el_salvador_dui_lookup @el_salvador_dui_lookup end |
#evrotrust ⇒ Object
Input for the evrotrust provider
28 29 30 |
# File 'lib/trinsic_api/models/provider_input.rb', line 28 def evrotrust @evrotrust end |
#france_identite ⇒ Object
Input for the france-identite provider
124 125 126 |
# File 'lib/trinsic_api/models/provider_input.rb', line 124 def france_identite @france_identite end |
#germany_eudi_sandbox ⇒ Object
Returns the value of attribute germany_eudi_sandbox.
129 130 131 |
# File 'lib/trinsic_api/models/provider_input.rb', line 129 def germany_eudi_sandbox @germany_eudi_sandbox end |
#google_wallet ⇒ Object
Input for the google-wallet provider
115 116 117 |
# File 'lib/trinsic_api/models/provider_input.rb', line 115 def google_wallet @google_wallet end |
#guatemala_cui_lookup ⇒ Object
Input for the guatemala-cui-lookup provider
151 152 153 |
# File 'lib/trinsic_api/models/provider_input.rb', line 151 def guatemala_cui_lookup @guatemala_cui_lookup end |
#india_digilocker_aadhaar_match ⇒ Object
Input for the india-digilocker-aadhaar-match provider
79 80 81 |
# File 'lib/trinsic_api/models/provider_input.rb', line 79 def india_digilocker_aadhaar_match @india_digilocker_aadhaar_match end |
#india_pan_lookup ⇒ Object
Input for the india-pan-lookup provider
82 83 84 |
# File 'lib/trinsic_api/models/provider_input.rb', line 82 def india_pan_lookup @india_pan_lookup end |
#indonesia_dukcapil_match ⇒ Object
Input for the indonesia-dukcapil-match provider
31 32 33 |
# File 'lib/trinsic_api/models/provider_input.rb', line 31 def indonesia_dukcapil_match @indonesia_dukcapil_match end |
#indonesia_nik_lookup ⇒ Object
Input for the indonesia-nik-lookup provider
22 23 24 |
# File 'lib/trinsic_api/models/provider_input.rb', line 22 def indonesia_nik_lookup @indonesia_nik_lookup end |
#italy_spid ⇒ Object
Input for the italy-spid provider
112 113 114 |
# File 'lib/trinsic_api/models/provider_input.rb', line 112 def italy_spid @italy_spid end |
#kenya_nid_lookup ⇒ Object
Input for the kenya-nid-lookup provider
40 41 42 |
# File 'lib/trinsic_api/models/provider_input.rb', line 40 def kenya_nid_lookup @kenya_nid_lookup end |
#kenya_nid_lookup_2 ⇒ Object
Input for the kenya-nid-lookup-2 provider
46 47 48 |
# File 'lib/trinsic_api/models/provider_input.rb', line 46 def kenya_nid_lookup_2 @kenya_nid_lookup_2 end |
#kenya_nid_lookup_3 ⇒ Object
Input for the kenya-nid-lookup-3 provider
61 62 63 |
# File 'lib/trinsic_api/models/provider_input.rb', line 61 def kenya_nid_lookup_3 @kenya_nid_lookup_3 end |
#kenya_nid_match_2 ⇒ Object
Input for the kenya-nid-match-2 provider
43 44 45 |
# File 'lib/trinsic_api/models/provider_input.rb', line 43 def kenya_nid_match_2 @kenya_nid_match_2 end |
#korea_telco_match ⇒ Object
Input for the korea-telco-match provider
85 86 87 |
# File 'lib/trinsic_api/models/provider_input.rb', line 85 def korea_telco_match @korea_telco_match end |
#mexico_curp_lookup ⇒ Object
Input for the mexico-curp-lookup provider
34 35 36 |
# File 'lib/trinsic_api/models/provider_input.rb', line 34 def mexico_curp_lookup @mexico_curp_lookup end |
#mobile_id ⇒ Object
Input for the mobile-id provider
106 107 108 |
# File 'lib/trinsic_api/models/provider_input.rb', line 106 def mobile_id @mobile_id end |
#moldova_evo_wallet ⇒ Object
Input for the moldova-evo-wallet provider
127 128 129 |
# File 'lib/trinsic_api/models/provider_input.rb', line 127 def moldova_evo_wallet @moldova_evo_wallet end |
#netherlands_eudi_sandbox ⇒ Object
Input for the netherlands-eudi-sandbox provider
136 137 138 |
# File 'lib/trinsic_api/models/provider_input.rb', line 136 def netherlands_eudi_sandbox @netherlands_eudi_sandbox end |
#netherlands_idin ⇒ Object
Input for the netherlands-idin provider
109 110 111 |
# File 'lib/trinsic_api/models/provider_input.rb', line 109 def netherlands_idin @netherlands_idin end |
#nigeria_nin_lookup ⇒ Object
Input for the nigeria-nin-lookup provider
76 77 78 |
# File 'lib/trinsic_api/models/provider_input.rb', line 76 def nigeria_nin_lookup @nigeria_nin_lookup end |
#nigeria_nin_lookup_2 ⇒ Object
Input for the nigeria-nin-lookup-2 provider
55 56 57 |
# File 'lib/trinsic_api/models/provider_input.rb', line 55 def nigeria_nin_lookup_2 @nigeria_nin_lookup_2 end |
#nigeria_nin_lookup_3 ⇒ Object
Input for the nigeria-nin-lookup-3 provider
58 59 60 |
# File 'lib/trinsic_api/models/provider_input.rb', line 58 def nigeria_nin_lookup_3 @nigeria_nin_lookup_3 end |
#nigeria_nin_match_2 ⇒ Object
Input for the nigeria-nin-match-2 provider
70 71 72 |
# File 'lib/trinsic_api/models/provider_input.rb', line 70 def nigeria_nin_match_2 @nigeria_nin_match_2 end |
#panama_cedula_lookup ⇒ Object
Input for the panama-cedula-lookup provider
154 155 156 |
# File 'lib/trinsic_api/models/provider_input.rb', line 154 def panama_cedula_lookup @panama_cedula_lookup end |
#peru_dni_lookup ⇒ Object
Input for the peru-dni-lookup provider
157 158 159 |
# File 'lib/trinsic_api/models/provider_input.rb', line 157 def peru_dni_lookup @peru_dni_lookup end |
#philippines_digital_national_id_qr ⇒ Object
Input for the philippines-digital-national-id-qr provider
100 101 102 |
# File 'lib/trinsic_api/models/provider_input.rb', line 100 def philippines_digital_national_id_qr @philippines_digital_national_id_qr end |
#philippines_philsys_match ⇒ Object
Input for the philippines-philsys-match provider
94 95 96 |
# File 'lib/trinsic_api/models/provider_input.rb', line 94 def philippines_philsys_match @philippines_philsys_match end |
#philippines_physical_national_id_qr ⇒ Object
Input for the philippines-physical-national-id-qr provider
97 98 99 |
# File 'lib/trinsic_api/models/provider_input.rb', line 97 def philippines_physical_national_id_qr @philippines_physical_national_id_qr end |
#poland_mobywatel_match ⇒ Object
Input for the poland-mobywatel-match provider
139 140 141 |
# File 'lib/trinsic_api/models/provider_input.rb', line 139 def poland_mobywatel_match @poland_mobywatel_match end |
#samsung_wallet ⇒ Object
Input for the samsung-wallet provider
121 122 123 |
# File 'lib/trinsic_api/models/provider_input.rb', line 121 def samsung_wallet @samsung_wallet end |
#smart_id ⇒ Object
Input for the smart-id provider
103 104 105 |
# File 'lib/trinsic_api/models/provider_input.rb', line 103 def smart_id @smart_id end |
#south_africa_nid_lookup ⇒ Object
Input for the south-africa-nid-lookup provider
37 38 39 |
# File 'lib/trinsic_api/models/provider_input.rb', line 37 def south_africa_nid_lookup @south_africa_nid_lookup end |
#south_africa_nid_lookup_2 ⇒ Object
Input for the south-africa-nid-lookup-2 provider
49 50 51 |
# File 'lib/trinsic_api/models/provider_input.rb', line 49 def south_africa_nid_lookup_2 @south_africa_nid_lookup_2 end |
#south_africa_nid_match_2 ⇒ Object
Input for the south-africa-nid-match-2 provider
52 53 54 |
# File 'lib/trinsic_api/models/provider_input.rb', line 52 def south_africa_nid_match_2 @south_africa_nid_match_2 end |
#trinsic_mock_output ⇒ Object
TEST MODE ONLY. Input for the trinsic-mock-output provider.
19 20 21 |
# File 'lib/trinsic_api/models/provider_input.rb', line 19 def trinsic_mock_output @trinsic_mock_output end |
#trinsic_test_database_lookup ⇒ Object
TEST MODE ONLY. Input for the trinsic-test-database-lookup provider
166 167 168 |
# File 'lib/trinsic_api/models/provider_input.rb', line 166 def trinsic_test_database_lookup @trinsic_test_database_lookup end |
#trinsic_test_sub_providers ⇒ Object
TEST MODE ONLY. Input for the trinsic-test-sub-providers provider
169 170 171 |
# File 'lib/trinsic_api/models/provider_input.rb', line 169 def trinsic_test_sub_providers @trinsic_test_sub_providers end |
#uganda_nid_match_2 ⇒ Object
Input for the uganda-nid-match-2 provider
73 74 75 |
# File 'lib/trinsic_api/models/provider_input.rb', line 73 def uganda_nid_match_2 @uganda_nid_match_2 end |
#uk_evisa_lookup ⇒ Object
Input for the uk-evisa-lookup provider
160 161 162 |
# File 'lib/trinsic_api/models/provider_input.rb', line 160 def uk_evisa_lookup @uk_evisa_lookup end |
#usa_california_dmv ⇒ Object
Input for the usa-california-dmv provider
163 164 165 |
# File 'lib/trinsic_api/models/provider_input.rb', line 163 def usa_california_dmv @usa_california_dmv end |
#zimbabwe_nid_lookup_2 ⇒ Object
Input for the zimbabwe-nid-lookup-2 provider
67 68 69 |
# File 'lib/trinsic_api/models/provider_input.rb', line 67 def zimbabwe_nid_lookup_2 @zimbabwe_nid_lookup_2 end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
230 231 232 |
# File 'lib/trinsic_api/models/provider_input.rb', line 230 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
235 236 237 |
# File 'lib/trinsic_api/models/provider_input.rb', line 235 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/trinsic_api/models/provider_input.rb', line 172 def self.attribute_map { :'trinsic_mock_output' => :'trinsic-mock-output', :'indonesia_nik_lookup' => :'indonesia-nik-lookup', :'china_resident_id_match' => :'china-resident-id-match', :'evrotrust' => :'evrotrust', :'indonesia_dukcapil_match' => :'indonesia-dukcapil-match', :'mexico_curp_lookup' => :'mexico-curp-lookup', :'south_africa_nid_lookup' => :'south-africa-nid-lookup', :'kenya_nid_lookup' => :'kenya-nid-lookup', :'kenya_nid_match_2' => :'kenya-nid-match-2', :'kenya_nid_lookup_2' => :'kenya-nid-lookup-2', :'south_africa_nid_lookup_2' => :'south-africa-nid-lookup-2', :'south_africa_nid_match_2' => :'south-africa-nid-match-2', :'nigeria_nin_lookup_2' => :'nigeria-nin-lookup-2', :'nigeria_nin_lookup_3' => :'nigeria-nin-lookup-3', :'kenya_nid_lookup_3' => :'kenya-nid-lookup-3', :'cote_divoire_nid_lookup_2' => :'cote-divoire-nid-lookup-2', :'zimbabwe_nid_lookup_2' => :'zimbabwe-nid-lookup-2', :'nigeria_nin_match_2' => :'nigeria-nin-match-2', :'uganda_nid_match_2' => :'uganda-nid-match-2', :'nigeria_nin_lookup' => :'nigeria-nin-lookup', :'india_digilocker_aadhaar_match' => :'india-digilocker-aadhaar-match', :'india_pan_lookup' => :'india-pan-lookup', :'korea_telco_match' => :'korea-telco-match', :'brazil_cpf_lookup' => :'brazil-cpf-lookup', :'brazil_digital_cnh' => :'brazil-digital-cnh', :'philippines_philsys_match' => :'philippines-philsys-match', :'philippines_physical_national_id_qr' => :'philippines-physical-national-id-qr', :'philippines_digital_national_id_qr' => :'philippines-digital-national-id-qr', :'smart_id' => :'smart-id', :'mobile_id' => :'mobile-id', :'netherlands_idin' => :'netherlands-idin', :'italy_spid' => :'italy-spid', :'google_wallet' => :'google-wallet', :'apple_wallet' => :'apple-wallet', :'samsung_wallet' => :'samsung-wallet', :'france_identite' => :'france-identite', :'moldova_evo_wallet' => :'moldova-evo-wallet', :'germany_eudi_sandbox' => :'germany-eudi-sandbox', :'denmark_altid' => :'denmark-altid', :'austria_valera_eudi_sandbox' => :'austria-valera-eudi-sandbox', :'netherlands_eudi_sandbox' => :'netherlands-eudi-sandbox', :'poland_mobywatel_match' => :'poland-mobywatel-match', :'bolivia_ci_lookup' => :'bolivia-ci-lookup', :'colombia_cc_lookup' => :'colombia-cc-lookup', :'el_salvador_dui_lookup' => :'el-salvador-dui-lookup', :'guatemala_cui_lookup' => :'guatemala-cui-lookup', :'panama_cedula_lookup' => :'panama-cedula-lookup', :'peru_dni_lookup' => :'peru-dni-lookup', :'uk_evisa_lookup' => :'uk-evisa-lookup', :'usa_california_dmv' => :'usa-california-dmv', :'trinsic_test_database_lookup' => :'trinsic-test-database-lookup', :'trinsic_test_sub_providers' => :'trinsic-test-sub-providers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 |
# File 'lib/trinsic_api/models/provider_input.rb', line 669 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/trinsic_api/models/provider_input.rb', line 298 def self.openapi_nullable Set.new([ :'trinsic_mock_output', :'indonesia_nik_lookup', :'china_resident_id_match', :'evrotrust', :'indonesia_dukcapil_match', :'mexico_curp_lookup', :'south_africa_nid_lookup', :'kenya_nid_lookup', :'kenya_nid_match_2', :'kenya_nid_lookup_2', :'south_africa_nid_lookup_2', :'south_africa_nid_match_2', :'nigeria_nin_lookup_2', :'nigeria_nin_lookup_3', :'kenya_nid_lookup_3', :'cote_divoire_nid_lookup_2', :'zimbabwe_nid_lookup_2', :'nigeria_nin_match_2', :'uganda_nid_match_2', :'nigeria_nin_lookup', :'india_digilocker_aadhaar_match', :'india_pan_lookup', :'korea_telco_match', :'brazil_cpf_lookup', :'brazil_digital_cnh', :'philippines_philsys_match', :'philippines_physical_national_id_qr', :'philippines_digital_national_id_qr', :'smart_id', :'mobile_id', :'netherlands_idin', :'italy_spid', :'google_wallet', :'apple_wallet', :'samsung_wallet', :'france_identite', :'moldova_evo_wallet', :'germany_eudi_sandbox', :'denmark_altid', :'austria_valera_eudi_sandbox', :'netherlands_eudi_sandbox', :'poland_mobywatel_match', :'bolivia_ci_lookup', :'colombia_cc_lookup', :'el_salvador_dui_lookup', :'guatemala_cui_lookup', :'panama_cedula_lookup', :'peru_dni_lookup', :'uk_evisa_lookup', :'usa_california_dmv', :'trinsic_test_database_lookup', :'trinsic_test_sub_providers' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 |
# File 'lib/trinsic_api/models/provider_input.rb', line 240 def self.openapi_types { :'trinsic_mock_output' => :'MockOutputProviderInput', :'indonesia_nik_lookup' => :'IndonesiaNikInput', :'china_resident_id_match' => :'ChinaResidentIdMatchInput', :'evrotrust' => :'EvrotrustInput', :'indonesia_dukcapil_match' => :'IndonesiaDukcapilMatchInput', :'mexico_curp_lookup' => :'MexicoCurpInput', :'south_africa_nid_lookup' => :'SouthAfricaNidInput', :'kenya_nid_lookup' => :'KenyaNidInput', :'kenya_nid_match_2' => :'KenyaNidMatch2Input', :'kenya_nid_lookup_2' => :'KenyaNidLookup2Input', :'south_africa_nid_lookup_2' => :'SouthAfricaNidLookup2Input', :'south_africa_nid_match_2' => :'SouthAfricaNidMatch2Input', :'nigeria_nin_lookup_2' => :'NigeriaNinLookup2Input', :'nigeria_nin_lookup_3' => :'NigeriaNinLookup3Input', :'kenya_nid_lookup_3' => :'KenyaNidLookup3Input', :'cote_divoire_nid_lookup_2' => :'CoteDIvoireNidLookup2Input', :'zimbabwe_nid_lookup_2' => :'ZimbabweNidLookup2Input', :'nigeria_nin_match_2' => :'NigeriaNinMatch2Input', :'uganda_nid_match_2' => :'UgandaNidMatch2Input', :'nigeria_nin_lookup' => :'NigeriaNinInput', :'india_digilocker_aadhaar_match' => :'AadhaarInput', :'india_pan_lookup' => :'IndiaPanLookupInput', :'korea_telco_match' => :'KoreaTelcoMatchInput', :'brazil_cpf_lookup' => :'BrazilCpfCheckInput', :'brazil_digital_cnh' => :'BrazilDigitalCnhInput', :'philippines_philsys_match' => :'PhilippineMatchInput', :'philippines_physical_national_id_qr' => :'PhilippineQRInput', :'philippines_digital_national_id_qr' => :'PhilippineQRInput', :'smart_id' => :'SmartIdInput', :'mobile_id' => :'MobileIdInput', :'netherlands_idin' => :'IdinInput', :'italy_spid' => :'SpidInput', :'google_wallet' => :'GoogleWalletInput', :'apple_wallet' => :'AppleWalletInput', :'samsung_wallet' => :'SamsungWalletInput', :'france_identite' => :'FranceIdentiteInput', :'moldova_evo_wallet' => :'MoldovaEvoWalletInput', :'germany_eudi_sandbox' => :'GermanyEudiSandboxInput', :'denmark_altid' => :'DenmarkAltIdInput', :'austria_valera_eudi_sandbox' => :'AustriaValeraEudiSandboxInput', :'netherlands_eudi_sandbox' => :'NetherlandsEudiSandboxInput', :'poland_mobywatel_match' => :'PolandMobywatelMatchInput', :'bolivia_ci_lookup' => :'BoliviaCiLookupInput', :'colombia_cc_lookup' => :'ColombiaCcLookupInput', :'el_salvador_dui_lookup' => :'ElSalvadorDuiLookupInput', :'guatemala_cui_lookup' => :'GuatemalaCuiLookupInput', :'panama_cedula_lookup' => :'PanamaCedulaLookupInput', :'peru_dni_lookup' => :'PeruDniLookupInput', :'uk_evisa_lookup' => :'UkEvisaLookupInput', :'usa_california_dmv' => :'UsaCaliforniaDmvInput', :'trinsic_test_database_lookup' => :'TrinsicTestDatabaseLookupInput', :'trinsic_test_sub_providers' => :'TrinsicTestSubProvidersInput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 |
# File 'lib/trinsic_api/models/provider_input.rb', line 597 def ==(o) return true if self.equal?(o) self.class == o.class && trinsic_mock_output == o.trinsic_mock_output && indonesia_nik_lookup == o.indonesia_nik_lookup && china_resident_id_match == o.china_resident_id_match && evrotrust == o.evrotrust && indonesia_dukcapil_match == o.indonesia_dukcapil_match && mexico_curp_lookup == o.mexico_curp_lookup && south_africa_nid_lookup == o.south_africa_nid_lookup && kenya_nid_lookup == o.kenya_nid_lookup && kenya_nid_match_2 == o.kenya_nid_match_2 && kenya_nid_lookup_2 == o.kenya_nid_lookup_2 && south_africa_nid_lookup_2 == o.south_africa_nid_lookup_2 && south_africa_nid_match_2 == o.south_africa_nid_match_2 && nigeria_nin_lookup_2 == o.nigeria_nin_lookup_2 && nigeria_nin_lookup_3 == o.nigeria_nin_lookup_3 && kenya_nid_lookup_3 == o.kenya_nid_lookup_3 && cote_divoire_nid_lookup_2 == o.cote_divoire_nid_lookup_2 && zimbabwe_nid_lookup_2 == o.zimbabwe_nid_lookup_2 && nigeria_nin_match_2 == o.nigeria_nin_match_2 && uganda_nid_match_2 == o.uganda_nid_match_2 && nigeria_nin_lookup == o.nigeria_nin_lookup && india_digilocker_aadhaar_match == o.india_digilocker_aadhaar_match && india_pan_lookup == o.india_pan_lookup && korea_telco_match == o.korea_telco_match && brazil_cpf_lookup == o.brazil_cpf_lookup && brazil_digital_cnh == o.brazil_digital_cnh && philippines_philsys_match == o.philippines_philsys_match && philippines_physical_national_id_qr == o.philippines_physical_national_id_qr && philippines_digital_national_id_qr == o.philippines_digital_national_id_qr && smart_id == o.smart_id && mobile_id == o.mobile_id && netherlands_idin == o.netherlands_idin && italy_spid == o.italy_spid && google_wallet == o.google_wallet && apple_wallet == o.apple_wallet && samsung_wallet == o.samsung_wallet && france_identite == o.france_identite && moldova_evo_wallet == o.moldova_evo_wallet && germany_eudi_sandbox == o.germany_eudi_sandbox && denmark_altid == o.denmark_altid && austria_valera_eudi_sandbox == o.austria_valera_eudi_sandbox && netherlands_eudi_sandbox == o.netherlands_eudi_sandbox && poland_mobywatel_match == o.poland_mobywatel_match && bolivia_ci_lookup == o.bolivia_ci_lookup && colombia_cc_lookup == o.colombia_cc_lookup && el_salvador_dui_lookup == o.el_salvador_dui_lookup && guatemala_cui_lookup == o.guatemala_cui_lookup && panama_cedula_lookup == o.panama_cedula_lookup && peru_dni_lookup == o.peru_dni_lookup && uk_evisa_lookup == o.uk_evisa_lookup && usa_california_dmv == o.usa_california_dmv && trinsic_test_database_lookup == o.trinsic_test_database_lookup && trinsic_test_sub_providers == o.trinsic_test_sub_providers end |
#eql?(o) ⇒ Boolean
656 657 658 |
# File 'lib/trinsic_api/models/provider_input.rb', line 656 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
662 663 664 |
# File 'lib/trinsic_api/models/provider_input.rb', line 662 def hash [trinsic_mock_output, indonesia_nik_lookup, china_resident_id_match, evrotrust, indonesia_dukcapil_match, mexico_curp_lookup, south_africa_nid_lookup, kenya_nid_lookup, kenya_nid_match_2, kenya_nid_lookup_2, south_africa_nid_lookup_2, south_africa_nid_match_2, nigeria_nin_lookup_2, nigeria_nin_lookup_3, kenya_nid_lookup_3, cote_divoire_nid_lookup_2, zimbabwe_nid_lookup_2, nigeria_nin_match_2, uganda_nid_match_2, nigeria_nin_lookup, india_digilocker_aadhaar_match, india_pan_lookup, korea_telco_match, brazil_cpf_lookup, brazil_digital_cnh, philippines_philsys_match, philippines_physical_national_id_qr, philippines_digital_national_id_qr, smart_id, mobile_id, netherlands_idin, italy_spid, google_wallet, apple_wallet, samsung_wallet, france_identite, moldova_evo_wallet, germany_eudi_sandbox, denmark_altid, austria_valera_eudi_sandbox, netherlands_eudi_sandbox, poland_mobywatel_match, bolivia_ci_lookup, colombia_cc_lookup, el_salvador_dui_lookup, guatemala_cui_lookup, panama_cedula_lookup, peru_dni_lookup, uk_evisa_lookup, usa_california_dmv, trinsic_test_database_lookup, trinsic_test_sub_providers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
582 583 584 585 586 |
# File 'lib/trinsic_api/models/provider_input.rb', line 582 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
691 692 693 694 695 696 697 698 699 700 701 702 703 |
# File 'lib/trinsic_api/models/provider_input.rb', line 691 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
590 591 592 593 |
# File 'lib/trinsic_api/models/provider_input.rb', line 590 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |