Class: TrinsicApi::ProviderInput

Inherits:
Object
  • Object
show all
Defined in:
lib/trinsic_api/models/provider_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ProviderInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
# File 'lib/trinsic_api/models/provider_input.rb', line 264

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ProviderInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ProviderInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'kenya_nid_match_biometric_2')
    self.kenya_nid_match_biometric_2 = attributes[:'kenya_nid_match_biometric_2']
  end

  if attributes.key?(:'indonesia_nik_lookup')
    self.indonesia_nik_lookup = attributes[:'indonesia_nik_lookup']
  end

  if attributes.key?(:'indonesia_dukcapil_match')
    self.indonesia_dukcapil_match = attributes[:'indonesia_dukcapil_match']
  end

  if attributes.key?(:'mexico_curp_lookup')
    self.mexico_curp_lookup = attributes[:'mexico_curp_lookup']
  end

  if attributes.key?(:'south_africa_nid_lookup')
    self.south_africa_nid_lookup = attributes[:'south_africa_nid_lookup']
  end

  if attributes.key?(:'kenya_nid_lookup')
    self.kenya_nid_lookup = attributes[:'kenya_nid_lookup']
  end

  if attributes.key?(:'kenya_nid_match_2')
    self.kenya_nid_match_2 = attributes[:'kenya_nid_match_2']
  end

  if attributes.key?(:'kenya_nid_lookup_2')
    self.kenya_nid_lookup_2 = attributes[:'kenya_nid_lookup_2']
  end

  if attributes.key?(:'south_africa_nid_lookup_2')
    self.south_africa_nid_lookup_2 = attributes[:'south_africa_nid_lookup_2']
  end

  if attributes.key?(:'south_africa_nid_match_2')
    self.south_africa_nid_match_2 = attributes[:'south_africa_nid_match_2']
  end

  if attributes.key?(:'south_africa_nid_match_biometric_2')
    self.south_africa_nid_match_biometric_2 = attributes[:'south_africa_nid_match_biometric_2']
  end

  if attributes.key?(:'nigeria_nin_lookup_2')
    self.nigeria_nin_lookup_2 = attributes[:'nigeria_nin_lookup_2']
  end

  if attributes.key?(:'cote_divoire_nid_lookup_2')
    self.cote_divoire_nid_lookup_2 = attributes[:'cote_divoire_nid_lookup_2']
  end

  if attributes.key?(:'zimbabwe_nid_lookup_2')
    self.zimbabwe_nid_lookup_2 = attributes[:'zimbabwe_nid_lookup_2']
  end

  if attributes.key?(:'nigeria_nin_match_2')
    self.nigeria_nin_match_2 = attributes[:'nigeria_nin_match_2']
  end

  if attributes.key?(:'uganda_nid_match_2')
    self.uganda_nid_match_2 = attributes[:'uganda_nid_match_2']
  end

  if attributes.key?(:'nigeria_nin_match_biometric_2')
    self.nigeria_nin_match_biometric_2 = attributes[:'nigeria_nin_match_biometric_2']
  end

  if attributes.key?(:'nigeria_nin_lookup')
    self.nigeria_nin_lookup = attributes[:'nigeria_nin_lookup']
  end

  if attributes.key?(:'india_digilocker_aadhaar_match')
    self.india_digilocker_aadhaar_match = attributes[:'india_digilocker_aadhaar_match']
  end

  if attributes.key?(:'brazil_cpf_lookup')
    self.brazil_cpf_lookup = attributes[:'brazil_cpf_lookup']
  end

  if attributes.key?(:'brazil_digital_cnh')
    self.brazil_digital_cnh = attributes[:'brazil_digital_cnh']
  end

  if attributes.key?(:'philippines_philsys_match')
    self.philippines_philsys_match = attributes[:'philippines_philsys_match']
  end

  if attributes.key?(:'philippines_physical_national_id_qr')
    self.philippines_physical_national_id_qr = attributes[:'philippines_physical_national_id_qr']
  end

  if attributes.key?(:'philippines_digital_national_id_qr')
    self.philippines_digital_national_id_qr = attributes[:'philippines_digital_national_id_qr']
  end

  if attributes.key?(:'smart_id')
    self.smart_id = attributes[:'smart_id']
  end

  if attributes.key?(:'mobile_id')
    self.mobile_id = attributes[:'mobile_id']
  end

  if attributes.key?(:'netherlands_idin')
    self.netherlands_idin = attributes[:'netherlands_idin']
  end

  if attributes.key?(:'italy_spid')
    self.italy_spid = attributes[:'italy_spid']
  end

  if attributes.key?(:'google_wallet')
    self.google_wallet = attributes[:'google_wallet']
  end

  if attributes.key?(:'apple_wallet')
    self.apple_wallet = attributes[:'apple_wallet']
  end

  if attributes.key?(:'samsung_wallet')
    self.samsung_wallet = attributes[:'samsung_wallet']
  end

  if attributes.key?(:'france_identite')
    self.france_identite = attributes[:'france_identite']
  end

  if attributes.key?(:'peru_dni_lookup')
    self.peru_dni_lookup = attributes[:'peru_dni_lookup']
  end

  if attributes.key?(:'uk_evisa_lookup')
    self.uk_evisa_lookup = attributes[:'uk_evisa_lookup']
  end

  if attributes.key?(:'trinsic_test_database_lookup')
    self.trinsic_test_database_lookup = attributes[:'trinsic_test_database_lookup']
  end

  if attributes.key?(:'trinsic_test_sub_providers')
    self.trinsic_test_sub_providers = attributes[:'trinsic_test_sub_providers']
  end
end

Instance Attribute Details

#apple_walletObject

Input for the ‘apple-wallet` provider



106
107
108
# File 'lib/trinsic_api/models/provider_input.rb', line 106

def apple_wallet
  @apple_wallet
end

#brazil_cpf_lookupObject

Input for the ‘brazil-cpf-lookup` provider



76
77
78
# File 'lib/trinsic_api/models/provider_input.rb', line 76

def brazil_cpf_lookup
  @brazil_cpf_lookup
end

#brazil_digital_cnhObject

Input for the ‘brazil-digital-cnh` provider



79
80
81
# File 'lib/trinsic_api/models/provider_input.rb', line 79

def brazil_digital_cnh
  @brazil_digital_cnh
end

#cote_divoire_nid_lookup_2Object

Input for the ‘cote-divoire-nid-lookup-2` provider



55
56
57
# File 'lib/trinsic_api/models/provider_input.rb', line 55

def cote_divoire_nid_lookup_2
  @cote_divoire_nid_lookup_2
end

#france_identiteObject

Input for the ‘france-identite` provider



112
113
114
# File 'lib/trinsic_api/models/provider_input.rb', line 112

def france_identite
  @france_identite
end

#google_walletObject

Input for the ‘google-wallet` provider



103
104
105
# File 'lib/trinsic_api/models/provider_input.rb', line 103

def google_wallet
  @google_wallet
end

#india_digilocker_aadhaar_matchObject

Input for the ‘india-digilocker-aadhaar-match` provider



73
74
75
# File 'lib/trinsic_api/models/provider_input.rb', line 73

def india_digilocker_aadhaar_match
  @india_digilocker_aadhaar_match
end

#indonesia_dukcapil_matchObject

Input for the ‘indonesia-dukcapil-match` provider



25
26
27
# File 'lib/trinsic_api/models/provider_input.rb', line 25

def indonesia_dukcapil_match
  @indonesia_dukcapil_match
end

#indonesia_nik_lookupObject

Input for the ‘indonesia-nik-lookup` provider



22
23
24
# File 'lib/trinsic_api/models/provider_input.rb', line 22

def indonesia_nik_lookup
  @indonesia_nik_lookup
end

#italy_spidObject

Input for the ‘italy-spid` provider



100
101
102
# File 'lib/trinsic_api/models/provider_input.rb', line 100

def italy_spid
  @italy_spid
end

#kenya_nid_lookupObject

Input for the ‘kenya-nid-lookup` provider



34
35
36
# File 'lib/trinsic_api/models/provider_input.rb', line 34

def kenya_nid_lookup
  @kenya_nid_lookup
end

#kenya_nid_lookup_2Object

Input for the ‘kenya-nid-lookup-2` provider



40
41
42
# File 'lib/trinsic_api/models/provider_input.rb', line 40

def kenya_nid_lookup_2
  @kenya_nid_lookup_2
end

#kenya_nid_match_2Object

Input for the ‘kenya-nid-match-2` provider



37
38
39
# File 'lib/trinsic_api/models/provider_input.rb', line 37

def kenya_nid_match_2
  @kenya_nid_match_2
end

#kenya_nid_match_biometric_2Object

Input for the ‘kenya-nid-match-biometric-2` provider



19
20
21
# File 'lib/trinsic_api/models/provider_input.rb', line 19

def kenya_nid_match_biometric_2
  @kenya_nid_match_biometric_2
end

#mexico_curp_lookupObject

Input for the ‘mexico-curp-lookup` provider



28
29
30
# File 'lib/trinsic_api/models/provider_input.rb', line 28

def mexico_curp_lookup
  @mexico_curp_lookup
end

#mobile_idObject

Input for the ‘mobile-id` provider



94
95
96
# File 'lib/trinsic_api/models/provider_input.rb', line 94

def mobile_id
  @mobile_id
end

#netherlands_idinObject

Input for the ‘netherlands-idin` provider



97
98
99
# File 'lib/trinsic_api/models/provider_input.rb', line 97

def netherlands_idin
  @netherlands_idin
end

#nigeria_nin_lookupObject

Input for the ‘nigeria-nin-lookup` provider



70
71
72
# File 'lib/trinsic_api/models/provider_input.rb', line 70

def nigeria_nin_lookup
  @nigeria_nin_lookup
end

#nigeria_nin_lookup_2Object

Input for the ‘nigeria-nin-lookup-2` provider



52
53
54
# File 'lib/trinsic_api/models/provider_input.rb', line 52

def nigeria_nin_lookup_2
  @nigeria_nin_lookup_2
end

#nigeria_nin_match_2Object

Input for the ‘nigeria-nin-match-2` provider



61
62
63
# File 'lib/trinsic_api/models/provider_input.rb', line 61

def nigeria_nin_match_2
  @nigeria_nin_match_2
end

#nigeria_nin_match_biometric_2Object

Input for the ‘nigeria-nin-match-biometric-2` provider



67
68
69
# File 'lib/trinsic_api/models/provider_input.rb', line 67

def nigeria_nin_match_biometric_2
  @nigeria_nin_match_biometric_2
end

#peru_dni_lookupObject

Input for the ‘peru-dni-lookup` provider



115
116
117
# File 'lib/trinsic_api/models/provider_input.rb', line 115

def peru_dni_lookup
  @peru_dni_lookup
end

#philippines_digital_national_id_qrObject

Input for the ‘philippines-digital-national-id-qr` provider



88
89
90
# File 'lib/trinsic_api/models/provider_input.rb', line 88

def philippines_digital_national_id_qr
  @philippines_digital_national_id_qr
end

#philippines_philsys_matchObject

Input for the ‘philippines-philsys-match` provider



82
83
84
# File 'lib/trinsic_api/models/provider_input.rb', line 82

def philippines_philsys_match
  @philippines_philsys_match
end

#philippines_physical_national_id_qrObject

Input for the ‘philippines-physical-national-id-qr` provider



85
86
87
# File 'lib/trinsic_api/models/provider_input.rb', line 85

def philippines_physical_national_id_qr
  @philippines_physical_national_id_qr
end

#samsung_walletObject

Input for the ‘samsung-wallet` provider



109
110
111
# File 'lib/trinsic_api/models/provider_input.rb', line 109

def samsung_wallet
  @samsung_wallet
end

#smart_idObject

Input for the ‘smart-id` provider



91
92
93
# File 'lib/trinsic_api/models/provider_input.rb', line 91

def smart_id
  @smart_id
end

#south_africa_nid_lookupObject

Input for the ‘south-africa-nid-lookup` provider



31
32
33
# File 'lib/trinsic_api/models/provider_input.rb', line 31

def south_africa_nid_lookup
  @south_africa_nid_lookup
end

#south_africa_nid_lookup_2Object

Input for the ‘south-africa-nid-lookup-2` provider



43
44
45
# File 'lib/trinsic_api/models/provider_input.rb', line 43

def south_africa_nid_lookup_2
  @south_africa_nid_lookup_2
end

#south_africa_nid_match_2Object

Input for the ‘south-africa-nid-match-2` provider



46
47
48
# File 'lib/trinsic_api/models/provider_input.rb', line 46

def south_africa_nid_match_2
  @south_africa_nid_match_2
end

#south_africa_nid_match_biometric_2Object

Input for the ‘south-africa-nid-match-biometric-2` provider



49
50
51
# File 'lib/trinsic_api/models/provider_input.rb', line 49

def south_africa_nid_match_biometric_2
  @south_africa_nid_match_biometric_2
end

#trinsic_test_database_lookupObject

*TEST MODE ONLY.* Input for the ‘trinsic-test-database-lookup` provider



121
122
123
# File 'lib/trinsic_api/models/provider_input.rb', line 121

def trinsic_test_database_lookup
  @trinsic_test_database_lookup
end

#trinsic_test_sub_providersObject

*TEST MODE ONLY.* Input for the ‘trinsic-test-sub-providers` provider



124
125
126
# File 'lib/trinsic_api/models/provider_input.rb', line 124

def trinsic_test_sub_providers
  @trinsic_test_sub_providers
end

#uganda_nid_match_2Object

Input for the ‘uganda-nid-match-2` provider



64
65
66
# File 'lib/trinsic_api/models/provider_input.rb', line 64

def uganda_nid_match_2
  @uganda_nid_match_2
end

#uk_evisa_lookupObject

Input for the ‘uk-evisa-lookup` provider



118
119
120
# File 'lib/trinsic_api/models/provider_input.rb', line 118

def uk_evisa_lookup
  @uk_evisa_lookup
end

#zimbabwe_nid_lookup_2Object

Input for the ‘zimbabwe-nid-lookup-2` provider



58
59
60
# File 'lib/trinsic_api/models/provider_input.rb', line 58

def zimbabwe_nid_lookup_2
  @zimbabwe_nid_lookup_2
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
# File 'lib/trinsic_api/models/provider_input.rb', line 520

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = TrinsicApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



169
170
171
# File 'lib/trinsic_api/models/provider_input.rb', line 169

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



174
175
176
# File 'lib/trinsic_api/models/provider_input.rb', line 174

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/trinsic_api/models/provider_input.rb', line 127

def self.attribute_map
  {
    :'kenya_nid_match_biometric_2' => :'kenya-nid-match-biometric-2',
    :'indonesia_nik_lookup' => :'indonesia-nik-lookup',
    :'indonesia_dukcapil_match' => :'indonesia-dukcapil-match',
    :'mexico_curp_lookup' => :'mexico-curp-lookup',
    :'south_africa_nid_lookup' => :'south-africa-nid-lookup',
    :'kenya_nid_lookup' => :'kenya-nid-lookup',
    :'kenya_nid_match_2' => :'kenya-nid-match-2',
    :'kenya_nid_lookup_2' => :'kenya-nid-lookup-2',
    :'south_africa_nid_lookup_2' => :'south-africa-nid-lookup-2',
    :'south_africa_nid_match_2' => :'south-africa-nid-match-2',
    :'south_africa_nid_match_biometric_2' => :'south-africa-nid-match-biometric-2',
    :'nigeria_nin_lookup_2' => :'nigeria-nin-lookup-2',
    :'cote_divoire_nid_lookup_2' => :'cote-divoire-nid-lookup-2',
    :'zimbabwe_nid_lookup_2' => :'zimbabwe-nid-lookup-2',
    :'nigeria_nin_match_2' => :'nigeria-nin-match-2',
    :'uganda_nid_match_2' => :'uganda-nid-match-2',
    :'nigeria_nin_match_biometric_2' => :'nigeria-nin-match-biometric-2',
    :'nigeria_nin_lookup' => :'nigeria-nin-lookup',
    :'india_digilocker_aadhaar_match' => :'india-digilocker-aadhaar-match',
    :'brazil_cpf_lookup' => :'brazil-cpf-lookup',
    :'brazil_digital_cnh' => :'brazil-digital-cnh',
    :'philippines_philsys_match' => :'philippines-philsys-match',
    :'philippines_physical_national_id_qr' => :'philippines-physical-national-id-qr',
    :'philippines_digital_national_id_qr' => :'philippines-digital-national-id-qr',
    :'smart_id' => :'smart-id',
    :'mobile_id' => :'mobile-id',
    :'netherlands_idin' => :'netherlands-idin',
    :'italy_spid' => :'italy-spid',
    :'google_wallet' => :'google-wallet',
    :'apple_wallet' => :'apple-wallet',
    :'samsung_wallet' => :'samsung-wallet',
    :'france_identite' => :'france-identite',
    :'peru_dni_lookup' => :'peru-dni-lookup',
    :'uk_evisa_lookup' => :'uk-evisa-lookup',
    :'trinsic_test_database_lookup' => :'trinsic-test-database-lookup',
    :'trinsic_test_sub_providers' => :'trinsic-test-sub-providers'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
# File 'lib/trinsic_api/models/provider_input.rb', line 496

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/trinsic_api/models/provider_input.rb', line 221

def self.openapi_nullable
  Set.new([
    :'kenya_nid_match_biometric_2',
    :'indonesia_nik_lookup',
    :'indonesia_dukcapil_match',
    :'mexico_curp_lookup',
    :'south_africa_nid_lookup',
    :'kenya_nid_lookup',
    :'kenya_nid_match_2',
    :'kenya_nid_lookup_2',
    :'south_africa_nid_lookup_2',
    :'south_africa_nid_match_2',
    :'south_africa_nid_match_biometric_2',
    :'nigeria_nin_lookup_2',
    :'cote_divoire_nid_lookup_2',
    :'zimbabwe_nid_lookup_2',
    :'nigeria_nin_match_2',
    :'uganda_nid_match_2',
    :'nigeria_nin_match_biometric_2',
    :'nigeria_nin_lookup',
    :'india_digilocker_aadhaar_match',
    :'brazil_cpf_lookup',
    :'brazil_digital_cnh',
    :'philippines_philsys_match',
    :'philippines_physical_national_id_qr',
    :'philippines_digital_national_id_qr',
    :'smart_id',
    :'mobile_id',
    :'netherlands_idin',
    :'italy_spid',
    :'google_wallet',
    :'apple_wallet',
    :'samsung_wallet',
    :'france_identite',
    :'peru_dni_lookup',
    :'uk_evisa_lookup',
    :'trinsic_test_database_lookup',
    :'trinsic_test_sub_providers'
  ])
end

.openapi_typesObject

Attribute type mapping.



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/trinsic_api/models/provider_input.rb', line 179

def self.openapi_types
  {
    :'kenya_nid_match_biometric_2' => :'KenyaNidBiometric2Input',
    :'indonesia_nik_lookup' => :'IndonesiaNikInput',
    :'indonesia_dukcapil_match' => :'IndonesiaDukcapilMatchInput',
    :'mexico_curp_lookup' => :'MexicoCurpInput',
    :'south_africa_nid_lookup' => :'SouthAfricaNidInput',
    :'kenya_nid_lookup' => :'KenyaNidInput',
    :'kenya_nid_match_2' => :'KenyaNidMatch2Input',
    :'kenya_nid_lookup_2' => :'KenyaNidLookup2Input',
    :'south_africa_nid_lookup_2' => :'SouthAfricaNidLookup2Input',
    :'south_africa_nid_match_2' => :'SouthAfricaNidMatch2Input',
    :'south_africa_nid_match_biometric_2' => :'SouthAfricaNidBiometric2Input',
    :'nigeria_nin_lookup_2' => :'NigeriaNinLookup2Input',
    :'cote_divoire_nid_lookup_2' => :'CoteDIvoireNidLookup2Input',
    :'zimbabwe_nid_lookup_2' => :'ZimbabweNidLookup2Input',
    :'nigeria_nin_match_2' => :'NigeriaNinMatch2Input',
    :'uganda_nid_match_2' => :'UgandaNidMatch2Input',
    :'nigeria_nin_match_biometric_2' => :'NigeriaNinBiometric2Input',
    :'nigeria_nin_lookup' => :'NigeriaNinInput',
    :'india_digilocker_aadhaar_match' => :'AadhaarInput',
    :'brazil_cpf_lookup' => :'BrazilCpfCheckInput',
    :'brazil_digital_cnh' => :'BrazilDigitalCnhInput',
    :'philippines_philsys_match' => :'PhilippineMatchInput',
    :'philippines_physical_national_id_qr' => :'PhilippineQRInput',
    :'philippines_digital_national_id_qr' => :'PhilippineQRInput',
    :'smart_id' => :'SmartIdInput',
    :'mobile_id' => :'MobileIdInput',
    :'netherlands_idin' => :'IdinInput',
    :'italy_spid' => :'SpidInput',
    :'google_wallet' => :'GoogleWalletInput',
    :'apple_wallet' => :'AppleWalletInput',
    :'samsung_wallet' => :'SamsungWalletInput',
    :'france_identite' => :'FranceIdentiteInput',
    :'peru_dni_lookup' => :'PeruDniLookupInput',
    :'uk_evisa_lookup' => :'UkEvisaLookupInput',
    :'trinsic_test_database_lookup' => :'TrinsicTestDatabaseLookupInput',
    :'trinsic_test_sub_providers' => :'TrinsicTestSubProvidersInput'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
# File 'lib/trinsic_api/models/provider_input.rb', line 440

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      kenya_nid_match_biometric_2 == o.kenya_nid_match_biometric_2 &&
      indonesia_nik_lookup == o.indonesia_nik_lookup &&
      indonesia_dukcapil_match == o.indonesia_dukcapil_match &&
      mexico_curp_lookup == o.mexico_curp_lookup &&
      south_africa_nid_lookup == o.south_africa_nid_lookup &&
      kenya_nid_lookup == o.kenya_nid_lookup &&
      kenya_nid_match_2 == o.kenya_nid_match_2 &&
      kenya_nid_lookup_2 == o.kenya_nid_lookup_2 &&
      south_africa_nid_lookup_2 == o.south_africa_nid_lookup_2 &&
      south_africa_nid_match_2 == o.south_africa_nid_match_2 &&
      south_africa_nid_match_biometric_2 == o.south_africa_nid_match_biometric_2 &&
      nigeria_nin_lookup_2 == o.nigeria_nin_lookup_2 &&
      cote_divoire_nid_lookup_2 == o.cote_divoire_nid_lookup_2 &&
      zimbabwe_nid_lookup_2 == o.zimbabwe_nid_lookup_2 &&
      nigeria_nin_match_2 == o.nigeria_nin_match_2 &&
      uganda_nid_match_2 == o.uganda_nid_match_2 &&
      nigeria_nin_match_biometric_2 == o.nigeria_nin_match_biometric_2 &&
      nigeria_nin_lookup == o.nigeria_nin_lookup &&
      india_digilocker_aadhaar_match == o.india_digilocker_aadhaar_match &&
      brazil_cpf_lookup == o.brazil_cpf_lookup &&
      brazil_digital_cnh == o.brazil_digital_cnh &&
      philippines_philsys_match == o.philippines_philsys_match &&
      philippines_physical_national_id_qr == o.philippines_physical_national_id_qr &&
      philippines_digital_national_id_qr == o.philippines_digital_national_id_qr &&
      smart_id == o.smart_id &&
      mobile_id == o.mobile_id &&
      netherlands_idin == o.netherlands_idin &&
      italy_spid == o.italy_spid &&
      google_wallet == o.google_wallet &&
      apple_wallet == o.apple_wallet &&
      samsung_wallet == o.samsung_wallet &&
      france_identite == o.france_identite &&
      peru_dni_lookup == o.peru_dni_lookup &&
      uk_evisa_lookup == o.uk_evisa_lookup &&
      trinsic_test_database_lookup == o.trinsic_test_database_lookup &&
      trinsic_test_sub_providers == o.trinsic_test_sub_providers
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



591
592
593
594
595
596
597
598
599
600
601
602
603
# File 'lib/trinsic_api/models/provider_input.rb', line 591

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


483
484
485
# File 'lib/trinsic_api/models/provider_input.rb', line 483

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



489
490
491
# File 'lib/trinsic_api/models/provider_input.rb', line 489

def hash
  [kenya_nid_match_biometric_2, indonesia_nik_lookup, indonesia_dukcapil_match, mexico_curp_lookup, south_africa_nid_lookup, kenya_nid_lookup, kenya_nid_match_2, kenya_nid_lookup_2, south_africa_nid_lookup_2, south_africa_nid_match_2, south_africa_nid_match_biometric_2, nigeria_nin_lookup_2, cote_divoire_nid_lookup_2, zimbabwe_nid_lookup_2, nigeria_nin_match_2, uganda_nid_match_2, nigeria_nin_match_biometric_2, nigeria_nin_lookup, india_digilocker_aadhaar_match, brazil_cpf_lookup, brazil_digital_cnh, philippines_philsys_match, philippines_physical_national_id_qr, philippines_digital_national_id_qr, smart_id, mobile_id, netherlands_idin, italy_spid, google_wallet, apple_wallet, samsung_wallet, france_identite, peru_dni_lookup, uk_evisa_lookup, trinsic_test_database_lookup, trinsic_test_sub_providers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



425
426
427
428
429
# File 'lib/trinsic_api/models/provider_input.rb', line 425

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



567
568
569
# File 'lib/trinsic_api/models/provider_input.rb', line 567

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



573
574
575
576
577
578
579
580
581
582
583
584
585
# File 'lib/trinsic_api/models/provider_input.rb', line 573

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



561
562
563
# File 'lib/trinsic_api/models/provider_input.rb', line 561

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



433
434
435
436
# File 'lib/trinsic_api/models/provider_input.rb', line 433

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end