Class: TrinsicApi::ProviderOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- TrinsicApi::ProviderOutput
- Defined in:
- lib/trinsic_api/models/provider_output.rb
Instance Attribute Summary collapse
-
#a_at_handy_signatur_login ⇒ Object
Exposed properties for the ‘a-at-handy-signatur-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_be_id_login ⇒ Object
Exposed properties for the ‘a-be-id-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_edoapp_eid_login ⇒ Object
Exposed properties for the ‘a-edoapp-eid-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_ee_web_eid_login ⇒ Object
Exposed properties for the ‘a-ee-web-eid-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_fi_id_login ⇒ Object
Exposed properties for the ‘a-fi-id-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_freja_eid_login ⇒ Object
Exposed properties for the ‘a-freja-eid-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_itsme_login ⇒ Object
Exposed properties for the ‘a-itsme-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_lt_id_login ⇒ Object
Exposed properties for the ‘a-lt-id-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_lv_eparaksts_id_login ⇒ Object
Exposed properties for the ‘a-lv-eparaksts-id-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_lv_eparaksts_mobile_login ⇒ Object
Exposed properties for the ‘a-lv-eparaksts-mobile-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_mojeid ⇒ Object
Exposed properties for the ‘a-mojeid` Provider which do not directly map to the normalized IdentityData model.
-
#a_pl_mojeid_login ⇒ Object
Exposed properties for the ‘a-pl-mojeid-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_pt_id_login ⇒ Object
Exposed properties for the ‘a-pt-id-login` Provider which do not directly map to the normalized IdentityData model.
-
#a_rs_id_login ⇒ Object
Exposed properties for the ‘a-rs-id-login` Provider which do not directly map to the normalized IdentityData model.
-
#apple_wallet ⇒ Object
Exposed properties for the ‘apple-wallet` Provider which do not directly map to the normalized IdentityData model.
-
#audkenni ⇒ Object
Exposed properties for the ‘audkenni` provider which do not directly map to the normalized IdentityData model.
-
#australia_connect_id ⇒ Object
Exposed properties for the ‘australia-connect-id` Provider which do not directly map to the normalized IdentityData model.
-
#bolivia_ci_lookup ⇒ Object
Exposed properties for the ‘bolivia-ci-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#china_resident_id_match ⇒ Object
Exposed properties for the ‘china-resident-id-match` Provider which do not directly map to the normalized IdentityData model.
-
#colombia_cc_lookup ⇒ Object
Exposed properties for the ‘colombia-cc-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#cote_divoire_nid_lookup_2 ⇒ Object
Exposed properties for the ‘cote-divoire-nid-lookup-2` Provider which do not directly map to the normalized IdentityData model.
-
#czech_republic_mojeid ⇒ Object
Exposed properties for the ‘czech-moje-id` Provider which do not directly map to the normalized IdentityData model.
-
#denmark_mitid ⇒ Object
Exposed properties for the ‘denmark-mitid` Provider which do not directly map to the normalized IdentityData model.
-
#el_salvador_dui_lookup ⇒ Object
Exposed properties for the ‘el-salvador-dui-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#ethiopia_fayda ⇒ Object
Exposed properties for the ‘ethiopia-fayda` Provider which do not directly map to the normalized IdentityData model.
-
#finnish_trust_network ⇒ Object
Exposed properties for the ‘finnish-trust-network` Provider which do not directly map to the normalized IdentityData model.
-
#france_identite ⇒ Object
Exposed properties for the ‘france-identite` Provider which do not directly map to the normalized IdentityData model.
-
#france_identite_numerique ⇒ Object
Exposed properties for the ‘france-identite-numerique` Provider which do not directly map to the normalized IdentityData model.
-
#freja ⇒ Object
Exposed properties for the ‘freja` Provider which do not directly map to the normalized IdentityData model.
-
#google_wallet ⇒ Object
Exposed properties for the ‘google-wallet` Provider which do not directly map to the normalized IdentityData model.
-
#guatemala_cui_lookup ⇒ Object
Exposed properties for the ‘guatemala-cui-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#india_digilocker_aadhaar ⇒ Object
Exposed properties for the ‘india-digilocker-aadhaar` Provider which do not directly map to the normalized IdentityData model.
-
#india_digilocker_aadhaar_fetch ⇒ Object
Exposed properties for the ‘india-digilocker-aadhaar-fetch` Provider which do not directly map to the normalized IdentityData model.
-
#india_pan_lookup ⇒ Object
Exposed properties for the ‘india-pan-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#italy_spid ⇒ Object
Exposed properties for the ‘italy-spid` Provider which do not directly map to the normalized IdentityData model.
-
#kenya_nid_lookup_2 ⇒ Object
Exposed properties for the ‘kenya-nid-lookup-2` Provider which do not directly map to the normalized IdentityData model.
-
#korea_telco_match ⇒ Object
Exposed properties for the ‘korea-telco-match` Provider which do not directly map to the normalized IdentityData model.
-
#lloyds_smart_id ⇒ Object
Exposed properties for the ‘lloyds-smart-id` Provider which do not directly map to the normalized IdentityData model.
-
#mexico_curp_lookup ⇒ Object
Exposed properties for the ‘mexico-curp-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#mobile_id ⇒ Object
Exposed properties for the ‘mobile-id` Provider which do not directly map to the normalized IdentityData model.
-
#netherlands_idin ⇒ Object
Exposed properties for the ‘netherlands-idin` Provider which do not directly map to the normalized IdentityData model.
-
#nigeria_nin_lookup_2 ⇒ Object
Exposed properties for the ‘nigeria-nin-lookup-2` Provider which do not directly map to the normalized IdentityData model.
-
#norway_bankid ⇒ Object
Exposed properties for the ‘norway-bankid` Provider which do not directly map to the normalized IdentityData model.
-
#oneid ⇒ Object
Exposed properties for the ‘oneid` Provider which do not directly map to the normalized IdentityData model.
-
#panama_cedula_lookup ⇒ Object
Exposed properties for the ‘panama-cedula-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#peru_dni_lookup ⇒ Object
Exposed properties for the ‘peru-dni-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#philippines_digital_national_id_qr ⇒ Object
Exposed properties for the ‘philippines-digital-national-id-qr` Provider which do not directly map to the normalized IdentityData model.
-
#philippines_physical_national_id_qr ⇒ Object
Exposed properties for the ‘philippines-physical-national-id-qr` Provider which do not directly map to the normalized IdentityData model.
-
#poland_mobywatel_match ⇒ Object
Exposed properties for the ‘poland-mobywatel-match` Provider which do not directly map to the normalized IdentityData model.
-
#post_office_easyid ⇒ Object
Exposed properties for the ‘post-office-easyid` Provider which do not directly map to the normalized IdentityData model.
-
#samsung_wallet ⇒ Object
Exposed properties for the ‘samsung-wallet` Provider which do not directly map to the normalized IdentityData model.
-
#singpass_login ⇒ Object
Exposed properties for the ‘singpass-login` Provider which do not directly map to the normalized IdentityData model.
-
#singpass_myinfo ⇒ Object
Exposed properties for the ‘singpass-myinfo` Provider which do not directly map to the normalized IdentityData model.
-
#smart_id ⇒ Object
Exposed properties for the ‘smart-id` Provider which do not directly map to the normalized IdentityData model.
-
#sweden_bankid ⇒ Object
Exposed properties for the ‘sweden-bankid` Provider which do not directly map to the normalized IdentityData model.
-
#uk_evisa_lookup ⇒ Object
Exposed properties for the ‘uk-evisa-lookup` Provider which do not directly map to the normalized IdentityData model.
-
#usa_louisiana_wallet ⇒ Object
Exposed properties for the ‘usa-louisiana-wallet` Provider which do not directly map to the normalized IdentityData model.
-
#yoti ⇒ Object
Exposed properties for the ‘yoti` Provider which do not directly map to the normalized IdentityData model.
-
#yoti_deeplink ⇒ Object
Exposed properties for the ‘yoti-deeplink` Provider which do not directly map to the normalized IdentityData model.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ProviderOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ProviderOutput
Initializes the object
402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 |
# File 'lib/trinsic_api/models/provider_output.rb', line 402 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::ProviderOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::ProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'audkenni') self.audkenni = attributes[:'audkenni'] end if attributes.key?(:'a_at_handy_signatur_login') self.a_at_handy_signatur_login = attributes[:'a_at_handy_signatur_login'] end if attributes.key?(:'a_be_id_login') self.a_be_id_login = attributes[:'a_be_id_login'] end if attributes.key?(:'a_edoapp_eid_login') self.a_edoapp_eid_login = attributes[:'a_edoapp_eid_login'] end if attributes.key?(:'a_ee_web_eid_login') self.a_ee_web_eid_login = attributes[:'a_ee_web_eid_login'] end if attributes.key?(:'a_fi_id_login') self.a_fi_id_login = attributes[:'a_fi_id_login'] end if attributes.key?(:'a_freja_eid_login') self.a_freja_eid_login = attributes[:'a_freja_eid_login'] end if attributes.key?(:'a_itsme_login') self.a_itsme_login = attributes[:'a_itsme_login'] end if attributes.key?(:'a_lt_id_login') self.a_lt_id_login = attributes[:'a_lt_id_login'] end if attributes.key?(:'a_lv_eparaksts_id_login') self.a_lv_eparaksts_id_login = attributes[:'a_lv_eparaksts_id_login'] end if attributes.key?(:'a_lv_eparaksts_mobile_login') self.a_lv_eparaksts_mobile_login = attributes[:'a_lv_eparaksts_mobile_login'] end if attributes.key?(:'a_mojeid') self.a_mojeid = attributes[:'a_mojeid'] end if attributes.key?(:'a_pl_mojeid_login') self.a_pl_mojeid_login = attributes[:'a_pl_mojeid_login'] end if attributes.key?(:'a_pt_id_login') self.a_pt_id_login = attributes[:'a_pt_id_login'] end if attributes.key?(:'a_rs_id_login') self.a_rs_id_login = attributes[:'a_rs_id_login'] end if attributes.key?(:'apple_wallet') self.apple_wallet = attributes[:'apple_wallet'] end if attributes.key?(:'australia_connect_id') self.australia_connect_id = attributes[:'australia_connect_id'] end if attributes.key?(:'bolivia_ci_lookup') self.bolivia_ci_lookup = attributes[:'bolivia_ci_lookup'] end if attributes.key?(:'colombia_cc_lookup') self.colombia_cc_lookup = attributes[:'colombia_cc_lookup'] end if attributes.key?(:'cote_divoire_nid_lookup_2') self.cote_divoire_nid_lookup_2 = attributes[:'cote_divoire_nid_lookup_2'] end if attributes.key?(:'el_salvador_dui_lookup') self.el_salvador_dui_lookup = attributes[:'el_salvador_dui_lookup'] end if attributes.key?(:'czech_republic_mojeid') self.czech_republic_mojeid = attributes[:'czech_republic_mojeid'] end if attributes.key?(:'denmark_mitid') self.denmark_mitid = attributes[:'denmark_mitid'] end if attributes.key?(:'ethiopia_fayda') self.ethiopia_fayda = attributes[:'ethiopia_fayda'] end if attributes.key?(:'finnish_trust_network') self.finnish_trust_network = attributes[:'finnish_trust_network'] end if attributes.key?(:'france_identite') self.france_identite = attributes[:'france_identite'] end if attributes.key?(:'france_identite_numerique') self.france_identite_numerique = attributes[:'france_identite_numerique'] end if attributes.key?(:'freja') self.freja = attributes[:'freja'] end if attributes.key?(:'google_wallet') self.google_wallet = attributes[:'google_wallet'] end if attributes.key?(:'guatemala_cui_lookup') self.guatemala_cui_lookup = attributes[:'guatemala_cui_lookup'] end if attributes.key?(:'panama_cedula_lookup') self.panama_cedula_lookup = attributes[:'panama_cedula_lookup'] end if attributes.key?(:'india_digilocker_aadhaar') self.india_digilocker_aadhaar = attributes[:'india_digilocker_aadhaar'] end if attributes.key?(:'india_digilocker_aadhaar_fetch') self.india_digilocker_aadhaar_fetch = attributes[:'india_digilocker_aadhaar_fetch'] end if attributes.key?(:'india_pan_lookup') self.india_pan_lookup = attributes[:'india_pan_lookup'] end if attributes.key?(:'china_resident_id_match') self.china_resident_id_match = attributes[:'china_resident_id_match'] end if attributes.key?(:'italy_spid') self.italy_spid = attributes[:'italy_spid'] end if attributes.key?(:'kenya_nid_lookup_2') self.kenya_nid_lookup_2 = attributes[:'kenya_nid_lookup_2'] end if attributes.key?(:'korea_telco_match') self.korea_telco_match = attributes[:'korea_telco_match'] end if attributes.key?(:'lloyds_smart_id') self.lloyds_smart_id = attributes[:'lloyds_smart_id'] end if attributes.key?(:'mexico_curp_lookup') self.mexico_curp_lookup = attributes[:'mexico_curp_lookup'] end if attributes.key?(:'mobile_id') self.mobile_id = attributes[:'mobile_id'] end if attributes.key?(:'nigeria_nin_lookup_2') self.nigeria_nin_lookup_2 = attributes[:'nigeria_nin_lookup_2'] end if attributes.key?(:'oneid') self.oneid = attributes[:'oneid'] end if attributes.key?(:'peru_dni_lookup') self.peru_dni_lookup = attributes[:'peru_dni_lookup'] end if attributes.key?(:'norway_bankid') self.norway_bankid = attributes[:'norway_bankid'] end if attributes.key?(:'philippines_digital_national_id_qr') self.philippines_digital_national_id_qr = attributes[:'philippines_digital_national_id_qr'] end if attributes.key?(:'philippines_physical_national_id_qr') self.philippines_physical_national_id_qr = attributes[:'philippines_physical_national_id_qr'] end if attributes.key?(:'poland_mobywatel_match') self.poland_mobywatel_match = attributes[:'poland_mobywatel_match'] end if attributes.key?(:'post_office_easyid') self.post_office_easyid = attributes[:'post_office_easyid'] end if attributes.key?(:'samsung_wallet') self.samsung_wallet = attributes[:'samsung_wallet'] end if attributes.key?(:'singpass_login') self.singpass_login = attributes[:'singpass_login'] end if attributes.key?(:'singpass_myinfo') self. = attributes[:'singpass_myinfo'] end if attributes.key?(:'smart_id') self.smart_id = attributes[:'smart_id'] end if attributes.key?(:'uk_evisa_lookup') self.uk_evisa_lookup = attributes[:'uk_evisa_lookup'] end if attributes.key?(:'sweden_bankid') self.sweden_bankid = attributes[:'sweden_bankid'] end if attributes.key?(:'usa_louisiana_wallet') self.usa_louisiana_wallet = attributes[:'usa_louisiana_wallet'] end if attributes.key?(:'netherlands_idin') self.netherlands_idin = attributes[:'netherlands_idin'] end if attributes.key?(:'yoti') self.yoti = attributes[:'yoti'] end if attributes.key?(:'yoti_deeplink') self.yoti_deeplink = attributes[:'yoti_deeplink'] end end |
Instance Attribute Details
#a_at_handy_signatur_login ⇒ Object
Exposed properties for the ‘a-at-handy-signatur-login` Provider which do not directly map to the normalized IdentityData model.
22 23 24 |
# File 'lib/trinsic_api/models/provider_output.rb', line 22 def a_at_handy_signatur_login @a_at_handy_signatur_login end |
#a_be_id_login ⇒ Object
Exposed properties for the ‘a-be-id-login` Provider which do not directly map to the normalized IdentityData model.
25 26 27 |
# File 'lib/trinsic_api/models/provider_output.rb', line 25 def a_be_id_login @a_be_id_login end |
#a_edoapp_eid_login ⇒ Object
Exposed properties for the ‘a-edoapp-eid-login` Provider which do not directly map to the normalized IdentityData model.
28 29 30 |
# File 'lib/trinsic_api/models/provider_output.rb', line 28 def a_edoapp_eid_login @a_edoapp_eid_login end |
#a_ee_web_eid_login ⇒ Object
Exposed properties for the ‘a-ee-web-eid-login` Provider which do not directly map to the normalized IdentityData model.
31 32 33 |
# File 'lib/trinsic_api/models/provider_output.rb', line 31 def a_ee_web_eid_login @a_ee_web_eid_login end |
#a_fi_id_login ⇒ Object
Exposed properties for the ‘a-fi-id-login` Provider which do not directly map to the normalized IdentityData model.
34 35 36 |
# File 'lib/trinsic_api/models/provider_output.rb', line 34 def a_fi_id_login @a_fi_id_login end |
#a_freja_eid_login ⇒ Object
Exposed properties for the ‘a-freja-eid-login` Provider which do not directly map to the normalized IdentityData model.
37 38 39 |
# File 'lib/trinsic_api/models/provider_output.rb', line 37 def a_freja_eid_login @a_freja_eid_login end |
#a_itsme_login ⇒ Object
Exposed properties for the ‘a-itsme-login` Provider which do not directly map to the normalized IdentityData model.
40 41 42 |
# File 'lib/trinsic_api/models/provider_output.rb', line 40 def a_itsme_login @a_itsme_login end |
#a_lt_id_login ⇒ Object
Exposed properties for the ‘a-lt-id-login` Provider which do not directly map to the normalized IdentityData model.
43 44 45 |
# File 'lib/trinsic_api/models/provider_output.rb', line 43 def a_lt_id_login @a_lt_id_login end |
#a_lv_eparaksts_id_login ⇒ Object
Exposed properties for the ‘a-lv-eparaksts-id-login` Provider which do not directly map to the normalized IdentityData model.
46 47 48 |
# File 'lib/trinsic_api/models/provider_output.rb', line 46 def a_lv_eparaksts_id_login @a_lv_eparaksts_id_login end |
#a_lv_eparaksts_mobile_login ⇒ Object
Exposed properties for the ‘a-lv-eparaksts-mobile-login` Provider which do not directly map to the normalized IdentityData model.
49 50 51 |
# File 'lib/trinsic_api/models/provider_output.rb', line 49 def a_lv_eparaksts_mobile_login @a_lv_eparaksts_mobile_login end |
#a_mojeid ⇒ Object
Exposed properties for the ‘a-mojeid` Provider which do not directly map to the normalized IdentityData model.
52 53 54 |
# File 'lib/trinsic_api/models/provider_output.rb', line 52 def a_mojeid @a_mojeid end |
#a_pl_mojeid_login ⇒ Object
Exposed properties for the ‘a-pl-mojeid-login` Provider which do not directly map to the normalized IdentityData model.
55 56 57 |
# File 'lib/trinsic_api/models/provider_output.rb', line 55 def a_pl_mojeid_login @a_pl_mojeid_login end |
#a_pt_id_login ⇒ Object
Exposed properties for the ‘a-pt-id-login` Provider which do not directly map to the normalized IdentityData model.
58 59 60 |
# File 'lib/trinsic_api/models/provider_output.rb', line 58 def a_pt_id_login @a_pt_id_login end |
#a_rs_id_login ⇒ Object
Exposed properties for the ‘a-rs-id-login` Provider which do not directly map to the normalized IdentityData model.
61 62 63 |
# File 'lib/trinsic_api/models/provider_output.rb', line 61 def a_rs_id_login @a_rs_id_login end |
#apple_wallet ⇒ Object
Exposed properties for the ‘apple-wallet` Provider which do not directly map to the normalized IdentityData model.
64 65 66 |
# File 'lib/trinsic_api/models/provider_output.rb', line 64 def apple_wallet @apple_wallet end |
#audkenni ⇒ Object
Exposed properties for the ‘audkenni` provider which do not directly map to the normalized IdentityData model.
19 20 21 |
# File 'lib/trinsic_api/models/provider_output.rb', line 19 def audkenni @audkenni end |
#australia_connect_id ⇒ Object
Exposed properties for the ‘australia-connect-id` Provider which do not directly map to the normalized IdentityData model.
67 68 69 |
# File 'lib/trinsic_api/models/provider_output.rb', line 67 def australia_connect_id @australia_connect_id end |
#bolivia_ci_lookup ⇒ Object
Exposed properties for the ‘bolivia-ci-lookup` Provider which do not directly map to the normalized IdentityData model.
70 71 72 |
# File 'lib/trinsic_api/models/provider_output.rb', line 70 def bolivia_ci_lookup @bolivia_ci_lookup end |
#china_resident_id_match ⇒ Object
Exposed properties for the ‘china-resident-id-match` Provider which do not directly map to the normalized IdentityData model.
121 122 123 |
# File 'lib/trinsic_api/models/provider_output.rb', line 121 def china_resident_id_match @china_resident_id_match end |
#colombia_cc_lookup ⇒ Object
Exposed properties for the ‘colombia-cc-lookup` Provider which do not directly map to the normalized IdentityData model.
73 74 75 |
# File 'lib/trinsic_api/models/provider_output.rb', line 73 def colombia_cc_lookup @colombia_cc_lookup end |
#cote_divoire_nid_lookup_2 ⇒ Object
Exposed properties for the ‘cote-divoire-nid-lookup-2` Provider which do not directly map to the normalized IdentityData model.
76 77 78 |
# File 'lib/trinsic_api/models/provider_output.rb', line 76 def cote_divoire_nid_lookup_2 @cote_divoire_nid_lookup_2 end |
#czech_republic_mojeid ⇒ Object
Exposed properties for the ‘czech-moje-id` Provider which do not directly map to the normalized IdentityData model.
82 83 84 |
# File 'lib/trinsic_api/models/provider_output.rb', line 82 def czech_republic_mojeid @czech_republic_mojeid end |
#denmark_mitid ⇒ Object
Exposed properties for the ‘denmark-mitid` Provider which do not directly map to the normalized IdentityData model.
85 86 87 |
# File 'lib/trinsic_api/models/provider_output.rb', line 85 def denmark_mitid @denmark_mitid end |
#el_salvador_dui_lookup ⇒ Object
Exposed properties for the ‘el-salvador-dui-lookup` Provider which do not directly map to the normalized IdentityData model.
79 80 81 |
# File 'lib/trinsic_api/models/provider_output.rb', line 79 def el_salvador_dui_lookup @el_salvador_dui_lookup end |
#ethiopia_fayda ⇒ Object
Exposed properties for the ‘ethiopia-fayda` Provider which do not directly map to the normalized IdentityData model.
88 89 90 |
# File 'lib/trinsic_api/models/provider_output.rb', line 88 def ethiopia_fayda @ethiopia_fayda end |
#finnish_trust_network ⇒ Object
Exposed properties for the ‘finnish-trust-network` Provider which do not directly map to the normalized IdentityData model.
91 92 93 |
# File 'lib/trinsic_api/models/provider_output.rb', line 91 def finnish_trust_network @finnish_trust_network end |
#france_identite ⇒ Object
Exposed properties for the ‘france-identite` Provider which do not directly map to the normalized IdentityData model.
94 95 96 |
# File 'lib/trinsic_api/models/provider_output.rb', line 94 def france_identite @france_identite end |
#france_identite_numerique ⇒ Object
Exposed properties for the ‘france-identite-numerique` Provider which do not directly map to the normalized IdentityData model.
97 98 99 |
# File 'lib/trinsic_api/models/provider_output.rb', line 97 def france_identite_numerique @france_identite_numerique end |
#freja ⇒ Object
Exposed properties for the ‘freja` Provider which do not directly map to the normalized IdentityData model.
100 101 102 |
# File 'lib/trinsic_api/models/provider_output.rb', line 100 def freja @freja end |
#google_wallet ⇒ Object
Exposed properties for the ‘google-wallet` Provider which do not directly map to the normalized IdentityData model.
103 104 105 |
# File 'lib/trinsic_api/models/provider_output.rb', line 103 def google_wallet @google_wallet end |
#guatemala_cui_lookup ⇒ Object
Exposed properties for the ‘guatemala-cui-lookup` Provider which do not directly map to the normalized IdentityData model.
106 107 108 |
# File 'lib/trinsic_api/models/provider_output.rb', line 106 def guatemala_cui_lookup @guatemala_cui_lookup end |
#india_digilocker_aadhaar ⇒ Object
Exposed properties for the ‘india-digilocker-aadhaar` Provider which do not directly map to the normalized IdentityData model.
112 113 114 |
# File 'lib/trinsic_api/models/provider_output.rb', line 112 def india_digilocker_aadhaar @india_digilocker_aadhaar end |
#india_digilocker_aadhaar_fetch ⇒ Object
Exposed properties for the ‘india-digilocker-aadhaar-fetch` Provider which do not directly map to the normalized IdentityData model.
115 116 117 |
# File 'lib/trinsic_api/models/provider_output.rb', line 115 def india_digilocker_aadhaar_fetch @india_digilocker_aadhaar_fetch end |
#india_pan_lookup ⇒ Object
Exposed properties for the ‘india-pan-lookup` Provider which do not directly map to the normalized IdentityData model.
118 119 120 |
# File 'lib/trinsic_api/models/provider_output.rb', line 118 def india_pan_lookup @india_pan_lookup end |
#italy_spid ⇒ Object
Exposed properties for the ‘italy-spid` Provider which do not directly map to the normalized IdentityData model.
124 125 126 |
# File 'lib/trinsic_api/models/provider_output.rb', line 124 def italy_spid @italy_spid end |
#kenya_nid_lookup_2 ⇒ Object
Exposed properties for the ‘kenya-nid-lookup-2` Provider which do not directly map to the normalized IdentityData model.
127 128 129 |
# File 'lib/trinsic_api/models/provider_output.rb', line 127 def kenya_nid_lookup_2 @kenya_nid_lookup_2 end |
#korea_telco_match ⇒ Object
Exposed properties for the ‘korea-telco-match` Provider which do not directly map to the normalized IdentityData model.
130 131 132 |
# File 'lib/trinsic_api/models/provider_output.rb', line 130 def korea_telco_match @korea_telco_match end |
#lloyds_smart_id ⇒ Object
Exposed properties for the ‘lloyds-smart-id` Provider which do not directly map to the normalized IdentityData model.
133 134 135 |
# File 'lib/trinsic_api/models/provider_output.rb', line 133 def lloyds_smart_id @lloyds_smart_id end |
#mexico_curp_lookup ⇒ Object
Exposed properties for the ‘mexico-curp-lookup` Provider which do not directly map to the normalized IdentityData model.
136 137 138 |
# File 'lib/trinsic_api/models/provider_output.rb', line 136 def mexico_curp_lookup @mexico_curp_lookup end |
#mobile_id ⇒ Object
Exposed properties for the ‘mobile-id` Provider which do not directly map to the normalized IdentityData model.
139 140 141 |
# File 'lib/trinsic_api/models/provider_output.rb', line 139 def mobile_id @mobile_id end |
#netherlands_idin ⇒ Object
Exposed properties for the ‘netherlands-idin` Provider which do not directly map to the normalized IdentityData model.
187 188 189 |
# File 'lib/trinsic_api/models/provider_output.rb', line 187 def netherlands_idin @netherlands_idin end |
#nigeria_nin_lookup_2 ⇒ Object
Exposed properties for the ‘nigeria-nin-lookup-2` Provider which do not directly map to the normalized IdentityData model.
142 143 144 |
# File 'lib/trinsic_api/models/provider_output.rb', line 142 def nigeria_nin_lookup_2 @nigeria_nin_lookup_2 end |
#norway_bankid ⇒ Object
Exposed properties for the ‘norway-bankid` Provider which do not directly map to the normalized IdentityData model.
151 152 153 |
# File 'lib/trinsic_api/models/provider_output.rb', line 151 def norway_bankid @norway_bankid end |
#oneid ⇒ Object
Exposed properties for the ‘oneid` Provider which do not directly map to the normalized IdentityData model.
145 146 147 |
# File 'lib/trinsic_api/models/provider_output.rb', line 145 def oneid @oneid end |
#panama_cedula_lookup ⇒ Object
Exposed properties for the ‘panama-cedula-lookup` Provider which do not directly map to the normalized IdentityData model.
109 110 111 |
# File 'lib/trinsic_api/models/provider_output.rb', line 109 def panama_cedula_lookup @panama_cedula_lookup end |
#peru_dni_lookup ⇒ Object
Exposed properties for the ‘peru-dni-lookup` Provider which do not directly map to the normalized IdentityData model.
148 149 150 |
# File 'lib/trinsic_api/models/provider_output.rb', line 148 def peru_dni_lookup @peru_dni_lookup end |
#philippines_digital_national_id_qr ⇒ Object
Exposed properties for the ‘philippines-digital-national-id-qr` Provider which do not directly map to the normalized IdentityData model.
154 155 156 |
# File 'lib/trinsic_api/models/provider_output.rb', line 154 def philippines_digital_national_id_qr @philippines_digital_national_id_qr end |
#philippines_physical_national_id_qr ⇒ Object
Exposed properties for the ‘philippines-physical-national-id-qr` Provider which do not directly map to the normalized IdentityData model.
157 158 159 |
# File 'lib/trinsic_api/models/provider_output.rb', line 157 def philippines_physical_national_id_qr @philippines_physical_national_id_qr end |
#poland_mobywatel_match ⇒ Object
Exposed properties for the ‘poland-mobywatel-match` Provider which do not directly map to the normalized IdentityData model.
160 161 162 |
# File 'lib/trinsic_api/models/provider_output.rb', line 160 def poland_mobywatel_match @poland_mobywatel_match end |
#post_office_easyid ⇒ Object
Exposed properties for the ‘post-office-easyid` Provider which do not directly map to the normalized IdentityData model.
163 164 165 |
# File 'lib/trinsic_api/models/provider_output.rb', line 163 def post_office_easyid @post_office_easyid end |
#samsung_wallet ⇒ Object
Exposed properties for the ‘samsung-wallet` Provider which do not directly map to the normalized IdentityData model.
166 167 168 |
# File 'lib/trinsic_api/models/provider_output.rb', line 166 def samsung_wallet @samsung_wallet end |
#singpass_login ⇒ Object
Exposed properties for the ‘singpass-login` Provider which do not directly map to the normalized IdentityData model.
169 170 171 |
# File 'lib/trinsic_api/models/provider_output.rb', line 169 def singpass_login @singpass_login end |
#singpass_myinfo ⇒ Object
Exposed properties for the ‘singpass-myinfo` Provider which do not directly map to the normalized IdentityData model.
172 173 174 |
# File 'lib/trinsic_api/models/provider_output.rb', line 172 def @singpass_myinfo end |
#smart_id ⇒ Object
Exposed properties for the ‘smart-id` Provider which do not directly map to the normalized IdentityData model.
175 176 177 |
# File 'lib/trinsic_api/models/provider_output.rb', line 175 def smart_id @smart_id end |
#sweden_bankid ⇒ Object
Exposed properties for the ‘sweden-bankid` Provider which do not directly map to the normalized IdentityData model.
181 182 183 |
# File 'lib/trinsic_api/models/provider_output.rb', line 181 def sweden_bankid @sweden_bankid end |
#uk_evisa_lookup ⇒ Object
Exposed properties for the ‘uk-evisa-lookup` Provider which do not directly map to the normalized IdentityData model.
178 179 180 |
# File 'lib/trinsic_api/models/provider_output.rb', line 178 def uk_evisa_lookup @uk_evisa_lookup end |
#usa_louisiana_wallet ⇒ Object
Exposed properties for the ‘usa-louisiana-wallet` Provider which do not directly map to the normalized IdentityData model.
184 185 186 |
# File 'lib/trinsic_api/models/provider_output.rb', line 184 def usa_louisiana_wallet @usa_louisiana_wallet end |
#yoti ⇒ Object
Exposed properties for the ‘yoti` Provider which do not directly map to the normalized IdentityData model.
190 191 192 |
# File 'lib/trinsic_api/models/provider_output.rb', line 190 def yoti @yoti end |
#yoti_deeplink ⇒ Object
Exposed properties for the ‘yoti-deeplink` Provider which do not directly map to the normalized IdentityData model.
193 194 195 |
# File 'lib/trinsic_api/models/provider_output.rb', line 193 def yoti_deeplink @yoti_deeplink end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
261 262 263 |
# File 'lib/trinsic_api/models/provider_output.rb', line 261 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
266 267 268 |
# File 'lib/trinsic_api/models/provider_output.rb', line 266 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/trinsic_api/models/provider_output.rb', line 196 def self.attribute_map { :'audkenni' => :'audkenni', :'a_at_handy_signatur_login' => :'a-at-handy-signatur-login', :'a_be_id_login' => :'a-be-id-login', :'a_edoapp_eid_login' => :'a-edoapp-eid-login', :'a_ee_web_eid_login' => :'a-ee-web-eid-login', :'a_fi_id_login' => :'a-fi-id-login', :'a_freja_eid_login' => :'a-freja-eid-login', :'a_itsme_login' => :'a-itsme-login', :'a_lt_id_login' => :'a-lt-id-login', :'a_lv_eparaksts_id_login' => :'a-lv-eparaksts-id-login', :'a_lv_eparaksts_mobile_login' => :'a-lv-eparaksts-mobile-login', :'a_mojeid' => :'a-mojeid', :'a_pl_mojeid_login' => :'a-pl-mojeid-login', :'a_pt_id_login' => :'a-pt-id-login', :'a_rs_id_login' => :'a-rs-id-login', :'apple_wallet' => :'apple-wallet', :'australia_connect_id' => :'australia-connect-id', :'bolivia_ci_lookup' => :'bolivia-ci-lookup', :'colombia_cc_lookup' => :'colombia-cc-lookup', :'cote_divoire_nid_lookup_2' => :'cote-divoire-nid-lookup-2', :'el_salvador_dui_lookup' => :'el-salvador-dui-lookup', :'czech_republic_mojeid' => :'czech-republic-mojeid', :'denmark_mitid' => :'denmark-mitid', :'ethiopia_fayda' => :'ethiopia-fayda', :'finnish_trust_network' => :'finnish-trust-network', :'france_identite' => :'france-identite', :'france_identite_numerique' => :'france-identite-numerique', :'freja' => :'freja', :'google_wallet' => :'google-wallet', :'guatemala_cui_lookup' => :'guatemala-cui-lookup', :'panama_cedula_lookup' => :'panama-cedula-lookup', :'india_digilocker_aadhaar' => :'india-digilocker-aadhaar', :'india_digilocker_aadhaar_fetch' => :'india-digilocker-aadhaar-fetch', :'india_pan_lookup' => :'india-pan-lookup', :'china_resident_id_match' => :'china-resident-id-match', :'italy_spid' => :'italy-spid', :'kenya_nid_lookup_2' => :'kenya-nid-lookup-2', :'korea_telco_match' => :'korea-telco-match', :'lloyds_smart_id' => :'lloyds-smart-id', :'mexico_curp_lookup' => :'mexico-curp-lookup', :'mobile_id' => :'mobile-id', :'nigeria_nin_lookup_2' => :'nigeria-nin-lookup-2', :'oneid' => :'oneid', :'peru_dni_lookup' => :'peru-dni-lookup', :'norway_bankid' => :'norway-bankid', :'philippines_digital_national_id_qr' => :'philippines-digital-national-id-qr', :'philippines_physical_national_id_qr' => :'philippines-physical-national-id-qr', :'poland_mobywatel_match' => :'poland-mobywatel-match', :'post_office_easyid' => :'post-office-easyid', :'samsung_wallet' => :'samsung-wallet', :'singpass_login' => :'singpass-login', :'singpass_myinfo' => :'singpass-myinfo', :'smart_id' => :'smart-id', :'uk_evisa_lookup' => :'uk-evisa-lookup', :'sweden_bankid' => :'sweden-bankid', :'usa_louisiana_wallet' => :'usa-louisiana-wallet', :'netherlands_idin' => :'netherlands-idin', :'yoti' => :'yoti', :'yoti_deeplink' => :'yoti-deeplink' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 |
# File 'lib/trinsic_api/models/provider_output.rb', line 749 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 |
# File 'lib/trinsic_api/models/provider_output.rb', line 336 def self.openapi_nullable Set.new([ :'audkenni', :'a_at_handy_signatur_login', :'a_be_id_login', :'a_edoapp_eid_login', :'a_ee_web_eid_login', :'a_fi_id_login', :'a_freja_eid_login', :'a_itsme_login', :'a_lt_id_login', :'a_lv_eparaksts_id_login', :'a_lv_eparaksts_mobile_login', :'a_mojeid', :'a_pl_mojeid_login', :'a_pt_id_login', :'a_rs_id_login', :'apple_wallet', :'australia_connect_id', :'bolivia_ci_lookup', :'colombia_cc_lookup', :'cote_divoire_nid_lookup_2', :'el_salvador_dui_lookup', :'czech_republic_mojeid', :'denmark_mitid', :'ethiopia_fayda', :'finnish_trust_network', :'france_identite', :'france_identite_numerique', :'freja', :'google_wallet', :'guatemala_cui_lookup', :'panama_cedula_lookup', :'india_digilocker_aadhaar', :'india_digilocker_aadhaar_fetch', :'india_pan_lookup', :'china_resident_id_match', :'italy_spid', :'kenya_nid_lookup_2', :'korea_telco_match', :'lloyds_smart_id', :'mexico_curp_lookup', :'mobile_id', :'nigeria_nin_lookup_2', :'oneid', :'peru_dni_lookup', :'norway_bankid', :'philippines_digital_national_id_qr', :'philippines_physical_national_id_qr', :'poland_mobywatel_match', :'post_office_easyid', :'samsung_wallet', :'singpass_login', :'singpass_myinfo', :'smart_id', :'uk_evisa_lookup', :'sweden_bankid', :'usa_louisiana_wallet', :'netherlands_idin', :'yoti', :'yoti_deeplink' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/trinsic_api/models/provider_output.rb', line 271 def self.openapi_types { :'audkenni' => :'AudkenniProviderOutput', :'a_at_handy_signatur_login' => :'AustriaHandySignaturProviderOutput', :'a_be_id_login' => :'BelgiumIdCardProviderOutput', :'a_edoapp_eid_login' => :'PolandEdoAppProviderOutput', :'a_ee_web_eid_login' => :'EstoniaIdCardProviderOutput', :'a_fi_id_login' => :'FinlandIdCardProviderOutput', :'a_freja_eid_login' => :'FrejaIndirectProviderOutput', :'a_itsme_login' => :'ItsmeProviderOutput', :'a_lt_id_login' => :'LithuaniaIdCardProviderOutput', :'a_lv_eparaksts_id_login' => :'LatviaEparakstsProviderOutput', :'a_lv_eparaksts_mobile_login' => :'LatviaEparakstsMobileProviderOutput', :'a_mojeid' => :'CzechiaMojeIdProviderOutput', :'a_pl_mojeid_login' => :'PolandMojeIdProviderOutput', :'a_pt_id_login' => :'PortugalIdCardProviderOutput', :'a_rs_id_login' => :'SerbiaIdCardProviderOutput', :'apple_wallet' => :'AppleWalletProviderOutput', :'australia_connect_id' => :'ConnectIdProviderOutput', :'bolivia_ci_lookup' => :'BoliviaCiProviderOutput', :'colombia_cc_lookup' => :'ColombiaCcProviderOutput', :'cote_divoire_nid_lookup_2' => :'CoteDIvoireNidLookup2ProviderOutput', :'el_salvador_dui_lookup' => :'ElSalvadorDuiProviderOutput', :'czech_republic_mojeid' => :'CzechMojeIdProviderOutput', :'denmark_mitid' => :'MitIdProviderOutput', :'ethiopia_fayda' => :'FaydaProviderOutput', :'finnish_trust_network' => :'FinnishTrustNetworkProviderOutput', :'france_identite' => :'FranceIdentiteProviderOutput', :'france_identite_numerique' => :'FrenchNumeriqueProviderOutput', :'freja' => :'FrejaProviderOutput', :'google_wallet' => :'GoogleWalletProviderOutput', :'guatemala_cui_lookup' => :'GuatemalaCuiProviderOutput', :'panama_cedula_lookup' => :'PanamaCedulaProviderOutput', :'india_digilocker_aadhaar' => :'DigilockerAadhaarProviderOutput', :'india_digilocker_aadhaar_fetch' => :'SignzyIndiaAadhaarFetchProviderOutput', :'india_pan_lookup' => :'IndiaPanLookupProviderOutput', :'china_resident_id_match' => :'ChinaResidentIdMatchOutput', :'italy_spid' => :'SpidProviderOutput', :'kenya_nid_lookup_2' => :'KenyaNidLookup2ProviderOutput', :'korea_telco_match' => :'KoreaTelcoMatchProviderOutput', :'lloyds_smart_id' => :'LloydsSmartIdProviderOutput', :'mexico_curp_lookup' => :'MexicoCurpProviderOutput', :'mobile_id' => :'MobileIdProviderOutput', :'nigeria_nin_lookup_2' => :'NigeriaNinLookup2ProviderOutput', :'oneid' => :'OneIdProviderOutput', :'peru_dni_lookup' => :'PeruDniProviderOutput', :'norway_bankid' => :'NorwegianBankIdProviderOutput', :'philippines_digital_national_id_qr' => :'PhilippinesDigitalNidProviderOutput', :'philippines_physical_national_id_qr' => :'PhilippinesPhysicalNidProviderOutput', :'poland_mobywatel_match' => :'PolandMobywatelMatchProviderOutput', :'post_office_easyid' => :'PostOfficeEasyIdProviderOutput', :'samsung_wallet' => :'SamsungWalletProviderOutput', :'singpass_login' => :'SingpassLoginProviderOutput', :'singpass_myinfo' => :'SingpassMyInfoProviderOutput', :'smart_id' => :'SmartIdProviderOutput', :'uk_evisa_lookup' => :'UnitedKingdomEvisaProviderOutput', :'sweden_bankid' => :'SwedenBankIdProviderOutput', :'usa_louisiana_wallet' => :'LaWalletProviderOutput', :'netherlands_idin' => :'NetherlandsIdinProviderOutput', :'yoti' => :'YotiProviderOutput', :'yoti_deeplink' => :'YotiDeeplinkProviderOutput' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'lib/trinsic_api/models/provider_output.rb', line 670 def ==(o) return true if self.equal?(o) self.class == o.class && audkenni == o.audkenni && a_at_handy_signatur_login == o.a_at_handy_signatur_login && a_be_id_login == o.a_be_id_login && a_edoapp_eid_login == o.a_edoapp_eid_login && a_ee_web_eid_login == o.a_ee_web_eid_login && a_fi_id_login == o.a_fi_id_login && a_freja_eid_login == o.a_freja_eid_login && a_itsme_login == o.a_itsme_login && a_lt_id_login == o.a_lt_id_login && a_lv_eparaksts_id_login == o.a_lv_eparaksts_id_login && a_lv_eparaksts_mobile_login == o.a_lv_eparaksts_mobile_login && a_mojeid == o.a_mojeid && a_pl_mojeid_login == o.a_pl_mojeid_login && a_pt_id_login == o.a_pt_id_login && a_rs_id_login == o.a_rs_id_login && apple_wallet == o.apple_wallet && australia_connect_id == o.australia_connect_id && bolivia_ci_lookup == o.bolivia_ci_lookup && colombia_cc_lookup == o.colombia_cc_lookup && cote_divoire_nid_lookup_2 == o.cote_divoire_nid_lookup_2 && el_salvador_dui_lookup == o.el_salvador_dui_lookup && czech_republic_mojeid == o.czech_republic_mojeid && denmark_mitid == o.denmark_mitid && ethiopia_fayda == o.ethiopia_fayda && finnish_trust_network == o.finnish_trust_network && france_identite == o.france_identite && france_identite_numerique == o.france_identite_numerique && freja == o.freja && google_wallet == o.google_wallet && guatemala_cui_lookup == o.guatemala_cui_lookup && panama_cedula_lookup == o.panama_cedula_lookup && india_digilocker_aadhaar == o.india_digilocker_aadhaar && india_digilocker_aadhaar_fetch == o.india_digilocker_aadhaar_fetch && india_pan_lookup == o.india_pan_lookup && china_resident_id_match == o.china_resident_id_match && italy_spid == o.italy_spid && kenya_nid_lookup_2 == o.kenya_nid_lookup_2 && korea_telco_match == o.korea_telco_match && lloyds_smart_id == o.lloyds_smart_id && mexico_curp_lookup == o.mexico_curp_lookup && mobile_id == o.mobile_id && nigeria_nin_lookup_2 == o.nigeria_nin_lookup_2 && oneid == o.oneid && peru_dni_lookup == o.peru_dni_lookup && norway_bankid == o.norway_bankid && philippines_digital_national_id_qr == o.philippines_digital_national_id_qr && philippines_physical_national_id_qr == o.philippines_physical_national_id_qr && poland_mobywatel_match == o.poland_mobywatel_match && post_office_easyid == o.post_office_easyid && samsung_wallet == o.samsung_wallet && singpass_login == o.singpass_login && == o. && smart_id == o.smart_id && uk_evisa_lookup == o.uk_evisa_lookup && sweden_bankid == o.sweden_bankid && usa_louisiana_wallet == o.usa_louisiana_wallet && netherlands_idin == o.netherlands_idin && yoti == o.yoti && yoti_deeplink == o.yoti_deeplink end |
#eql?(o) ⇒ Boolean
736 737 738 |
# File 'lib/trinsic_api/models/provider_output.rb', line 736 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
742 743 744 |
# File 'lib/trinsic_api/models/provider_output.rb', line 742 def hash [audkenni, a_at_handy_signatur_login, a_be_id_login, a_edoapp_eid_login, a_ee_web_eid_login, a_fi_id_login, a_freja_eid_login, a_itsme_login, a_lt_id_login, a_lv_eparaksts_id_login, a_lv_eparaksts_mobile_login, a_mojeid, a_pl_mojeid_login, a_pt_id_login, a_rs_id_login, apple_wallet, australia_connect_id, bolivia_ci_lookup, colombia_cc_lookup, cote_divoire_nid_lookup_2, el_salvador_dui_lookup, czech_republic_mojeid, denmark_mitid, ethiopia_fayda, finnish_trust_network, france_identite, france_identite_numerique, freja, google_wallet, guatemala_cui_lookup, panama_cedula_lookup, india_digilocker_aadhaar, india_digilocker_aadhaar_fetch, india_pan_lookup, china_resident_id_match, italy_spid, kenya_nid_lookup_2, korea_telco_match, lloyds_smart_id, mexico_curp_lookup, mobile_id, nigeria_nin_lookup_2, oneid, peru_dni_lookup, norway_bankid, philippines_digital_national_id_qr, philippines_physical_national_id_qr, poland_mobywatel_match, post_office_easyid, samsung_wallet, singpass_login, , smart_id, uk_evisa_lookup, sweden_bankid, usa_louisiana_wallet, netherlands_idin, yoti, yoti_deeplink].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
655 656 657 658 659 |
# File 'lib/trinsic_api/models/provider_output.rb', line 655 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
771 772 773 774 775 776 777 778 779 780 781 782 783 |
# File 'lib/trinsic_api/models/provider_output.rb', line 771 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
663 664 665 666 |
# File 'lib/trinsic_api/models/provider_output.rb', line 663 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |