Class: TrinsicApi::SwedenBankIdProviderOutput

Inherits:
Object
  • Object
show all
Defined in:
lib/trinsic_api/models/sweden_bank_id_provider_output.rb

Overview

Exposed properties for the ‘sweden-bankid` Provider which do not directly map to the normalized IdentityData model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ SwedenBankIdProviderOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::SwedenBankIdProviderOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::SwedenBankIdProviderOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'full_name')
    self.full_name = attributes[:'full_name']
  end

  if attributes.key?(:'date_of_birth')
    self.date_of_birth = attributes[:'date_of_birth']
  end

  if attributes.key?(:'personal_identity_number')
    self.personal_identity_number = attributes[:'personal_identity_number']
  end

  if attributes.key?(:'given_name')
    self.given_name = attributes[:'given_name']
  end

  if attributes.key?(:'family_name')
    self.family_name = attributes[:'family_name']
  end

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'certificate_policy')
    self.certificate_policy = attributes[:'certificate_policy']
  end

  if attributes.key?(:'common_name')
    self.common_name = attributes[:'common_name']
  end

  if attributes.key?(:'distinguished_name')
    self.distinguished_name = attributes[:'distinguished_name']
  end

  if attributes.key?(:'personal_identity_number_issuing_country')
    self.personal_identity_number_issuing_country = attributes[:'personal_identity_number_issuing_country']
  end

  if attributes.key?(:'authentication_device_ip')
    self.authentication_device_ip = attributes[:'authentication_device_ip']
  end

  if attributes.key?(:'not_before')
    self.not_before = attributes[:'not_before']
  end

  if attributes.key?(:'not_after')
    self.not_after = attributes[:'not_after']
  end
end

Instance Attribute Details

#authentication_device_ipObject

The IP address of the device used for authentication



50
51
52
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 50

def authentication_device_ip
  @authentication_device_ip
end

#certificate_policyObject

The object identifier policy of the individual’s verified certificate



38
39
40
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 38

def certificate_policy
  @certificate_policy
end

#common_nameObject

The common name of the end user’s verified certificate



41
42
43
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 41

def common_name
  @common_name
end

#countryObject

The end user’s country on the verified certificate. This is ISO 2-character code of the country.



35
36
37
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 35

def country
  @country
end

#date_of_birthObject

The date of birth of the individual.



23
24
25
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 23

def date_of_birth
  @date_of_birth
end

#distinguished_nameObject

The distinguished name of the end user’s verified certificate



44
45
46
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 44

def distinguished_name
  @distinguished_name
end

#family_nameObject

The family name of the individual



32
33
34
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 32

def family_name
  @family_name
end

#full_nameObject

The full name of the individual.



20
21
22
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 20

def full_name
  @full_name
end

#given_nameObject

The given name of the individual



29
30
31
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 29

def given_name
  @given_name
end

#not_afterObject

The certificate validity end date (not after) in UTC



56
57
58
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 56

def not_after
  @not_after
end

#not_beforeObject

The certificate validity start date (not before) in UTC



53
54
55
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 53

def not_before
  @not_before
end

#personal_identity_numberObject

The Swedish personal number (personnummer) associated with the verified individual. The value is typically a 12-digit number. This is in the format YYYYMMDDXXXX, where: - YYYYMMDD is the date of birth. - XXXX is an individual number, indicating gender. If XXXX is even, the individual is female. If XXXX is odd, the individual is male.



26
27
28
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 26

def personal_identity_number
  @personal_identity_number
end

#personal_identity_number_issuing_countryObject

The country that issued the Swedish personal number. This is an ISO 2-character code of the country and is extracted from the certificate. This will always be ‘SE`.



47
48
49
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 47

def personal_identity_number_issuing_country
  @personal_identity_number_issuing_country
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 268

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = TrinsicApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 59

def self.attribute_map
  {
    :'full_name' => :'fullName',
    :'date_of_birth' => :'dateOfBirth',
    :'personal_identity_number' => :'personalIdentityNumber',
    :'given_name' => :'givenName',
    :'family_name' => :'familyName',
    :'country' => :'country',
    :'certificate_policy' => :'certificatePolicy',
    :'common_name' => :'commonName',
    :'distinguished_name' => :'distinguishedName',
    :'personal_identity_number_issuing_country' => :'personalIdentityNumberIssuingCountry',
    :'authentication_device_ip' => :'authenticationDeviceIp',
    :'not_before' => :'notBefore',
    :'not_after' => :'notAfter'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 244

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 107

def self.openapi_nullable
  Set.new([
    :'full_name',
    :'date_of_birth',
    :'personal_identity_number',
    :'given_name',
    :'family_name',
    :'country',
    :'certificate_policy',
    :'common_name',
    :'distinguished_name',
    :'personal_identity_number_issuing_country',
    :'authentication_device_ip',
    :'not_before',
    :'not_after'
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 88

def self.openapi_types
  {
    :'full_name' => :'String',
    :'date_of_birth' => :'Date',
    :'personal_identity_number' => :'String',
    :'given_name' => :'String',
    :'family_name' => :'String',
    :'country' => :'String',
    :'certificate_policy' => :'String',
    :'common_name' => :'String',
    :'distinguished_name' => :'String',
    :'personal_identity_number_issuing_country' => :'String',
    :'authentication_device_ip' => :'String',
    :'not_before' => :'Time',
    :'not_after' => :'Time'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 211

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      full_name == o.full_name &&
      date_of_birth == o.date_of_birth &&
      personal_identity_number == o.personal_identity_number &&
      given_name == o.given_name &&
      family_name == o.family_name &&
      country == o.country &&
      certificate_policy == o.certificate_policy &&
      common_name == o.common_name &&
      distinguished_name == o.distinguished_name &&
      personal_identity_number_issuing_country == o.personal_identity_number_issuing_country &&
      authentication_device_ip == o.authentication_device_ip &&
      not_before == o.not_before &&
      not_after == o.not_after
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



339
340
341
342
343
344
345
346
347
348
349
350
351
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 339

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


231
232
233
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 231

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



237
238
239
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 237

def hash
  [full_name, date_of_birth, personal_identity_number, given_name, family_name, country, certificate_policy, common_name, distinguished_name, personal_identity_number_issuing_country, authentication_device_ip, not_before, not_after].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



196
197
198
199
200
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 196

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 315

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 321

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



309
310
311
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 309

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



204
205
206
207
# File 'lib/trinsic_api/models/sweden_bank_id_provider_output.rb', line 204

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end