Class: TrinsicApi::VerificationProfileResponse
- Inherits:
-
Object
- Object
- TrinsicApi::VerificationProfileResponse
- Defined in:
- lib/trinsic_api/models/verification_profile_response.rb
Instance Attribute Summary collapse
-
#_alias ⇒ Object
An alias of the verification profile shown to developers and administrators.
-
#brand_name ⇒ Object
The brand name of the verification profile shown to end-users.
-
#enabled_providers ⇒ Object
The providers that are currently enabled for the verification profile.
-
#id ⇒ Object
The ID of the verification profile.
-
#is_production_usage ⇒ Object
Whether this profile is for production usage.
-
#logo_url ⇒ Object
The URL of the verification profile’s logo.
-
#primary_color ⇒ Object
The primary color of the verification profile.
-
#session_expiration ⇒ Object
The session expiration for verification sessions created with this profile.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ VerificationProfileResponse
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ VerificationProfileResponse
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::VerificationProfileResponse` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::VerificationProfileResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'_alias') self._alias = attributes[:'_alias'] else self._alias = nil end if attributes.key?(:'brand_name') self.brand_name = attributes[:'brand_name'] else self.brand_name = nil end if attributes.key?(:'logo_url') self.logo_url = attributes[:'logo_url'] else self.logo_url = nil end if attributes.key?(:'primary_color') self.primary_color = attributes[:'primary_color'] else self.primary_color = nil end if attributes.key?(:'enabled_providers') if (value = attributes[:'enabled_providers']).is_a?(Array) self.enabled_providers = value end else self.enabled_providers = nil end if attributes.key?(:'session_expiration') self.session_expiration = attributes[:'session_expiration'] else self.session_expiration = nil end if attributes.key?(:'is_production_usage') self.is_production_usage = attributes[:'is_production_usage'] else self.is_production_usage = nil end end |
Instance Attribute Details
#_alias ⇒ Object
An alias of the verification profile shown to developers and administrators.
22 23 24 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 22 def _alias @_alias end |
#brand_name ⇒ Object
The brand name of the verification profile shown to end-users.
25 26 27 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 25 def brand_name @brand_name end |
#enabled_providers ⇒ Object
The providers that are currently enabled for the verification profile.
34 35 36 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 34 def enabled_providers @enabled_providers end |
#id ⇒ Object
The ID of the verification profile
19 20 21 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 19 def id @id end |
#is_production_usage ⇒ Object
Whether this profile is for production usage. Only applicable for Live environment profiles.
40 41 42 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 40 def is_production_usage @is_production_usage end |
#logo_url ⇒ Object
The URL of the verification profile’s logo.
28 29 30 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 28 def logo_url @logo_url end |
#primary_color ⇒ Object
The primary color of the verification profile.
31 32 33 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 31 def primary_color @primary_color end |
#session_expiration ⇒ Object
The session expiration for verification sessions created with this profile.
37 38 39 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 37 def session_expiration @session_expiration end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 342 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = TrinsicApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
57 58 59 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 57 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
62 63 64 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 62 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
43 44 45 46 47 48 49 50 51 52 53 54 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 43 def self.attribute_map { :'id' => :'id', :'_alias' => :'alias', :'brand_name' => :'brandName', :'logo_url' => :'logoUrl', :'primary_color' => :'primaryColor', :'enabled_providers' => :'enabledProviders', :'session_expiration' => :'sessionExpiration', :'is_production_usage' => :'isProductionUsage' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 318 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 67 def self.openapi_types { :'id' => :'String', :'_alias' => :'String', :'brand_name' => :'String', :'logo_url' => :'String', :'primary_color' => :'String', :'enabled_providers' => :'Array<String>', :'session_expiration' => :'String', :'is_production_usage' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 290 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && _alias == o._alias && brand_name == o.brand_name && logo_url == o.logo_url && primary_color == o.primary_color && enabled_providers == o.enabled_providers && session_expiration == o.session_expiration && is_production_usage == o.is_production_usage end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 413 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
305 306 307 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 305 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
311 312 313 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 311 def hash [id, _alias, brand_name, logo_url, primary_color, enabled_providers, session_expiration, is_production_usage].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @_alias.nil? invalid_properties.push('invalid value for "_alias", _alias cannot be nil.') end if @brand_name.nil? invalid_properties.push('invalid value for "brand_name", brand_name cannot be nil.') end if @logo_url.nil? invalid_properties.push('invalid value for "logo_url", logo_url cannot be nil.') end if @primary_color.nil? invalid_properties.push('invalid value for "primary_color", primary_color cannot be nil.') end if @enabled_providers.nil? invalid_properties.push('invalid value for "enabled_providers", enabled_providers cannot be nil.') end if @session_expiration.nil? invalid_properties.push('invalid value for "session_expiration", session_expiration cannot be nil.') end if @is_production_usage.nil? invalid_properties.push('invalid value for "is_production_usage", is_production_usage cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
389 390 391 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 389 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 395 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
383 384 385 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 383 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/trinsic_api/models/verification_profile_response.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @_alias.nil? return false if @brand_name.nil? return false if @logo_url.nil? return false if @primary_color.nil? return false if @enabled_providers.nil? return false if @session_expiration.nil? return false if @is_production_usage.nil? true end |