Class: TrinsicApi::YotiStructuredPostalAddress

Inherits:
Object
  • Object
show all
Defined in:
lib/trinsic_api/models/yoti_structured_postal_address.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ YotiStructuredPostalAddress

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 168

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `TrinsicApi::YotiStructuredPostalAddress` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `TrinsicApi::YotiStructuredPostalAddress`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'country')
    self.country = attributes[:'country']
  end

  if attributes.key?(:'country_iso')
    self.country_iso = attributes[:'country_iso']
  end

  if attributes.key?(:'formatted_address')
    self.formatted_address = attributes[:'formatted_address']
  end

  if attributes.key?(:'line1')
    self.line1 = attributes[:'line1']
  end

  if attributes.key?(:'line2')
    self.line2 = attributes[:'line2']
  end

  if attributes.key?(:'line3')
    self.line3 = attributes[:'line3']
  end

  if attributes.key?(:'line4')
    self.line4 = attributes[:'line4']
  end

  if attributes.key?(:'town_city')
    self.town_city = attributes[:'town_city']
  end

  if attributes.key?(:'state')
    self.state = attributes[:'state']
  end

  if attributes.key?(:'postal_code')
    self.postal_code = attributes[:'postal_code']
  end

  if attributes.key?(:'building_number')
    self.building_number = attributes[:'building_number']
  end

  if attributes.key?(:'building')
    self.building = attributes[:'building']
  end

  if attributes.key?(:'sub_building')
    self.sub_building = attributes[:'sub_building']
  end

  if attributes.key?(:'locality')
    self.locality = attributes[:'locality']
  end

  if attributes.key?(:'delivery_point_reference_number')
    self.delivery_point_reference_number = attributes[:'delivery_point_reference_number']
  end

  if attributes.key?(:'landmark')
    self.landmark = attributes[:'landmark']
  end

  if attributes.key?(:'subdistrict')
    self.subdistrict = attributes[:'subdistrict']
  end

  if attributes.key?(:'district')
    self.district = attributes[:'district']
  end

  if attributes.key?(:'post_office')
    self.post_office = attributes[:'post_office']
  end

  if attributes.key?(:'care_of')
    self.care_of = attributes[:'care_of']
  end
end

Instance Attribute Details

#buildingObject

The address’s building name



52
53
54
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 52

def building
  @building
end

#building_numberObject

The address’s building number



49
50
51
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 49

def building_number
  @building_number
end

#care_ofObject

The address’s care-of field. This indicates that mail should be delivered to an individual through another person or entity who is a known resident at the address. This optional field may appear only for Indian addresses.



76
77
78
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 76

def care_of
  @care_of
end

#countryObject

The address’s country. This field does not have a specified format, but is recommended to use for the country field.



19
20
21
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 19

def country
  @country
end

#country_isoObject

The address’s ISO alpha-3 country code



22
23
24
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 22

def country_iso
  @country_iso
end

#delivery_point_reference_numberObject

The unique delivery point reference number. This is an 8-digit code used in the UK for identifying delivery addresses.



61
62
63
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 61

def delivery_point_reference_number
  @delivery_point_reference_number
end

#districtObject

The address’s district. This optional field may appear only for Indian addresses.



70
71
72
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 70

def district
  @district
end

#formatted_addressObject

The whole address in proper order and formatted with line breaks. Examples: United Kingdom: "15a North Street\nCARSHALTON\nSM5 2HW\nUK" India: "S/O: Vipen Kumar Aggarwal\nHouse No.86-A\nRajguru Nagar\nLudhiana\nPunjab\n141012\nIndia" United States of America: "1512 Ferry Street\nAnniston AL 36201\nUSA"



25
26
27
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 25

def formatted_address
  @formatted_address
end

#landmarkObject

The address’s landmark. A landmark is a recognizable feature or place that helps locate the address. This optional field may appear only for Indian addresses.



64
65
66
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 64

def landmark
  @landmark
end

#line1Object

The first line of the address



28
29
30
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 28

def line1
  @line1
end

#line2Object

The second line of the address



31
32
33
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 31

def line2
  @line2
end

#line3Object

The third line of the address



34
35
36
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 34

def line3
  @line3
end

#line4Object

The fourth line of the address



37
38
39
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 37

def line4
  @line4
end

#localityObject

The address’ss locality can be an area, a village, a region, or a known neighborhood



58
59
60
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 58

def locality
  @locality
end

#post_officeObject

The address’s post office. This optional field may appear only for Indian addresses.



73
74
75
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 73

def post_office
  @post_office
end

#postal_codeObject

The address’s postal code



46
47
48
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 46

def postal_code
  @postal_code
end

#stateObject

The address’s state. This is an optional field that may only appear for US addresses.



43
44
45
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 43

def state
  @state
end

#sub_buildingObject

The address’s sub building or specific part of the building



55
56
57
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 55

def sub_building
  @sub_building
end

#subdistrictObject

The address’s subdistrict. This optional field may appear only for Indian addresses.



67
68
69
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 67

def subdistrict
  @subdistrict
end

#town_cityObject

The address’s town or city



40
41
42
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 40

def town_city
  @town_city
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 344

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = TrinsicApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



105
106
107
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 105

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



110
111
112
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 110

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 79

def self.attribute_map
  {
    :'country' => :'country',
    :'country_iso' => :'countryIso',
    :'formatted_address' => :'formattedAddress',
    :'line1' => :'line1',
    :'line2' => :'line2',
    :'line3' => :'line3',
    :'line4' => :'line4',
    :'town_city' => :'townCity',
    :'state' => :'state',
    :'postal_code' => :'postalCode',
    :'building_number' => :'buildingNumber',
    :'building' => :'building',
    :'sub_building' => :'subBuilding',
    :'locality' => :'locality',
    :'delivery_point_reference_number' => :'deliveryPointReferenceNumber',
    :'landmark' => :'landmark',
    :'subdistrict' => :'subdistrict',
    :'district' => :'district',
    :'post_office' => :'postOffice',
    :'care_of' => :'careOf'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 320

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 141

def self.openapi_nullable
  Set.new([
    :'country',
    :'country_iso',
    :'formatted_address',
    :'line1',
    :'line2',
    :'line3',
    :'line4',
    :'town_city',
    :'state',
    :'postal_code',
    :'building_number',
    :'building',
    :'sub_building',
    :'locality',
    :'delivery_point_reference_number',
    :'landmark',
    :'subdistrict',
    :'district',
    :'post_office',
    :'care_of'
  ])
end

.openapi_typesObject

Attribute type mapping.



115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 115

def self.openapi_types
  {
    :'country' => :'String',
    :'country_iso' => :'String',
    :'formatted_address' => :'String',
    :'line1' => :'String',
    :'line2' => :'String',
    :'line3' => :'String',
    :'line4' => :'String',
    :'town_city' => :'String',
    :'state' => :'String',
    :'postal_code' => :'String',
    :'building_number' => :'String',
    :'building' => :'String',
    :'sub_building' => :'String',
    :'locality' => :'String',
    :'delivery_point_reference_number' => :'String',
    :'landmark' => :'String',
    :'subdistrict' => :'String',
    :'district' => :'String',
    :'post_office' => :'String',
    :'care_of' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 280

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      country == o.country &&
      country_iso == o.country_iso &&
      formatted_address == o.formatted_address &&
      line1 == o.line1 &&
      line2 == o.line2 &&
      line3 == o.line3 &&
      line4 == o.line4 &&
      town_city == o.town_city &&
      state == o.state &&
      postal_code == o.postal_code &&
      building_number == o.building_number &&
      building == o.building &&
      sub_building == o.sub_building &&
      locality == o.locality &&
      delivery_point_reference_number == o.delivery_point_reference_number &&
      landmark == o.landmark &&
      subdistrict == o.subdistrict &&
      district == o.district &&
      post_office == o.post_office &&
      care_of == o.care_of
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



415
416
417
418
419
420
421
422
423
424
425
426
427
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 415

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


307
308
309
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 307

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



313
314
315
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 313

def hash
  [country, country_iso, formatted_address, line1, line2, line3, line4, town_city, state, postal_code, building_number, building, sub_building, locality, delivery_point_reference_number, landmark, subdistrict, district, post_office, care_of].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



265
266
267
268
269
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 265

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



391
392
393
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 391

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



385
386
387
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 385

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



273
274
275
276
# File 'lib/trinsic_api/models/yoti_structured_postal_address.rb', line 273

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end